(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    255961,       3941]*)
(*NotebookOutlinePosition[    274653,       4634]*)
(*  CellTagsIndexPosition[    274609,       4630]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["A Taxonomy of Cell Bracket Annotations", "Title"],

Cell[TextData[{
  ButtonBox["P.J. Hinton",
    ButtonData:>{
      URL[ "mailto:paulh@wolfram.com"], None},
    ButtonStyle->"Hyperlink",
    ButtonNote->"Send mail to P.J. Hinton"],
  "\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Programming Group\nWolfram Research, Inc."
}], "Subsubtitle"],

Cell["Last Revision: June 21, 1999", "Subsubtitle"],

Cell["\<\
This notebook is designed to serve as a key to deciphering cell \
bracket glyphs.\
\>", "Text"],

Cell["\<\
A cell bracket with a horizontal notch at the top means that the \
cell is not evaluatable.  This is the result of setting the cell option \
Evaluatable to False.  This property is desirable for cells that contain \
plain text or kernel output.\
\>", "ItemizedText"],

Cell["\<\
If you select this cell and then attempt to evaluate it, the front \
end will beep because the cell cannot be evaluated with its current settings.\
\
\>", "ItemizedTextNote",
  ShowCellBracket->True,
  Evaluatable->False],

Cell[TextData[{
  "A cell bracket with a triangular notch means that the cell contains \
StandardForm two\[Dash]dimensional typeset structures (boxes).  StandardForm \
content is interpreted by the kernel without ambiguity.  StandardForm is used \
by default for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " kernel input and output."
}], "ItemizedText",
  ShowSpecialCharacters->True],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["c", "2"], "==", 
        RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"]}]}], "/.", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{"a", "\[Rule]", "3"}], ",", 
          RowBox[{"b", "\[Rule]", "4"}], ",", 
          RowBox[{"c", "\[Rule]", "5"}]}], "}"}]}]], "ItemizedTextNote",
  ShowCellBracket->True,
  Evaluatable->True],

Cell[TextData[
"A cell bracket with a jagged line means that the cell contains \
TraditionalForm two\[Dash]dimensional typeset structures (boxes).  \
TraditionalForm is used typically for display formulae.  If you attempt to \
evaluate a cell like this, the front end will warn you that the kernel may \
not interpret the syntax as you might have expected"], "ItemizedText"],

Cell[BoxData[
    FormBox[
      RowBox[{"x", "=", 
        FractionBox[
          RowBox[{
            RowBox[{"-", "b"}], "\[PlusMinus]", 
            SqrtBox[
              RowBox[{
                SuperscriptBox["b", "2"], "-", 
                RowBox[{"4", " ", "a", " ", "c"}]}]]}], 
          RowBox[{"2", " ", "a"}]]}], TraditionalForm]], "ItemizedTextNote",
  ShowCellBracket->True,
  Evaluatable->True],

Cell[TextData[
"A cell bracket with a captial \"A\" at the top indicates that the cell is \
active. This is the result of setting the option Active to True.  Buttons, \
hyperlinks, and other ButtonBox\[Dash]based structures will perform their \
actions only if the option Active is set to True.  Setting this option at the \
cell level saves the author the effort of having to set the option for every \
button in the cell."], "ItemizedText",
  ShowSpecialCharacters->True],

Cell[TextData[Cell[BoxData[GridBox[{
        {
          ButtonBox[
            StyleBox[
              RowBox[{
              "Print", " ", "message", " ", "in", " ", "status", " ", 
                "area"}],
              FontFamily->"Times"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEnd`SetNotebookStatusLine[ 
                  FrontEnd`ButtonNotebook[ ], "Hello, world!"]}]], 
          ButtonBox[
            StyleBox[
              RowBox[{"Clear", " ", "status", " ", "area"}],
              FontFamily->"Times"],
            ButtonFunction:>FrontEndExecute[ {
                FrontEnd`SetNotebookStatusLine[ 
                  FrontEnd`ButtonNotebook[ ], ""]}]]}
        }]]]], "ItemizedTextNote",
  ShowCellBracket->True,
  Active->True,
  Evaluatable->True,
  ShowSpecialCharacters->True,
  TextAlignment->Center],

Cell["\<\
A cell bracket with an \"X\" at the top indicates that the cell is \
not editable.  This is the result of setting the option Editable to \
False.\
\>", "ItemizedText"],

Cell["\<\
The contents of this cell may not be edited.  The front end will \
beep if you attempt to perform an editing operation.\
\>", "ItemizedTextNote",\

  Editable->False,
  ShowCellBracket->True,
  Evaluatable->True],

Cell["\<\
A cell bracket with an \"I\" at the top indicates that the cell is \
an initialization cell.  This is the result of setting the option \
InitializationCell to True.  Initialization cells allow the author to specify \
that particular cells should be evaluated first.    Initialization cells are \
not commented out or omitted when a notebook is exported as a package.\
\>", \
"ItemizedText"],

Cell[TextData[StyleBox["(* This is an initialization cell. *)\n2 + 2", \
"Input"]], "ItemizedTextNote",
  ShowCellBracket->True,
  Evaluatable->True,
  InitializationCell->True],

Cell[TextData[
"A closed cell group has a filled, \
downard\[NegativeVeryThinSpace]\[Dash]pointing half\[Dash]triangle at the \
base of the bracket.  Closing large groups of cells can help the reader get \
an overview of the notebook from its heading cells."], "ItemizedText",
  ShowSpecialCharacters->True],

Cell[CellGroupData[{

Cell["\<\
This cell is at the top of a cell group.  Double-click the cell's \
bracket to open the rest of the cell group.\
\>", "ItemizedTextNote",
  ShowCellBracket->True,
  Evaluatable->True],

Cell["Here is the other cell in the group.", "ItemizedTextNote",
  ShowCellBracket->True,
  Evaluatable->True]
}, Closed]],

Cell[TextData[
"A cell bracket with a rightward\[Dash]pointing triangle inside a rectangle, \
reminiscent of a speaker in an enclosure, indicates that it contains a \
playable sampled sound.  Double\[Dash]clicking the speaker icon will cause \
the front end to play the sound."], "ItemizedText",
  ShowSpecialCharacters->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 8192 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "ItemizedTextNote",
  CellLabel->"",
  ShowCellBracket->True,
  Evaluatable->True,
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40n007h00Oo`008@0000080000
0ooo0000000900000ooo0000000200000ooo0000000>00000ooo0000000200001Ooo00000000ool0
1`0000?oo`0000004P0000?oo`0000002@0000?oo`0000000P0000?oo`0000003P0000?oo`000000
0P0000Goo`0000000?oo00L00003ool0000001800003ool0000000T00003ool0000000800003ool0
000000h00003ool0000000800005ool00000003oo`0700000ooo0000000B00000ooo000000090000
0ooo0000000200000ooo0000000>00000ooo0000000200001Ooo00000000ool01`0000?oo`000000
2P00000300000ooo0000000700000ooo0000000200000ooo000000080002ool:00000ooo00000002
00000ooo0000000400000ooo0000000200000ooo0000000200000ooo0000000200000ooo00000004
00000ooo0000000700000ooo0000000200000ooo000000080002ool:00000ooo0000000200000ooo
0000000400000ooo0000000200000ooo0000000200000ooo0000000200000ooo0000000400000ooo
0000000700000ooo0000000200000ooo000000080002ool:00000ooo0000000200000ooo00000004
00000ooo0000000200000ooo0000000200000ooo0000000200000ooo0000000400000ooo00000007
00000ooo0000000200000ooo000000080002ool:00000ooo0000000200000ooo0000000400000ooo
0000000200000ooo0000000200000ooo0000000200000ooo00000001000000T00004ool00000ool8
00000ooo0000000200000ooo0000000>00001Ooo00000000ool00P0000?oo`0000001`0000Goo`00
00000?oo00800003ool0000000/00004ool00000ool800000ooo0000000200000ooo0000000>0000
1Ooo00000000ool00P0000?oo`0000001`0000Goo`0000000?oo00800003ool0000000/00004ool0
0000ool800000ooo0000000200000ooo0000000>00001Ooo00000000ool00P0000?oo`0000001`00
00Goo`0000000?oo00800003ool0000000/00004ool00000ool800000ooo0000000200000ooo0000
000>00001Ooo00000000ool00P0000?oo`0000001`0000Goo`0000000?oo00800003ool000000080
00000`0000?oo`00ool02P000_oo100000?oo`0000001`000_oo10000_oo2@0000?oo`0000000P00
0_oo2P0000?oo`00ool00P000_oo0P0000?oo`00ool02P000_oo100000?oo`0000001`000_oo1000
0_oo2@0000?oo`0000000P000_oo2P0000?oo`00ool00P000_oo0P0000?oo`00ool02P000_oo1000
00?oo`0000001`000_oo10000_oo2@0000?oo`0000000P000_oo2P0000?oo`00ool00P000_oo0P00
00?oo`00ool02P000_oo100000?oo`0000001`000_oo10000_oo2@0000?oo`0000000P000_oo2P00
00?oo`00ool00`00000200000ooo000000020002ool400000ooo000000030002ool80003ool20000
1?oo00000?oo0P000_oo2@000_oo1@0000?oo`0000000P000_oo100000?oo`0000000P0000?oo`00
00000P000_oo100000?oo`0000000`000_oo20000ooo0P0000Coo`00003oo`8000;oo`T000;oo`D0
0003ool00000008000;oo`@00003ool0000000800003ool00000008000;oo`@00003ool0000000<0
00;oo`P000?oo`800004ool00000ool20002ool90002ool500000ooo000000020002ool400000ooo
0000000200000ooo000000020002ool400000ooo000000030002ool80003ool200001?oo00000?oo
0P000_oo2@000_oo1@0000?oo`0000000P000_oo10000Ooo0@000@00000900001?oo00000?oo2000
0_oo00H00?oo003oo`00ool400000ooo0000000200000ooo0000000200001_oo003oo`00ool000;o
o`T00003ool00?oo00@00004ool000000002ool800001?oo00000?oo20000_oo00H00?oo003oo`00
ool400000ooo0000000200000ooo0000000200001_oo003oo`00ool000;oo`T00003ool00?oo00@0
0004ool000000002ool800001?oo00000?oo20000_oo00H00?oo003oo`00ool400000ooo00000002
00000ooo0000000200001_oo003oo`00ool000;oo`T00003ool00?oo00@00004ool000000002ool8
00001?oo00000?oo20000_oo00H00?oo003oo`00ool400000ooo0000000200000ooo000000020000
1_oo003oo`00ool000;oo`T00003ool00?oo00@00003ool000000080000000H00?oo003oo`00ool:
0002ool200001?oo000000000_oo100000Goo`0000000?oo00800005ool00?oo003oo`040002ool3
00001_oo00000?oo003oo`T00003ool00?oo00@00005ool00?oo003oo`0:0002ool200001?oo0000
00000_oo100000Goo`0000000?oo00800005ool00?oo003oo`040002ool300001_oo00000?oo003o
o`T00003ool00?oo00@00005ool00?oo003oo`0:0002ool200001?oo000000000_oo100000Goo`00
00000?oo00800005ool00?oo003oo`040002ool300001_oo00000?oo003oo`T00003ool00?oo00@0
0005ool00?oo003oo`0:0002ool200001?oo000000000_oo100000Goo`0000000?oo00800005ool0
0?oo003oo`040002ool300001_oo00000?oo003oo`T00003ool00?oo00<000001@0000Soo`00ool0
0?oo003oo`000_oo00<00?oo0000200000?oo`00ool0100000Koo`00ooooo`00ool400000ooo003o
o`0400000ooo0000000200003?oo003ooooo003oo`00ool00?oo003oo`X00008ool00?oo003oo`00
ool000;oo`03003oo`0000P00003ool00?oo00@00006ool00?ooool00?oo100000?oo`00ool01000
00?oo`0000000P0000coo`00ooooo`00ool00?oo003oo`00ool:00002?oo003oo`00ool00?oo0002
ool00`00ool0000800000ooo003oo`0400001_oo003ooooo003oo`@00003ool00?oo00@00003ool0
00000080000<ool00?ooool00?oo003oo`00ool00?oo2P0000Soo`00ool00?oo003oo`000_oo00<0
0?oo0000200000?oo`00ool0100000Koo`00ooooo`00ool400000ooo003oo`0400000ooo00000002
00003?oo003ooooo003oo`00ool00?oo003oo`D0000000@00?oo003oo`@00003ool0000000800003
ool0000000800005ool00?oo003oo`0<00001Ooo003oo`00ool02@0000?oo`0000000P0000Goo`00
ool00?oo00@00003ool0000000800008ool00000ool00?oo003oo`@00003ool0000000800003ool0
000000800005ool00?oo003oo`0<00001Ooo003oo`00ool02@0000?oo`0000000P0000Goo`00ool0
0?oo00@00003ool0000000800008ool00000ool00?oo003oo`@00003ool0000000800003ool00000
00800005ool00?oo003oo`0<00001Ooo003oo`00ool02@0000?oo`0000000P0000Goo`00ool00?oo
00@00003ool0000000800008ool00000ool00?oo003oo`@00003ool0000000800003ool000000080
0005ool00?oo003oo`0<00001Ooo003oo`00ool02@0000?oo`0000000P0000Goo`00ool00?oo00@0
0003ool0000000800003ool00000004000000P0000?oo`0000000P0000?oo`0000002@0000?oo`00
00000P0000?oo`0000000`0000?oo`000000200000?oo`0000000`0000?oo`0000000P0000?oo`00
00002@0000?oo`0000000P0000?oo`0000000P0000?oo`0000000P0000?oo`0000002@0000?oo`00
00000P0000?oo`0000000`0000?oo`000000200000?oo`0000000`0000?oo`0000000P0000?oo`00
00002@0000?oo`0000000P0000?oo`0000000P0000?oo`0000000P0000?oo`0000002@0000?oo`00
00000P0000?oo`0000000`0000?oo`000000200000?oo`0000000`0000?oo`0000000P0000?oo`00
00002@0000?oo`0000000P0000?oo`0000000P0000?oo`0000000P0000?oo`0000002@0000?oo`00
00000P0000?oo`0000000`0000?oo`000000200000?oo`0000000`0000?oo`0000000P0000?oo`00
00002@0000?oo`0000000P000Ooo0@000@0000040003ool20003ool30003ool30002ool30003ool3
0002ool30003ool30003ool30002ool30003ool30003ool20003ool30002ool30003ool20003ool3
0003ool30002ool30003ool30002ool30003ool30003ool30002ool30003ool30003ool20003ool3
0002ool30003ool20003ool30003ool30002ool30003ool30002ool30003ool30003ool30002ool3
0003ool30003ool20003ool30002ool30003ool20003ool30003ool30002ool30003ool30002ool3
0003ool30003ool30002ool30003ool30003ool20003ool400000004003oooooool30003ool30000
0ooo000000020003ool30002ool40002ool300000ooo000000020002ool40002ool30003ool40000
1?oo000000000ooo0`000ooo0P000ooo0`000ooo0`0000?oo`0000000P000ooo0`000_oo10000_oo
0`0000?oo`0000000P000_oo10000_oo0`000ooo100000Coo`00000000?oo`<000?oo`8000?oo`<0
00?oo`<00003ool00000008000?oo`<000;oo`@000;oo`<00003ool00000008000;oo`@000;oo`<0
00?oo`@00004ool000000003ool30003ool20003ool30003ool300000ooo000000020003ool30002
ool40002ool300000ooo000000020002ool40002ool30003ool400001?oo000000000ooo0`000ooo
0@00000500000ooo0000000300001_oo00000?oo003oo`@00003ool00000008000?oo`<000;oo`@0
00;oo`<000?oo`800003ool00?oo00@00003ool0000000800003ool0000000<00003ool0000000P0
0003ool0000000<00006ool00000ool00?oo100000?oo`0000000P000ooo0`000_oo10000_oo0`00
0ooo0P0000?oo`00ool0100000?oo`0000000P0000?oo`0000000`0000?oo`000000200000?oo`00
00000`0000Koo`00003oo`00ool400000ooo000000020003ool30002ool40002ool30003ool20000
0ooo003oo`0400000ooo0000000200000ooo0000000300000ooo0000000800000ooo000000030000
1_oo00000?oo003oo`@00003ool00000008000?oo`<000;oo`@000;oo`<000?oo`800003ool00?oo
00@00003ool0000000800003ool0000000<00003ool0000000<0000000@00?oo003oo`@00003ool0
0000008000?oo`800006ool00000003oo`000_oo2@000_oo2@000_oo00<00?oo00000P0000?oo`00
00000ooo100000?oo`0000000P0000?oo`00ool00P0000?oo`00ool0100000?oo`0000000P000ooo
0P0000Koo`0000000?oo0002ool90002ool90002ool00`00ool0000200000ooo00000003ool40000
0ooo0000000200000ooo003oo`0200000ooo003oo`0400000ooo000000020003ool200001_oo0000
0000ool000;oo`T000;oo`T000;oo`03003oo`0000800003ool0000000?oo`@00003ool000000080
0003ool00?oo00800003ool00?oo00@00003ool00000008000?oo`800006ool00000003oo`000_oo
2@000_oo2@000_oo00<00?oo00000P0000?oo`0000000ooo100000?oo`0000000P0000?oo`00ool0
0@00000700000ooo0000000900000ooo0000000400000ooo003oo`0200000ooo0000000700001Ooo
003oo`00ool00P0000Goo`0000000?oo00T00004ool00000ool300001?oo003ooooo1P0000?oo`00
00002@0000?oo`000000100000?oo`00ool00P0000?oo`0000001`0000Goo`00ool00?oo00800005
ool00000003oo`0900001?oo00000?oo0`0000Coo`00ooooo`H00003ool0000000T00003ool00000
00@00003ool00?oo00800003ool0000000L00005ool00?oo003oo`0200001Ooo00000000ool02@00
00Coo`00003oo`<00004ool00?ooool600000ooo0000000900000ooo0000000400000ooo003oo`02
00000ooo0000000700001Ooo003oo`00ool00P0000Goo`0000000?oo00T00004ool00000ool30001
ool10001000000D00003ool00000008000;oo`T000;oo`@00003ool0000000800003ool0000000@0
0003ool0000000800003ool00000008000;oo`T000;oo`@00003ool0000000P00003ool000000080
00;oo`T000;oo`@00003ool0000000800003ool0000000@00003ool0000000800003ool000000080
00;oo`T000;oo`@00003ool0000000P00003ool00000008000;oo`T000;oo`@00003ool000000080
0003ool0000000@00003ool0000000800003ool00000008000;oo`T000;oo`@00003ool0000000P0
0003ool00000008000;oo`T000;oo`@00003ool0000000800003ool0000000@00003ool000000080
0003ool00000008000;oo`T000;oo`@00003ool0000000<0000000<00?oo00001@0000?oo`000000
100000Coo`00003oo`H00003ool0000000L000;oo`T00003ool0000000@00004ool00000ool60000
0ooo0000000400001?oo00000?oo1P0000?oo`000000100000Coo`00003oo`H00003ool0000000L0
00;oo`T00003ool0000000@00004ool00000ool600000ooo0000000400001?oo00000?oo1P0000?o
o`000000100000Coo`00003oo`H00003ool0000000L000;oo`T00003ool0000000@00004ool00000
ool600000ooo0000000400001?oo00000?oo1P0000?oo`000000100000Coo`00003oo`H00003ool0
000000L000;oo`T00003ool0000000@00004ool00000ool600000ooo000000040001ool100000080
0003ool0000000800003ool0000000T00005ool00000003oo`0L00000ooo0000000>00000ooo0000
000200000ooo0000000200000ooo0000000900001Ooo00000000ool0700000?oo`0000003P0000?o
o`0000000P0000?oo`0000000P0000?oo`0000002@0000Goo`0000000?oo01`00003ool0000000h0
0003ool0000000800003ool0000000800003ool0000000T00005ool00000003oo`0L00000ooo0000
000>0001ool10001000000H00003ool0000000D00003ool0000000H00003ool0000000T000;oo`<0
0005ool00000003oo`0<00001Ooo00000000ool0400000?oo`0000001@0000?oo`0000001P0000?o
o`0000002@000_oo0`0000Goo`0000000?oo00`00005ool00000003oo`0@00000ooo000000050000
0ooo0000000600000ooo000000090002ool300001Ooo00000000ool0300000Goo`0000000?oo0100
0003ool0000000D00003ool0000000H00003ool0000000T000;oo`<00005ool00000003oo`0<0000
1Ooo00000000ool02P00000200001Ooo00000000ool00`0000?oo`0000002P0000Goo`0000000?oo
00`00005ool00000003oo`0<00001Ooo00000000ool0300000Goo`0000000?oo00<00003ool00000
00X00005ool00000003oo`0<00001Ooo00000000ool0300000Goo`0000000?oo00`00005ool00000
003oo`0300000ooo0000000:00001Ooo00000000ool0300000Goo`0000000?oo00`00005ool00000
003oo`0<00001Ooo00000000ool00`0000?oo`0000002P0000Goo`0000000?oo00`00005ool00000
003oo`0<00001Ooo00000000ool02P00003o000Q00000003003oo`0000?oo`8000?oo`8000?oo`04
003ooooo0003ool20003ool20003ool20003ool01000ooooo`000_oo00<00?oo00000ooo0P000ooo
00<00?oo00000ooo00<00?oo00000_oo00<00?oo00000ooo00<00?oo00000ooo0P000ooo0P000ooo
00@00?ooool000?oo`8000?oo`8000?oo`8000?oo`04003ooooo0002ool00`00ool00003ool20003
ool00`00ool00003ool00`00ool00002ool00`00ool00003ool00`00ool00003ool20003ool20003
ool01000ooooo`000ooo0P000ooo0P000ooo0P000ooo00@00?ooool000;oo`03003oo`0000?oo`80
00?oo`03003oo`0000?oo`03003oo`0000;oo`03003oo`0000?oo`03003oo`0000?oo`8000?oo`80
00?oo`04003ooooo0003ool20003ool20003ool20003ool01000ooooo`000_oo00<00?oo00000ooo
0P000ooo00<00?oo00000ooo00<00?oo00000_oo00<00?oo00000_oo0@0000000`00ooooo`020003
ool00`00ool00002ool00`00ool00004ool20003ool00`00ool00003ool20003ool20004ool00`00
ooooo`03ool20003ool20003ool20005ool00`00ooooo`02ool20003ool20003ool00`00ool00002
ool00`00ool00004ool20003ool00`00ool00003ool20003ool20004ool00`00ooooo`03ool20003
ool20003ool20005ool00`00ooooo`02ool20003ool20003ool00`00ool00002ool00`00ool00004
ool20003ool00`00ool00003ool20003ool20004ool00`00ooooo`03ool20003ool20003ool20005
ool00`00ooooo`02ool20003ool20003ool00`00ool00002ool00`00ool00004ool20003ool00`00
ool00003ool20003ool20004ool00`00ooooo`03ool20003ool20003ool20005ool00`00ooooo`02
ool200000003003oo`0000?oo`8000?oo`800004ool00?oo0002ool01000ool00?oo0P000ooo0P00
0ooo00H00?oo00000?oo0002ool00`00ooooo`030002ool200001_oo003ooooo003oo`8000;oo`<0
00;oo`05003ooooo003oo`0200000ooo003oo`02ool20003ool200001?oo003oo`000_oo00@00?oo
003oo`8000?oo`8000?oo`06003oo`00003oo`000_oo00<00?ooool00`000_oo0P0000Koo`00oooo
o`00ool20002ool30002ool01@00ooooo`00ool00P0000?oo`00ool00_oo0P000ooo0P0000Coo`00
ool000;oo`04003oo`00ool20003ool20003ool01P00ool00000ool000;oo`03003ooooo00<000;o
o`800006ool00?ooool00?oo0P000_oo0`000_oo00D00?ooool00?oo00800003ool00?oo00;oo`80
00?oo`800004ool00?oo0002ool01000ool00?oo0P000ooo0P000ooo00H00?oo00000?oo0002ool0
0`00ooooo`030002ool200001_oo003ooooo003oo`8000;oo`<000;oo`05003ooooo003oo`010000
008000[oo`03003ooooo00;oo`8000Coo`03003ooooo00Soo`03003ooooo00?oo`03003ooooo00;o
o`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00?o
o`03003ooooo00Soo`03003ooooo00;oo`8000Coo`03003ooooo00Soo`03003ooooo00?oo`03003o
oooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003o
oooo00?oo`03003ooooo00Soo`03003ooooo00;oo`8000Coo`03003ooooo00Soo`03003ooooo00?o
o`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;o
o`03003ooooo00?oo`03003ooooo00Soo`03003ooooo00;oo`8000Coo`03003ooooo00Soo`03003o
oooo00?oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003o
oooo00;oo`04003oooooool100000003003oo`0000?oo`<000;oo`03003oo`0000;oo`06003ooooo
003oo`000_oo00<00?ooool00`000ooo00H00?ooool00?oo0002ool01P00ooooo`00ool000;oo`03
003oo`0000Coo`03003oo`0000;oo`03003oo`0000;oo`03003oo`0000;oo`04003ooooo0003ool3
0002ool00`00ool00002ool01P00ooooo`00ool000;oo`03003ooooo00<000?oo`06003ooooo003o
o`000_oo00H00?ooool00?oo0002ool00`00ool00004ool00`00ool00002ool00`00ool00002ool0
0`00ool00002ool01000ooooo`000ooo0`000_oo00<00?oo00000_oo00H00?ooool00?oo0002ool0
0`00ooooo`030003ool01P00ooooo`00ool000;oo`06003ooooo003oo`000_oo00<00?oo00001?oo
00<00?oo00000_oo00<00?oo00000_oo00<00?oo00000_oo00@00?ooool000?oo`<000;oo`03003o
o`0000;oo`06003ooooo003oo`000_oo00<00?ooool00`000ooo00H00?ooool00?oo0002ool01P00
ooooo`00ool000;oo`03003oo`0000Coo`03003oo`0000;oo`03003oo`0000;oo`03003oo`0000;o
o`40000000<00?ooool00P001Ooo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<0
0?ooool00_oo00<00?oo00001?oo00<00?ooool00_oo00<00?ooool00_oo0P001?oo0P001?oo00<0
0?ooool00ooo00<00?ooool00_oo00<00?ooool00_oo0P001Ooo00<00?ooool00_oo00<00?ooool0
0_oo00<00?ooool00_oo00<00?ooool00_oo00<00?oo00001?oo00<00?ooool00_oo00<00?ooool0
0_oo0P001?oo0P001?oo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool00_oo0P001Ooo00<0
0?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?oo00001?oo00<0
0?ooool00_oo00<00?ooool00_oo0P001?oo0P001?oo00<00?ooool00ooo00<00?ooool00_oo00<0
0?ooool00_oo0P001Ooo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool0
0_oo00<00?oo00001?oo00<00?ooool00_oo00<00?ooool00_oo0P001?oo0P001?oo00<00?ooool0
0ooo00<00?ooool00_oo0P0000000`00ooooo`020003ool00`00ooooo`0@ool01000oooooooo0P00
0ooo00<00?ooool02_oo00@00?ooooooo`8000?oo`03003ooooo00[oo`04003oooooool20003ool0
0`00ooooo`0@ool01000oooooooo0P000ooo00<00?ooool02_oo00@00?ooooooo`8000?oo`03003o
oooo00[oo`04003oooooool20003ool00`00ooooo`0@ool01000oooooooo0P000ooo00<00?ooool0
2_oo00@00?ooooooo`8000?oo`03003ooooo00[oo`04003oooooool20003ool00`00ooooo`0@ool0
1000oooooooo0P000ooo00<00?ooool02_oo00@00?ooooooo`8000?oo`03003ooooo00[oo`400000
00<00?oo00000ooo0P000ooo00H00?ooool00?oo0002ool00`00ool00002ool01000oooooooo0P00
0ooo00<00?ooool00_oo00@00?ooool000;oo`03003oo`0000Goo`04003ooooo0005ool00`00ool0
0002ool01000ooooo`001?oo00@00?ooooooo`8000?oo`06003ooooo003oo`000_oo00<00?oo0000
0_oo00@00?ooooooo`8000?oo`03003ooooo00;oo`04003ooooo0002ool00`00ool00005ool01000
ooooo`001Ooo00<00?oo00000_oo00@00?ooool000Coo`04003oooooool20003ool01P00ooooo`00
ool000;oo`03003oo`0000;oo`04003oooooool20003ool00`00ooooo`02ool01000ooooo`000_oo
00<00?oo00001Ooo00@00?ooool000Goo`03003oo`0000;oo`04003ooooo0004ool01000oooooooo
0P000ooo00H00?ooool00?oo0002ool00`00ool00002ool01000oooooooo0P000ooo00<00?ooool0
0_oo00@00?ooool000;oo`03003oo`0000Goo`04003ooooo0005ool00`00ool00002ool01@00oooo
o`00ool00@0000000`00ooooo`09ool00`00ooooo`08ool00`00ooooo`09ool00`00ooooo`02ool0
0`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool0
0`00ooooo`02ool00`00ooooo`09ool00`00ooooo`08ool00`00ooooo`09ool00`00ooooo`02ool0
0`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool0
0`00ooooo`02ool00`00ooooo`09ool00`00ooooo`08ool00`00ooooo`09ool00`00ooooo`02ool0
0`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool0
0`00ooooo`02ool00`00ooooo`09ool00`00ooooo`08ool00`00ooooo`09ool00`00ooooo`02ool0
0`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool0
1000oooooooo0@0000030003ool20004ool00`00ooooo`02ool20004ool00`00ooooo`02ool20003
ool20005ool00`00ooooo`02ool00`00ooooo`02ool20004ool20004ool00`00ooooo`02ool00`00
ooooo`03ool20003ool20004ool00`00ooooo`02ool20004ool00`00ooooo`02ool20003ool20005
ool00`00ooooo`02ool00`00ooooo`02ool20004ool20004ool00`00ooooo`02ool00`00ooooo`03
ool20003ool20004ool00`00ooooo`02ool20004ool00`00ooooo`02ool20003ool20005ool00`00
ooooo`02ool00`00ooooo`02ool20004ool20004ool00`00ooooo`02ool00`00ooooo`03ool20003
ool20004ool00`00ooooo`02ool20004ool00`00ooooo`02ool20003ool20005ool00`00ooooo`02
ool00`00ooooo`02ool20004ool20004ool00`00ooooo`02ool01000oooooooo0@0000000`00oooo
o`05ool01P00ooooo`00ool000;oo`04003ooooo0002ool00`00ool00002ool00`00ooooo`06ool0
1P00ooooo`00ool000;oo`03003oo`0000;oo`03003ooooo00Koo`06003ooooo003oo`000_oo00<0
0?oo00000_oo00<00?ooool01_oo00H00?ooool00?oo0002ool01000ooooo`000_oo00<00?oo0000
0_oo00<00?ooool01_oo00H00?ooool00?oo0002ool00`00ool00002ool00`00ooooo`06ool01P00
ooooo`00ool000;oo`03003oo`0000;oo`03003ooooo00Koo`06003ooooo003oo`000_oo00@00?oo
ool000;oo`03003oo`0000;oo`03003ooooo00Koo`06003ooooo003oo`000_oo00<00?oo00000_oo
00<00?ooool01_oo00H00?ooool00?oo0002ool00`00ool00002ool00`00ooooo`06ool01P00oooo
o`00ool000;oo`04003ooooo0002ool00`00ool00002ool00`00ooooo`06ool01P00ooooo`00ool0
00;oo`03003oo`0000;oo`03003ooooo00Koo`06003ooooo003oo`000_oo00<00?oo00000_oo0@00
00000`00ooooo`020005ool00`00ooooo`0<ool00`00ooooo`02ool00`00ool0000>ool00`00oooo
o`03ool20004ool00`00ooooo`0=ool20005ool00`00ooooo`0<ool00`00ooooo`02ool00`00ool0
000>ool00`00ooooo`03ool20004ool00`00ooooo`0=ool20005ool00`00ooooo`0<ool00`00oooo
o`02ool00`00ool0000>ool00`00ooooo`03ool20004ool00`00ooooo`0=ool20005ool00`00oooo
o`0<ool00`00ooooo`02ool00`00ool0000>ool00`00ooooo`03ool20004ool00`00ooooo`09ool1
00000004003ooooo0005ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`02ool00`00oooo
o`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`08ool00`00oooo
o`02ool20004ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`03ool00`00ooooo`02ool0
0`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`03ool0
0`00ooooo`08ool00`00ooooo`02ool20004ool00`00ooooo`02ool00`00ooooo`03ool00`00oooo
o`03ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00oooo
o`02ool00`00ooooo`03ool00`00ooooo`08ool00`00ooooo`02ool20004ool00`00ooooo`02ool0
0`00ooooo`03ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool0
0`00ooooo`02ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`08ool00`00ooooo`02ool2
0004ool200000005003oooooool00003ool00`00ooooo`03ool00`00ool00002ool00`00ool00005
ool01@00oooooooo00001?oo00<00?ooool00_oo00@00?ooool000Coo`04003oooooool20003ool0
0`00ooooo`02ool01000ooooo`001?oo00<00?ooool00_oo00D00?ooooooo`0000Goo`03003oo`00
00;oo`03003oo`0000Goo`05003oooooool00004ool00`00ooooo`02ool01000ooooo`001?oo00@0
0?ooooooo`8000?oo`03003ooooo00;oo`04003ooooo0004ool00`00ooooo`02ool01@00oooooooo
00001Ooo00<00?oo00000_oo00<00?oo00001Ooo00D00?ooooooo`0000Coo`03003ooooo00;oo`04
003ooooo0004ool01000oooooooo0P000ooo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo
00;oo`05003oooooool00005ool00`00ool00002ool00`00ool00005ool01@00oooooooo00001?oo
00<00?ooool00_oo00@00?ooool000Coo`04003oooooool20003ool00`00ooooo`02ool01000oooo
o`001?oo0@0000000`00ool00008ool00`00ooooo`0:ool00`00ooooo`06ool00`00ooooo`02ool0
0`00ooooo`05ool00`00ooooo`0<ool00`00ooooo`05ool00`00ooooo`02ool00`00ooooo`06ool0
0`00ooooo`0:ool00`00ooooo`06ool00`00ooooo`02ool00`00ooooo`05ool00`00ooooo`0<ool0
0`00ooooo`05ool00`00ooooo`02ool00`00ooooo`06ool00`00ooooo`0:ool00`00ooooo`06ool0
0`00ooooo`02ool00`00ooooo`05ool00`00ooooo`0<ool00`00ooooo`05ool00`00ooooo`02ool0
0`00ooooo`06ool00`00ooooo`0:ool00`00ooooo`06ool00`00ooooo`02ool00`00ooooo`05ool0
0`00ooooo`0<ool00`00ooooo`05ool10001ool100000003003ooooo00?oo`8000Coo`03003ooooo
00Soo`03003ooooo00;oo`8000Goo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03
003oo`0000;oo`03003oo`0000Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00?oo`80
00Coo`03003ooooo00Soo`03003ooooo00;oo`8000Goo`03003ooooo00;oo`03003ooooo00;oo`03
003ooooo00;oo`03003oo`0000;oo`03003oo`0000Coo`03003ooooo00;oo`03003ooooo00;oo`03
003ooooo00?oo`8000Coo`03003ooooo00Soo`03003ooooo00;oo`8000Goo`03003ooooo00;oo`03
003ooooo00;oo`03003ooooo00;oo`03003oo`0000;oo`03003oo`0000Coo`03003ooooo00;oo`03
003ooooo00;oo`03003ooooo00?oo`8000Coo`03003ooooo00Soo`03003ooooo00;oo`8000Goo`03
003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003oo`0000;oo`03003oo`0000Coo`03
003ooooo00;oo`04003oooooool10000008000Coo`8000Coo`03003ooooo00;oo`8000Coo`03003o
oooo00;oo`8000Coo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Co
o`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo00;oo`8000Coo`03003o
oooo00;oo`8000Coo`03003ooooo00;oo`8000Coo`03003ooooo00?oo`03003ooooo00;oo`03003o
oooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00?oo`03003o
oooo00;oo`8000Coo`03003ooooo00;oo`8000Coo`03003ooooo00;oo`8000Coo`03003ooooo00?o
o`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;o
o`03003ooooo00?oo`03003ooooo00;oo`8000Coo`03003ooooo00;oo`8000Coo`03003ooooo00;o
o`8000Coo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003o
oooo00;oo`03003ooooo00;oo`04003oooooool100000003003oo`0000Soo`03003ooooo00[oo`03
003ooooo00Koo`03003ooooo00[oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03
003ooooo00[oo`03003ooooo00Koo`03003ooooo00[oo`03003ooooo00Koo`03003ooooo00[oo`03
003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00[oo`03003ooooo00Koo`03
003ooooo00[oo`03003ooooo00Koo`03003ooooo00[oo`03003ooooo00;oo`03003ooooo00;oo`03
003ooooo00;oo`03003ooooo00[oo`03003ooooo00Koo`03003ooooo00[oo`03003ooooo00Koo`03
003ooooo00[oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Ooo`40
000000<00?ooool01Ooo00<00?ooool00_oo00@00?ooool000;oo`04003ooooo0004ool00`00oooo
o`06ool01P00ooooo`00ool000;oo`03003ooooo00;oo`03003ooooo00Koo`03003ooooo00;oo`06
003ooooo003oo`000_oo00<00?ooool01_oo00<00?ooool00_oo00@00?ooool000;oo`04003ooooo
0004ool00`00ooooo`06ool01P00ooooo`00ool000;oo`03003ooooo00;oo`03003ooooo00Koo`03
003ooooo00;oo`06003ooooo003oo`000_oo00<00?ooool01_oo00<00?ooool00_oo00@00?ooool0
00;oo`04003ooooo0004ool00`00ooooo`06ool01P00ooooo`00ool000;oo`03003ooooo00;oo`03
003ooooo00Koo`03003ooooo00;oo`06003ooooo003oo`000_oo00<00?ooool01_oo00<00?ooool0
0_oo00@00?ooool000;oo`04003ooooo0004ool00`00ooooo`06ool01P00ooooo`00ool000;oo`03
003ooooo00;oo`03003ooooo00Koo`03003ooooo00;oo`06003ooooo003oo`000_oo0@0000001P00
ooooo`00ool000Coo`03003ooooo00coo`03003ooooo00;oo`03003oo`0001Coo`8001Coo`03003o
o`0000Coo`03003ooooo00coo`03003ooooo00;oo`03003oo`0001Coo`8001Coo`03003oo`0000Co
o`03003ooooo00coo`03003ooooo00;oo`03003oo`0001Coo`8001Coo`03003oo`0000Coo`03003o
oooo00coo`03003ooooo00;oo`03003oo`0001Coo`80013oo`40000000<00?ooool03?oo00<00?oo
ool00_oo00<00?ooool03_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool02_oo00@00?oo
ooooo`8000Coo`03003ooooo00koo`03003ooooo00;oo`03003ooooo00koo`03003ooooo00;oo`03
003ooooo00;oo`03003ooooo00[oo`04003oooooool20004ool00`00ooooo`0>ool00`00ooooo`02
ool00`00ooooo`0>ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`0:ool01000oooooooo
0P001?oo00<00?ooool03_oo00<00?ooool00_oo00<00?ooool03_oo00<00?ooool00_oo00<00?oo
ool00_oo00<00?ooool02_oo00@00?ooooooo`8000Coo`80000000<00?ooool00P000ooo0P003ooo
0P001?oo0P003ooo0P000ooo0P000ooo0P003ooo0P000ooo0P003ooo0P001?oo0P003ooo0P000ooo
0P000ooo0P003ooo0P000ooo0P003ooo0P001?oo0P003ooo0P000ooo0P000ooo0P003ooo0P000ooo
0P003ooo0P001?oo0P003ooo0P000ooo0P000ooo0P002ooo0@0000000`00ooooo`0;ool00`00oooo
o`04ool00`00ooooo`0<ool00`00ooooo`02ool00`00ool0000Cool01000ooooo`001?oo00<00?oo
ool03?oo00<00?ooool01?oo00<00?ooool03?oo00<00?ooool00_oo00<00?oo00004ooo00@00?oo
ool000Coo`03003ooooo00coo`03003ooooo00Coo`03003ooooo00coo`03003ooooo00;oo`03003o
o`0001?oo`04003ooooo0004ool00`00ooooo`0<ool00`00ooooo`04ool00`00ooooo`0<ool00`00
ooooo`02ool00`00ool0000Cool01000ooooo`001?oo0@0000000`00ool00003ool00`00ooooo`02
ool00`00ooooo`02ool01000ooooo`001?oo00<00?ooool00_oo00D00?ooooooo`0000Coo`03003o
oooo00Goo`03003ooooo00?oo`04003ooooo0004ool00`00ooooo`06ool00`00ooooo`02ool01@00
oooooooo00001?oo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo00;oo`05003oooooool0
0004ool00`00ooooo`05ool00`00ooooo`03ool01000ooooo`001?oo00<00?ooool01_oo00<00?oo
ool00_oo00D00?ooooooo`0000Coo`03003ooooo00;oo`04003ooooo0004ool00`00ooooo`02ool0
1@00oooooooo00001?oo00<00?ooool01Ooo00<00?ooool00ooo00@00?ooool000Coo`03003ooooo
00Koo`03003ooooo00;oo`05003oooooool00004ool00`00ooooo`02ool01000ooooo`001?oo00<0
0?ooool00_oo00D00?ooooooo`0000Coo`03003ooooo00Goo`03003ooooo00?oo`04003ooooo0004
ool00`00ooooo`06ool10001ool100000003003ooooo00Coo`03003ooooo00;oo`03003ooooo00;o
o`8000Coo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003o
oooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003o
oooo00Coo`03003ooooo00;oo`03003ooooo00;oo`8000Coo`03003ooooo00;oo`03003ooooo00Co
o`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;o
o`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;o
o`8000Coo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003o
oooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003o
oooo00Coo`03003ooooo00;oo`03003ooooo00;oo`8000Coo`03003ooooo00;oo`03003ooooo00Co
o`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;o
o`03003ooooo00;oo`04003oooooool100000003003ooooo00Woo`03003ooooo00Soo`03003ooooo
00koo`03003ooooo00;oo`03003ooooo00koo`03003ooooo00;oo`03003ooooo00koo`03003ooooo
00Soo`03003ooooo00koo`03003ooooo00;oo`03003ooooo00koo`03003ooooo00;oo`03003ooooo
00koo`03003ooooo00Soo`03003ooooo00koo`03003ooooo00;oo`03003ooooo00koo`03003ooooo
00;oo`03003ooooo00koo`03003ooooo00Soo`03003ooooo00koo`03003ooooo00;oo`03003ooooo
00koo`03003ooooo00;oo`04003oooooool1000000<000?oo`8000?oo`03003ooooo00[oo`04003o
ooooool20003ool2000?ool20004ool2000?ool20003ool20003ool00`00ooooo`0:ool01000oooo
oooo0P000ooo0P003ooo0P001?oo0P003ooo0P000ooo0P000ooo00<00?ooool02_oo00@00?oooooo
o`8000?oo`8000ooo`8000Coo`8000ooo`8000?oo`8000?oo`03003ooooo00[oo`04003oooooool2
0003ool2000?ool20004ool2000=ool100000003003ooooo00[oo`04003ooooo0002ool01000oooo
o`004?oo00<00?oo00000_oo00<00?oo00003_oo00<00?oo00000_oo00<00?oo00004?oo00@00?oo
ool000;oo`04003ooooo000@ool00`00ool00002ool00`00ool0000>ool00`00ool00002ool00`00
ool0000@ool01000ooooo`000_oo00@00?ooool0013oo`03003oo`0000;oo`03003oo`0000koo`03
003oo`0000;oo`03003oo`00013oo`04003ooooo0002ool01000ooooo`004?oo00<00?oo00000_oo
00<00?oo00003_oo00<00?oo00000_oo00<00?oo00000_oo0@0000000`00ooooo`02ool01000oooo
o`004_oo00@00?ooool000Goo`03003ooooo00[oo`03003ooooo00Koo`03003ooooo00[oo`03003o
oooo00?oo`04003ooooo000Bool01000ooooo`001Ooo00<00?ooool02_oo00<00?ooool01_oo00<0
0?ooool02_oo00<00?ooool00ooo00@00?ooool001;oo`04003ooooo0005ool00`00ooooo`0:ool0
0`00ooooo`06ool00`00ooooo`0:ool00`00ooooo`03ool01000ooooo`004_oo00@00?ooool000Go
o`03003ooooo00[oo`03003ooooo00Koo`03003ooooo00[oo`40000000@00?ooool000Koo`03003o
oooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003o
oooo00Ooo`03003ooooo00?oo`8000Goo`03003ooooo00Ooo`03003ooooo00;oo`03003ooooo00Co
o`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;o
o`03003ooooo00Ooo`03003ooooo00?oo`8000Goo`03003ooooo00Ooo`03003ooooo00;oo`03003o
oooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003o
oooo00;oo`03003ooooo00Ooo`03003ooooo00?oo`8000Goo`03003ooooo00Ooo`03003ooooo00;o
o`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Co
o`03003ooooo00;oo`03003ooooo00Ooo`03003ooooo00?oo`8000Goo`03003ooooo00Ooo`800000
00<00?ooool03?oo00<00?ooool00_oo00<00?ooool04ooo0P005?oo0P005Ooo00<00?ooool00_oo
00<00?ooool04ooo0P005?oo0P005Ooo00<00?ooool00_oo00<00?ooool04ooo0P005?oo0P005Ooo
00<00?ooool00_oo00<00?ooool04ooo0P005?oo0P001Ooo0@0000000`00ooooo`020004ool00`00
ooooo`0>ool00`00ooooo`02ool20004ool00`00ooooo`08ool00`00ooooo`02ool20004ool00`00
ooooo`08ool00`00ooooo`02ool20004ool00`00ooooo`0>ool00`00ooooo`02ool20004ool00`00
ooooo`08ool00`00ooooo`02ool20004ool00`00ooooo`08ool00`00ooooo`02ool20004ool00`00
ooooo`0>ool00`00ooooo`02ool20004ool00`00ooooo`08ool00`00ooooo`02ool20004ool00`00
ooooo`08ool00`00ooooo`02ool20004ool00`00ooooo`0>ool00`00ooooo`02ool20004ool00`00
ooooo`08ool00`00ooooo`02ool20004ool00`00ooooo`08ool200000003003ooooo00_oo`03003o
o`0000;oo`03003oo`0000koo`03003ooooo00;oo`03003oo`0000Goo`03003ooooo00Koo`03003o
oooo00;oo`04003ooooo0004ool00`00ooooo`0<ool00`00ool00002ool00`00ool0000>ool00`00
ooooo`02ool00`00ool00005ool00`00ooooo`06ool00`00ooooo`02ool01000ooooo`001?oo00<0
0?ooool03?oo00<00?oo00000_oo00<00?oo00003_oo00<00?ooool00_oo00<00?oo00001Ooo00<0
0?ooool01_oo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo00coo`03003oo`0000;oo`03
003oo`0000koo`03003ooooo00;oo`03003oo`0000Goo`03003ooooo00Koo`03003ooooo00;oo`04
003ooooo0004ool100000003003ooooo00Soo`03003ooooo00[oo`03003ooooo00_oo`03003ooooo
00Goo`03003ooooo00_oo`03003ooooo00Koo`03003ooooo00_oo`03003ooooo00[oo`03003ooooo
00_oo`03003ooooo00Goo`03003ooooo00_oo`03003ooooo00Koo`03003ooooo00_oo`03003ooooo
00[oo`03003ooooo00_oo`03003ooooo00Goo`03003ooooo00_oo`03003ooooo00Koo`03003ooooo
00_oo`03003ooooo00[oo`03003ooooo00_oo`03003ooooo00Goo`03003ooooo00_oo`03003ooooo
00Koo`40007oo`40000000<00?oo00000_oo00<00?oo00005?oo0P000ooo00<00?oo00003_oo00<0
0?oo00000_oo00<00?oo00003_oo00<00?oo00000_oo00<00?oo00005?oo0P000ooo00<00?oo0000
3_oo00<00?oo00000_oo00<00?oo00003_oo00<00?oo00000_oo00<00?oo00005?oo0P000ooo00<0
0?oo00003_oo00<00?oo00000_oo00<00?oo00003_oo00<00?oo00000_oo00<00?oo00005?oo0P00
0ooo00<00?oo00003_oo00<00?oo00000_oo00<00?oo00003Ooo0@0000000`00ooooo`09ool00`00
ooooo`02ool20003ool00`00ooooo`0?ool00`00ooooo`02ool00`00ooooo`0>ool00`00ooooo`02
ool00`00ooooo`0>ool00`00ooooo`02ool20003ool00`00ooooo`0?ool00`00ooooo`02ool00`00
ooooo`0>ool00`00ooooo`02ool00`00ooooo`0>ool00`00ooooo`02ool20003ool00`00ooooo`0?
ool00`00ooooo`02ool00`00ooooo`0>ool00`00ooooo`02ool00`00ooooo`0>ool00`00ooooo`02
ool20003ool00`00ooooo`0?ool00`00ooooo`02ool00`00ooooo`0>ool00`00ooooo`02ool01000
oooooooo0@000002000:ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`0=ool00`00oooo
o`04ool00`00ooooo`0=ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00oooo
o`0=ool00`00ooooo`04ool00`00ooooo`0=ool00`00ooooo`08ool00`00ooooo`08ool00`00oooo
o`08ool00`00ooooo`0=ool00`00ooooo`04ool00`00ooooo`0=ool00`00ooooo`08ool00`00oooo
o`08ool00`00ooooo`08ool00`00ooooo`0=ool00`00ooooo`04ool00`00ooooo`0;ool100000003
003oo`0000?oo`8000?oo`03003ooooo00[oo`04003oooooool20003ool00`00ooooo`0:ool00`00
ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`0:ool01000oooooooo0P000ooo
00<00?ooool02_oo00@00?ooooooo`8000?oo`03003ooooo00[oo`03003ooooo00;oo`03003ooooo
00;oo`03003ooooo00;oo`03003ooooo00[oo`04003oooooool20003ool00`00ooooo`0:ool01000
oooooooo0P000ooo00<00?ooool02_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo
00<00?ooool02_oo00@00?ooooooo`8000?oo`03003ooooo00[oo`04003oooooool20003ool00`00
ooooo`0:ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`07ool10000
0003003ooooo00[oo`04003ooooo0002ool01000ooooo`003Ooo00H00?ooool00?oo0002ool00`00
ooooo`0@ool01P00ooooo`00ool000;oo`03003ooooo00_oo`04003ooooo0002ool01000ooooo`00
3Ooo00H00?ooool00?oo0002ool00`00ooooo`0@ool01P00ooooo`00ool000;oo`03003ooooo00_o
o`04003ooooo0002ool01000ooooo`003Ooo00H00?ooool00?oo0002ool00`00ooooo`0@ool01P00
ooooo`00ool000;oo`03003ooooo00_oo`04003ooooo0002ool01000ooooo`003Ooo00H00?ooool0
0?oo0002ool00`00ooooo`0@ool01P00ooooo`00ool000;oo`40000000<00?ooool00_oo00@00?oo
ool001;oo`04003ooooo000Bool00`00ooooo`06ool00`00ooooo`0@ool01000ooooo`004_oo00@0
0?ooool001;oo`03003ooooo00Koo`03003ooooo013oo`04003ooooo000Bool01000ooooo`004_oo
00<00?ooool01_oo00<00?ooool04?oo00@00?ooool001;oo`04003ooooo000Bool00`00ooooo`06
ool00`00ooooo`0:ool100000004003ooooo0006ool00`00ooooo`0<ool00`00ooooo`04ool00`00
ooooo`02ool00`00ooooo`07ool00`00ooooo`03ool20005ool00`00ooooo`07ool00`00ooooo`02
ool00`00ooooo`04ool00`00ooooo`0<ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`07
ool00`00ooooo`03ool20005ool00`00ooooo`07ool00`00ooooo`02ool00`00ooooo`04ool00`00
ooooo`0<ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`07ool00`00ooooo`03ool20005
ool00`00ooooo`07ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`0<ool00`00ooooo`04
ool00`00ooooo`02ool00`00ooooo`07ool00`00ooooo`03ool20005ool00`00ooooo`07ool20000
0003003ooooo00coo`03003ooooo00;oo`03003ooooo01?oo`8001Coo`8001Goo`03003ooooo00;o
o`03003ooooo01?oo`8001Coo`8001Goo`03003ooooo00;oo`03003ooooo01?oo`8001Coo`8001Go
o`03003ooooo00;oo`03003ooooo01?oo`8001Coo`8000Goo`40000000@00?ooool000Goo`03003o
oooo00?oo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo00?oo`03003ooooo00;oo`03003o
oooo00Soo`03003ooooo00;oo`8000Coo`03003ooooo00Soo`03003ooooo00;oo`03003ooooo00?o
o`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo00?oo`03003ooooo00;o
o`03003ooooo00Soo`03003ooooo00;oo`8000Coo`03003ooooo00Soo`03003ooooo00;oo`03003o
oooo00?oo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo00?oo`03003o
oooo00;oo`03003ooooo00Soo`03003ooooo00;oo`8000Coo`03003ooooo00Soo`03003ooooo00;o
o`03003ooooo00?oo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo00?o
o`03003ooooo00;oo`03003ooooo00Soo`03003ooooo00;oo`8000Coo`03003ooooo00Soo`800000
00D00?ooooooo`0000Coo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo
00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00?oo`03003ooooo00Koo`03003ooooo
00?oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo
00Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo
00?oo`03003ooooo00Koo`03003ooooo00?oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo
00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo
00;oo`03003ooooo00Coo`03003ooooo00?oo`03003ooooo00Koo`03003ooooo00?oo`03003ooooo
00Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo
00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00?oo`03003ooooo
00Koo`03003ooooo00?oo`03003ooooo00Coo`40000000<00?ooool03Ooo00@00?ooool001Goo`03
003ooooo01Koo`03003ooooo01?oo`04003ooooo000Eool00`00ooooo`0Fool00`00ooooo`0Cool0
1000ooooo`005Ooo00<00?ooool05_oo00<00?ooool04ooo00@00?ooool001Goo`03003ooooo01Ko
o`03003ooooo00;oo`40000000<00?oo00000_oo00<00?ooool00ooo00<00?ooool02_oo00<00?oo
ool00_oo00D00?ooooooo`0000Coo`03003ooooo00Koo`03003ooooo00;oo`04003ooooo0004ool0
0`00ooooo`06ool00`00ooooo`02ool01000ooooo`001Ooo00<00?ooool02_oo00<00?ooool00_oo
00D00?ooooooo`0000Coo`03003ooooo00Koo`03003ooooo00;oo`04003ooooo0004ool00`00oooo
o`06ool00`00ooooo`02ool01000ooooo`001Ooo00<00?ooool02_oo00<00?ooool00_oo00D00?oo
ooooo`0000Coo`03003ooooo00Koo`03003ooooo00;oo`04003ooooo0004ool00`00ooooo`06ool0
0`00ooooo`02ool01000ooooo`001Ooo00<00?ooool02_oo00<00?ooool00_oo00D00?ooooooo`00
00Coo`03003ooooo00Koo`03003ooooo00;oo`04003ooooo0004ool00`00ooooo`06ool10001ool1
00000003003ooooo00Coo`03003ooooo00;oo`03003ooooo00Ooo`03003ooooo00?oo`03003ooooo
00Coo`03003ooooo00Ooo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo
00Ooo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00Ooo`03003ooooo00?oo`03003ooooo
00Coo`03003ooooo00Ooo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo
00Ooo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00Ooo`03003ooooo00?oo`03003ooooo
00Coo`03003ooooo00Ooo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo
00Ooo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00Ooo`03003ooooo00?oo`03003ooooo
00Coo`03003ooooo00Ooo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo
00Koo`40000000<00?ooool03_oo0P005?oo0P006_oo00<00?ooool04ooo0P005?oo0P006_oo00<0
0?ooool04ooo0P005?oo0P006_oo00<00?ooool04ooo0P005?oo0P006_oo00@00?ooooooo`400000
0P001?oo0P001?oo00<00?ooool02?oo00<00?ooool00_oo0P001?oo00<00?ooool02?oo00<00?oo
ool00_oo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool02?oo00<00?ooool00_oo0P001?oo
00<00?ooool02?oo00<00?ooool00_oo0P001?oo00<00?ooool02?oo00<00?ooool00_oo00<00?oo
ool00ooo00<00?ooool00ooo00<00?ooool02?oo00<00?ooool00_oo0P001?oo00<00?ooool02?oo
00<00?ooool00_oo0P001?oo00<00?ooool02?oo00<00?ooool00_oo00<00?ooool00ooo00<00?oo
ool00ooo00<00?ooool02?oo00<00?ooool00_oo0P001?oo00<00?ooool02?oo00<00?ooool00_oo
0P001?oo00<00?ooool02?oo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool00ooo00<00?oo
ool01_oo0@0000000`00ool00008ool00`00ooooo`0:ool00`00ooooo`06ool00`00ooooo`03ool0
0`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool0
0`00ooooo`03ool00`00ooooo`06ool00`00ooooo`0:ool00`00ooooo`06ool00`00ooooo`03ool0
0`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool0
0`00ooooo`03ool00`00ooooo`06ool00`00ooooo`0:ool00`00ooooo`06ool00`00ooooo`03ool0
0`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool0
0`00ooooo`03ool00`00ooooo`06ool00`00ooooo`0:ool00`00ooooo`06ool00`00ooooo`03ool0
0`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool0
0`00ooooo`0100000003003ooooo00goo`04003ooooo000Eool01000ooooo`004_oo00@00?ooool0
01Goo`04003ooooo000Eool01000ooooo`004_oo00@00?ooool001Goo`04003ooooo000Eool01000
ooooo`004_oo00@00?ooool001Goo`04003ooooo000Eool01000ooooo`004_oo00@00?ooool000Co
o`40000000<00?ooool00_oo00@00?ooool000Coo`03003ooooo00Koo`03003ooooo00;oo`04003o
oooo0005ool00`00ooooo`0:ool00`00ooooo`06ool00`00ooooo`0:ool00`00ooooo`03ool01000
ooooo`001?oo00<00?ooool01_oo00<00?ooool00_oo00@00?ooool000Goo`03003ooooo00[oo`03
003ooooo00Koo`03003ooooo00[oo`03003ooooo00?oo`04003ooooo0004ool00`00ooooo`06ool0
0`00ooooo`02ool01000ooooo`001Ooo00<00?ooool02_oo00<00?ooool01_oo00<00?ooool02_oo
00<00?ooool00ooo00@00?ooool000Coo`03003ooooo00Koo`03003ooooo00;oo`04003ooooo0005
ool00`00ooooo`0:ool00`00ooooo`06ool00`00ooooo`0:ool100000004003ooooo0006ool00`00
ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00
ooooo`07ool00`00ooooo`03ool20005ool00`00ooooo`07ool00`00ooooo`02ool00`00ooooo`04
ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02
ool00`00ooooo`07ool00`00ooooo`03ool20005ool00`00ooooo`07ool00`00ooooo`02ool00`00
ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00
ooooo`02ool00`00ooooo`07ool00`00ooooo`03ool20005ool00`00ooooo`07ool00`00ooooo`02
ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04
ool00`00ooooo`02ool00`00ooooo`07ool00`00ooooo`03ool20005ool00`00ooooo`07ool20000
0003003ooooo02Ooo`8001Coo`80033oo`8001Coo`80033oo`8001Coo`80033oo`8001Coo`8000Go
o`40000000@00?ooool000Goo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00?oo`03003o
oooo00?oo`03003ooooo00;oo`03003ooooo00Soo`03003ooooo00;oo`8000Coo`03003ooooo00So
o`03003ooooo00;oo`03003ooooo00?oo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00?o
o`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00Soo`03003ooooo00;oo`8000Coo`03003o
oooo00Soo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo00?oo`03003ooooo00;oo`03003o
oooo00?oo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00Soo`03003ooooo00;oo`8000Co
o`03003ooooo00Soo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo00?oo`03003ooooo00;o
o`03003ooooo00?oo`03003ooooo00?oo`03003ooooo00;oo`03003ooooo00Soo`03003ooooo00;o
o`8000Coo`03003ooooo00Soo`80000000D00?ooooooo`0000Coo`03003ooooo00koo`03003ooooo
00;oo`03003ooooo02[oo`03003ooooo00;oo`03003ooooo00koo`03003ooooo00;oo`03003ooooo
02[oo`03003ooooo00;oo`03003ooooo00koo`03003ooooo00;oo`03003ooooo02[oo`03003ooooo
00;oo`03003ooooo00koo`03003ooooo00;oo`03003ooooo02Goo`40000000<00?ooool02ooo00<0
0?oo00000_oo00<00?oo00003_oo00<00?ooool00_oo00<00?oo00001Ooo00<00?ooool01_oo00<0
0?ooool00ooo00<00?oo00001?oo00<00?ooool03?oo00<00?oo00000_oo00<00?oo00003_oo00<0
0?ooool00_oo00<00?oo00001Ooo00<00?ooool01_oo00<00?ooool00ooo00<00?oo00001?oo00<0
0?ooool03?oo00<00?oo00000_oo00<00?oo00003_oo00<00?ooool00_oo00<00?oo00001Ooo00<0
0?ooool01_oo00<00?ooool00ooo00<00?oo00001?oo00<00?ooool03?oo00<00?oo00000_oo00<0
0?oo00003_oo00<00?ooool00_oo00<00?oo00001Ooo00<00?ooool01_oo00<00?ooool00ooo00<0
0?oo00001?oo0@0000000`00ool00008ool00`00ooooo`0:ool00`00ooooo`06ool00`00ooooo`02
ool00`00ooooo`06ool00`00ooooo`02ool01000ooooo`001?oo00<00?ooool01_oo00<00?ooool0
0_oo00<00?ooool01_oo00<00?ooool02_oo00<00?ooool01_oo00<00?ooool00_oo00<00?ooool0
1_oo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo00Koo`03003ooooo00;oo`03003ooooo
00Koo`03003ooooo00[oo`03003ooooo00Koo`03003ooooo00;oo`03003ooooo00Koo`03003ooooo
00;oo`04003ooooo0004ool00`00ooooo`06ool00`00ooooo`02ool00`00ooooo`06ool00`00oooo
o`0:ool00`00ooooo`06ool00`00ooooo`02ool00`00ooooo`06ool00`00ooooo`02ool01000oooo
o`001?oo00<00?ooool01_oo0@000Ooo0@0000000`00ooooo`02ool00`00ool0000Dool00`00ool0
000^ool00`00ool0000Dool00`00ool0000^ool00`00ool0000Dool00`00ool0000^ool00`00ool0
000Dool00`00ool0000Xool100000003003ooooo00[oo`04003oooooool20003ool00`00ooooo`0:
ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02
ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`0:ool01000oooooooo0P000ooo00<00?oo
ool02_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool01?oo00<00?oo
ool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool02_oo00@00?ooooooo`8000?oo`03
003ooooo00[oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03
003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00[oo`04003oooooool20003
ool00`00ooooo`0:ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04
ool00`00ooooo`02ool00`00ooooo`02ool01000oooooooo0@000002000:ool00`00ooooo`08ool0
0`00ooooo`08ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`03ool0
0`00ooooo`03ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`08ool00`00ooooo`08ool0
0`00ooooo`08ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`03ool0
0`00ooooo`03ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`08ool00`00ooooo`08ool0
0`00ooooo`08ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`03ool0
0`00ooooo`03ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`08ool00`00ooooo`08ool0
0`00ooooo`08ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`03ool0
0`00ooooo`03ool00`00ooooo`02ool01000oooooooo0@0000000`00ooooo`03ool2000Dool2000`
ool2000Dool2000`ool2000Dool2000`ool2000Dool2000Yool10000008000Woo`03003ooooo00;o
o`03003oo`0000Goo`03003ooooo00Koo`03003ooooo00?oo`03003ooooo00Coo`03003ooooo00;o
o`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00Oo
o`03003ooooo00;oo`03003oo`0000Goo`03003ooooo00Koo`03003ooooo00?oo`03003ooooo00Co
o`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;o
o`03003ooooo00Ooo`03003ooooo00;oo`03003oo`0000Goo`03003ooooo00Koo`03003ooooo00?o
o`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00Co
o`03003ooooo00;oo`03003ooooo00Ooo`03003ooooo00;oo`03003oo`0000Goo`03003ooooo00Ko
o`03003ooooo00?oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;o
o`03003ooooo00Coo`03003ooooo0040000000<00?ooool02_oo00<00?ooool01_oo00<00?ooool0
2ooo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo00Koo`03003ooooo00;oo`04003ooooo
0004ool00`00ooooo`0;ool00`00ooooo`06ool00`00ooooo`0;ool00`00ooooo`02ool01000oooo
o`001?oo00<00?ooool01_oo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo00_oo`03003o
oooo00Koo`03003ooooo00_oo`03003ooooo00;oo`04003ooooo0004ool00`00ooooo`06ool00`00
ooooo`02ool01000ooooo`001?oo00<00?ooool02ooo00<00?ooool01_oo00<00?ooool02ooo00<0
0?ooool00_oo00@00?ooool000Coo`03003ooooo00Koo`03003ooooo00;oo`04003ooooo0004ool1
00000003003ooooo00;oo`04003ooooo000Bool01000ooooo`00;_oo00@00?ooool001;oo`04003o
oooo000^ool01000ooooo`004_oo00@00?ooool002koo`04003ooooo000Bool01000ooooo`00:?oo
0@0000001000ooooo`001_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?oo
ool01?oo00<00?ooool00_oo00<00?ooool01ooo00<00?ooool00ooo0P001Ooo00<00?ooool01ooo
00<00?ooool00_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo
00<00?ooool01?oo00<00?ooool00_oo00<00?ooool01ooo00<00?ooool00ooo0P001Ooo00<00?oo
ool01ooo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool00_oo00<00?oo
ool00_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool01ooo00<00?ooool00ooo0P001Ooo
00<00?ooool01ooo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool00_oo
00<00?ooool00_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool01ooo00<00?ooool00ooo
0P001Ooo00<00?ooool01ooo0P0000000`00ooooo`0Wool2000Dool2000`ool2000Dool2000`ool2
000Dool2000`ool2000Dool20005ool100000004003ooooo0005ool00`00ooooo`03ool00`00oooo
o`02ool00`00ooooo`03ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`08ool00`00oooo
o`08ool00`00ooooo`08ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`03ool00`00oooo
o`02ool00`00ooooo`03ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`08ool00`00oooo
o`08ool00`00ooooo`08ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`03ool00`00oooo
o`02ool00`00ooooo`03ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`08ool00`00oooo
o`08ool00`00ooooo`08ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`03ool00`00oooo
o`02ool00`00ooooo`03ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`08ool00`00oooo
o`08ool00`00ooooo`08ool200000005003oooooool00004ool00`00ooooo`0>ool00`00ooooo`02
ool00`00ooooo`02ool00`00ooooo`0:ool01000oooooooo0P000ooo00<00?ooool02_oo00<00?oo
ool00_oo00<00?ooool00_oo00<00?ooool03_oo00<00?ooool00_oo00<00?ooool00_oo00<00?oo
ool02_oo00@00?ooooooo`8000?oo`03003ooooo00[oo`03003ooooo00;oo`03003ooooo00;oo`03
003ooooo00koo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00[oo`04003oooooool20003
ool00`00ooooo`0:ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`0>ool00`00ooooo`02
ool00`00ooooo`02ool00`00ooooo`0:ool01000oooooooo0P000ooo00<00?ooool02_oo0@000000
0`00ooooo`0;ool00`00ooooo`04ool00`00ooooo`0Aool00`00ool0000Dool00`00ool0000Cool0
0`00ooooo`04ool00`00ooooo`0Aool00`00ool0000Dool00`00ool0000Cool00`00ooooo`04ool0
0`00ooooo`0Aool00`00ool0000Dool00`00ool0000Cool00`00ooooo`04ool00`00ooooo`0Aool0
0`00ool0000Dool00`00ool00004ool100000003003oo`0000Soo`03003ooooo00;oo`04003ooooo
0004ool00`00ooooo`06ool00`00ooooo`02ool00`00ooooo`06ool00`00ooooo`0:ool00`00oooo
o`06ool00`00ooooo`02ool00`00ooooo`06ool00`00ooooo`02ool01000ooooo`001?oo00<00?oo
ool01_oo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool02_oo00<00?ooool01_oo00<00?oo
ool00_oo00<00?ooool01_oo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo00Koo`03003o
oooo00;oo`03003ooooo00Koo`03003ooooo00[oo`03003ooooo00Koo`03003ooooo00;oo`03003o
oooo00Koo`03003ooooo00;oo`04003ooooo0004ool00`00ooooo`06ool00`00ooooo`02ool00`00
ooooo`06ool00`00ooooo`0:ool00`00ooooo`06ool10001ool100000003003ooooo00;oo`03003o
o`0001Coo`03003oo`0000Coo`03003ooooo00coo`03003oo`0000;oo`03003oo`0000koo`03003o
oooo00;oo`03003oo`0001Coo`03003oo`0000Coo`03003ooooo00coo`03003oo`0000;oo`03003o
o`0000koo`03003ooooo00;oo`03003oo`0001Coo`03003oo`0000Coo`03003ooooo00coo`03003o
o`0000;oo`03003oo`0000koo`03003ooooo00;oo`03003oo`0001Coo`03003oo`0000Coo`03003o
oooo00coo`03003oo`0000;oo`03003oo`0000goo`40000000<00?ooool02_oo00<00?ooool01_oo
00<00?ooool03ooo00<00?ooool00_oo00<00?ooool03_oo00<00?ooool00_oo00<00?ooool03ooo
00<00?ooool01_oo00<00?ooool03ooo00<00?ooool00_oo00<00?ooool03_oo00<00?ooool00_oo
00<00?ooool03ooo00<00?ooool01_oo00<00?ooool03ooo00<00?ooool00_oo00<00?ooool03_oo
00<00?ooool00_oo00<00?ooool03ooo00<00?ooool01_oo00<00?ooool03ooo00<00?ooool00_oo
00<00?ooool03_oo00<00?ooool00_oo00@00?ooooooo`4000000P002_oo00<00?ooool00_oo0P00
1?oo00<00?ooool02?oo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool03_oo00<00?ooool0
0ooo00<00?ooool00_oo00<00?ooool02?oo00<00?ooool00_oo0P001?oo00<00?ooool02?oo00<0
0?ooool00_oo00<00?ooool00ooo00<00?ooool03_oo00<00?ooool00ooo00<00?ooool00_oo00<0
0?ooool02?oo00<00?ooool00_oo0P001?oo00<00?ooool02?oo00<00?ooool00_oo00<00?ooool0
0ooo00<00?ooool03_oo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool02?oo00<00?ooool0
0_oo0P001?oo00<00?ooool02?oo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool03_oo00<0
0?ooool00ooo00<00?ooool00@0000020004ool2000Dool20003ool00`00ooooo`0?ool00`00oooo
o`02ool00`00ooooo`0>ool00`00ooooo`02ool2000Dool20003ool00`00ooooo`0?ool00`00oooo
o`02ool00`00ooooo`0>ool00`00ooooo`02ool2000Dool20003ool00`00ooooo`0?ool00`00oooo
o`02ool00`00ooooo`0>ool00`00ooooo`02ool2000Dool20003ool00`00ooooo`0?ool00`00oooo
o`02ool00`00ooooo`0<ool100000003003ooooo00Soo`03003ooooo00[oo`03003ooooo01?oo`03
003ooooo00coo`03003ooooo01?oo`03003ooooo00[oo`03003ooooo01?oo`03003ooooo00coo`03
003ooooo01?oo`03003ooooo00[oo`03003ooooo01?oo`03003ooooo00coo`03003ooooo01?oo`03
003ooooo00[oo`03003ooooo01?oo`03003ooooo00coo`03003ooooo00Ooo`40000000<00?ooool0
2_oo00H00?ooool00?oo0003ool00`00ooooo`0:ool01`00oooooooo003oo`0000;oo`03003ooooo
013oo`06003ooooo003oo`004?oo00H00?ooool00?oo0003ool00`00ooooo`0:ool01`00oooooooo
003oo`0000;oo`03003ooooo013oo`06003ooooo003oo`004?oo00H00?ooool00?oo0003ool00`00
ooooo`0>ool00`00ool00002ool00`00ooooo`0@ool01P00ooooo`00ool0013oo`06003ooooo003o
o`000ooo00<00?ooool02_oo00L00?ooooooo`00ool00002ool00`00ooooo`0@ool01P00ooooo`00
ool000;oo`400000o`008@0000001P00ooooo`00ool000Coo`03003ooooo00coo`03003ooooo00;o
o`03003oo`0000koo`03003ooooo00;oo`03003oo`0000Goo`03003ooooo00coo`03003oo`0000Co
o`03003ooooo00coo`03003ooooo00;oo`03003oo`0000koo`03003ooooo00;oo`03003oo`0000Go
o`03003ooooo00coo`03003oo`0000Coo`03003ooooo00coo`03003ooooo00;oo`03003oo`0000ko
o`03003ooooo00;oo`03003oo`0000Goo`03003ooooo00coo`03003oo`0000Coo`03003ooooo00co
o`03003ooooo00;oo`03003oo`0000koo`03003ooooo00;oo`03003oo`0000Goo`03003ooooo00So
o`40000000<00?ooool03?oo00<00?ooool00_oo00<00?ooool03_oo00<00?ooool00_oo0P005?oo
0P000ooo00<00?ooool03ooo00<00?ooool00_oo00<00?ooool03_oo00<00?ooool00_oo0P005?oo
0P000ooo00<00?ooool03ooo00<00?ooool00_oo00<00?ooool03_oo00<00?ooool00_oo0P005?oo
0P000ooo00<00?ooool03ooo00<00?ooool00_oo00<00?ooool03_oo00<00?ooool00_oo0P005?oo
0P000ooo0@000Ooo0@0000000`00ooooo`06ool00`00ooooo`0>ool00`00ooooo`08ool00`00oooo
o`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`0>ool00`00oooo
o`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00oooo
o`0>ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00oooo
o`08ool00`00ooooo`0>ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`08ool00`00oooo
o`08ool200000003003ooooo008000Coo`03003ooooo00koo`03003ooooo00;oo`80013oo`04003o
ooooool20003ool00`00ooooo`0>ool20004ool00`00ooooo`0>ool00`00ooooo`02ool2000@ool0
1000oooooooo0P000ooo00<00?ooool03_oo0P001?oo00<00?ooool03_oo00<00?ooool00_oo0P00
4?oo00@00?ooooooo`8000?oo`03003ooooo00koo`8000Coo`03003ooooo00koo`03003ooooo00;o
o`80013oo`04003oooooool20003ool00`00ooooo`0:ool100000003003ooooo00_oo`03003oo`00
00;oo`03003oo`0000koo`03003ooooo00;oo`03003oo`0001Coo`03003oo`0000Coo`03003ooooo
00coo`03003oo`0000;oo`03003oo`0000koo`03003ooooo00;oo`03003oo`0001Coo`03003oo`00
00Coo`03003ooooo00coo`03003oo`0000;oo`03003oo`0000koo`03003ooooo00;oo`03003oo`00
01Coo`03003oo`0000Coo`03003ooooo00coo`03003oo`0000;oo`03003oo`0000koo`03003ooooo
00;oo`03003oo`0001Coo`03003oo`0000Coo`40000000<00?ooool02?oo00<00?ooool02_oo00<0
0?ooool02ooo00<00?ooool01_oo00<00?ooool02_oo00<00?ooool01_oo00<00?ooool02ooo00<0
0?ooool02_oo00<00?ooool02ooo00<00?ooool01_oo00<00?ooool02_oo00<00?ooool01_oo00<0
0?ooool02ooo00<00?ooool02_oo00<00?ooool02ooo00<00?ooool01_oo00<00?ooool02_oo00<0
0?ooool01_oo00<00?ooool02ooo00<00?ooool02_oo00<00?ooool02ooo00<00?ooool01_oo00<0
0?ooool02_oo00<00?ooool01_oo0@000Ooo0@0000000`00ool00002ool00`00ool0000Dool00`00
ool00002ool00`00ooooo`0>ool00`00ool00002ool00`00ool0000@ool01P00ooooo`00ool001Co
o`03003oo`0000;oo`03003ooooo00koo`03003oo`0000;oo`03003oo`00013oo`06003ooooo003o
o`005?oo00<00?oo00000_oo00<00?ooool03_oo00<00?oo00000_oo00<00?oo00004?oo00H00?oo
ool00?oo000Dool00`00ool00002ool00`00ooooo`0>ool00`00ool00002ool00`00ool0000=ool1
00000003003ooooo00[oo`04003oooooool20003ool00`00ooooo`0:ool00`00ooooo`02ool00`00
ooooo`02ool00`00ooooo`0>ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`0:ool01000
oooooooo0P000ooo00<00?ooool02_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool03_oo
00<00?ooool00_oo00<00?ooool00_oo00<00?ooool02_oo00@00?ooooooo`8000?oo`03003ooooo
00[oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00koo`03003ooooo00;oo`03003ooooo
00;oo`03003ooooo00[oo`04003oooooool20003ool00`00ooooo`0:ool00`00ooooo`02ool00`00
ooooo`02ool00`00ooooo`0>ool00`00ooooo`02ool01000oooooooo0@0000000`00ooooo`0Tool0
0`00ooooo`03ool00`00ooooo`0>ool00`00ooooo`03ool00`00ooooo`0Xool00`00ooooo`03ool0
0`00ooooo`0>ool00`00ooooo`03ool00`00ooooo`0Xool00`00ooooo`03ool00`00ooooo`0>ool0
0`00ooooo`03ool00`00ooooo`0Xool00`00ooooo`03ool00`00ooooo`0>ool00`00ooooo`03ool0
0`00ooooo`010000008000Coo`8000Coo`03003ooooo00Soo`03003ooooo00;oo`8000Coo`03003o
oooo00koo`03003ooooo00;oo`03003ooooo00koo`03003ooooo00;oo`8000Coo`03003ooooo00So
o`03003ooooo00;oo`8000Coo`03003ooooo00koo`03003ooooo00;oo`03003ooooo00koo`03003o
oooo00;oo`8000Coo`03003ooooo00Soo`03003ooooo00;oo`8000Coo`03003ooooo00koo`03003o
oooo00;oo`03003ooooo00koo`03003ooooo00;oo`8000Coo`03003ooooo00Soo`03003ooooo00;o
o`8000Coo`03003ooooo00koo`03003ooooo00;oo`03003ooooo00coo`4000000P002Ooo00<00?oo
ool02_oo00<00?ooool01ooo00<00?ooool03_oo00<00?ooool00_oo00<00?ooool03_oo00<00?oo
ool01ooo00<00?ooool02_oo00<00?ooool01ooo00<00?ooool03_oo00<00?ooool00_oo00<00?oo
ool03_oo00<00?ooool01ooo00<00?ooool02_oo00<00?ooool01ooo00<00?ooool03_oo00<00?oo
ool00_oo00<00?ooool03_oo00<00?ooool01ooo00<00?ooool02_oo00<00?ooool01ooo00<00?oo
ool03_oo00<00?ooool00_oo00<00?ooool03?oo0@0000000`00ooooo`0>ool2000Dool00`00ool0
0002ool00`00ool0000>ool00`00ool00002ool00`00ool0000Dool2000Dool00`00ool00002ool0
0`00ool0000>ool00`00ool00002ool00`00ool0000Dool2000Dool00`00ool00002ool00`00ool0
000>ool00`00ool00002ool00`00ool0000Dool2000Dool00`00ool00002ool00`00ool0000>ool0
0`00ool00002ool00`00ool00002ool100000003003ooooo00;oo`04003ooooo0004ool00`00oooo
o`06ool00`00ooooo`02ool01000ooooo`001?oo00<00?ooool02ooo00<00?ooool01_oo00<00?oo
ool02ooo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo00Koo`03003ooooo00;oo`04003o
oooo0004ool00`00ooooo`0;ool00`00ooooo`06ool00`00ooooo`0;ool00`00ooooo`02ool01000
ooooo`001?oo00<00?ooool01_oo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo00_oo`03
003ooooo00Koo`03003ooooo00_oo`03003ooooo00;oo`04003ooooo0004ool00`00ooooo`06ool0
0`00ooooo`02ool01000ooooo`001?oo00<00?ooool02ooo00<00?ooool01_oo00<00?ooool02_oo
0@0000001000ooooo`001_oo00<00?ooool03?oo00<00?ooool01?oo00<00?ooool04Ooo00<00?oo
00005?oo00<00?ooool01?oo00<00?ooool03?oo00<00?ooool01?oo00<00?ooool04Ooo00<00?oo
00005?oo00<00?ooool01?oo00<00?ooool03?oo00<00?ooool01?oo00<00?ooool04Ooo00<00?oo
00005?oo00<00?ooool01?oo00<00?ooool03?oo00<00?ooool01?oo00<00?ooool04Ooo00<00?oo
00004?oo0@0000000`00ooooo`0<ool00`00ooooo`02ool00`00ooooo`0>ool00`00ooooo`02ool2
0003ool00`00ooooo`0:ool01000oooooooo0P000ooo00<00?ooool03ooo00<00?ooool00_oo00<0
0?ooool03_oo00<00?ooool00_oo0P000ooo00<00?ooool02_oo00@00?ooooooo`8000?oo`03003o
oooo00ooo`03003ooooo00;oo`03003ooooo00koo`03003ooooo00;oo`8000?oo`03003ooooo00[o
o`04003oooooool20003ool00`00ooooo`0?ool00`00ooooo`02ool00`00ooooo`0>ool00`00oooo
o`02ool20003ool00`00ooooo`0:ool01000oooooooo0P000ooo0@000Ooo0@0000001000ooooo`00
1Ooo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool0
0ooo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool00_oo00<00?ooool0
0ooo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool0
0ooo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool00_oo00<00?ooool0
0ooo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool0
0ooo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool00_oo00<00?ooool0
0ooo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool0
0ooo00<00?ooool02?oo00<00?ooool02?oo00<00?ooool02?oo0P0000001@00oooooooo00001?oo
00<00?ooool03_oo00<00?ooool00_oo00<00?ooool04ooo0P005Ooo00<00?ooool00_oo00<00?oo
ool03_oo00<00?ooool00_oo00<00?ooool04ooo0P005Ooo00<00?ooool00_oo00<00?ooool03_oo
00<00?ooool00_oo00<00?ooool04ooo0P005Ooo00<00?ooool00_oo00<00?ooool03_oo00<00?oo
ool00_oo00<00?ooool04ooo0P004?oo0@0000000`00ooooo`0;ool00`00ooooo`04ool00`00oooo
o`0<ool00`00ooooo`02ool00`00ool00005ool00`00ooooo`06ool00`00ooooo`03ool00`00ool0
0004ool00`00ooooo`0<ool00`00ooooo`04ool00`00ooooo`0<ool00`00ooooo`02ool00`00ool0
0005ool00`00ooooo`06ool00`00ooooo`03ool00`00ool00004ool00`00ooooo`0<ool00`00oooo
o`04ool00`00ooooo`0<ool00`00ooooo`02ool00`00ool00005ool00`00ooooo`06ool00`00oooo
o`03ool00`00ool00004ool00`00ooooo`0<ool00`00ooooo`04ool00`00ooooo`0<ool00`00oooo
o`02ool00`00ool00005ool00`00ooooo`06ool00`00ooooo`03ool00`00ool00004ool100000003
003oo`0000Soo`03003ooooo00;oo`04003ooooo0004ool00`00ooooo`06ool00`00ooooo`02ool0
0`00ooooo`06ool00`00ooooo`0:ool00`00ooooo`06ool00`00ooooo`02ool00`00ooooo`06ool0
0`00ooooo`02ool01000ooooo`001?oo00<00?ooool01_oo00<00?ooool00_oo00<00?ooool01_oo
00<00?ooool02_oo00<00?ooool01_oo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool00_oo
00@00?ooool000Coo`03003ooooo00Koo`03003ooooo00;oo`03003ooooo00Koo`03003ooooo00[o
o`03003ooooo00Koo`03003ooooo00;oo`03003ooooo00Koo`03003ooooo00;oo`04003ooooo0004
ool00`00ooooo`06ool00`00ooooo`02ool00`00ooooo`06ool00`00ooooo`0:ool00`00ooooo`06
ool10001ool100000003003ooooo00;oo`03003oo`0001Coo`03003oo`0001Goo`04003ooooo000E
ool00`00ool0000Dool00`00ool0000Eool01000ooooo`005Ooo00<00?oo00005?oo00<00?oo0000
5Ooo00@00?ooool001Goo`03003oo`0001Coo`03003oo`0001Goo`04003ooooo000?ool100000003
003ooooo00[oo`03003ooooo00Koo`03003ooooo00[oo`03003ooooo00;oo`03003ooooo00;oo`03
003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03
003ooooo00[oo`03003ooooo00Koo`03003ooooo00[oo`03003ooooo00;oo`03003ooooo00;oo`03
003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03
003ooooo00[oo`03003ooooo00Koo`03003ooooo00[oo`03003ooooo00;oo`03003ooooo00;oo`03
003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03
003ooooo00[oo`03003ooooo00Koo`03003ooooo00[oo`03003ooooo00;oo`03003ooooo00;oo`03
003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;oo`04003oooooool10000
0003003ooooo00koo`8001Coo`03003ooooo00?oo`03003ooooo00koo`03003ooooo00?oo`03003o
oooo01;oo`8001Coo`03003ooooo00?oo`03003ooooo00koo`03003ooooo00?oo`03003ooooo01;o
o`8001Coo`03003ooooo00?oo`03003ooooo00koo`03003ooooo00?oo`03003ooooo01;oo`8001Co
o`03003ooooo00?oo`03003ooooo00koo`03003ooooo00?oo`03003ooooo004000000P001?oo0P00
1?oo00<00?ooool02?oo00<00?ooool00_oo0P001?oo00<00?ooool03_oo00<00?ooool00_oo00<0
0?ooool03_oo00<00?ooool00_oo0P001?oo00<00?ooool02?oo00<00?ooool00_oo0P001?oo00<0
0?ooool03_oo00<00?ooool00_oo00<00?ooool03_oo00<00?ooool00_oo0P001?oo00<00?ooool0
2?oo00<00?ooool00_oo0P001?oo00<00?ooool03_oo00<00?ooool00_oo00<00?ooool03_oo00<0
0?ooool00_oo0P001?oo00<00?ooool02?oo00<00?ooool00_oo0P001?oo00<00?ooool03_oo00<0
0?ooool00_oo00<00?ooool03?oo0@0000020009ool00`00ooooo`03ool20005ool00`00ooooo`07
ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02
ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`07ool00`00ooooo`03ool20005ool00`00
ooooo`07ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00
ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`07ool00`00ooooo`03ool20005
ool00`00ooooo`07ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02
ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`07ool00`00ooooo`03
ool20005ool00`00ooooo`07ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00
ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`0100000003003ooooo02Koo`04
003ooooo000Bool01000ooooo`00;_oo00@00?ooool001;oo`04003ooooo000^ool01000ooooo`00
4_oo00@00?ooool002koo`04003ooooo000Bool01000ooooo`001?oo0@0000000`00ooooo`02ool0
1000ooooo`001?oo00<00?ooool01_oo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo00_o
o`04003ooooo0002ool01000ooooo`003Ooo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo
00Koo`03003ooooo00;oo`04003ooooo0004ool00`00ooooo`0;ool01000ooooo`000_oo00@00?oo
ool000goo`03003ooooo00;oo`04003ooooo0004ool00`00ooooo`06ool00`00ooooo`02ool01000
ooooo`001?oo00<00?ooool02ooo00@00?ooool000;oo`04003ooooo000=ool00`00ooooo`02ool0
1000ooooo`001?oo00<00?ooool01_oo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo00_o
o`04003ooooo0002ool01000ooooo`003?oo0@0000001000ooooo`001_oo00<00?ooool00_oo00<0
0?ooool00_oo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool01_oo00<0
0?ooool02_oo00<00?ooool01_oo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool00_oo00<0
0?ooool00_oo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool01_oo00<0
0?ooool02_oo00<00?ooool01_oo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool00_oo00<0
0?ooool00_oo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool01_oo00<0
0?ooool02_oo00<00?ooool01_oo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool00_oo00<0
0?ooool00_oo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool00ooo00<00?ooool01_oo00<0
0?ooool02_oo00<00?ooool01_oo0@000Ooo0@0000000`00ooooo`0;ool00`00ooooo`03ool00`00
ooooo`0Cool2000Dool2000Dool00`00ooooo`03ool00`00ooooo`0Cool2000Dool2000Dool00`00
ooooo`03ool00`00ooooo`0Cool2000Dool2000Dool00`00ooooo`03ool00`00ooooo`0Cool2000D
ool20005ool100000003003ooooo008000Coo`03003ooooo00koo`03003ooooo00;oo`03003ooooo
00?oo`03003ooooo00Soo`03003ooooo00;oo`8000Coo`03003ooooo00Soo`03003ooooo00;oo`80
00Coo`03003ooooo00koo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo00Soo`03003ooooo
00;oo`8000Coo`03003ooooo00Soo`03003ooooo00;oo`8000Coo`03003ooooo00koo`03003ooooo
00;oo`03003ooooo00?oo`03003ooooo00Soo`03003ooooo00;oo`8000Coo`03003ooooo00Soo`03
003ooooo00;oo`8000Coo`03003ooooo00koo`03003ooooo00;oo`03003ooooo00?oo`03003ooooo
00Soo`03003ooooo00;oo`8000Coo`03003ooooo00Soo`80000000<00?ooool01_oo00<00?ooool0
0_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool01ooo00<00?ooool01?oo00<00?ooool0
0_oo00<00?ooool01ooo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool01ooo00<00?ooool0
0_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool01ooo00<00?ooool01?oo00<00?ooool0
0_oo00<00?ooool01ooo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool01ooo00<00?ooool0
0_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool01ooo00<00?ooool01?oo00<00?ooool0
0_oo00<00?ooool01ooo00<00?ooool00ooo00<00?ooool01?oo00<00?ooool01ooo00<00?ooool0
0_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool01ooo00<00?ooool01?oo00<00?ooool0
0_oo00<00?ooool01ooo00<00?ooool00ooo00<00?ooool01?oo0@0000000`00ooooo`0=ool01000
ooooo`004_oo00@00?ooool001Ooo`05003oooooool0000Bool01000ooooo`004_oo00@00?ooool0
01Ooo`05003oooooool0000Bool01000ooooo`004_oo00@00?ooool001Ooo`05003oooooool0000B
ool01000ooooo`004_oo00@00?ooool001Ooo`06003oooooool00?oo0@0000000`00ool00002ool0
0`00ooooo`03ool00`00ooooo`0:ool00`00ooooo`03ool01000ooooo`003Ooo00<00?ooool00_oo
00@00?ooool000Coo`03003ooooo00_oo`04003ooooo0005ool00`00ooooo`0:ool00`00ooooo`03
ool01000ooooo`003Ooo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo00_oo`04003ooooo
0005ool00`00ooooo`0:ool00`00ooooo`03ool01000ooooo`003Ooo00<00?ooool00_oo00@00?oo
ool000Coo`03003ooooo00_oo`04003ooooo0005ool00`00ooooo`0:ool00`00ooooo`03ool01000
ooooo`003Ooo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo00Soo`40000000<00?ooool0
1?oo00<00?ooool04_oo00<00?ooool01?oo00<00?ooool03?oo00<00?ooool01?oo00<00?ooool0
3?oo00<00?ooool01?oo00<00?ooool04_oo00<00?ooool01?oo00<00?ooool03?oo00<00?ooool0
1?oo00<00?ooool03?oo00<00?ooool01?oo00<00?ooool04_oo00<00?ooool01?oo00<00?ooool0
3?oo00<00?ooool01?oo00<00?ooool03?oo00<00?ooool01?oo00<00?ooool04_oo00<00?ooool0
1?oo00<00?ooool03?oo00<00?ooool01?oo00<00?ooool02ooo0@0000000`00ooooo`0:ool01000
oooooooo0P000ooo00<00?ooool03_oo0P001?oo00<00?ooool03_oo00<00?ooool00_oo0P004?oo
00@00?ooooooo`8000?oo`03003ooooo00koo`8000Coo`03003ooooo00koo`03003ooooo00;oo`80
013oo`04003oooooool20003ool00`00ooooo`0>ool20004ool00`00ooooo`0>ool00`00ooooo`02
ool2000@ool01000oooooooo0P000ooo00<00?ooool03_oo0P001?oo00<00?ooool03_oo00<00?oo
ool00_oo0P000_oo0@0000020004ool20004ool00`00ooooo`08ool00`00ooooo`02ool20004ool0
0`00ooooo`0>ool00`00ooooo`02ool00`00ooooo`0>ool00`00ooooo`02ool20004ool00`00oooo
o`08ool00`00ooooo`02ool20004ool00`00ooooo`0>ool00`00ooooo`02ool00`00ooooo`0>ool0
0`00ooooo`02ool20004ool00`00ooooo`08ool00`00ooooo`02ool20004ool00`00ooooo`0>ool0
0`00ooooo`02ool00`00ooooo`0>ool00`00ooooo`02ool20004ool00`00ooooo`08ool00`00oooo
o`02ool20004ool00`00ooooo`0>ool00`00ooooo`02ool00`00ooooo`0<ool10000008000Woo`03
003ooooo00[oo`03003ooooo00Ooo`03003ooooo00Woo`03003ooooo00coo`03003ooooo00Woo`03
003ooooo00Ooo`03003ooooo00[oo`03003ooooo00Ooo`03003ooooo00Woo`03003ooooo00coo`03
003ooooo00Woo`03003ooooo00Ooo`03003ooooo00[oo`03003ooooo00Ooo`03003ooooo00Woo`03
003ooooo00coo`03003ooooo00Woo`03003ooooo00Ooo`03003ooooo00[oo`03003ooooo00Ooo`03
003ooooo00Woo`03003ooooo00coo`03003ooooo00Ooo`40000000<00?ooool02_oo00@00?oooooo
o`8000?oo`03003ooooo00koo`03003oo`0000;oo`03003ooooo013oo`06003ooooo003oo`004?oo
00@00?ooooooo`8000?oo`03003ooooo00koo`03003oo`0000;oo`03003ooooo013oo`06003ooooo
003oo`004?oo00@00?ooooooo`8000?oo`03003ooooo00koo`03003oo`0000;oo`03003ooooo013o
o`06003ooooo003oo`004?oo00@00?ooooooo`8000?oo`03003ooooo00koo`03003oo`0000;oo`03
003ooooo013oo`06003ooooo003oo`000_oo0@0000001P00ooooo`00ool000;oo`03003ooooo013o
o`06003ooooo003oo`000_oo00<00?ooool02ooo00@00?ooool000;oo`04003ooooo000=ool01P00
ooooo`00ool000;oo`03003ooooo013oo`06003ooooo003oo`000_oo00<00?ooool02ooo00@00?oo
ool000;oo`04003ooooo000=ool01P00ooooo`00ool000;oo`03003ooooo013oo`06003ooooo003o
o`000_oo00<00?ooool02ooo00@00?ooool000;oo`04003ooooo000=ool01P00ooooo`00ool000;o
o`03003ooooo013oo`06003ooooo003oo`000_oo00<00?ooool02ooo00@00?ooool000;oo`04003o
oooo000<ool100000003003ooooo00Ooo`03003ooooo00coo`03003ooooo00[oo`03003ooooo00Ko
o`03003ooooo00[oo`03003ooooo00Koo`03003ooooo00[oo`03003ooooo00coo`03003ooooo00[o
o`03003ooooo00Koo`03003ooooo00[oo`03003ooooo00Koo`03003ooooo00[oo`03003ooooo00co
o`03003ooooo00[oo`03003ooooo00Koo`03003ooooo00[oo`03003ooooo00Koo`03003ooooo00[o
o`03003ooooo00coo`03003ooooo00[oo`03003ooooo00Koo`03003ooooo00[oo`03003ooooo00Ko
o`40007oo`40000000<00?ooool02ooo0P001?oo0P003ooo00<00?ooool00_oo0P001?oo00<00?oo
ool02?oo00<00?ooool00_oo0P001?oo00<00?ooool03Ooo0P001?oo0P003ooo00<00?ooool00_oo
0P001?oo00<00?ooool02?oo00<00?ooool00_oo0P001?oo00<00?ooool03Ooo0P001?oo0P003ooo
00<00?ooool00_oo0P001?oo00<00?ooool02?oo00<00?ooool00_oo0P001?oo00<00?ooool03Ooo
0P001?oo0P003ooo00<00?ooool00_oo0P001?oo00<00?ooool02?oo00<00?ooool00_oo0P001?oo
0P0000001@00oooooooo00001?oo00<00?ooool03_oo00<00?ooool00_oo00<00?ooool03_oo00<0
0?ooool00_oo0P000ooo00<00?ooool03ooo00<00?ooool00_oo00<00?ooool03_oo00<00?ooool0
0_oo00<00?ooool03_oo00<00?ooool00_oo0P000ooo00<00?ooool03ooo00<00?ooool00_oo00<0
0?ooool03_oo00<00?ooool00_oo00<00?ooool03_oo00<00?ooool00_oo0P000ooo00<00?ooool0
3ooo00<00?ooool00_oo00<00?ooool03_oo00<00?ooool00_oo00<00?ooool03_oo00<00?ooool0
0_oo0P000ooo00<00?ooool02_oo0@0000000`00ooooo`0;ool00`00ooooo`04ool00`00ooooo`0<
ool00`00ooooo`04ool00`00ooooo`0Bool00`00ooooo`04ool00`00ooooo`0<ool00`00ooooo`04
ool00`00ooooo`0<ool00`00ooooo`04ool00`00ooooo`0Bool00`00ooooo`04ool00`00ooooo`0<
ool00`00ooooo`04ool00`00ooooo`0<ool00`00ooooo`04ool00`00ooooo`0Bool00`00ooooo`04
ool00`00ooooo`0<ool00`00ooooo`04ool00`00ooooo`0<ool00`00ooooo`04ool00`00ooooo`0B
ool00`00ooooo`04ool100000003003oo`0000Ooo`03003ooooo00?oo`04003ooooo0004ool00`00
ooooo`06ool00`00ooooo`02ool01000ooooo`001Ooo00<00?ooool02_oo00<00?ooool00_oo00D0
0?ooooooo`0000Coo`03003ooooo00Goo`03003ooooo00?oo`04003ooooo0004ool00`00ooooo`06
ool00`00ooooo`02ool01000ooooo`001Ooo00<00?ooool02_oo00<00?ooool00_oo00D00?oooooo
o`0000Coo`03003ooooo00Goo`03003ooooo00?oo`04003ooooo0004ool00`00ooooo`06ool00`00
ooooo`02ool01000ooooo`001Ooo00<00?ooool02_oo00<00?ooool00_oo00D00?ooooooo`0000Co
o`03003ooooo00Goo`03003ooooo00?oo`04003ooooo0004ool00`00ooooo`06ool00`00ooooo`02
ool01000ooooo`001Ooo00<00?ooool02_oo00<00?ooool00_oo00H00?ooooooo`00ool100000003
003ooooo00;oo`03003oo`0001?oo`04003ooooo000Eool01000ooooo`005Ooo00<00?oo00004ooo
00@00?ooool001Goo`04003ooooo000Eool00`00ool0000Cool01000ooooo`005Ooo00@00?ooool0
01Goo`03003oo`0001?oo`04003ooooo000Eool01000ooooo`003ooo0@0000000`00ooooo`0:ool0
1000oooooooo0P000ooo00<00?ooool02_oo00@00?ooooooo`8000Coo`03003ooooo00;oo`03003o
oooo00Coo`03003ooooo00;oo`03003ooooo00;oo`8000?oo`03003ooooo00[oo`04003oooooool2
0003ool00`00ooooo`0:ool01000oooooooo0P001?oo00<00?ooool00_oo00<00?ooool01?oo00<0
0?ooool00_oo00<00?ooool00_oo0P000ooo00<00?ooool02_oo00@00?ooooooo`8000?oo`03003o
oooo00[oo`04003oooooool20004ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool0
0`00ooooo`02ool20003ool00`00ooooo`0:ool01000oooooooo0P000ooo00<00?ooool02_oo00@0
0?ooooooo`8000Coo`03003ooooo00;oo`03003ooooo00Coo`03003ooooo00;oo`03003ooooo00;o
o`8000;oo`4000000P001?oo0P001?oo00<00?ooool02?oo00<00?ooool00_oo0P001?oo00<00?oo
ool02?oo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool02?oo00<00?oo
ool00_oo0P001?oo00<00?ooool02?oo00<00?ooool00_oo0P001?oo00<00?ooool02?oo00<00?oo
ool00ooo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool02?oo00<00?ooool00_oo0P001?oo
00<00?ooool02?oo00<00?ooool00_oo0P001?oo00<00?ooool02?oo00<00?ooool00ooo00<00?oo
ool00_oo00<00?ooool00ooo00<00?ooool02?oo00<00?ooool00_oo0P001?oo00<00?ooool02?oo
00<00?ooool00_oo0P001?oo00<00?ooool02?oo00<00?ooool00ooo00<00?ooool00_oo00<00?oo
ool00ooo00<00?ooool01_oo0@0000020009ool00`00ooooo`0:ool00`00ooooo`07ool00`00oooo
o`0>ool00`00ooooo`02ool00`00ooooo`0>ool00`00ooooo`07ool00`00ooooo`0:ool00`00oooo
o`07ool00`00ooooo`0>ool00`00ooooo`02ool00`00ooooo`0>ool00`00ooooo`07ool00`00oooo
o`0:ool00`00ooooo`07ool00`00ooooo`0>ool00`00ooooo`02ool00`00ooooo`0>ool00`00oooo
o`07ool00`00ooooo`0:ool00`00ooooo`07ool00`00ooooo`0>ool00`00ooooo`02ool00`00oooo
o`0<ool100000003003ooooo00[oo`04003oooooool20003ool00`00ooooo`0:ool01`00oooooooo
003oo`0000;oo`03003oo`0000koo`03003oo`0000;oo`03003oo`0000?oo`03003ooooo00[oo`04
003oooooool20003ool00`00ooooo`0:ool01`00oooooooo003oo`0000;oo`03003oo`0000koo`03
003oo`0000;oo`03003oo`0000?oo`03003ooooo00[oo`04003oooooool20003ool00`00ooooo`0:
ool01`00oooooooo003oo`0000;oo`03003oo`0000koo`03003oo`0000;oo`03003oo`0000?oo`03
003ooooo00[oo`04003oooooool20003ool00`00ooooo`0:ool01`00oooooooo003oo`0000;oo`03
003oo`0000koo`03003oo`0000;oo`03003oo`0000;oo`40000000H00?ooool00?oo0002ool00`00
ool0000>ool00`00ool00002ool00`00ool0000@ool01000ooooo`000_oo00@00?ooool0013oo`03
003oo`0000;oo`03003oo`0000koo`03003oo`0000;oo`03003oo`00013oo`04003ooooo0002ool0
1000ooooo`004?oo00<00?oo00000_oo00<00?oo00003_oo00<00?oo00000_oo00<00?oo00004?oo
00@00?ooool000;oo`04003ooooo000@ool00`00ool00002ool00`00ool0000>ool00`00ool00002
ool00`00ool0000@ool01000ooooo`000_oo00@00?ooool000coo`40000000<00?ooool03?oo00<0
0?ooool00_oo00<00?ooool03ooo00<00?ooool01_oo00<00?ooool02_oo00<00?ooool01_oo00<0
0?ooool03ooo00<00?ooool00_oo00<00?ooool03ooo00<00?ooool01_oo00<00?ooool02_oo00<0
0?ooool01_oo00<00?ooool03ooo00<00?ooool00_oo00<00?ooool03ooo00<00?ooool01_oo00<0
0?ooool02_oo00<00?ooool01_oo00<00?ooool03ooo00<00?ooool00_oo00<00?ooool03ooo00<0
0?ooool01_oo00<00?ooool02_oo00<00?ooool01_oo0@000Ooo0@0000001@00oooooooo00001?oo
00<00?ooool00_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00ooo
00<00?ooool00_oo0P001?oo00<00?ooool02?oo00<00?ooool00_oo0P001?oo00<00?ooool00ooo
00<00?ooool00_oo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool00_oo
00<00?ooool00ooo00<00?ooool00_oo0P001?oo00<00?ooool02?oo00<00?ooool00_oo0P001?oo
00<00?ooool00ooo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool00_oo
00<00?ooool00_oo00<00?ooool00ooo00<00?ooool00_oo0P001?oo00<00?ooool02?oo00<00?oo
ool00_oo0P001?oo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool01?oo
00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00ooo00<00?ooool00_oo0P001?oo00<00?oo
ool02?oo00<00?ooool00_oo0P001?oo0P0000001@00oooooooo00001?oo00<00?ooool00_oo00<0
0?ooool01?oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool01?oo00<0
0?ooool00_oo00<00?ooool00_oo0P001?oo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool0
0_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool0
0_oo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool00_oo0P001?oo00<0
0?ooool00_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<0
0?ooool01?oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool01?oo00<0
0?ooool00_oo00<00?ooool00_oo0P001?oo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool0
0_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool0
0_oo00<00?ooool00_oo00<00?ooool01?oo00<00?ooool00_oo00<00?ooool00_oo0P001?oo00<0
0?ooool00_oo00<00?ooool01?oo0@0000000`00ooooo`0=ool01000ooooo`004_oo00D00?oooooo
o`0000Coo`03003ooooo00[oo`03003ooooo00;oo`05003oooooool0000Bool01000ooooo`004_oo
00D00?ooooooo`0000Coo`03003ooooo00[oo`03003ooooo00;oo`05003oooooool0000Bool01000
ooooo`004_oo00D00?ooooooo`0000Coo`03003ooooo00[oo`03003ooooo00;oo`05003oooooool0
000Bool01000ooooo`004_oo00D00?ooooooo`0000Coo`03003ooooo00[oo`03003ooooo00;oo`06
003oooooool00?oo0@0000000`00ool00002ool00`00ool00002ool00`00ooooo`0;ool01000oooo
o`000_oo00H00?ooool00?oo000>ool00`00ool00002ool00`00ool0000>ool00`00ool00002ool0
0`00ool00002ool00`00ooooo`0;ool01000ooooo`000_oo00H00?ooool00?oo000>ool00`00ool0
0002ool00`00ool0000>ool00`00ool00002ool00`00ool00002ool00`00ooooo`0;ool01000oooo
o`000_oo00H00?ooool00?oo000>ool00`00ool00002ool00`00ool0000>ool00`00ool00002ool0
0`00ool00002ool00`00ooooo`0;ool01000ooooo`000_oo00H00?ooool00?oo000>ool00`00ool0
0002ool00`00ool0000=ool100000003003ooooo00[oo`03003ooooo00Koo`03003ooooo00ooo`05
003oooooool0000Aool00`00ooooo`02ool00`00ooooo`0?ool00`00ooooo`06ool00`00ooooo`0?
ool01@00oooooooo00004Ooo00<00?ooool00_oo00<00?ooool03ooo00<00?ooool01_oo00<00?oo
ool03ooo00D00?ooooooo`00017oo`03003ooooo00;oo`03003ooooo00ooo`03003ooooo00Koo`03
003ooooo00ooo`05003oooooool0000Aool00`00ooooo`02ool01000oooooooo0@0000020004ool0
0`00ooooo`03ool00`00ooooo`02ool20004ool00`00ooooo`02ool20004ool00`00ooooo`02ool0
0`00ooooo`03ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool0
0`00ooooo`02ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`02ool20004ool00`00oooo
o`02ool20004ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`03ool00`00ooooo`02ool0
0`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`03ool0
0`00ooooo`02ool20004ool00`00ooooo`02ool20004ool00`00ooooo`02ool00`00ooooo`03ool0
0`00ooooo`03ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool0
0`00ooooo`02ool00`00ooooo`03ool00`00ooooo`02ool20004ool00`00ooooo`02ool20004ool0
0`00ooooo`02ool00`00ooooo`03ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`02ool0
0`00ooooo`04ool00`00ooooo`010000008000Woo`03003ooooo00?oo`8000Goo`03003ooooo00Oo
o`03003ooooo00;oo`03003oo`0000Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;o
o`03003ooooo00;oo`03003oo`0000Coo`03003ooooo00Ooo`03003ooooo00?oo`8000Goo`03003o
oooo00Ooo`03003ooooo00;oo`03003oo`0000Coo`03003ooooo00;oo`03003ooooo00;oo`03003o
oooo00;oo`03003ooooo00;oo`03003oo`0000Coo`03003ooooo00Ooo`03003ooooo00?oo`8000Go
o`03003ooooo00Ooo`03003ooooo00;oo`03003oo`0000Coo`03003ooooo00;oo`03003ooooo00;o
o`03003ooooo00;oo`03003ooooo00;oo`03003oo`0000Coo`03003ooooo00Ooo`03003ooooo00?o
o`8000Goo`03003ooooo00Ooo`03003ooooo00;oo`03003oo`0000Coo`03003ooooo00;oo`03003o
oooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003oo`0000;oo`40000000<00?ooool02_oo
00<00?ooool01_oo00<00?ooool02_oo00<00?ooool01_oo00<00?ooool00_oo00<00?ooool01_oo
00<00?ooool00_oo00<00?ooool01_oo00<00?ooool02_oo00<00?ooool01_oo00<00?ooool02_oo
00<00?ooool01_oo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool00_oo00<00?ooool01_oo
00<00?ooool02_oo00<00?ooool01_oo00<00?ooool02_oo00<00?ooool01_oo00<00?ooool00_oo
00<00?ooool01_oo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool02_oo00<00?ooool01_oo
00<00?ooool02_oo00<00?ooool01_oo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool00_oo
00<00?ooool01Ooo0@0000001P00ooooo`00ool000;oo`03003oo`0000Coo`03003ooooo00;oo`03
003ooooo00;oo`03003oo`0000;oo`03003oo`0000Goo`03003ooooo00Koo`03003ooooo00;oo`04
003ooooo0004ool00`00ooooo`06ool00`00ooooo`03ool00`00ool00002ool00`00ool00004ool0
0`00ooooo`02ool00`00ooooo`02ool00`00ool00002ool00`00ool00005ool00`00ooooo`06ool0
0`00ooooo`02ool01000ooooo`001?oo00<00?ooool01_oo00<00?ooool00ooo00<00?oo00000_oo
00<00?oo00001?oo00<00?ooool00_oo00<00?ooool00_oo00<00?oo00000_oo00<00?oo00001Ooo
00<00?ooool01_oo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo00Koo`03003ooooo00?o
o`03003oo`0000;oo`03003oo`0000Coo`03003ooooo00;oo`03003ooooo00;oo`03003oo`0000;o
o`03003oo`0000Goo`03003ooooo00Koo`03003ooooo00;oo`04003ooooo0004ool00`00ooooo`06
ool10001ool100000005003oooooool00004ool00`00ooooo`02ool00`00ooooo`04ool00`00oooo
o`02ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`02ool20004ool00`00ooooo`02ool2
0004ool00`00ooooo`02ool20004ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`02ool0
0`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`02ool2
0004ool00`00ooooo`02ool20004ool00`00ooooo`02ool20004ool00`00ooooo`03ool00`00oooo
o`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00oooo
o`03ool00`00ooooo`02ool20004ool00`00ooooo`02ool20004ool00`00ooooo`02ool20004ool0
0`00ooooo`03ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool0
0`00ooooo`02ool00`00ooooo`03ool00`00ooooo`02ool20004ool00`00ooooo`02ool20004ool0
0`00ooooo`02ool20004ool200000005003oooooool00004ool00`00ooooo`0>ool00`00ooooo`02
ool00`00ooooo`02ool00`00ooooo`09ool00`00ooooo`08ool00`00ooooo`09ool00`00ooooo`02
ool00`00ooooo`02ool00`00ooooo`0>ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`09
ool00`00ooooo`08ool00`00ooooo`09ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`0>
ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`09ool00`00ooooo`08ool00`00ooooo`09
ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`0>ool00`00ooooo`02ool00`00ooooo`02
ool00`00ooooo`09ool00`00ooooo`08ool00`00ooooo`09ool100000003003oo`0000Ooo`07003o
ooooool00?oo00000_oo00<00?oo00000ooo00<00?ooool01Ooo00<00?ooool00_oo00@00?oooooo
o`8000?oo`03003ooooo00[oo`04003oooooool20003ool00`00ooooo`02ool00`00ooooo`05ool0
1`00oooooooo003oo`0000;oo`03003oo`0000?oo`03003ooooo00Goo`03003ooooo00;oo`04003o
ooooool20003ool00`00ooooo`0:ool01000oooooooo0P000ooo00<00?ooool00_oo00<00?ooool0
1Ooo00L00?ooooooo`00ool00002ool00`00ool00003ool00`00ooooo`05ool00`00ooooo`02ool0
1000oooooooo0P000ooo00<00?ooool02_oo00@00?ooooooo`8000?oo`03003ooooo00;oo`03003o
oooo00Goo`07003oooooool00?oo00000_oo00<00?oo00000ooo00<00?ooool01Ooo00<00?ooool0
0_oo00@00?ooooooo`8000?oo`03003ooooo00[oo`04003oooooool20003ool10001ool100000003
003ooooo00;oo`04003ooooo0004ool01000oooooooo0P000ooo00<00?ooool00_oo00@00?ooool0
00Coo`03003ooooo00;oo`05003oooooool00005ool00`00ool00002ool00`00ool00005ool01@00
oooooooo00001?oo00<00?ooool00_oo00@00?ooool000Coo`04003oooooool20003ool00`00oooo
o`02ool01000ooooo`001?oo00<00?ooool00_oo00D00?ooooooo`0000Goo`03003oo`0000;oo`03
003oo`0000Goo`05003oooooool00004ool00`00ooooo`02ool01000ooooo`001?oo00@00?oooooo
o`8000?oo`03003ooooo00;oo`04003ooooo0004ool00`00ooooo`02ool01@00oooooooo00001Ooo
00<00?oo00000_oo00<00?oo00001Ooo00D00?ooooooo`0000Coo`03003ooooo00;oo`04003ooooo
0004ool01000oooooooo0P000ooo00<00?ooool00_oo00@00?ooool000Coo`03003ooooo00;oo`05
003oooooool00005ool00`00ool00002ool00`00ool00005ool01@00oooooooo00000ooo0@000002
000:ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`02ool00`00ooooo`03ool00`00oooo
o`03ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00oooo
o`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`02ool00`00ooooo`03ool00`00oooo
o`03ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00oooo
o`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`02ool00`00ooooo`03ool00`00oooo
o`03ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00oooo
o`08ool00`00ooooo`08ool00`00ooooo`08ool00`00ooooo`02ool00`00ooooo`03ool00`00oooo
o`03ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`04ool00`00ooooo`010000008000Co
o`03003ooooo00;oo`03003ooooo00?oo`8000Coo`03003ooooo00;oo`8000Coo`03003ooooo00;o
o`8000Goo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003o
o`0000Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00?oo`8000Coo`03003ooooo00;o
o`8000Coo`03003ooooo00;oo`8000Goo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;o
o`03003ooooo00;oo`03003oo`0000Coo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00?o
o`8000Coo`03003ooooo00;oo`8000Coo`03003ooooo00;oo`8000Goo`03003ooooo00;oo`03003o
oooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003oo`0000Coo`03003ooooo00;oo`03003o
oooo00;oo`03003ooooo00?oo`8000Coo`03003ooooo00;oo`8000Coo`03003ooooo00;oo`8000Go
o`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003ooooo00;oo`03003oo`0000;o
o`40000000<00?ooool01Ooo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool00_oo00<00?oo
ool01Ooo00<00?ooool01_oo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool00_oo00<00?oo
ool01_oo00<00?ooool01Ooo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool00_oo00<00?oo
ool01Ooo00<00?ooool01_oo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool00_oo00<00?oo
ool01_oo00<00?ooool01Ooo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool00_oo00<00?oo
ool01Ooo00<00?ooool01_oo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool00_oo00<00?oo
ool01_oo00<00?ooool01Ooo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool00_oo00<00?oo
ool01Ooo00<00?ooool01_oo00<00?ooool00_oo00<00?ooool01_oo00<00?ooool00_oo00<00?oo
ool01Ooo0@0000001P00ooooo`00ool000Coo`04003oooooool20004ool20003ool00`00ooooo`02
ool00`00ool00005ool01000oooooooo0P000ooo00<00?ooool00_oo00@00?ooool000Coo`04003o
ooooool20003ool00`00ooooo`03ool00`00ool00004ool01000oooooooo0P001?oo0P000ooo00<0
0?ooool00_oo00<00?oo00001Ooo00@00?ooooooo`8000?oo`03003ooooo00;oo`04003ooooo0004
ool01000oooooooo0P000ooo00<00?ooool00ooo00<00?oo00001?oo00@00?ooooooo`8000Coo`80
00?oo`03003ooooo00;oo`03003oo`0000Goo`04003oooooool20003ool00`00ooooo`02ool01000
ooooo`001?oo00@00?ooooooo`8000?oo`03003ooooo00?oo`03003oo`0000Coo`04003oooooool2
0004ool20003ool00`00ooooo`02ool00`00ool00005ool01000oooooooo0P000ooo00<00?ooool0
0_oo00@00?ooool000Coo`04003oooooool20003ool10001ool100000005003oooooool00004ool0
0`00ooooo`02ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool2
000:ool00`00ooooo`02ool20004ool00`00ooooo`08ool20004ool00`00ooooo`02ool00`00oooo
o`02ool00`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool2000:ool0
0`00ooooo`02ool20004ool00`00ooooo`08ool20004ool00`00ooooo`02ool00`00ooooo`02ool0
0`00ooooo`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool2000:ool00`00oooo
o`02ool20004ool00`00ooooo`08ool20004ool00`00ooooo`02ool00`00ooooo`02ool00`00oooo
o`04ool00`00ooooo`02ool00`00ooooo`02ool00`00ooooo`02ool2000:ool00`00ooooo`02ool2
0004ool00`00ooooo`08ool200000003003ooooo00Ooo`03003ooooo00?oo`04003ooooo0005ool0
0`00ooooo`0:ool01000oooooooo0P000ooo00<00?ooool02_oo00@00?ooooooo`8000?oo`03003o
oooo00[oo`03003ooooo00?oo`04003ooooo0005ool00`00ooooo`0:ool01000oooooooo0P000ooo
00<00?ooool02_oo00@00?ooooooo`8000?oo`03003ooooo00[oo`03003ooooo00?oo`04003ooooo
0005ool00`00ooooo`0:ool01000oooooooo0P000ooo00<00?ooool02_oo00@00?ooooooo`8000?o
o`03003ooooo00[oo`03003ooooo00?oo`04003ooooo0005ool00`00ooooo`0:ool01000oooooooo
0P000ooo00<00?ooool02_oo00@00?ooooooo`8000?oo`40007oo`40000000<00?oo00000_oo00@0
0?ooool000Coo`04003oooooool20003ool00`00ooooo`02ool01000ooooo`000_oo00<00?oo0000
0ooo0P000ooo00<00?ooool00ooo00<00?oo00000_oo00<00?oo00001Ooo00@00?ooooooo`8000?o
o`03003oo`0000;oo`04003ooooo0004ool01000oooooooo0P000ooo00<00?ooool00_oo00@00?oo
ool000;oo`03003oo`0000?oo`8000?oo`03003ooooo00?oo`03003oo`0000;oo`03003oo`0000Go
o`04003oooooool20003ool00`00ool00002ool01000ooooo`001?oo00@00?ooooooo`8000?oo`03
003ooooo00;oo`04003ooooo0002ool00`00ool00003ool20003ool00`00ooooo`03ool00`00ool0
0002ool00`00ool00005ool01000oooooooo0P000ooo00<00?oo00000_oo00@00?ooool000Coo`04
003oooooool20003ool00`00ooooo`02ool01000ooooo`000_oo00<00?oo00000ooo0P000ooo00<0
0?ooool00ooo00<00?oo00000_oo00<00?oo00001Ooo00@00?ooooooo`8000;oo`4000000P001?oo
00<00?ooool00_oo0P001?oo0P001?oo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool00_oo
0P001Ooo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?oo
00001?oo00<00?ooool00_oo00<00?ooool00_oo0P001?oo0P001?oo00<00?ooool00ooo00<00?oo
ool00_oo00<00?ooool00_oo0P001Ooo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo
00<00?ooool00_oo00<00?oo00001?oo00<00?ooool00_oo00<00?ooool00_oo0P001?oo0P001?oo
00<00?ooool00ooo00<00?ooool00_oo00<00?ooool00_oo0P001Ooo00<00?ooool00_oo00<00?oo
ool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?oo00001?oo00<00?ooool00_oo00<00?oo
ool00_oo0P001?oo0P001?oo00<00?ooool00ooo00<00?ooool00_oo00<00?ooool00_oo0P001Ooo
00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?ooool00_oo00<00?oo00000_oo
0@0000000`00ooooo`02ool01000ooooo`001?oo00<00?ooool01_oo00<00?ooool00_oo00@00?oo
ool000Coo`03003ooooo00Koo`03003ooooo00;oo`04003ooooo0002ool00`00ool00005ool00`00
ooooo`06ool00`00ooooo`02ool01000ooooo`001?oo00<00?ooool01_oo00<00?ooool00_oo00@0
0?ooool000Coo`03003ooooo00Koo`03003ooooo00;oo`04003ooooo0002ool00`00ool00005ool0
0`00ooooo`06ool00`00ooooo`02ool01000ooooo`001?oo00<00?ooool01_oo00<00?ooool00_oo
00@00?ooool000Coo`03003ooooo00Koo`03003ooooo00;oo`04003ooooo0002ool00`00ool00005
ool00`00ooooo`06ool00`00ooooo`02ool01000ooooo`001?oo00<00?ooool01_oo00<00?ooool0
0_oo00@00?ooool000Coo`03003ooooo00Koo`03003ooooo00;oo`04003ooooo0002ool00`00ool0
0005ool00`00ooooo`05ool100000005003oo`00ool00004ool20003ool20004ool20003ool20004
ool20004ool20003ool20003ool20004ool20004ool20003ool20003ool20003ool00`00ool00004
ool20003ool20004ool20003ool20004ool20004ool20003ool20003ool20004ool20004ool20003
ool20003ool20003ool00`00ool00004ool20003ool20004ool20003ool20004ool20004ool20003
ool20003ool20004ool20004ool20003ool20003ool20003ool00`00ool00004ool20003ool20004
ool20003ool20004ool20004ool20003ool20003ool20004ool20004ool20003ool20003ool30000
0003003oo`0000;oo`03003ooooo00<000;oo`800006ool00?ooool00?oo0P000_oo0`000_oo00D0
0?ooool00?oo00800003ool00?oo00;oo`8000?oo`800004ool00?oo0002ool01000ool00?oo0P00
0ooo0P000ooo00H00?oo00000?oo0002ool00`00ooooo`030002ool200001_oo003ooooo003oo`80
00;oo`<000;oo`05003ooooo003oo`0200000ooo003oo`02ool20003ool200001?oo003oo`000_oo
00@00?oo003oo`8000?oo`8000?oo`06003oo`00003oo`000_oo00<00?ooool00`000_oo0P0000Ko
o`00ooooo`00ool20002ool30002ool01@00ooooo`00ool00P0000?oo`00ool00_oo0P000ooo0P00
00Coo`00ool000;oo`04003oo`00ool20003ool20003ool01P00ool00000ool000;oo`03003ooooo
00<000;oo`800006ool00?ooool00?oo0P000_oo0`000_oo00D00?ooool00?oo00800003ool00?oo
00;oo`8000?oo`800004ool00?oo0002ool01000ool00?oo0P000ooo0P000ooo0@000Ooo0@000002
0004ool00`00ooooo`03ool00`00ooooo`02ool20004ool00`00ooooo`03ool00`00ooooo`02ool0
0`00ooooo`02ool20003ool00`00ool00004ool00`00ooooo`02ool00`00ooooo`02ool00`00ool0
0003ool20004ool00`00ooooo`02ool00`00ooooo`03ool00`00ooooo`02ool20004ool00`00oooo
o`03ool00`00ooooo`02ool00`00ooooo`02ool20003ool00`00ool00004ool00`00ooooo`02ool0
0`00ooooo`02ool00`00ool00003ool20004ool00`00ooooo`02ool00`00ooooo`03ool00`00oooo
o`02ool20004ool00`00ooooo`03ool00`00ooooo`02ool00`00ooooo`02ool20003ool00`00ool0
0004ool00`00ooooo`02ool00`00ooooo`02ool00`00ool00003ool20004ool00`00ooooo`02ool0
0`00ooooo`03ool00`00ooooo`02ool20004ool00`00ooooo`03ool00`00ooooo`02ool00`00oooo
o`02ool20003ool00`00ool00004ool00`00ooooo`02ool00`00ooooo`02ool00`00ool00003ool2
0002ool1000000<000;oo`07003ooooo003oo`00ool0100000Goo`0000000?oo00<00004ool00?oo
0002ool01000ool00?oo0`0000Goo`0000000?oo00<00003ool0000000800003ool0000000;oo`<0
0005ool00000003oo`0300000ooo0000000200001?oo000000000_oo00L00?ooool00?oo003oo`04
00001Ooo00000000ool00`0000Coo`00ool000;oo`04003oo`00ool300001Ooo00000000ool00`00
00?oo`0000000P0000?oo`0000000_oo0`0000Goo`0000000?oo00<00003ool0000000800004ool0
00000002ool01`00ooooo`00ool00?oo00@00005ool00000003oo`0300001?oo003oo`000_oo00@0
0?oo003oo`<00005ool00000003oo`0300000ooo0000000200000ooo00000002ool300001Ooo0000
0000ool00`0000?oo`0000000P0000Coo`00000000;oo`07003ooooo003oo`00ool0100000Goo`00
00000?oo00<00004ool00?oo0002ool01000ool00?oo0`0000Goo`0000000?oo00<00003ool00000
00800003ool0000000;oo`<00005ool00000003oo`0300000ooo0000000300000?l002400000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0263022, -0.0250052, \
0.00366761, 0.00593432}},
  ImageSoundCache->{{{0, 287}, {176.938, 0}} -> GraphicsData["XSound", "\<\
0000004000089IH8f2:F20\>"]},
  ImageCacheContents->"Sound"]
}, Open  ]],

Cell[TextData[{
  "A cell bracket with a double-thick horizontal line at the top indicates \
that the cell contains a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Graphics Format (MGF) bitmap image."
}], "ItemizedText"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003200012A000`40n007
h00O`_oo0032ool0000?0Z0003</S54443600Z0c9U:Z001BZP0@<0`aS36C
009BZP:4409S;005Q11QQYcCVc>44002W=<00f<cQ12<D@02Hb`02haAW=>L
dhaAHHb<DIcCHc>448aAQ1000U:Z00^<DIcCQ11TdjeEW==S<haA[EDc;6</
00:<D@0MQ11S;666Hbb443</S55TdhaAQ11S;8@@W=>K<icCHc=S;8aAHbaS
9XaAW=>]EF<cS56Ldc<cQ1044002Hb`01H@@HbaTdjeEHc<00X@@00/448@@
Q12<DJeEI=V<DH@@<bb443</00:44006W==S<c</HbIBZP@@0f</00JLdf<c
I==QS6<cW=T3WWT00fCCVc>Ld`02Q1001haA<b`aP0:P<0IS;6<c008c;00?
S54c;360DZXaP3</DZXc;8aAQ11BZV</Q11S;36<00:44009Hc=S9V<VQ11S
<h@@I=<c;6<V009S;004W=<449cCQ102<bH02f66HbHaS8@@Hc>LdfCCW=>K
<icC[ED019cC0ZeE0IcC00020Z002S</S54c9P:P0002X5:Z0Z0c9S6C0P0@
00<aTc6<<b`00X@@0f</00B449cCS55S<`:Ld`0YHc>448aAHbaQS6CCVc>L
dh@@Vbb<DIcCHc>448aAQ11BZV<VVc>LdhaAHc>]EIcCHc=TdicCHbIQS6CC
S56K<h@@HHJ448aA<bbLdhaAHbb44002Hb`2W=<02XaAI=<c;8@@<baQQXaA
W=><DF</0X@@00/c;8@@Q12448aAI=><DF<c[EF<DC</00>4400FS55S<jeE
W=><DF</<Hb446</Q1044:eEW==S9U:Z<Hb443</HHaS9VCCQ102DZX01C</
Hc>]EFCI[ED00iii00=TfC<cQ1000e:Z01T2X3</Q12446</W==S;360DZYS
9S<VDZYS<fCCHb`c9V6<Hb`c9U:ZHb`c;6CCHbaS9P02Q1004f</W=<aS6<V
<b`04JeEHbbLdh@@HbHc9V66<bIS;0@@Q12Ldf<c00:Ld`05Hc>LdfCCVc>]
E@02W=<1W=T1[ED0000>0Z1BZU:ZQ104c0:PDZX2X5:Z001BZP0@<H`04@<a
S006S55Tdf6<Q11QS6</0XaA00B448aAW==S<`9Td`0NQ11QS8@@W=>]EF<c
HbJ<DIcCHc=S;8aAQ11BZV<VS56Ldf<cS56LdhaAHbb449cC111S;8aAW=>K
<fCC0X@@00B<DF</S55Td`:44003Hbb448aA00:Ld`05I=<aS8aAQ11BZP02
Q1000f6<HbITd`02Q10056<cS55S;8aAW=>448aA[EFLdf<c<bb<DF</S55S
<jeEW=>K<h@@<bH2Q1001F</Q12]EF<c<b`00S<V0X@@00EBZP:PHc>445:Z
008aP007Q12]ECCIW=<c>IcCW=T00Yii00JmecCCHb`c;36<DZX2<b`06f</
S55S9S<VDZYS9V</DZYS;9cCQ10aS5:Z<bHaS666Q11Tdh@@<b`c9V<cS564
46CCHbaS9P02Hb`04ZeE<baTdh@@HbaS9S60HbIS;8@@Hc>LdfCCW=><DIcC
[EFK<`:]E@03I=>K<icI006Ld`000P:P00Pc;8@@Hb`2X0000Z1BZS600S6<
00T0436C014aS3</S56446</Q1000V</00>LdhaAHc<00YcC0X@@00BLdh@@
HbaS<`:Ld`04S55S;8aAW=<2Q1003FCCQ11BZV66Q12<DH@@S55S<h@@HbaS
<icC009S;00CHc>]EJeEW==S;8aAI==S;9cCI==S;8@@Hbb448aAW=>K<h@@
Hb`00X@@00Dc;6</111S;36<00:Ld`04Hc=TdhaAHb`2S54026<cW=>LdhaA
Q10c;8aAHb`2Q1001IcIW=><DH@@<b`00V</01Z446<c[EF<DF</<H0aS6</
Q11BZV66I==S;0:PDZX`1VCC[EES<icCI=UQTc</HH`dfLHH0Yii022mefCC
<bIBZVCC112Ldf<VDZXaP5:ZQ10aS8@@I=><DF</DZYS9S<P<H`c;8@@S55S
;6<VQ11S<h@@S55S;3<V0V</00ATdh@@W=><D@9S9P0@<H1S9S6<I==S<jeE
Vc>LdfCCW=>]EIcCS56K<jeEW=<2[ED0000A001BZU:Z<b`dc00:0Z1BZP00
0Z002S6<010aS00A<HaQS002S5405h@@HbaS;6<VW=>K<h@@W=>]EF6CQ12L
dh@@HbJ448aA[EEQTf</S56Ldf<c<b`00XaA00Dc9U:ZQ124466<00>44006
Hbb449cCQ10c;8aA0ZeE00NK<f</S56K<h@@Hc>Ld`02Q1003V</HbJ<DJeE
S55Tdc6<S55Tdf</Q12<DIcCHc<3W=<03FCCW==S9X@@W=>446CC[EFLdh@@
<Hb<DFC<00:440>Ld`06Q10aS6</S56446</0XaA01EBZS60DZYS;6C<<bIB
ZV6<Hb`c9U:Z002446CC<baS;8aAW=<4400:DZX00V<c01ETfJeEWWVNNFCI
[EDc<icCQ10c;5:ZHHJ445:ZHbbLdjeE<c<c9X@@<b`00U:Z00B446CCHbHc
9P:44003<bb<D@@@009S9P0>Hc>Ldh@@I=><DF<V<H1QQS<VHbb443<cW==T
d`:<D@08Vc><DIcCW=VLdjeEW=>Lf@6]E@000P:P00<c;8@@I<`00`:P00]B
ZP:PDZX0436<010aS00@<bbLdhaA00AS;0:<D@0?Hc>LdjeES55TdhaAQ10c
;8@@W=>]EHaAHHJ<DIcC00:44007S56445:Z<bIS9X@@<b`00XaA016Ldf<c
I=>Ldh@@HbaTdicC[EFLdf</Q12Ldh@@Hc>Ldf<V00:44006<bbK;6<c<bb4
43</0XaA02aQS8@@W=>Ldh@@I=>]EHaAI=>Ldh@@S56Ldh@@S56LfFCCQ11S
9YcCHbJK<fC<VcVLdfCCQ11QS6</I<b446<cI=>445:Z<H0c9S</Q10c9U:Z
HbHc;3600U:Z016449cC<b`003</Hbb445:ZHHH443</<HaQS6<iW=>NNLii
00:NN@05S54443</HHb44002<b`04ZeES56446</S54c;5:Z<bJ<DFCCHbaQ
QV</Q10c;9cCHb`aS09S;003I=V449cC00:44008<b1BZV66Hbb446CCW==S
<`:Ld`03Q12LdicC00:]E@03W=V]EJeE006Lf@0000/2X5:ZDZYS;6C<<bIB
ZP:PDZX005:Z008aS00600`aS36C<bb<DFCC0V</00F445:ZS56Ldf<c00:L
d`9S<`07W=>446</Q12<DIcCS5400X@@00><DH@@Hb`00XaA00<c9V66HbH0
0XaA00b449cCW=><DH@@W=>443</Q12LdicIS542Q1004IcCHc=TdicCHc>4
46</DZYS9V</Q11S<fCCQ12<DF</Q1000YcC00AS<haA[EES<`:Ld`03Hbb<
DIcC00:<D@05[EFLdh@@<baTd`03Q10039cC[EETdi/c<bIS;6CCQ11S;9cC
Hb`c9P9BZP0<<Hb<DF</HbHc9P@@HHHc9S60HbaTdfCI0U:Z00HaP8aAI==B
ZS</Hb`2DZX00`@@<HbLf@02W=T02<iiWWVNNJeEI=<ddc</HbH2[ED02C<c
HbJ<DH@@DZXc;6CCQ11S;002<bH2Hb`04H@@<b`c9V<VHbb]E@@@W==S<h@@
<H1QP6<V<bIS;6<c[ED00X@@00><DIcCW=T00ZeE00BLfJeE[EF]E@6K<`00
00l000:P<bb<DFC<<bH000:PDZX2X5:Z<H`0436<01000S6<00V<DH@@Q11S
;8@@HHb<DIcCHb`00YcC01B<DFCCW=>443</Q12K<icCS55QS6</Q11S;3</
S56443<VHHJ449cC0X@@016LfJeEQ10c<jeES55S;6<cW=>]EIcCQ11S;9cC
Hc>LdfCC009S;00=Q11S;6<cW=>]EI/cHc=TdhaAHbJ04:eEW=<00X@@00V]
EFCCI=>Ldf</S55Tdi/cI=<00YcC00>446</S5400X@@02=S<icC[EF<DH@@
<bJ448aAHbb446CCHb`aP000DZYS;6C<Hb`c;5:ZQ10c;36<DZZ449cC[EDc
;306<bIQS6</DZX443</009BZP0AS55S<fCC[EES<icIW=>LfIiicWW666CI
Hc=TdjeEQ11S;002Q1003c<VHbaTdf</Q11QQS</Hb`c;8aAHbaBZS<V<I>L
d`02Q1002fC<HbHc8360DZYS;0@@Hc>]EHaAHc<00icC00>]EIcCW=T00YcC
0ZeE00003`:PDZYBZS</I<`c9P:PDZX2X306<H0aS00@<H`aT`02<H`01YcC
I=>4466<HbaS9P:Ld`0QHc><DJeEVc=S<jeEQ10c;8@@S55Tdh@@HHIS9X@@
Hb`c;8aAW=<c;6<VQ12Ldf<cS56]EIcCHc><DJeEQ11S;8@@00:]E@05W==S
<f<VQ11S;002W=<01FCCQ11S;6</S5400YcC00IS<fCCW==Tdf</Q102W=<0
1i/cS56]EFCCVc>Ldc</00:<D@07Vc=TdicC[EES<c</S5400h@@00QTdjeE
Vc><DC<VHbb<DFC<0h@@01=BZP:PDZYBZXaAQ11S;3<VS55Tdf<cDZXc;9cC
I=Tc;5:Z0Z1QQP02DZX09f</Q102X5:ZQ11S<haA[ED448aAHc=S;6<cW=>L
fIiicWVNNKgG<c=S;8@@I<aQS6</W=>443</<bIS;8@@HbaTdf</<bIBZV</
[ED44002Q1002U:Z<H1BZV60HbIS;8@@W==TdhaA0icC00JLfJeE[EFLdicI
[ED1W=<000050002X5:ZI<bLd`040Z00200:DZXaS36<014`300@<b`2S542
Q1001F</HbJK<icCHb`00YcC00ATdh@@[EF4409S;00IQ11S;6</HHIS;8@@
S55S;6CCW==S;3<PVc>]EHaAHc>]EIcCI=>449cCS55QS8@@W=<00X@@00Hc
;6</HbaS;6CCW=<3Q1000f</Q12]E@02W=<046<cW=>Ldf</Q12<DJeES55S
<jeES55TdjeEHbb449cC0X@@00J]EIcCQ11S;6C<Hb`2Q1003f<c[EFLdhaA
<b`c9YcCHbb446<c<bIBZS60DZXc;003Q10023</W=>]EF</DZX449cCQ102
DZX04c60<baS;3</HbaTde:Z<Hb446CCHc><DH@@I=>443<VDZYS;8@@009S
<`0<WWW>NIiiWWVLfH@@Hb`448aADZZ445:Z0h@@00Z<DH@@DZYBZS6<[EDc
;8@@I<aS9P8aP004DZYS;3</<c<3W=<016CCW=>Ldi/c1:eE0IcI0JeE0000
2`:PDZX2X3</W=<405:Z0Z0005:Z0Z000S6<00L04C6<<I=BZXaAI=>44003
Hb`00haAW==S<`02W=<01Y/cS56]EH@@DZXc;0>4400:HbJ449cCS54c;9/c
W==S;6<VQ102W=<028@@W=>]EI/cS56LdfCCHb`2Q1003c</HbaS;8@@S564
46<c_MN446</Q11S9XaA[EFK<`02I=<05ZeEW=<c;6</W=>]EF<cS56]EFCI
Q12]EF</Q12LdfCCQ12]EI/cHc>448aA0X@@00ES;9cC[EFLdf<c009S;007
W==S;8@@S56445:Z<H000U:Z00N<DH@@Q11QQ/HHW=Tc9P02DZX038aA<baQ
P0:P<0IS;6<VI<b448aA<bHaS0>44006[EDc<fCCQ11S9S<V0V</00<c9V</
W=<00YcI01NNNLHHWWUVNF<c[ED446C<HHJ448aAI=>K<fCCHbHc9V</W=<4
48@@Hb`c9U:Z008aP007HbHc;8@@[EETdi/cS5400YcC00J]EIcI[EFLfIcC
W=T1[ED000070002X5:ZI<bLd`<PDZX00P:P00=@05:Z<H`00S6<00`0436C
<HbLdhaAHbb446</HHb<DIcCQ102S5407f<cI=>]EH@@DZZ449/cW=><DF<V
Q12Ldi/cQ11TdicCHbaQQXaAW=><DF<cW=>]EF<cQ12Ldh@@Hb`449/c00:L
d`06Q11S;9cCHbaTdjeE0h@@00iS;8aA[EF]EI/cI==TfJeE<bJ449/c[EET
dh@@0ZeE00Lc<jeEHbb449/cI==S<`02[ED2Q10018aAQ12446<c0icC00j<
DF<V<bbLdf</Q11Tdh@@<H02X5:ZHbaTc6</0X@@00nmeicCDZXaP8@@S54c
9U:ZHbHaS6CCQ12<DF</I=<00U:Z0XaA00d44:eEQ12Ldh@@Hb`aP5:ZQ10c
;66<I=>]E@02Hc<04ZeEW=W>NIiiaQRLfFCC112<DI/cI=><DFCCHHIBZS</
Q11Td`:4400?<b1BZS60<H1BZX@@Hc=TdicCVc><DI/cW=>]EIcC00:]E@6L
d`6]E@6]E@0000IBZP:PDZZ449cC1402<H0010:PDZX2X36<0`0@00AQS36<
S56Ld`:4409S;00>Q12<DF</Hc>446</Q12]EH@@Hbb448aA[EF<D@:4400=
W=>K<`@@S56]EC</HbJ448aAW==S;8aAQ1000V</00FLdfCCQ11S;9cC00:]
E@06Hc>409cCI=>44:eE0h@@00=S;8aAW=<00YcC00ITdjeE[EDc;8@@S542
W=<02X@@[EFLdf<c[EDc;8@@S56Ldh@@0YcC00=Tdf</S5400h@@00BLdjeE
W==Td`9S;007W==Tc8@@Q10445:Z<H000U:Z0h@@00aS;8aAS54c9S60<bb<
DF</<bIS9XaAW=<2Q1002C</S54c;3</Q11Tdf<c[ED44002S5402V</<H1Q
QV<V<baBZXaAW=V<DH@@0V<c00>446<cW=T00iii01J]EFCCI=>K<fCC<b`c
9V</Q11Tdh@@I=<c9V60<H1BZS60Hbb446CCW==Td`>Ld`:]E@04W=V]EIcC
W=T1[ED00082X00<HHITc9cC<bH2X5:Z<H1BZV66<b`0436<0P0A00@aS8aA
I=>4409S;005HHIS;8@@Hbb44002S5404h@@[EF<DF</Q12<DIcCVc=S;8@@
[EF<DC</S56]EF</HHIS;8@@009S;009Hc>448@@112]EIcCHbb449cC00:]
E@0;S56K;9cCHc>44;gGS55S;8aAHbbK<`02W=<03Y/cI=>LdjeEHHJ449cC
[EF<DH@@W=VLdh@@W=<2Q1000haAI=>44002[ED00haA<bb44002Q1003HaA
I=>]EIcCS55S;3</W==S;8@@S56445:Z008aP00@<bJ448@@Q11S;8@@HbaB
ZV66<bb<DF</HHIQS;gGW=<2Q1002@@@W=<c9S6<Q12Ldh@@[EF44002S540
4E:Z0Z1BZU:ZQ10aS9cC[EF<DF</Q12<DC<VHI>]EF<cW=<00YcI0Yii00>m
eicCHb`00V</00IS<icCQ12Ldc<VDZX2<H0015:ZQ10c<jeE0icC00J<DIcC
W=>LdhaAW=T2W=<1W=T0000;<H1QQU:ZHbbLdh@0HbIBZV60HHJIP002<H`0
1666011QS36<0YcC00V443<VHHIBZV<VHbb448aA[ED00V<c00^]EFCCQ11S
;8aA[EFLdh@@HbbLdi/c00:44005[EDc;3<VHbIBZP02Hb`3W=<00f<cW=>L
d`02Hb`02YcCW=V]EI/cHbb<DI/cI=>mef<c0X@@01aS9Y//W=>]EF<c[EET
fIcCHbb448aA[EFLdc<c[EETdf<cW=>446</W=>K<h@@[EFLdhaAHbb<D@>4
4007S56LfIcCS56443</W=<00X@@00AS<fCCHH0c9P9BZP:4400BI<aQQV</
HbaBZP:P<0J<DF</<bJ44:eE_MLaTf</<bJ<DC</0X@@00NLd`@@W=US;9cC
I==S9P02DZX02F<VQ11BZX@@W==S<h@@Hbb<D@02Hb`01fCCHc=Tdh@@HbbL
fKgG00>NN@9Td`07HbbLdfCCW=<c9V66<b000U:Z00IS;6<cS56]EFCCVc<2
S543W=<00jeEW=>]E@01[ED00005V039P9/VVbJ]E@02VbH00f66VH2IQP02
bH000iP6VHIP1P02HH`01XaAW==S;666HbIQQP:<D@0RQ11S<jeEW=>44:eE
S56446</S56K>IcCHbb449cCI==S;8aAW==S;666Q12LdhaAHc>LdjeEW=>4
46CIW=>446<cW=<2[ED2Q1001IcCS55S<iicS5400X@@00iS;8aAW=>]EHaA
I==S<kgGHbJ449/c[EFLdc</0ZeE00B448aAQ12440:Ld`0:Q12LdicIS54a
S6CCS56446CCHc<2[ED028aAHbaS;9cCHbb449/cI=<2<H000e:Z<H244002
Q1001S</DZYBZU:Z0Z0aS0:4400><Hb<DH@@W=>446CCQ12<DF</<I>44;gG
112]E@:<D@0BW==S9U:ZHbHc;6</<Hb44:eES55S9X@@S55S;66<I=>446CC
0V</00FK<icCHcV]EIcI00>NN@06W==S<icC<bIBZV</0S</00UQS6CCHc>]
EFCCW=>K<haAVcT00ZeE0YcC0I/c0JeE00002/V6bH2IQY//[EFh09/V^03;
9/V61LV000o9QY//W=>]EI//Hbb446<VQ12Ldh@@W=>]EIcCHc<00YcC00>4
43</W=<00YcC00>445:ZHb`00V</00ES<jeEHbaS9V</00:Ld`0bHbb<DJeE
W==S<icC[EF446<VW=>]EIcIS56448aAW==S<jeES56448aAHbJ449cC[EFK
<fCIS56mec</Q12<DJeEW==S<jeEW=>449cCI=>448aAW=>449cC[EFLdf</
Q12<D@>440:]E@04Vc>443</W=<3Q1001FCCHHIBZS60<bH00X@@0V</00<a
P5:ZHb`00U:Z01mS;6CCI=>446</HH`c;6</HbJ<DH@@I=>]EIcCHc>]EFCC
Hc>Ldf</<bIS9V</Q11BZX@@[EETdf</Q11Td`02Hb`2Q1002fCC<baS9XaA
I==S<fCCHHaS<haAW=T00iii00aTdf<c110c;8@@<b`ddh@@[EETdicCVc<3
[ED2W=<1Vc<1W=<1[ED0000=bH39QYV6HHc>Ll//Vbbh09/VbHJh0<V6b000
0/V000C9QYV<W=?<d`:K;09S;004S56]EF<cS542W=<01H@@[EF<DH@@<b`0
0X@@00/c9U:ZHHb448aA<bb44:eEQ11S9V</00:Ld`0:Q12K<jeEW=<c<jeE
W==S<f</W=<2[ED04HaAQ12<DIcCQ12]EHaAHbb<DF<VVc>]EIcCS55Tdh@@
[ED00V</00VK<jeEW=<c;:eEW=V449cCQ1000XaA00>LdfCC[ED00YcC00aS
;8@@S56448aAHc>]EIcCS56443</W=<2Q1002haAI==BZU:Z<H0c9V<cW<`a
P5:Z<b`00V</01P005:ZW=>Ldh@@HHIBZS6<0Z1BZS<VQ12K>LiiWWVLdh@@
W=><DFCCW==S;3<VHbH2Hb`03S<V<c>]EIcCHbb448aAHb`c;6</I=><DC</
HHH3Hb`026CCDZYBZS6<HbbLfIcCW=T2WWT02:eEI=>448@@Hc<44;gGS544
W=<01I/cW=>LdjeEW=<00LcI00001YV6VbbK9V</_MNLd`:K;00;VHc;;8@@
bHbIQY//bHbK9Y//W=?<d`02bb`03X@@HbbK;9cCS56LdjeEVcV449cCI=>4
46</Q102Hb`2Q102W=<06F<cQ12]EH@@HbIS;9cC[EEQS9cC[EFLdh@@W=>]
EH@@Hbb]EIcI[EFK<h@@S56Ldf<c00:Ld`:4400>HbJ449cCW=>K<fCCHc>]
EH@@Hbb<DIcC[EDc;0:]E@03Q11TdicC00:44003W==S<icC00:Ld`041124
49cCI<`2Q1001jeEW=>Ldh@@<HbLdhaA00:4400<I==S;666<bIBZV</I<aS
;5:Z<b`aS3<V0U:Z00=S;6CCHb`00S</01aBZP:PDZX02X@@_MO>NIiiVcUS
;:eEI=>44:eE<bIS9V66Hbb443<VHbb]EIcCQ11S;8aAHb`c;0>44007<baS
9U:ZDZYS;8aA<b`00U:Z00Lc;6<c112Ldf<cS56Lf@02WWT01fCII=>44:eE
S56LdfCC00:Ld`>]E@6Lf@6Ld`6]E@0000YS9YV<HHb44<cCW=>K;<V<Hbc9
S0BIS005VI>K;9VCW=>]E@02bb`03Y//<bb449cCQ11S<jeES54c<jeEW==S
;66<I=<2W=<04i//HbbLdjeE11244:eEQ11S9X@@Vc>]EH@@S56]EIcC<c>]
EIcC00:44008W=>]EJeES56K;9cCI=>440:Ld`0:Q12<DF</Q12LdjeEI=>L
df</W=<2Q1003YcCVc>]EF<VI=V]EHaAW=><DH@@W=><DH@@[ED2W=<00c</
I=>Ld`02Q1001f<cW=>LdicCQ10c;9cC00:4400AHc=Tdc<V<H0c9S6<Q11T
c5:Z00Z446</<b`c9U:ZQ12Ld`07DZX03F<c_MO<fIiiI=>44:eES54c;:eE
Hb`c9V66009S;00O<Hb449cIS56446</S55S9S6<HHITdhaA<bIBZS<V<H1S
<haAHbHc9V66112]EH@@I=>443<VHb`aTjeE_ML00iii00>Ldi/cI=<00YcC
00B]EIcI[EG<f@:]E@0001BH1YV<Hbb44:eEc=>K;</cVbc;<i//Q12H366<
Q12IS6<cW=>mel/c0Y//00=S;9//W=<00h@@0V</00B]EIcC111S;0:Ld`03
[EES<f</00:Ld`06Hc>44:eEI<aS9V</0YcC00ES<haA[EFLdi/c00:]E@0:
Q11S;9cC[EFLfIcCHbb<DIcCQ102W=<016C<Q11S9Y//0ZeE00YS<haAHbbL
dhaAQ02<DIcC[EES;0:]E@0=Q11S<icCI<b<DIcCQ12LdjeEVcUS;8@@W=<0
0h@@00>]EFCIW=<00V</01RLdh@@Q1244:eE<b`c9U:Z<H1S;9cC<bHc;8@@
<baS;5:Z<H1S;8aA<bIBZS</DZX2<b`01c6<Q12]EFCCWWVK<h@@009Td`06
Hc>]EF<VHbHc9V<V0f</01f]EFCCHbaQS6</<bIBZV</I=>443</DZYS9V</
Q11Tdf</<baS9V</aQQS<fCCHb`c9V66<H0c;6<c00:Lf@08_MNLfHaA[EFL
dicI[EFLf@>]E@6Lf@0001B449V<HHaS;:eEc=>K<i//Vc?;;9/cVbbITf</
Vbb048@@Vc>mel/c0Y//0V<V0X@@01j<DJeE[EES<icC_MN443</S56LdjeE
S55S;9cC[EES<f</[EF<DF<VQ12<DJeEHc><DJeEVcV448aA_ML2Hb`018aA
[EF]EHaA0X@@00fLdf<cS56]EF<VQ11S9X@@W=>]EF<cW=<c;002S54056</
W=>LdjeEHc><DKgGHc>44:eEHbJ<DIcCQ12LdjeEW==S<f</[ED3Q1001IcC
[EFLdh@@<b`00XaA0X@@026LdhaAHbaBZP:PHHbLd`@0Q10c;8@@<bIBZP00
HbbLdc<V0Z1QS6</I==S;3</Q11TdicIW==Tdh@@S56Ldc</W=<00S<V00eB
ZS60HbIBZS</S55Tdf<V<bJ<DF</<bIS;002S5402X@@<bb448aAHbbLdc</
<bIBZV660h@@00/446<V<H`c9U:Z<H`c;6<c[EFNNIcI00:Ld`05W=V]EIcC
W=VLd`02[ED0000HHbbK;9//HHbLdjeEbc>449/cbc>K<i//P12IQ//cVHb4
48aA[EG;<l//Vc=QQX@@0YcC00eS<icC[EFK<fCC[EF446</Vc>]EIcCS55S
;002W=<01XaA<bbmehaAHbaQS0:Ld`:440:]E@03Q12<DJeE00:4400RW=>]
ELcIW=>449/cW==S;8@@[EF448aAHbb449cC[EFLdhaAHbb<DIcCHbbK<jeE
W=>448aA[EETdf</[EF448aAW=<2S5401JeEW=>448@@W=<00h@@016LfIcC
W=>443</S56Ldf</Q11TfIcCQ11S9S<V<bbLdf6<00:4400;S54aP5:Z<b0c
;8aADZXc9S</P11Td`02Q1003V</_MMTdhaAW=>446CCS56449cCHbHaP5:Z
<H02DZX053<cW=><DH@@Hbb<DF</DZZ446CCS55Tc666Hbb443</W=<c;6<V
<H02<b`04C6<Q10c;360<0IBZS</Hb`443<cW=>LfIcC[EFLdi/cW=<01:eE
0IcI00003i//VHaS;36<W=>mei/cVbc;<i/cS56IS</cbbbK<`02Vb`02Y/c
_MO;<i/cQ11QQX@@W=>K<haA0ZeE01]S<jeE[EF443</S56LdjeEVc=S;8aA
W=>K<f</[EF<DF</Q02LdjeEQ12<DKgGW==S<haA_ML00X@@00B<DJeE[EFL
d`:4400AW==S;8aA[EES;8aAHbbK;9cC[EFK<haAHc>449cCHbb<D@02[ED0
2f</S56]EFCCHbb]EH@@VbbLdh@@I=<00ZeE00IS<h@@W==Tdf</Q102[ED0
59/iS55S9Y/cW==Tc8@@W=>]EF<cHbHc9V</W=<c9VCCQ12<DF<V<bH2DZX0
4haA<bIBZS</HbaTdi/cI==S;6CCS55S<icC<bb<DH@@<bbLdf</008c9P0?
HHHc9V<VHbb]EIcCS56448aAQ11S;3</W==Tdh@@008c9P0<HHHc;8aA<baB
ZP00DZXc;36<I=<445:Z0S</0V</00@c;6<c[EES<`:Ld`07I=>]EJeEW=V]
EIcI[ED00IcC00001V</P12446</Vbbme`:K<`04S57;<i/cVb`2Vc<03L/c
Vc>4466<cW>Ldi//Q11QQX@@[EF<DF<c00:]E@03Hc>]EJeE00:4400AI=>K
<jeES56449cC[EETdf</[EFLdf</HbJK<icCS55S<`02[ED00haAQ12]E@02
Q1003XaAW=V]EIcCQ12<DIcCHbaTc:eEQ12<DF</Q103W=<066CCHbaTc9cC
Hbb<DIcC[EF448aA[EFLdf</[EF448aAW=>K<fCC[EFLdh@@I=>Ld`:44008
S56LdjeEW=><DC<VI=>]E@:44009W=>]EHaAHb`c9S</W=<aS9cC00:<D@8a
P00ADZXc9YcC<bIBZX@@HHaTdhaAW=<c;8aAQ11TdicC<bb<D@02Q1001IcC
Q11QQU:ZHbH00V</00dc;9cCW=V<DF</I=><DF<V<bb<DH@@S542X002DZX0
33</Q10c9U:Z0Z002X@@012446CC<baS;08c;007Q12]EFCCWWV]EIcC[ED0
0YcC0ZeE00>meicIW=<00JeE000039V<bb`aS6</W=>mel/cVc?;<i/cS57;
<`:K<`06bc>K;9/cHHb]EIcC0X@@00eQS8@@S56Ldi/cW=>]EF<c[EFmef<c
Hbb<D@02[ED01V<cQ12K;:eEVc=S;0:Ld`04Q01S;9cC[ED2Q102[ED016<c
S56]EHaA0X@@0ZeE00BLdh@@Q12Ld`:4400>[EF448@@HbbK;8aA[EFLdfCC
Hbb44:eEQ02440:Ld`0;I=>44:eEW==S<jeEI<b449cCQ11Td`02[ED018@@
HbbLdhaA0X@@01UTdicIW=><DF</S56]EF</Q12LdjeEI==S;666Hbb<DF</
W==S<haAHbIBZP:PHHJLd`02Hb`02XaA<bb448@@I==S;9cCI=>449cC0X@@
00BLd`@@W=><D@8c9P08Hbb443<VHbb]EIcIW==S;0:<D@0;<b`c9XaAQ104
4666DZX2X00:Q1044002DZX03c</Q11Tdh@@I==S<h@@111S9V</Hc=TfKgG
cWVNN@02W=<3[ED00icI[EF]E@01[ED0000HVbc;;9V<HbbLc;gGW=>K;9/c
bc>K<i//bbbK;9/cVbb446</[EFLdf</Q11S9X@@0YcC00IS<jeE[EFK<fCC
_ML2Q1002haAW=>]EHaAQ12K<jeEI==S;:eEW=<00V</02B<DJeES56449cC
_MN<DH@@[EF<DH@@S56]EIcI[EFK;8aAW=<c;8@@[EF446</Q12K;8aA[EFL
dhaAQ11S;:eEHbbK<jeEW=<2Q1001jeEW=>44:eEQ12<DIcC00:<D@:]E@03
Q11S<icC00>44004W=>]EIcCS542Hb`09kgGI<aS<fCC[EF446</<bHc;8aA
Hbb<DH@@S54c9U00<bIS;8aAHb`c;8@@<HaTdh@@W=<c;9cC<c>44:eEI=><
DJeE112LdhaAHbHaP002Hb`2<b`2[ED028aAHbb446</DZX448aAHc<2<b`0
4000DZYBZX@@I=>446</111S<jeE112Ldh@@HbaBZS</0V</00YS<fCI[EFL
fIcCVc>]EIcC[EFLf@:]E@6Ld`0000K;;9/cVbb449//aQP2bc<02Y/cbbbK
;9//S56K<icCVbb443</0YcC00ATc8@@<bJK;0:Ld`03Hc>LdicC00:Ld`08
_MN446</I=>LdjeEVc=S;0:Ld`0:Vc=S;:eEW=>44660S56]EI/cQ102[ED0
1V<cI=>LdicCVbb440:]E@08W=>448@@W==S<h@@_MMTc0:4400<HbJLdjeE
W=>K<fCCHbJ]EFC<HbbLdjeE0X@@00BLdjeE112]E@:44008W=><DHaA[EFL
dhaAQ12]E@>440:]E@0:W=><DF</Q12]EF</Q12<DJeEQ102<bH07V6<W<b4
46CCHc><DF<P<H1BZS60S56443</Q11BZV</Hc>Ldc</W==Tdh@@[EF446<c
W=<c;9cCQ11S9P9BZP0=HbJ445:ZS56LdhaADZXaS6</<b`aS9cCI=<00X@@
00lc;6CCI=>K<fCCQ11S9S</Q11Tdf<c[ED4436<<b`00V</00Lc;6CCW=>]
EFCC[EFLd`05[ED1VcT1W=<00006VbbK<i//HbbLc<HH0i//0XaA00^04:eE
[EF<DF</Q11Tc:eEW=>449//009S;0:Ld`0:Q12]EIcIS5644:eEI=>449/c
[ED2W=<03F</S56]EFCC<bbLdjeEQ11S9XaA[EETdh@@00:]E@09S55Tc9cC
W=>446<c[EFmeicC00:4400?[EF440@@_MN446C<HbbK;9cCW=VLdhaAI==S
9ZeE00:4400=W=>]EFCCQ12]EIcCQ12]EH@@S56LdhaAHc<00ZeE00=Tdc</
[ED00X@@011S<jeEW=VLdhaA<bb44:eEHbb446CCS56446<V<bHaP0:4400D
S55S;8@@DZX2X5:Z<bb<DF</DZYS<e:ZS55S<icC<bbLdi/cI=>Ld`:4400?
[EF448aAS55S9U:ZHbaS9S60DZZ<D@@@Q11S;0@@00:44007<bbK<fCCI==S
;8@@Vc<00fCC00Lc;6</<bb448aA112]E@02Q1001f<PDZYS9S6<Q11TdjeE
00BLd`03VcV]EIcC00>]E@0000aQQX@@W==S<haAaQRLdh@@HbJ<DI/cQ102
[ED01i/cHc><DF<cW=>]EH@@009S;00:HbJLdicCHbbLdjeEW==S<jeEW=<2
Q1000icC[EFK<`02Q1002jeEVc>448@@[EETc666S56]EI/cQ1000ZeE00JK
<h@@W=>LdfC<Q102[ED019cCVc>K;9cC0X@@00jmeh@@Q11S;8@@S56]EIcC
S55S<f</_MMS;9//0ZeE0XaA00BmefCCVc>]E@:44003W=><DHaA00:]E@04
Hc>448aAW=<2S5403jeEI=>Ldh@@HbIS;:eEI<IS;8aAW=>446</HbIBZP03
Q1000c</Q11S9P03DZX00icCI==BZP02<b`01H@@Hc>Ldc</[ED00VCC00NL
dfCCQ12]E@@@S56Ld`02<bH03666<bIBZU:ZQ11TfIcCHbb448aAQ10c9P:4
400?W==S;6</S56Ldh@@W=>443<V<bb446CCHc>LdfCC009S9P0:DZXaP6<V
Q11S<jeEW=><DIcCS542W=<00jeEW=VLd`01[ED0000<HHJ<DIcCHbb<DLHH
S55QS8@@W==S<f6<0ZeE00JLdf</Q1244:eEW=<2Q102Hb`2W=<08H@@W=>]
EIcCI=>]EHaAHbaTdi/c[EF<DH@@Vc>]EFCCQ12<DJeEQ11QS8aA[EF<DI//
W=V]EIcCHbJLdjeEHbb44003[ED2Q1001:eES55S;;gG0h@@01:K;9cCW=>L
fIcCS55S9YicQ12K;9cCW=V<DF</_MN]EFCC[ED2Q1000icCI=>44002[ED0
28aAQ12LdhaAHbb44:eES542Q102Hb`03JeEHbJ448aAW=V<DH@@<b1BZX@@
=<bK<c</009S9P0?<b`aP00@[EF445:ZHbaS9S<c[EFLdc</S56446<c00:<
D@06<bbLdf</S56445:Z0S</00V443</DZZ449cI[EES;8@@S5400V</00V<
DFCC[EES;3</Hbb446<cI=<00X@@00eS<`@@[EF44:eES55S9S60DZXaP3</
Q11Td`02W=<00haAQ11S<`02W=<3[ED1W=<0000BDZYS;9cCHc>44<HHW=>4
46<VS56Ldh@@[EFLdjeEHbb<DH@@0ZeE0X@@00]S;6<VW=>Ldi/cW=>]EI/c
S56meicC00:4400@W=>]EIcCQ12K;:eEVc>448aA_MMS;6<VS56LdjeEHc<2
[ED019cC<HbLdjeE0X@@0ZeE00VLfH@@Q12Ldi/c113669c<Q1000V<V00R<
DJeEW=>LdfCCHc>mef<V0XaA00>]EIcCQ1000ZeE00ES<jeES56449cC00:<
D@:]E@08S54448aAW==S;8@@S56Ld`:44003<bIS;:eE00:44006S56meicC
S54c9S6<0h@@010446<VDZXc;36<DZZ]EFCC<bb443</Hc>mefCCHbb<D@>4
4007I==QQX@@DZX449cCI=<00V</01F446</<bJ44:eEW==S;8aAW=>443<V
Q12<DIcC111QS8@@HbaS<jeEI=<00V</00f<DKgG112LdhaAHbaS8360HbIB
ZV</S56]E@03S5400icC[EFLd`03[ED1W=T00003DZZ449cC00:44004aQR<
DF</Q102S5401f</W=V]EIcCHbb<D@@@00:Ld`04Q11S;8@@HH`2W=<02F<c
[EF]EIcCHc>meicCHbb44003W=<03F6<S56]EIcC11244;gGQ11QQXaA[EF<
DH@@00:]E@04W==S;8@@[ED2Q103[ED2Q102W=<00c<V_MN44003Q1003I/c
[EF]EIcCI=<c9[gGHbb<DIcC[EETdf</00:]E@05Vc>]EIcCQ12Ld`02S540
3:eES56<DH@@S56Ldf<VHbaTdicCS564409S;00M[EF<DH@@Q12]EIcCS55S
9S<VQ12<DH@@Hc=BZV<c<baBZS</W=>446</<HaS;6<ccWUTdc</W==S<`03
Hb`033</Q12448@@W=>446<VDZZ443</DZZ440:]E@03HbbK;8aA009S;00J
I=>LdicCI=>446CCW==TdicCHbaTc6</Hc>mef<cW==Tc8@@HbHaP5:ZHbIS
<haA[EF440BLd`04[EFK<icCW=<1W=T0000DHbJ448aAVbb44<HHW=>446<V
Q12Ldf</[EFLdjeEP12446</W=>]E@:44005HbIQQYcC[EF44002W=<02IcI
Q12mefCCQ11S<icC[EFLd`02Q1002icC[EDaThaA_MMTc666S56]EI/cQ100
0ZeE00]Tdh@@Q12mecC<Q12]EIcI[EF<DH@@00:Ld`07<Hbmeh@@I<b446<V
S5400ZeE00ZK<fCCQ12]EI//Q12<DJeEW=>440:]E@04I=>]EIcCI<`2S540
2h@@I=><DH@@Hbb<DIcCHbb448aA[ED00YcC02Z443</[EETc8aAQ12mefCI
Q11S;6<VQ12Lc0@@S55S;8@@Hb`aS5:ZQ11Tdf</<bIBZX@@cWUTfF<VW=>]
EFCCHc<c;6<c[EETdf<c[EES;3<PHbH2Q1002E:Z<bbmeicII<aS;8aAQ11S
;002S54026CCQ11S;8aAW==S<jeEQ102Hb`03h@@_MMTdicCS56443<P<H1S
9U:ZHbaTdjeEI=><D@02W=<00jeEVcVLd`02[ED1W=<00003HH2449cC00:4
4007_MNLdf</Q12K<haAHb`00ZeE00JLdf</Q12449cC[ED3Q1002V<VVc>]
EH@@[EFLdjeEHc>meicC0X@@00FLdjeEW=>448aA00:]E@0<Q12<DLHHS55Q
QXaA[EFLdf</[EG<fHaA0X@@00>meh@@Q1000jeE0X@@0YcC00<c9[gGS540
0X@@00jK9Y/cW=>]EFCCW==S;;gGI<b449/c[EFLdf</0ZeE00ATdjeEW==S
;0>44009W=><DF</Q12<DIcCQ12<DFCC00:]E@05S56443</[EF<D@02Q100
5kgG[EF<DC<VDZYTdic<HHb4436<HbaTdc6<<bJ<DJeE<HaBZS6<Q12meicI
Hb`00X@@015TdicC<b`c<jeEQ11TdicCQ10c9U:ZQ11S;5:Z<bc669cI00:4
4003S55S;6</00><D@9S;004Q12Ld`@@[ED3Hb`048@@[EETdicCS56446<V
<H1S83</HbaTdjeEVc><DIcC0ZeE00>LdjeE[ED00ZeE00003c60Hbc<dic<
Q12meicCHbaS9XaAW=>449cCW=VLd`02Q1006F</S56]EHaAQ11S;6<VW=>]
EF<cW=>LfIcCVc>mejeEQ10c;9cC[EFK<haAQ12]EI/c00:44004_MN446<V
S542W=<01h@@[EFLdicCQ11S;;gG00:44003W=>]EJeE00:440:Ld`0LHbbm
efC<S56446<VS56]EIcCVc>Ld`@@[EETc8@@S56meicCHbb]EIcCVc>LdjeE
Hbb408@@Hb`2W=<03XaAQ11TdjeEQ12<DIcC_MN]EHaAQ10c;:eEW=<2Q100
1icIW=>Ldh@@DZYS;8aA008c9P0KHHJ446CIHbIBZV<cW=<c;3<VQ11S<i/c
I=<c;8aA<baS;9/cI=>44:eEHc>44:eEQ10c9V6600:4400:DZXc;;gG[EF4
46</S56443</Q102I=<01h@@Hbb<DIcCHc>]E@@@009S;00=Q12mefCCS56L
dfC<HHIBZS60HHHc;9cC[ED01YcC00>]EIcI_ML00IcC00002E:ZVbJLdhaA
Q13>LjeEQ11S;002S5402F</W=>]EIcCHbb446</I=>me`02Q1001V</VbJ<
DJeEQ12Ld`:]E@03S56]EIcC00:44007W=>]EIcCI<b04:eEW=<00X@@00[6
68aAHHJK;:eEW==QS;gG[EFLd`:44008_MN446<c[EFLfKgGS56440:Ld`03
<bJmehaA00:4400;Hbb<DJeEW=><DJeE<bb]EHaAVbb<D@02W=<016</W=><
DFCC0YcC0h@@00Lc;9cCW=V<DH@@W=>]E@03S5401IcI[EFLdh@@<b`00YcC
0X@@012meicCS55S;5:ZI<bLdc600Z1BZY/cI==S;36<I=>]E@9S;00HQ11T
df<cHb`c;8@@111S;8@@Hc>446CCW=>44:eEQ11S;3<VHbb445:Z<bbmejeE
0X@@00f<DH@@<bb44:eEW==Tc6<VVc=Tdh@@W=>44002Hb`00c<c[EETd`02
W=<036C<HbIBZS<PHHaS;6CCW=VLdjeEI=VK<`>]E@6Ld`6Lf@6]E@0000mB
ZV<PW<bLdhaAaQR]EH@0Hbb448aAQ12LdjeEVcT00h@@00B<DKgGQ124409S
;003W=>]EHaA00:Ld`07W=V449cIWW=S<h@@W=<00ZeE01ES<i//[EF]EF<c
Q12meic<HbJ44:eEW=>44:eEW=>]EF</Q12mehaAQ1000jeE00NK<h@@W=>L
df</[EFLd`02Q1005f<VS56]EJeEVc=Td`@@[EF446<VQ12<DH@@HbJ<DIcC
Hc>LdkgGI<b<DIcCQ1000ZeE00BLdf<cW=?660:44006S56mejeEI=>4466<
0YcC00YTc8@@[EF]EHaA<bIQQV</W==S9P9BZP0JQ12Ldc<c<bb44;gG<b`a
S8@@Hc>443</<HaS;:eE_MLddf<cQ12K<jeE112]EFC<HbIQQP:4400;<bIS
;;gG_MMS<h@@S56446</Q11Td`02S5405C</Q12<DHaA[EF443</Q11S;:eE
I=>LdjeEHbaS9S<PHHIS9S</W=>me`02W=<00i/c[EF]E@02[ED1W=<1c=T1
W=<0000<DZZ449//cW>44<HHW==S;6<VS55S<f</0icC00N446</Q1244<HH
S5644002Hb`00haAW==S<`02[ED019cCQ12LfJeE0X@@0icC0X@@00^LdjeE
Hc=Tc<HHW==S9X@@W=>]EF</00:]E@04W==S;6CCaQP2Q103[ED01haAQ12L
dicC<bb]EIcC00:4400>VHJ<DIcCW=>44:eEQ12]EHaAHH2448aAQ11S;0>L
d`06I=>]EH@@S56Ldh@@0jeE00=TdicC_ML00XaA00AS<jeE[EFLd`:44004
W=>]EH@@Hb`2[ED04X@@<bHc9V</WW>443<V<H`c;:eEQ11QS0@@_MLc;36<
I=<c<`:44006DZZ449iiW==S;6<c0VCC00J]EC</_MN<DC<VHbH2Q10073</
Hbb]EJeEQ11S9X@@Hb`c9X@@W==TdhaAHbJ448aAHc=Tdh@@Hb`c;8@@[EFL
dhaA[EF446<V0S600V</00=TdjeEW=<00ZeE00>LdjeEVcT00ZeE0IcI0JeE
00003360HbJK;9cCQ12meicCQ11S9V</S55S9P>Ld`9S;0:4400>_MMTc8@@
HbaS9XaA[EFK<jeEW=>]EH@@W=>me`:44005W=>]EI/iW<aS;002[ED04H@@
<bbmeic<Hbb449cC[EES;:eEW=VLdhaAQ12mefC<S5400ZeE00RLfIcCQ12L
djeEHbbLdjeE0X@@01MS9X@@W=>Ldh@@S56449cCW<aS;8@@S56Ldf</W=>]
EFCCW=>meh@@S56Ldf<c00:]E@05W==S<icC_MMTc002Q103[ED05X@@<bb<
DJeEQ11S;9cCI==QQS<VQ10c;;gGHbaS9S<VHbbLfH@@HbJ44;gG0S</00R4
46<c[EF443</Q12<DC<V0V</00J449cC_MLc;:eES542HbH098@@HbaS9V</
_MN<DH@@HHb<DH@@<bIS;9cCI=><DC<VQ12Ldh@@W=>446</HbIS;9cCI=V<
DJeEI<aS9U:Z<H1S9S</W=>Lf@:Ld`04[EFLdjeEW=<4[ED0009QQP0:W<b]
EH@@cW>Ldf</HbIS;8@@HbH3S5403H@@HbaS;8@@_MN<DF<VQ11QQXaA[EES
<icC00:]E@0:Hc><DIicS56449cC[EFLdh@@Vb`2W=<2Q1002[gGW==S9X@@
W=>]EF</W=>meicC0X@@00>meh@@Hc<00ZeE00>mehaAVbH00YcC00=S9YcC
W=<00X@@0V<V0h@@00ITdh@@[EF<DH@@S542W=<02X@@I=>mejeEW=>]EH@@
S56LdfCC0jeE00><DJeE_ML00h@@0ZeE01BLdh@@Hbb<DIcCDZXc;9cCS564
46</HbIS;:eEHbaQS5:ZQ12LfFCC0S</02:]EH@@<Hb446<c[EFLdh@@Hbb4
43<V<bb446<cW=>]EH@@[EF<DF</<H2446</<b`aS;gG[EF<DF<VS56446<V
112Ld`:<D@06HHJ449cCI=>LdfC<0V</00h44:eE[EETdjeEQ11S85:Z<H1Q
QV</S56LfJeE0YcC00J<DIcC[EF]EIcI_ML1[ED0000<DZXaP9c<VbaS;:eE
W==S;3<VHbJ4466<0h@@01AS;6<VQ1244;gGW<aS;8@@HH2448aAVc>LdjeE
VcUS;8aA_MN446</0YcC01N]EH@@Q12LdjeEHc>44:eEW==S;9//W=>mef6<
[EFmeicCHc>44;gGW<b449cC00:]E@0;W=>449cCW==S;9cC[EDc;6</HbIS
;003Q1001ZeEHc>LdicCI<bK;0:]E@0;HbbLdkgGI==S<lHHI<b<DIcCQ12L
d`02[ED00h@@W=>me`02S54028@@W=>Ldh@@Hb`c;8@@[ED2Q102[ED08VCC
HbaQQV</[EF408@@0Z244:eEI=<c;6</aQQTdf6<I=>LdjeEW==S<f</I<aS
;66<HbaS<icCaQQS<jeES55S;3<V0V<V00eS;6<V[EF]EIcCQ11S<haAHbb4
49cCI=><D@02Q1004XaAW==S<haAQ11S9V</W=>]EF<c[EF448@0<HaS85:Z
<bITd`:]E@>Ld`04W=V]EJeE_ML2[ED0009BZP07W<bLdc<V[EG>Lh@@<H`0
0f<V0X@@0V</00ES9V</HbbmehaA009S;004HbJ448aAQ103W=<02V</I=>]
EHaAQ12LdjeES56K;8@@0YcC0X@@02V]EIc<Hbb449/c[EF449cCW=V]EHaA
<bbmeicCQ12LdjeEW=VLdf</Q12<DC</S56]EH@0Hb`c89//S56LdfCC[EF4
49cC[EF448aAW=>]EF</00>]E@06S56meh@@S56Ldh@@0jeE01b<DIcC_MN<
DF</Q12Ldf</<baS;8@@S56NLhaAHc>LdkgGS56443<VQ12]EF<VQ11QQP@@
_MNLd`9S;007_MMTdh@@Hc=QTkgGW=<00X@@00aTc6<V<Hb446CCVc>NNF</
_MNLdf</HH02Q1001S</HbJ]EJeES56440:<D@0;<bb449cCS55Tdf<VQ12K
<fCCW==Td`03Hb`04FCC[EF44:eEI=>40360DZYS9V</Hc>]EIcCVcV]EIcC
[ED00icC0JeE0IcC00001F66HbJK;<ic<b`00ZeE00n446</HbJ445:ZHbb4
46</HbIBZV</Q13666C<Hb`00V<V00=S;8@@Q1000XaA00NLdf</S56]EH@@
HbbLd`02S5403X@@HbbLdicCQ11S;:eEW=>446<VW=>]EH@@W=<2[ED2Q100
2:eEW==S;:eEW=>]EHaAHbH2Q10045:ZS56]EF<VHbaS9X@@W=>]EI/c[EET
dhaA[EES;8aA0ZeE04QS;8aA[EFLdfCC_MN449c<[EF446CC[EFLdh@@Hc?6
66</HbJ449cCI=>LdhaAQ11TdkgGQ11S;9cC_MMTdh@@<bIS;9cCI<b44360
Hbc<fFCI<baS;:eEQ11QQYcCI=>meicCHc>448aA<bIS;3<VHc>LdlHHQ12]
EFCCI<aQQV</Q10c;5:ZS56mefCIHbH2S5401h@@Hbb]EH@@I==S;8@@00:<
D@0;W==Tdh@@Q11S;8aA_ML44:eES5640002<H001V<PHHaTdicC[EFLd`:]
E@05W=><DIcCW=>Lf@01[ED00008<bIQP8aAc=>449cC_MN<D@9S9P0;Q11S
9XaAHbb446<V<bJ448aA_MN44002Hb`01F66HbJ448@@W=<00XaA00Dc;8aA
[EES;8@@00:<D@03Q11S;66600:<D@0:Q11S<iicS55S9Y//W=>]EH@@W=<2
[ED2Q1001JeEW==S;:eEW=<00XaA00<c9X@@S5400V</01Jmeh@@S55S;8@@
W=>]EFCC[EES<h@@WW>K;8aAW=>]EH@@W=>LfJeEW=>]E@><D@>44007HbIS
;6CC_MN446CCQ1000jeE01R<DF</I=>meh@@I=>LdkgG[EF446<VHbbLdfC<
Q10aS66<aQR]EC</HbbLdfCCHH`2W=<04[gG[EETdh@@W=<c85:ZQ11S<icC
aQP44;gGS55S;3<VHbb4409S;004Hc>mejeEQ102S5402c</Hbb]EFC<W==S
9X@@I=>K<icCI=<00f</00AS<kgGQ12]E@:44006<H1BZV<VHHaTdicC0jeE
0YcC00B<DI/i[EF]E@6Lf@0000Tc9V<VQ12Lc8aA_MN]EHaAHb`00X@@00]S
;8@@Q12446<VHHIS;8aAaQRLc8@@00=S9P9S;007S56448@@Hbb<DJeE1100
0h@@0V</02mS9X@@Q12446</W=><DF</Q12<DJeEQ12<DJeEW=><DF</[EFL
c8@@W=><DIcCQ11S;9//W==S;8@@_MMS;8@@HbbK;9cC[EFK<icCI=>44:eE
Hbb<DIcC[EES;9c<00:]E@03W=>]EH@@00AS;005Q12<DFCCS56]E@02S540
3X@@[EFLfJeES55S;:eE_MMS;8@@S56meicCS542Hb`0AIcCW<aS;3<VHbc6
69ii<b`aS8aAQ10aS6<cS56meicCS56446CCQ00aS6</I=>LdkgGHc>]EIcC
Q10c9V</S56440:PQ12mejeEHbb<DIcCHbb449cCQ12<DC</Hbb<DIcCI=>L
dh@@Hb`c;8aA_ML44;gGQ11Tc666DZXaP6</I=>LdjeEW=>]E@03W=<4[ED0
000<HHIS9Y/V[EF<DKgG[EFLdf<VHbb<DF<V0h@@019S;6<V<bJ44;gGS564
46</HbHc9Y//HbaTdi//Hb`c;8@@_ML2Hb`01HaAHHIS9S<VHbH00f</00P4
4:eEW<aS9V</S56Ldh@@0YcC00B<DH@@Q12]E@:440>Ld`07Vc>448aA[EF4
46C<_ML00X@@00US;8@@W=>mehaAW==Tdh@@[ED00X@@0ZeE00Z448aAW=><
DI/c_MMTc6<VHbaTd`:Ld`07[EFK<h@@_MNLdhaA11000jeE00B<DF</W=>m
e`:44004I=>]EJeES542Hb`03icCQ11S;0:PQ13<fLiiQ11S;8aAI=<c;6</
Q12me`02W=<058@@W=<c9V<VHHaTfIcCaQQTdjeEW==S;6<VHbb443</DZZ4
49iiW=<2Q10029cCHbaS;8aAI=>Ldf<VQ102S5404VCCW==S9X@@HbaTdkgG
112mehaAQ00c9V60<b1S;6<cW=>]E@BLd`03Vc>LdicC00:]E@0000=QQS<V
HbH00XaA00O66:eEW==S;8@@S55S;002Q1002F</HbHc9V</Q12]EIcCS564
4002Hb`00h@@Hbb<D@02Q1004V<VS56mec</Q11Tdc<VDZXaP666HbHc9V</
Q12<DFC<HbaS9P:<D@03HbbLdh@@00=S;0:Ld`0;I<J<DKgGW=>]EH@@S56]
EF<cQ12]E@02S54018@0Q12LdjeE0icC00J44;gGQ12449cCS542Hb`016C<
Q11TdjeE0XaA00^LdhaAW=>mejeEI=>44:eES56Lc8@@00:]E@05W=>446</
S56]E@02Q1004YcC[EFLdh@@HbIS;9cCI<aS9S<VQ12]ELii==UQQZeEI=V4
409S;00<[EFLdh@@HbbLdfC<DZXc;9cC[EG666<c0ZeE01lc;6<VHbb<DH@@
DZYS;;gGW==Tdf</W==S;6<VS55TdicCHbaS9XaAW=>K<jeE<bb446<VQ12L
fH@@[EF<D@02HbH01S<P<H1S;8@@I=>]E@:<D@>Ld`03[EFLdkgG006Ld`00
0V6600=S9Yc<Q1000[gG00BLdf</Hbb4409S;0:4400:HbaQQV</Hbc>LjeE
W=><DF<VVH`2Q1002icCS56<DF</I=>mefC<Hbb<DF<VDZX00S6000eBZV66
<bb449cCS55QQV<VHbb446<VQ11Tc002Hb`02c</W<bLdh@@S56mejeEW=>4
48aA[ED00X@@01:NLh@@Q11S9Y//W=>LfIcCI=>Ldf</WW=S;6<VHb`c;3<V
Q102W=<03HaAW=>LdhaAW=><DIcCW=V]EIcCHc>meicC00:440:]E@09S55S
;6<VQ12Ldh@@HbbLdhaA00:4400HHbHc;9cCQ11QQS6<Hbb<DKgGI=<aS9cC
[EETdf<c<bb<DH@@<bHc;9cCHbaQQV6<0YcI00g>NFCCW=>mef</HbIS;8@@
HbaBZX@@_MNLd`02Q10018aAQ10449c<0XaA01R446<VS56<DFCC[EES9V</
<bb44;gGS56]EIcCHb`aP5:ZHb0c;6<cI=>mehaAW=<2[ED019cC[EFLdicI
0JeE0002<bH00f</W<b<D@02_ML018aA<baS9XaA0h@@00=S;6<V<bH00V</
0ZeE00NLc9cCHbb446C<S5644004S5402KgGS56446CCHbHc9V<VDZXaP002
HbH00h@@S56<D@02<bH00f66HbIS9P02S54049//Q102X9c<[ED448aA[EFL
djeEQ12K;:eEI=>44;gG0X@@00AS;8@@S56]E@><D@08<bbmef<VHbJ<DIcC
S56440:]E@04Q12]EIcCI<`2W=<3[ED05icCHbb]EIcCS56449cCS55S;6<V
<bIS;:eEI<IS9YcCS56406</HbHc;8aAQ1000c<V02>449cIQ11BZXaA_MMT
fH@@Hbb445:Z0Z1BZYcCQ10c9X@@WWW66;gGW=>LfJeEHb`c9V<VQ11S;3<V
Q12]EIcCQ11S;9cC009S;00IQ11TdicCI<aS;8@@S55S<jeE=<b443<VQ12m
efCC[EETdhaAQ01BZS60Hbb<DIcC_ML00YcC00>]EIcCW=<00ZeE0IcI0JeE
00000f66HbHc;002Q1000kgG[EF44002Hb`00haA<bb44002Q1008F</HbIS
;8@0[EFmeicCS55S;9//S56448aAW=><DH@@I=>meicCQ12<DH@@HbHc9V66
<H1BZV<VI=>LdhaAHbHc9P02HbH02f66Q12<DH@0Q10c;9c<W=>448aA[ED0
0YcC00IS9X@@W=><DF<V_ML2Q102Hb`00h@0HbaS;002S54016<V[EF448@@
0ZeE0X@@00>]EKgGS5400YcC00Z<DIcCS55TdkgG[EFLd`@@_MNLd`:4400I
W==S;6<VHHHc9S</W==S;666W<aTdf66<H1S9S<VS56Lc666<H`c;9cCVc<4
46<VHc<00ZeE01UTdc</DZXaP00:<bJLdf<cHbbmeicIWWW669cCI=>]EH@@
HbIS;8aA<b`aS8@@_MNLd`02Q1001YcCHbaS;8aAI=>Ld`9S;005Q12Ldh@@
[EES;002Q1001c</_MMS<jeEW=><DF<V008aP008Q11S<cCC_MNLdjeEW=>]
E@:Ld`>]E@0000YQQS<PHHK<c8aA_MN]EH@@HbIS;0F44006<bIQQV</Hbb]
EKgG0XaA00F446<VS56<DH@@00><D@07Vc?66:eEQ12Lc6</HbH00U:Z00@c
9V</HbJ<D@:Ld`=S9P0IHbaS9VC<Q11S;8@@<H2<DJeEI<J<DIcCS56Ldf</
Q12<DH@@HbbmefC6Hb`aP6<VHH`00X@@00B<DIcCQ12NL`:4400:W=>]EHaA
Q12]EKgGHc>meicCQ103W=<2[ED0:HaAQ12LdicCI<aS;9cCI<aBZS60<bIS
9YcCHbaS9X@@I==S83<PDZXaP8@@S5440360Hbbmef<c<b`aS6</[EETdjeE
<c=S;36<<bIBZXaAW=<00Yii036LfIcCWWUTdicC[ED446<VHbb<DH@@DZZ4
4;gG[EF446</S56443</Q12<DFCCQ11S9XaAW==S<jeEQ10c;6</<bbmefCC
W=>]EH@@<bIS85:ZHbJ446CCc=V<DJeEW=>]E@04W=<1[ED0009BZP06H0JL
c8aA_MN]EH@@0V</0X@@016<DH@@Q12446<VHbaTc9cC_MNLdhaAQ11S;8aA
Q11S;9cC00:<D@05Q12NNJeEHbb44003HbH02666Q02446</Q11TdjeEHb`2
HbH018@@HHbLc8@@0V</00Dc;9c<W==S;9cC00><D@06HbaS9X@@Hb`c9[gG
0X@@00=S;8@0S5400YcC00R<DFCC<bJmeh@@VbbLdjeE0X@@00^LfJeEI=>L
djeES56LdfCCW=>mejeE00:440:Ld`05HbIS;8aAHb`c9P02<H00166<W<aS
;5:Z0XaA00IBZS60DZYQQVC<W=<2DZX08F</[EF448@@DZXdc:eEHc>]EC<c
[EETdc<VDZZ<DKgGcWV]EIcI<c>meicCI=>]EH@@HbIS;9cCQ11BZX@@_MN]
E@02Q10039cCQ11S;6CCW=><DH@@Hbb449cCI=>]E@>44003<bbmefCC00:]
E@0:Q10c9V60<H0c;9/c=W>mehaAVcT2[ED00icCQ12Ld`02[ED0000;<bHa
P6<PW<b44:eE_MNLc6</HbJ44002S5401YcCVc>446<VHbb440:]E@05W=><
DH@@HHJ<D@02Q102S542Q1001KgGS55S;8@@HbH00X@@01AS88@@S56446</
W=>mefC<HbJ449c<HbaTc8@@VbaS;6<VS56]EFC60XaA0V</00<c9V6<<bH0
0V</00FmefC<HbaS9V</00:<D@0<W=>449cCQ12]EIc<Q12<DKgGS5644;gG
0icC00>mefC<Vc<00icC00^<DFC<HHb44:eE<b0c9XaAHbaBZS60009BZP0X
I<b443<PQ11Tc3<VHbIBZS60HbbLdc<P<H1S;9cCI=><DF<VQ12LdhaA[EDc
<i/cW=<c;5:ZS5766:eEI=>K<h@@_MN]EF<c_MN443<VHb`2S5401S</Hbc6
6:eEI=>440:<D@0F<bb449cCI=><DF</S56Ldf<c[ED448@@Hbb44:eEI=>L
djeEQ12405:Z<H02Q1000fCCc=VLd`02[ED3W=<1[ED1Vc<1W=<000=BZP05
c<bLdlHHaQR<D@02Hb`00haAQ12<D@02W=<038@@HbJ446</[EFmeicCS564
46<VQ11S;0>4400BHb`44;gGW=<c;8@@W=><DH@@<bbK;8aAHbb449cCaQR<
DF<V0XaA0X@@00BLdh@@Q10440:]E@06Q11Tc8@@Hb`c9V<V0f</00@c9[gG
Q11S;09S9P07Q12<DHaAI<bLdf<V[ED00X@@00Z<DIcCW==S9[gG[EETdicC
[EFLc0:<D@03W=><DF</009S9P0:Hbb]EF<V<H2<DFC<HH0c9S60DZX2Q100
0f66=<bLd`02<H02DZX043C<[EEBZS60HbbK<fCCS55S9S</[EES<kgGI=><
DFCC0U:Z00f<DIiiQ11S;8aA112]EIcCQ12]EH@@HbIQQP02S54013<V<bb]
ELcI0X@@0XaA00YS;0@@[EETdic<HbIS<icCI=>]E@:4409S;00=[EFLdfCC
[EF446<V<bHaP6</Vc=TdkgGW=<00jeE00BLdjeE[EF]E@6Ld`0000Xc9V<V
HbK<c9cC_MO669cCQ11BZP>44006W=><DHaAHbb446</0ZeE00>LdhaAHb`0
0f<V00F448aAQ12443</00:]E@03Q12Lc8aA00:<D@0=HbbLc6CCQ11S;:eE
_MN<DH@@Vbb<DH@@HbH00XaA00F446</W=>]E@@@00:<D@09Q11S9V<V<bIS
9V</HHbmeic<00=S9P0=HbbK;8@@Q11Tdf</[EETc6</S56LdhaAHb`00ZeE
00=TdjeE[ED00h@@01Z<DFC<HbHc9U:ZHbbNLf<VDZZ446C<H0Hc9S60DZZ4
49c<<bIS;9cC101BZS60HbIS;9cC0S<V00ABZV</I=><D@9S;00I_MMTc:eE
Hc>LdicI<b`388aAaQPc9V<VQ11S;;gGW=<44:eEI=<c;6<VQ12<DC</HH`0
0ZeE00ATdh@@S564409S;00:[EF<DFC<<bb449cCQ12]EFCCQ102Hb`029cC
[EF]EJeEQ11S9S<V<H02Q1000fCC_MNLd`02[ED00icC[EFK>@02W=<1[ED0
00=S;008W<b<DIcCaQRLdh@@Hbb<D@:44006W=><DH@@HbJ448aA0[gG00V<
DH@@Hb`c86</Vbb<DIcCS5400X@@00FLdkgGI=>Lc9cC00:<D@09HbJK;8aA
Q11S;9iiaQR<DF6600>4408c9P05<baS;3</[EFme`03S542Q10026<VHHIS
9VC<HbJ]EIcCQ102HbH02V</VbaS;6C<W==S;:eEQ12408@@0XaA03MS9ZeE
W==S<icCWW>446</<bJLdf</HHHc9V<V<bJ]EF<PDZZ446C<<H1BZP:PDZYT
c9cC<bHc;:eEHHIS9V66<bJ449cCDZX2X66<HbaTdf</Q10c;:eEHbbLfIcC
[EFLde:Z<bJ<DJeEDZXc8002Q1001icI[EF44:eEW<`c;6<V00:<D@07<b`a
S:eE_MN<DH@@S5400X@@01X44:eEI=>Ldc60Q12Ldf<c[EF<DF</Q11S9VCI
W=>]EKgGS55S9S60HbIS;8aAI=>LfIcC0ZeE00>LdjeE[ED00icC00001:eE
I=><DJeE0XaA00C669c<Q12400:<D@0>Hbb<DHaAQ11S9V</S56mejeEI<aS
;6<VHH2440:<D@06[EFLdhaAQ12LdkgG0XaA0YcC00>446<VQ1000X@@00IS
;;gG_MMTc66<<bH2DZX01C<PQ12448@@Hb`00[gG00><DFCCS5400X@@00Xc
9V<PQ12449/cWWV]EH@@HbaS809S9P9S;006S5644:eEI<b446</0X@@00MS
9YcCW=><DJeE_MLc9P02HbH038aAHbaS9S<VHHIS;;gG<b1BZX@@I<aBZP8a
P005DZYS;:eES5644002[ED01SCCS56NNF<c_MLc9P9BZP0A<baTfH@@I==S
;:eE<bbLdjeEHc=Tdc</DZZ449cCQ01BZP02Q1003ZeE_MLaTjeEQ11S;6<V
Q12<DC</Hbb]EKgGI=<3Q1001V<PHbb]EI/cW=<c9P:4400<S56]EIc<Q104
46<VW=>mefCC[EF<DH@00U:Z00=S9X@@I=<00jeE00>LfJeE[ED00icC0JeE
000039cIWWV]EIii_MMTdkgGW==Tdf</I=><D@>44007HbaS9V6<S56mejeE
S5400X@@00AS9XaAS56440:Ld`:<D@03W=?669cC00>Ld`0?S55S9X@@S564
4666WWVmef</DZYS9X@0Hb`c;9c<00>44009WWW668aAQ12<DH@@Vbb446<V
00:<D@06Vc>NNJeES56446<P0X@@00^Lc6</S5444;gGW<aS;8@0Q11S;6<V
00><D@0>W=>mef</<bIS9X@@I<aQQS<PDZZ44;gGHbHc9P:4400/0Z1BZU:Z
HbIQS9iicWV<DIiicWVNNIcIg_^LdkgGWWV]EC<VQ12]EIcCS54c;;gGHbbI
TiiiQ12<DC6<DZYTc9cCHbIQQX@@I=>]EKgG112mehaAHbaQQP:<D@06<bIS
<jeE_MNLdf<V0X@@00MBZV</[EETdicCHbJ44002S5404VCIW=>448@@<bb<
DKgGI=>]EHaAQ00aP5:ZHbbK;6CIW=>me`:]E@05W=V]EIcC[EFLd`01[ED0
000;S55TdjeEW=VmejeEWWVLfKgG[EFNN@02W=<02FCCQ11S9S<VQ01TdjeE
_MNLd`02S54016</Vbb<DH@@0YcC00N<DF</W=?669cCS56Ld`02S5401F</
HbIS9V<V<b`00[gG00><DFC<HbH00X@@00=QQXaAQ1000X@@01:]EKgGS55S
;9cCI<b446<VHHJ448aAW=?>NKgGW==Tdf</Q102S5401X@@W=>44:eEW==S
9P9S;00<I<aQQVC<Q11S;:eE_ML446<PHHIS;6C<0S<V01IQQXaA_ML406<V
Hbb448@0DZYS88@@<bcNnlii==>]ELii_MO66=kk<c?660;>N@0<<bb446<c
W=>448aA_MMS;8@@WWVK<h@@0S</00n449cC101QQX@@S56]EIcCHc>]EHaA
Hb`c9X@@S5400V</0icC00aS;8aAS55S;8@@[EETdjeE<bIS;8aAW=<2[ED0
3f</Q10c;8aAWWVK<jeEW=>443<P<H2408@@I=>Ld`02[ED019cC[EF]EJeE
0YcC0HaA00004h@@112<DIc<_MNLdkgGW==TfJeE_MNLfIii[EFNNJeEI=V<
DFCC00>]E@06S56446<VQ12<DF</0YcC00b<DF</S57668aAHbb446<VHbaS
9X@@Hb`2Q1001:eEaQR<DF</0V<V00aTc6</Q12K;8@@HbbmelHHS54c9XaA
I<`2Q1002V</Q12Ldf<ccWW669cCS55S;9//0XaA00=TdicCQ1000YcC00]S
9Yc<S56443</W<aS;3</[EG>Lf</008c9P0MHbb44660<bHaP8@@aQQS;5:Z
I<ITdc<V<c>LdkgG113>NMkkS56meliiW=VNNMkkVcVNNMkkWWUS;002Q100
3VCCHbaTdjeEQ12K<liiI=<c;8@@<bb44:eE<b`2HbH038@@I=Vmeh@@[EF<
DF</HH2448aAHb`c;0:]E@04W==S;8aAS542Q1002ZeEI=>]EF66Q12LdfCC
W=>NLf</0X@@00bK<iiiI=>meicCQ10c8666HbIS;6CIW=<5[ED00kgGW=>L
d`01W=<0000<W=V]EJeEI=V]EKgGW==S<fCC<baS<icC0ZeE00BLdicI_MNm
e`:NN@:me`03I=>LdfC<00:<D@09Q11TdhaAS55S;8aAcW<446</00>4409S
;0:<D@06Q11TdkgGS56446<V0X@@00mS;8aAQ11Tc6</[EFmeicCHbbLdic<
S56446<VS5400YcC00K>NKgGI=><DH@0Q102W=<00haAW==Td`02[ED02cC<
Q12<DHaAHbbLc6</Q12<DKgG<b`00V<V00=S;6C<HbH00U:Z00^44;gGHbb4
46</[EF<DJeEcWVNNF6C00;>N@0]I=>meliiW=W66=kkI=?66=kkWWTc;6CC
I<b445:ZHbbme`@@S57>NF<cHbbLdf<cQ11VLf<VHHIS;8@@W=>mefCC_MNL
df</<b2449cCQ10c;9cC_MN]EC</00:<D@07Q01S<jeEI=>Ldf</Q1000XaA
01:LdjeE<bb443</S57669cC_MN<DFC6HH1BZV<VQ11TdicCW=T2[ED00kgG
[EF]E@02W=<1[ED00007W==TfJeE[EFmeicIWWT00[gG0YcC00=Tdic<I=T0
0YcC00ETdhaA[EFLdicI00:]E@0=W=VNNJeEWWVLdjeES55S<f</S56meic<
Q1000XaA00B446<VHbIS;0:44004W=?668aAHb`2HbH00f</W<b<D@02Q100
;V6<WWW669cCHbbLdhaAW=>448@0S5644:eEcWW669cCS55S;9//W=><DH@@
W=><DJeE_MNK;8aAW=><DC</S55S9V</I=?>Lf</<bIS9S</Q10c9V<V<bIS
;<HH0[gG02>449ii[EF]EMkkWWV44<HHg_]TdkgGcWVmeicIg_^LdicIg__>
NC</W=<c;6</DZXc;:eEQ12<DLHHQ10aS9ii[EFK<icC009S9P0AQ11S<fCC
_MN<DKgGW=>446<VHbbLdc</HbbLdkgG[EES9P02Q1002f<VQ12]EFCCW==S
9V</S56LdfCC[ED00X@@00eS;6CC_MMTdkgGW=>443<PDZYS9V<cW==Td`02
_ML019cI[EF]EIcI0ZeE0IcC0003Hb`03H@@S56<DHaA[EFLfJeEWWVLfJeE
W=V]EFCI00:<D@0;I=UTdicCI==TfHaAW==TdjeE_MNNN@02[ED01FIcW=Vm
eicCQ1000XaA16</00R446</W=?666CCQ10c86</0X@@00R<DIc<S55S;:eE
_MNLdfCC0icC00F<DF<VS56<DJeE00;6600=W=><DH@@HbbLdhaAQ12Lc6CC
W=>mef<VS5400YcC01AS9Yc<Q11BZX@@_MMS;6<V<bIS;8@@<bIS9V</S576
6<iiWWUS<kgG0YcC01o>NIiiQ1366=kk==V]ELiiW=W66=kkW=VmemkkWWUS
;:eE111S;3<VHbbme`@@S56LfF</Q13NnicIHc>NL`02HbH02f</Q12LdkgG
Q12LfIcCI<aQQV</W=<00V</00j]EKgGW==S;8@@S55S;8@@[EF449cC<baS
;8aA0YcC00Nme`@@Q11S;9cC_MMTd`02[ED01H@@Hb0aP6<VQ1000VCC00>m
ejeE[ED00[gG00>]EIcC[ED00JeE000023<VHHIS9V6<I<b448@0W=<2S540
2VCC[EETdjeE_MNNNIcI_MN]EIcI0ZeE00]Tdc<cQ11S<haAI=>LdjeEW=VL
diii00:]E@06IWV]EJeEI=>440@@0X@@00D449cC_MN<DH@@009S;004Q11S
;9cCS542Q10019cC_MN]EHaA0ZeE00ZLdhaAHbb<DIcCHc?>NLHHW=><D@9S
;009W=><DF</Q12<DIc<[EF448aA00:Ld`0CHbaTc8@@HbJ<DKgGHbaS9S<P
HbJ445:ZQ13668@@W=WNnliiI=<00[gG00bLdliicWV44<HHcWV]EFCCg_^L
fIiicWT2[ED05LiocWT4c:eEQ11Tdf</<c>mefCCW=><DF6<S57>NIiiS56m
ec<VHbJ44002S5401IcIQ12]EIcCHb`00V<V016Ldf</<HbLdkgG[EES;8@@
S55S9V<c[EETdjeEHbb406<c00:Ld`0>[EF448aA<bb44<HH==>]EIcCQ10c
9V60<bJ440:Ld`06W=V]EKgG[EFLfJeE0icC00002c</<bIS9V<VW<b409c<
W=><DF</Q1000XaA00JLdfCCS55S<haAI=<2W=<04YcI[EFNNJeEWWV]EFCI
W==Tdf<cI=>446CCW==TfIcC[EEVN@>]E@9Td`06[EFLdh@@<H`c;8@@0V</
00F446</Q11S;8aA00:]E@07S56]EIcCW=><DH@0S5400YcC00K>NLHHW=><
DH@@Q002S543Q1005ZeE_MMTc8@@S56Ldf</I<b446<PQ12mefC<HbHc9V</
I==S;;gGcWUS>Lic0/ii00`c<jeE[EFLdliiWWUTdlHHcWV]EFCCg_/2_ML0
5LiiW=VmemkkcWTc<kgGQ11Tdh@@<bbmefCCW=<c;66<[EG<fIiiHc>]E@02
HbH01F</I<b<DKgGI=<00ZeE015S;3<VHbJLdh@@<bJ]ELHHW=UTc8@@W==S
;8@@W==TdjeE009S;00:S56Ldf<caQP448@@Hbb<DLHHS542[ED026C<HbHa
P6<VQ11TdfCIaQP3[ED01;gG[EFLfIcC0HaA000019cC==>448@@0icC00><
DH@@Hb`00X@@00US;8@@HbaS;6<VHbb446CCS5400icC00YS<jeEI=>]EIcI
WWV]EIii[EETf@:Ld`03I=>K<fCC009Td`07[EFLdfCCW=V]EFIi[ED00VCC
00Z<DFCCHc<c;8@@=<b449cCS56440>Ld`07S55S;9//W=><DIiiaQP00YcC
00ES;9//W=><DFC<00:<D@03WWVmef<V00><D@0@<bJ448@@<bJ44;gGS55S
9S<VHbITdh@@_MO666CI_ML2cWT016CC[EFmeicC0/ii01Z44:eEg_^]EIcC
cWVNNKgGcWVNNIcIg__>NFCC[EES<icCQ10aS;gG[EES<c<VHbaTdicI0VCC
01>]EC</Hb1S;9/cI=?668aAI=>]EH@@<bIS;9cCQ10aS9cCaQRLd`02Q100
3IcCHbaS<jeEI=>LdfC<HbJK<jeEI=>mef</00:44003Hc>NNIcC00:]E@08
S55S85:Z<bJ44:eEI=?<f@>]E@03c=V]EJeE00:Ld`0000f]EIcI_MNNNJeE
W=VLdfCIS56443C<<b`aS003Q102Hb`3S542W=<00haAHbb44002Q1002f<c
W=?>NLiiW=VLdkgGI=VNLicII=<00YcC0fCC00JLdfCCHc>LdicIcWT2WWT0
1LHHWWVmecCIW=<00XaA00>448aA[ED00XaA00IS;6C<S56LdicIcWT2W=<0
16</I<b<DIcC0X@@00><DKgG[ED00X@@00VLc9cCQ11S;8@@<bJ<DJeEI<`0
0f</00b<DH@@[EFmeicC_MO>NLHHI=>]EIiiW=<2cWT01VCC_MO>NIiiQ13>
N@:me`0HcWVLfJeEg_^NNFCC[EDddhaAI==QS;gGI=US85:ZHHaS<kgG1124
4:eE<baS9V</0X@@012mefCCS56mef</HbIS;9cCQ10c9YcCaQR]EF<cVbb<
D@:4400I[EETdjeE111QS8aA[EFLdlHHQ12<DF</Q12mefCC[EFLdfC<Hb1B
ZV66Q12LdjeEWWT01JeE0icC00001C</Q12<DF<c[ED00YcC00JNNJeEW=VL
diiiW=<3I=<01X@@112K;8@@S56Ld`:<D@9S;00D<bb448@@Hc?669iiQ12<
DIcCHc>LdjeEW==TfJeEW=V]EFCI[EETd`8c;006S56LfLiiWWW>NIii0/ii
00NNNLHHWWVLdfCCW=>]E@02Q102S5402IcC[EG>NJeES56K;6</S56Ld`02
Q1004FCCW=>Ldh@@S56LdhaAHbb408@@HbJ44:eEI<b448aAHb`00X@@00IT
dicCS56meliiaQP2W=<03kgGW=?66<iiS56melii_MN44<ii_MN]ELiiWWUT
d`02g_/09fCC[EF<DH@@I=<c;:eEWWUS9V</112K<fCC<bb44:eEHbHc9V</
Q11TdkgGW==TdiicQ11S9V</W=>4436<S5766:eEI<b449cC<bb44002[ED0
29cCI<aS;8aAW==S<kgGHb`2Q1002@@@_MN<DJeEW=>446<V<bHaP002S540
0icCWWV]E@03[ED2_ML2W=<00007<bIBZP:PHHIS;8@0Q1000haA00BLdicI
W=>Lf@>]E@05I=>LdcCCI<aS<`02S5404Y/cI=>448@@<baS<haAI==S;8@@
S56449cCI=><DFCCQ12<D@>Ld`07I=<c;36<W==TfIiiW=T00iii01jLfIii
_MNNNKgGIWV]EIiiW=>]EFCCW==TdhaAaQRLdhaAI<aS9XaAW=><DH@@I=>4
4;gGI<b448aAW=<2Q100<6C<HHIS;:eEW=><DJeE111Tc8@@S56LdhaA[EG6
6;gGQ11TdjeEW=>meliiW=>meliicW<44<ii_MN]ELii_MN]EMkkcWUTdkgG
Q10448aA<bb]ELiiI=<449/cW=<4409S;00=[EDc9S<VHbJ<DH@@_MMTfHaA
_MN443<VHbH00XaA00MBZX@@aQR]EFCCHbb<D@02Q1001XaA[EF]E@@@HbJ<
D@:Ld`07_ML448@@Q11S;;gGI=<00YcC00ATc6<V<H1S9P:44006I=VmejeE
_MN]ELcI0ZeE0IcC0JeE0003DZX01H@0W<aS9X@0W=<00h@@00F<DH@@W=><
DFCC00:Ld`09[EETfJeEI==S<fCCVc=Tdc<c00F4400<Hbb448aAQ12]EIcC
S56446</S56Ld`@@0XaA0X@@00=Tdf<cW=<00YcI00Nmeiii[EFLfFCI[EET
f@02W=<05JeEI=V]EIii[EFNNJeEW=V]EHaAI=>448aAVc<448@@S55S;;gG
Q12K;002S543Q10026<V<bbLdjeEW=>]EC</Q103S5408h@@W=?669cCQ12L
c9cCW<c>LlHHW=?66<iicW>44<iicW>LdliiWWVmeliig_]TdiiiW==S;6CC
HbaTfLiig_^NNFCC[ED00c</00J]EF</HHIS;8aAQ102_ML00fCC_MN<D@02
HbH018@@HbaBZXaA0[gG00n<DH@@W==S;8@@W==VLicCQ11S9X@@S55TdkgG
I<`00V</00dc;:eES56mehaAHbIS8360<b2446CC[EFme`02[ED01KgG[EFm
ejeEW=<00JeE0002Q10013</Q12Ldc<V0YcC00j446</Hbb<DH@@S56443</
HbaS<icC[EES<haA0X@@0VCC00JLdjeEI=UTdicCHc<2Q1001haAHc>LdhaA
W=>446</00:<D@0MHbbLdicCS56446C<S56LdfCC[EFLdicIW=<dfHaAWWVL
fKgGIWVLdfCCW==S<fCCI=VLdjeEIW>Lf@02[ED00icCIW>Ld`02Q1002fCC
[EF446</Q12<DH@@I=>443<PHb`00[gG00B]ELHH<c>440:Ld`0O[EETdh@@
aQRLdfC<Q12Ldic<W=?<dic<WWW>LicCQ13669icW=?669ii[EG>NMkkI=>m
ejeE112443<V[ED00]kk00?>OfC<WWT00V</01mBZXaAI<`c9V<VS55S<lHH
W==S<lHHQ11S9S<VQ12<DC<VS5766;gGS56449cCQ11S;8@@W=>]EH@@<bIS
9P02Hb`04JeEQ11BZV66Hbb]EFCC[EETdfC<Hb1BZV60Q12<DJeEWWT00jeE
00>LdjeE[ED00YcC00000f<cW==Td`02[ED02YcCS56<DF</<bIQQP@@Hc>4
46<c0h@@00=QS8@@S5400haA00ES9X@@W==TdicC009Td`0=Hc=TdfCCI=>L
dfCC[EETdf<cI<b<DIc<Hb`00icC01V446</S56<DH@@W=><DFCCS56448aA
[EETdicCI=V]EIcIIWV]EKgG==VLdfCIW==Tf@02I=<02IcI[EF]EIiiW=>N
NJeEW==Td`02Q1000haAQ1244002HbH06IcIaQRNNLiiS55TdlHHW=VmeicC
I<c669cCQ11TaYcCVbbNK:eEW<b]EKgGWVaS9[gG00:Ld`0QcW?669cCcWWN
nfIc[EFme`@@<b`aS:eEcWWNnliiI=?660@@DZXc;9cCQ11BZV<VHbb449ii
[ED44;gGQ11S;6<V00:<D@0HHbJ<DKgG_MN<DF</W=>446<VI=>]EFCCQ11Q
QS<VDZYS;:eEI<`c9U:Z112]EHaA0YcC00N446<PDZYS9X@@S55Td`02_ML0
1YcI[EFmeicI_MN]E@6Ld`0000=S;8@@Hb`00X@@0YcC00=VNHaAI=<00h@@
00=TdhaA==<00X@@00MS9SC<S56<DIcCS55S;002Q102S542W=<3Q1001FCC
Q11TdjeEI=T00ZeE00=TfIcCI=T00XaA00aTdf<cVbJ<DIcCQ12Ldi/cW=>4
46<VQ103S5405jeEW==TdhaAW==TfIcC[EETfJeEI=V]EFCIW==S<cCIS56L
dicI[EFNNKgG[ED00Yii01R<DFCCQ11QS9cCcW?66<iiI=>]ELiiWWW>NIcI
Q1366;gGI==S;:eEW<bNK9cCW<`2_ML029c6<bJLdii/W<c<djeES542cWT0
4icC_MNNNFC<Q11BZYcCcWW>OlHHI=VmecC<<bIBZZeES54c;6<V00:4400F
[EFLdh@@_MN443<VHbJ<DIcCHHJ44<HH_MN<DF</S55Tc6</Q12LdfCCS542
<bH01C60<bJ]E@@@<b`00V<V00b]EFCCHc>meh@@HbHc9V<VQ12<DIcI_ML2
[ED01KgG[EF]EJeEW=<00HaA00005S<VHb`c;6</<bb449/cI==S<f</1124
48aAI=V]EIcIW=>NNJeEI=>LdfCC0XaA00D449/VS55TdhaA00:Ld`0VS55Q
QX@@S56448aAW=><DFCCQ12]EFCC[EETfJeES55TfFCCW==TfFCCIW>K;8aA
Q10c9Y//W=><DH@@W=>]EHaAHbb449/cI=><D@9Td`:Ld`07I=VNNLiiW=UV
NIcCI=T00VCC00UTfIcC[EEVNLcIWWUVNJeEIWT00ZeE00?<fFCCW=<00lii
00JNNIcCaQS>NJeEI<H2_ML02icC[EFLc:eEcW>LaVC6W=?<c8aAcV`00YcC
00W66<iiI=>LdliiS54c;36<I=<00/ii01o666CC[EF445:Z<HbmeiicHHIS
9S<VQ12mefCCQ12meh@@HbIQP8@@I<aBZX@@_MN]EH@@HbIS;6<V<bJ<D@02
W=<04VC<<H1BZU:Z<Hb]EIc<<baS;3</[EFLdfCC_MN<DH@0HbIS80:44003
IWW<fKgG00:]E@04_MN]EJeE[ED1W=<00003<bIS9S</00AS;004Q11S;6<V
Hb`2Q1002haA[EETdicCI=V<DIcI[EEVNJeEI=T00ZeE00/dfIc<Q11Tdh@@
S55S;6C<S56446C<00:Ld`03Q11S;8aA00:<D@0=I=>LdfCCW==TdicCW=Vm
eicI[EEVNHaAI=<00X@@0XaA026]EIcCS56446<PQ11Tc666Q11S;8@@<baS
;:eEcWVNNIcCW=VNNKgGW=VNNJeEI=UTdicCHc=TdjeEW=Vmeiii[ED00Yii
00ZLfKgGW=Vmeh@@aQS>NJeEI=?660;>L`0:[EETaZeEcW>Lc3</W<bNK9//
WV`2W=<02/HHcW=Tdic<WWV]E@@@HH244<HH0Yii018c<haAQ10c9V<V_MNN
NF<P<bIQQV</[EETc8aA_MLc;6<VDZX2HbH01E:ZQ12meic<<bH00V<V010c
;666S56LdfCCI<aS9S<VHbIS;;gG[EES<h@@<bITd`:]E@05_MNLdh@@<H1S
9P02Q1001jeE_MNNNJeE_MN]EIcI00>]E@0000Pc<h@@I==Tc6CC<baTc8@@
0f</00Z446</W=>LdhaAQ11S9X@@W=><D@>Ld`09I=>LdicIWWV]EIiiI=><
DFCC00>44005W=><DIcCQ11S9P03S542W=<00haAQ1244002S5402VCCW=>L
dfCI[EFLdfCII=><DFCC0XaA00MTdh@@HbIS;8@@DZZ44002Hb`038@@HbbK
<iii[EF449cCI=>Ldic<I=V]E@:Lf@0CIWVNNFCCW==TfFCCI=VLdicI[EFN
NKgGWWVmeiii[EFmejeES5400ZeE02bLdlicW<bLc<HHcVb409cCWVc<c9i/
[EFLdliiWW>Ldh@@aQRme`@@DZZ44;gGWWVmehaAI<aS9S6<<bbLdlHHHHHc
83<V<bbLdf</<bb]EF<V<bHaP5:Z0S6001>44;gGQ10c9U:ZHb2440@@Q12]
EHaAI==S9V</Q11TdkgGWWV]E@02Q1001YcC[EF]EIiiW<b4408c8008Q11S
9VCI[EGNnicC_MN]E@:me`:]E@00019S;8@@I=>LdfCIW=>]EFCC[EETdh@@
S56446CCS56K<h@@Hb`2Q1002V</S56LdhaAQ11S;9cCI=>K<fCC0ZeE00MT
fIcCWWUTfIcCI=>Ld`02I=<00icCQ1244003W=<02X@@<bJ449cCQ12<DIcC
I=>446</0h@@00mTdhaAS55TdhaA112443</112446</HH`4466<S5400YcC
00B448aAW=>Ld`:44004S56LdjeEI=T2W=<02icIIWV]EIii[EDdfFCCI=VL
dfCIS5400ZeE00fNNKgGWWVNNKgGW=>mefCCW=?66<i/I<Jme`04cW<02YcC
aQRmeicCHbc669icS55S;3</0jeE01/c;3<V<H1BZS60S57660@@Hb1BZV<V
[ED446<V[ED405:Z<H1BZS60DZYS9/HH<baS9V66Hb`00haA01>]EH@@I==S
9V</S56LdjeE_MN]EFC<DZZLdkgGW=>meh@@111S;002Q1001P@@[EFLc:eE
I=?660:me`6Lf@6]E@6Ld`0000=S;6<VHb`00X@@00><DH@@S5400VCC00BL
dfCI[EFLd`9Td`05Q11S;8@@Q11S;002S5400icCHbaS9P03S5401:eES56<
DH@@0XaA00UTdicC==V]EIcI[EFNNFCIW=<00VCC0X@@0V</00^<DH@@W<bL
dhaAQ10c9V<VHb`c9S</00:44003S56Ldh@@00>4400AI==VNJeEI=<ddicC
S55Tdf</S56LdhaAHbb448aAW=><D@02Q1001c</Q11S;8aAI=VmeicI00:N
N@09[EEVNFCIW=VLdfCIW==TdicI00:NN@0kcWVNNKgG[EFmefCC_MO>LlHH
cW?666CCcW?>NIicI<c>NIiiI==BZS</[EES;5:Z001BZP000Z1BZV<c[EDa
P5:Z<bHc;9cCHbIS;;gGHb`c9V<V<bHaP5:Z<HbmefC<<baS88@@S56]EF<c
_MMTc:eEHbIS;002Q1001JeEW==BZU:Z<bH00XaA00ATdjeEQ124408c;09S
;005I=V<DH@@HcW66003_ML2[ED0000=<baS9V</HbaS88@0HbJ448aAQ11S
;6CCS5400VCC00>]EFCCI=<00fCC00VLdhaAS54448@0Vc=Tdh@@W=<00XaA
00Dc;6</S56<DH@@00:Ld`:<D@0=I=>LdjeEI=VLdfCCW==Tdh@@I==S;6CC
S5400X@@00@c9V</Q11S<`:44004112448@@HbH3S5402VCCW=>LfFCCWWV]
EIcIIWV<DFCI0XaA00IS<fC<S56LdhaA<b`2Hb`01f<V<bIS;8aAW==S<haA
00:]E@03WWVmeiii00>NN@03W=V]EJeE00:]E@07I=>]EFCI_MNNNLiiWWT0
0/HH016]EFCCc=?>NKgGS57>NIii_ML443</[EDc;3<V<b1BZP00009BZP03
Q11VLe:Z009BZP08<bJLdhaA112meh@@<bIS;08c9P08<H1S9ZeES55S;6<V
Hbb440:<D@04_MMTdicCHbH2<bH015:ZS55Tdf</0S</00MS;6<VQ12mecCC
Hb`44002Q1001c</W==TdfCCW=?669cI00:me`:]E@0000=Tc3</HbH00U:Z
00=QQS60Hb000X@@00YQQVCCQ12448aAI=><DC</Q12<D@9Td`08W=VLdfCI
I=>LdfCCQ12<D@:4409S;0:44005S56LdhaAQ11S9P02S54016CCS56<DFCC
0h@@00ETdicCW=><D@@@00:44004112448@@Hb`2S5401icCHbaS;8aAW=>4
48aA00:Ld`0?S56446CCW=>LfIcCWWVLfFIi[EDdfJeEI=>Ld`@@009S;009
<bIQQS<VHbaTc6</<bb]EKgG00?>N@;66003WWVmeiii00>NN@05W=VmeicI
W==S<`02[ED2WWT01;gGWWVmeiii0YcC00O>NLHH_MNmefCCW=<c9P02Hb`0
1c<V<b`c9U:ZQ12mec<V00=S9P05I=>]EH@@WWVLd`02Q1001V<VDZYBZS<V
aQQTc08c9P05HHHc9V</Q12me`02Q1005c</Hb`c;5:ZW==Tdf</<bHc;3<P
DZXc;;gGI=>446</HbJ<D@@@[EFLdjeEI=<00[gG00>]EKgGW=T00JeE0000
0icCI=V]E@02I=<00h@@11244002Q10033</S56448@@S56Ldh@@HbJ448aA
Hbb<D@:Ld`:440ETd`05W=>446CCQ11Td`03Q102Hb`038@@S56448@@S54c
;6</<bHc;6</Q11Td`B44006I=>]EIiiI=VNNHaA0VCC00>448aAI=<00X@@
00V]EHaAI==QS9//S56Ldh@@I=<00YcC00^]EFCI_MMTfIiiI=V]ECIiI=><
DCCC00>44003<bbLdkgG00?660;>N@04cW=TdkgGcWT3_ML5WWT02:eEWWVL
djeEI=>LdicIW=<2WWT02/HHWWW666CCS54c;5:ZS55TdicC0fCC00RLdf<V
HbHc9V</Q12]EHaA0ZeE00UTc8aAQ10c9V<VDZZ]EHaA<b`00f<V00ABZV<V
[EETd`:4408c;005HHITdicCI==S;002<b`02P@@Q12meicCI<aS;6<PQ11S
9YcC0jeE00FmejeE[EG<fJeE006me`0000@c;6</HI=Td`>Ld`0;I=V]EIcC
I=>LdfCCW<b<DI/c111S;003Q1001IcCS56<DH@@Hb`00XaA00V449cCS55T
dhaAI==S<fCCQ1000VCC00N<D@@@Hb`c;6</<bb44002<b`00f</<bb44002
Hb`2S542Q1005haAI=>LdhaA==VmeicIWWUVNKgGI=VLdfCCW=>K<fCCQ11S
<icCI=>448aAW=<00XaA00AS;9cCW=>Ld`9Td`03[EETfJeE00:NN@0=W=Vm
ecIcW==TdicC[EFLdlic_MO>LfC<aQP00/ic00Nmeiii_MNmeicCS56NO`02
cWT01Yii_MNNNJeEIWV]E@:Lf@08_MNNNIiiW=VNNKgG==W>N@>NN@04_MMV
NJeEHb`2HbH01V</Q12LdfCC[EFLd`>44008<bIS9U:Z[EFLdf<V<b`4409S
;003112]EH@@008c;006HbaTdf</I=>]E@@@0X@@0XaA00aQS9iiW=>Lc6<V
<H1S9XaAI=>]EIcCI=T3_ML1WWT1_ML1_ML0009BZP0@<bJ449//cW>448aA
W==S<fCCS55TdjeEI=V]EFCC[ED2I=<039/cI=>448@@Hc=S9X@@S55S;9cC
I=><D@9S;00CS56443</Q11S;8@@I=>]ECCCQ10c;8@@HbaS<h@@<bb443</
Q1000YcC00N<DF</Hbb<DIcCHbb]E@02W=<04fCCS56]EFCI_MMVNIcIWWUV
NJeEI=>]EFCCQ11Tc8aAW==Tc6<V00:<D@03W=>440@@00=S;00:S56LfIii
WWVLfLiiWWVmeicCI=<2W=<01Ic<Q12Ldic<[ED00XaA00V446</Hb`44;gG
cWW>LliicW<00/HH00>NNLiiWWT00Yii00>LfJeEI=<00X@@015Tdmkkg__N
nliicWo66<iiIWUTdh@@111S9YcCS56]EIcC009S;08c9P9BZP09W==VLf<c
Hbb446</<baS;:eE008dd`0:Hbb<DFCC<bJ44:eE111S9S<VHbH2Hb`01KgG
W=>443<PHH000X@@00R<DKgGW==TfKgGWWVmelHH0ZeE00000f</HHHc9P02
Hb`01ic<HbJ448aAQ10c;8aA00:4400@W==TdicCHc><DFIiW==TfIcCI=<d
dh@@<bb446</S542Q1001c<VHbJ446<V<baQS3</009S;0B440ATd`03I=V]
EFCC009Td`07Hc>446C<112Lc8aA<b`00YcC00N<DH@@Q12<DIcCS55Td`02
[ED01IcCI=VmeiiiW=T00Yii015TfJeEHc=Tc9/cI=>Lc8@@HbaQQV<V<bIS
9ZeEcWVNNHaA00;66004WWV]EIc<S542[ED016CCHb`aS8@00X@@00ITc8@@
[EFLdic<cWT2cW<00lHHco?>N@02cWT00fCC_MNNN@02WWT01YcI111BZV<c
cWVNO`;Nn`0BcooNnmkkcWVNNKgGWWVLdfCCQ12LdfC<DZXc;6<V<b`c9P@@
0YcC00IQQV<V111TdhaA==<2[ED028aA==>Ldf</<bJ<DIcC<bH2DZX04C<P
Hb`c;;gGW<b446<PHbIS;8@@I=>]EKgGW=>]EKgGW=T00[gG0JeE0003I=<0
28@@112446</HbJ446</HH`2Q1003haAW==TdhaAHbb448aAQ11TdicCI==S
<h@@11244002I=<02h@@<b`c;6</<HaS;3</Q00446</<bH00h@@00AS9YcC
S56Ld`:4400;S55TdicCI=V]EFIiW=UTfJeE==V44002S5402VCCQ10c;8aA
W==Tdf</[EETdhaA0X@@01YTdicCW=>LfKgGWWVLfIiiW=UVNJeE==VLc0@@
=<aS9V</S5766;gGQ12]ELHH[EFLdfC<0h@@00eTc8@@Q12446CIWWVmeicI
WWUS<icC[EG>K003cW<3cWT01Yc<cWVNNIicQ12]E@8dd`0=I=>]EFCI[EET
fIiiaQS>OiiiHc=TfHaAI=<00ZeE00YVNJeEI=><DH@@<bIQP3</W=>]E@9T
d`0EW=>]EJeEI=>LdkgGI=><DJeE110c9X@@W=<c9V<V<bIS9U:Z<bJ]EFC<
009S9P07DZYS9VC<S56meicCI=<00kgG0JeE0LHH0KgG0002<b`00h@@I=>K
<`04I=<01CCCQ10448@@<b`00h@@00@c9V</Q11S;0:<D@:44004DZYS9S</
Q102I=<03h@@<b`c;6C<I==TfCCCI=><DC6<112<DH@@I<bLd`02S5401X@0
HbbLdfCCQ11Td`>Ld`08I=>]EFIiW=UVNKgGWWV]E@9Td`03W=>446</00:L
d`0AS55S9X@@W=><DH@@I=>LdhaAI=>449cCI=>LdcCI[EFLd`02I=<02jeE
I=>448@@HbIS;8@0HbHc;6</I<H00YcC00N<DIcCWWVmeicI_MNNN@02cWT3
WWT4_ML02<iccWW666CCcWVmejeE<bH2cWT01;gGS55Tdh@@0fCC00AS<jeE
WWV]E@844003Q11TfJeE00:Lf@>NN@06IWV]EFCCW=>NLicC0haA00NLdh@@
W=>mehaAQ12NL`02Q10010@@[EETc6</0S<V00AS9S</[EF4409S9P04HHIS
9X@@<c<2[ED00fCI[EFLf@02_ML1[ED1_ML000=BZP04<H1S9VC<HH`2S540
1V<cQ11Tdf<cI=><D@9Td`05<bb448@@<bb44002Hb`013C<HHHc;3</0f</
01:445:ZHbJ<DF<cS55TdjeEI=UTdiii[EETdfCI[EETdhaA1102Q1001HaA
Q02LdicCS5400V</00J<DIcCQ12LdjeEI=T2W=<03[gGWWVLfFIiW=VLdfCC
S56446CCQ11Tc8@@W=<2S5400f<VQ11S;002Hb`01h@@<baS;8@@[EETdh@@
008c;00<HbaTdfCCW=>]EIcC_MO>LfC<[EFmelHH0/ii00jNOlHHWWVNNIcC
[EG669ii_MNNNLiiWWW>NIii0[gG00VLdf</_MN]EH@0Q11S;6C<Hb`00S<V
01TaS6</W=<446</Q12LfIiicWUVNIiiIWV]EIcCI=V]EIii_MNNNKgGI=>L
dfCCS55Tc002W=<00h@@<bbLd`02S5400h@@[EDdd`02HbH00f</Q10c9P02
W=<02VC6HbIQQX@0Q12<DKgG[EETdjeE1;gG0Iii000026</<bIBZV</HHJL
aVC<W=<2Q1001S<VQ12446</I==S;0:440=Td`0@<bb446</<c>446</111S
9XaAHbb4466<HbJLc8@@Hb`2W=<048aAQ12446CI[EETdiiiW=VNNIcIIWV]
EFCII=>]EFCC0X@@00iTc8aAS54448aA[EFLdhaAQ12<DIcC[EF<DIii0ZeE
01UVNJeE[EETfIcCI=><DFCCHb`c9V</HbHaP3</HbHc;6<V<baS9X@@W=>]
EFC<W=?66002WWT02LiiWWVmeicIW==VNLcIWWW66004cWT00kgG[EG66004
cW<01;gGWWVmekgG19ii00J]ECCIQ10ddf<V<b`2DZX2<bH01f</S55S;3</
Q11Td`@@00:]E@0DW=W669iocWVNNFIiW=VLdfCI_MNLdfCI_MNNNKgGIWVL
dhaAI=><D@:44003112]EHaA009S;00?S56Ldf</I=>mehaAI<IQS8@0Q11T
djeE_MNLdicI00:me`:]E@6me`000VCC016440@@Hbb446</Q11S;8@@DZYS
;8@@<bIS;6<V<bIQS3</00ES;008Q11TdfCCI=>]ECCII=>Ld`9Td`06Q11T
dh@@W<aTdhaA0V</0XaA00]S;9cCI=>LdhaAI=>]EFCI_MNNNIcI00:NN@04
I=VLdfCCQ102S5400icCS5444002S5400fCCQ12]E@02S54056</Q12440@@
Q11TdhaAWWVLdcCCHb`c9S</Q10c;5:Z<bHc;6<VS542cWT026CC[EG66<ii
aQS>Liii_ML2WWT02lHHcWVNNLiiWWVmeicIcWVNNIcCaQP00lic00K>K:eE
W<bLc3</Hb`2Q1003fCCW=VNNJeEI=VmecCIS54dc8@@111S;6C<<bIS9P02
Q10025:ZQ10c;8@@W=>NNIcCI=<2[ED3WWT02IcIIWVLdicCI=VLdkgGIWVm
e`02WWT02icCI=>]EF</<H1S;6CCQ10c;6<c[ED00XaA00US;6C6S56<DJeE
_MMTdicI_ML00ZeE0[gG000028aAHc>443</Hbb440@@Q102I=<00f</<bHc
;003Hb`00c<V<HaS9P02<bH4Q1001C<VQ11Tdh@@S5400VCC00FLdfCI[EET
dcCI00:Ld`07I==Tc0@@W<aTdf<VW=<00XaA0V</00BLdhaAHbaVL`:Ld`0;
I=>LdicIWWV]EFIi[EETdhaAI=><D@02Q10026</W=>448@@HbIBZV<V<bH2
DZX00c</Q1244002Hb`00h@@I=>me`02WWT02jeEI=>446CC[EG666C<[EG6
6<icaQP00lic00>mefCCI=<00YcI0Yii00?>NIiicWT00iii0ZeE00JLc8@@
Q01S9U:Z<bH4DZX03f</I=>446CCW==TdhaAI=>LdjeEIWV443</<bIS;003
<b`02f</<bb<DHaA<baBZS</Hbb446CC[ED00YcC00QVNJeEWWUTfIcCI=VL
dicI0Yii00G669iiIWTc;5:Z00:NN@09IW>LdicCS56Lc8@@Q02446CC00:]
E@03I=>]EKgG00>me`76600000><DF</<bH00U:Z00L2X36<Hbb440@@Hb`c
9P02Hb`4I=<01H@@112448@@I<`00X@@00EQQX@@Q11S;6C<00:Ld`0EQ10c
;8aAI=><DIcCIWUTfIcCI=VLdfCIS55TdhaAI=>446</Q12<DF</00:Ld`03
S56446</00:<D@05W==TdicC<bb44002S5403fCCW==VNFCCQ10c9S</<bIS
;36<<bIS9VC<Hb`aP002HbH01h@@W==TdfCCW==TfJeE00:NN@03_MN]EJeE
00:]E@04W=>meli/cW<2[ED02IcC[EG66<iiWWV]EIcII=>Ld`02I=<03JeE
_MNNNKgGIWVLdfCC=<`c;6</I<aTdc</00=S;004Q11Tc6</<b`2Hb`01HaA
W=<c;6</Q1000VCC00^NNJeE[EETdh@@Hb`c;360HbaS9S</00:44003HbaS
9X@@00:44003S55TdicI00:NN@03W=VmecCI009Td`0;HHb44<iig_^NNMkk
IWVNNFIcQ11Tc002Q1001KgGI=UTdjeEWWT00kgG0IcI00002C</HHHc;3<V
DZXc9U:Z<bIS9P03DZX03fC<HbJ<DFCCQ11TdhaAI=UTdfCIW==TfFCC==><
D@02Q10026CCS56<DH@@Hbb448aAHbH2W=<03XaAQ12446CCW=><DFIi[EET
fFCCWWV]EFCCQ102S5401VC<HbaS;8aAI<b440:<D@0@Q11S;3<VDZXc;8@@
W==Tdc</HbIS;6<cIW>]EFIiW=<2Q1000c</HHITc002S5401X@@I==S9S</
Hbb440:]E@0SWWVLfJeEWWVmeiiiW=VNNJeEI=>446CC[EFmejeES56446</
<HaBZS<V<H`c;0@@Q12K<iicW=V]EFCCS55TdlHHI=<c9P02HbH016</111S
;3</0V</00L448@@HbaS9S<VQ12<D@02W=T3WWT07KgGWWUTdfCCQ11S;8@@
I=>446C<Hbb443</Q12]EIcCI=>NNFCCW=VNNJeEIWTc;8@@WWoNnliicol0
0]kk00_>NIii[EFmecCC_MN]EIcC[EFmejeE00:me`6]E@0000lc;6</<b`c
;8aA===S;6CCHbH446<VHHJ443</W=<00XaA00>446</S5400X@@0VCC00N<
DFCC[EDdfFIcI=VLd`03I=<2S5401S</S56Lc9c<111QQP:<D@04HbbLdfCC
W=<2S5403VCCS55TdfCCW==TdicCI<b<DFCCQ11S9VC<<b`2<bH2<b`2Hb`0
1VC<S55Tc6</Q12Ld`:Lf@0>_MNNNIiiWWVmeiiiI=>LdfCCQ10c;6<V<bIS
9P:me`03cWV<DFC<00:4400D112446CC[EETfJeEWWV]EIiiW=>440@@D00a
S0@0<bb446CCS56Ld`:NL`07W=>NK8@@Hbb44;gGI=<00X@@01L448@@Q12<
DFCCHbHaS8aAQ11S;6<VHHIS9X@@Hbb]EFCCQ12<DFCCW=VNNKgG00>NN@0=
W=V]EFCII=>LdhaAW=>mejeEW=>]EHaAW=<00ZeE00mS<h@@==V]ECIiI=VL
fKgGWWnmeiiiaQRNOiiig_/00Yii00F]ELHH_MNmejeE006me`0000dc9V<V
Hb`c;8@@I=><DFCI[EETdfIiI=>Ld`02I=<03haAI==QS3</W<b446C<W=>4
48aA<bb448aAQ12<D@02I=<04XaAI==TfIcCIWVLdfCIW=<ddfC6I==Tc3</
W<b<DH@@HbaS9P:<D@03Q11Tdh@@009S;004<bb<DIcC1102Hb`033</Q11T
dh@@<bb446</W=><DH@@HbJ440:Ld`9Td`0;W=><DHaAI=>LdfCI_MNNNKgG
IWVLd`02I=<02ZeEW=>mehaA<bIBZU000Z1BZP:P0U:Z0S</00IS<haAIWV]
EIiiIW<2S5402FCC[EFNNJeEcW>Ldic<VbaTc002<b`01V<cI=>LdfCC<bIB
ZP9S;00?S55Tde:ZS56NNJeEI==Tc0@@Hbb440@0W=><DH@@009S;0:44004
W=VLdfCCc=T2WWT01<iiaQRNNIcI0ZeE00>Ldh@@W=<00XaA00FLdkgGWWVm
eiii00:]E@05I==TfF<cWWW>N@02WWT01liiIWVmelHHI=V]EKgG00:]E@:m
e`0000ES;36<<bIQQS</009S9P03Hbb446<c00:4409Td`0?W=V]EFCI[EDf
LicCI=UTdic<I=>443<PP12446<V00:<D@0=W=>443</Q12<DFCCW==TfIcC
I=>]EFCI[ED00VCC00J440@@Q10dc8@@I<`2Hb`00c</<bHc9P02<bH2Hb`0
1X@@I<aTdicCI=V]E@:NN@06I=VNNIcCHc=TdfC<0XaA00R449c<W=>Ld`@@
<bIQQX@@0XaA0VCC01>]EFCI[EFNNKgGIWVLdfCCQ10dc0@@Hb`c830<<bIB
ZS</Q11Tc002S5402FCCW=><DFCCS56mefCCQ11S;002Q102I=<00icCI=>m
e`02g_/07Iii<b`aS3<VHbIS;3<VQ12NNJeEW=VNNKgGWWVmeiiiI=VmeicI
I=><DFC6Q12<DJeES55TdicCWWT00[gG00fLfIiiW=W>NFIiW=TfNHaAI=>4
48aAW=>]E@02W=<04HaAQ10c;8@@112]EKgGI=>]EKgGWWW>NIioaQS>NIii
aQP00[gG0JeE00001fCCQ10446</<baS;6<V009BZP09Q11S9V</S55S;8aA
I=><DI/c009Td`0:W==TfJeEI=VLfCIcW==TfFC<==<3Q1001F<VQ12<DC</
W<`00XaA00J446</Q12<DH@@I=<2Q1004icCI=>443</HbHaS6C<<bb446</
<baS9VC<Q12]EHaAI<b446CC00:Ld`05Hc>]EIii[EFLf@03WWT04fCI[EET
dhaAQ1044660HbJ446</S54c9U:Z<baBZS</Q10448@@009Td`08W==TdicI
IW><DFCCI<b<D@:]E@05W=><DH@@Hb`c;003Hb`01X@@I==TdicCWW>me`:N
N@0KcWVNNIii_MO>NJeES54443<VQ10c;9cC[EFmeicIW=>446<c[EFNNIcI
WWW>NIiiW=UVNJeE00>Ld`:44003WWW<fIii00:me`05[EFmejeE[EDdd`02
Q1000f</Q12<D@03Q1000haAHc>44004W=<038aAQ12LdicC[EFmeiiicWW6
6;gG[EFme`6]E@001VCC00dddfCCI==Tdh@@I=>446</Q12<DIc<111S9P02
Q1002c</W=>LdfCCQ11S<fCC[EDdfJeEI=T016CC02QTc8@@Q11Tdf</HbJ4
46<V<bIS;5:Z<bHc;6</HbIS;6<VI=>NLicIWWUTdiii[EETfFCCW==Tdi//
<bb<DIcCI=>449icI=><DF</S56Ld`>]E@03WWVmefIi00:]E@06=WVLc6CC
Q10c;3600S<V00=BZV<VHbH00e:Z00]QS8@@Q12<DFCCS57669iiS55S;6C<
00:44006<baTdjeE==>Ldiii0[gG00NNNKgGW=?>LkgG[EFNN@02cWT02/oo
WWW669ii[EFLfCCC_MN]EIcI0YcC0V</00V<DJeE[EFNNJeEW=V]EIiic=T0
0Yii00=TfFCCW=<00ZeE00>meicC_ML00YcC00><DH@@Hb`00X@@00<448aA
Hc<00VCC00>LfIiiWWT00Yii00NLfJeEW<bLc8@0S56Ld`03[ED3_ML1[ED1
_ML1[ED000>4400C<H`c9X@@<bb440@@I=><DFCII=<fLjeE==VLdfCCQ11S
;8@@I<`00XaA00>443<VQ1000X@@00B<DIcCS55Td`:4400@HbaTdfCC[EET
df</<bIS;3</<HaS9S</HbaS9V6<Hb`2Q1001YcCS56448@@Vc=Td`:]E@0:
WWVmefIi_MNNNIcC[EETdh@@[ED4Q1001HaAW=><DF</I=<00X@@018448@@
I=UTdiii[EDfNJeEI=><DFC6I=>Lc3</Q12NK9c<I<`2<bH03C</<bJ448aA
I=>448aAI=>NNLiiWWW>NKgG00:NN@;>N@08WWW>NKgGWW>Ldh@@_MO660;>
N@0@WWVLfIiiWWW>NIiicWVNNLHHWWVLdh@@I<IS<icCS542_ML01JeEW==T
dhaAI=<00ZeE011Tdh@@W=>meiiiS56446C<112446<cHbaTdh@@I=>Ld`>m
e`03WWW<fIii00;>N@:]E@06W=><DI/VW=>Lc9cC0jeE1KgG00002h@@<baS
;6<VI<b443<VI<`2X5:ZHbH00h@@00><DFCCW=<00VCC00>LdfIiS5400VCC
00Z<DFC<Q10448@@Hbb<DFC<Q10c9P=BZP0;<bIS;6</<b`c9V</I<b]EIii
IWV]E@02I=<02VIcS55Tdh@@S55Tc6</Q12<DIcC0XaA01>LdfCCW=><DIcC
WWVLfKgGWWV]EFIiW==TdicCI==S;0@@HH0c;006DZX02c</Q12446CCQ11T
c:eE_MMTdh@@Q0000V</00hc;6</Q12<DFCCHHJ<DIc<S56LdjeE_MNNNLii
0Yii00c>NLioWWW>NLHHWWW>NKgG==>meliiWWT2cWT01KgG[EFLfJeEW=<0
0Yii00?669iiWWT00Yii00RLfIi/==>LdicI[EFLdic<18@@00Xc;0@@Q11T
dicCQ11Tdh@@W=Vme`:NN@04_MN<DIcCW=<2_ML01<HHc=W>NIii0/HH0ZeE
00FLdic<I<b<DIcC00>]E@Bme`6Ld`6me`001FCC00F<D@@@Q12440@@009T
c003S55S;8aA00:<D@06Q10c9X@@W==TdicC0XaA00ETdhaAQ11VLfCC009S
;00D<bHc;0@0HHaS;66<<bHaP5:Z<b1S;8aAHbb]EFCCW==TdicCW=V]E@>N
N@0;[EEVLhaAI=><DFCCHbb]EHaAHbb44003S54016</I=>448@@0VCC00^]
EIiiW==VNIcCI<`448@@I<aS;3<V00=BZP8c9P0?HH`c9X@0Q11Tc6</<HaT
c8aAWWVmeiii[EFNNFCC00:]E@JLd`03Q12meiii00;>N@05WWo>NIiicWo>
N@02WWT01=kkWWW669ii0jeE00FLdfCC_MN]EIcI00:]E@0=I=>Lc6CI[EET
dicCaQRNNFCCQ12406</Hc<00X@@00aTdicCI=>]EKgGW=VmeiiiW=W669ii
cWT2S5402JeEW=VmeliiWWW>NLcI_MO66002[ED01IcCQ12LaYcCW<`00jeE
0[gG00>]EKgGW=<00JeE0000<C</HbaS;3</Q12<DFCCS55TdicC[EETdicC
I=>LdfC<S55S;3<VQ12mec</W<aTdf</HbIBZS<VHbb443</DZYS9V</S56]
EFIcI==VLfCCQ10dc8@@Vb`449cCS56446</00:4400IW==TdicC[EETfIcC
[EFNNKgGIWV]EIiiI=>Ldh@@I==Tc606<baP1S<VDZXc85:Z<bH00V</00Z<
DFCCS55TdhaA[EFNNFC<Hb`c9P9S9P06HH`c;6C<Hb`c;6</0V<V00B408@@
S56]E@:me`03WWW669ii00BNN@04[EFLfFIcHc<2[ED2_ML02iiicWW>NLii
WWVLfLiig_^NNMkkWWl00Yii00>]EFCCI=<01:eE00fLdf</HbIS;8@@Hbb<
DIcCI=V<DH@@S55Tf@03WWT01;gG[EF]ELcI1;gG00G66;gG[EFmehaA00:L
d`:me`03W=W66<HH00;66003WWV]EIcC00:Ld`07W<b<DIcC_MN]EKgG[ED0
0kgG0JeE0KgG00001f</<bIS;5:ZHbb443<V009S;005112Lc8@@I==Tc002
W=<01fCCQ12446C<W=>446</008c9P0IHHHc;6<VHbIS;6<V<bIS9S<VHHIT
c8@@[EFLdfCC[EFLdfIi[EEVLjeEIW><DCC<Q1000haA00ETdicCQ11S;6C<
00:<D@0OI=>448@@Q11VNJeEW=UVNIcCIW><DFC<110c9X@@I<b443</Q10c
9V</<bIS9V</I==S;8@@I=><DFIc_ML00Yii00>]EHaAI=<00XaA00l44666
Hbb446C<S55Tdh@@[EFmeliiWWWNniiicWT00iii01>NLicI[EFNNJeEWWV]
EKgGS5766<iiWWW>NMkkWWV]EIiiW=><D@02WWT03JeEI=>443</Hb`c;6CC
<c>LdjeEW=>]EHaA00:Ld`04_MO669cIcWT2[ED3_ML01<cI_MNmelcI0[gG
00>LdhaAW=<00[gG00C<fLiicWW660>me`06cW>Ldic<VbbLdic<0ZeE0[gG
00C66;gG_MN]E@6me`0000RLdfCCS54dc6C<Q11S;3</0S<V00RLc3</S55S
9X@@Hb`c9V660V</00R443</HbaS9X@@S55VLhaA0VCC00ATc8@@<b`c;0=S
;0:Ld`0:I<aS;6</S56LdfCC[EFLdjeEI=<2[ED02fIcI=>LdicCS55Tc66<
Hb`c9S06<bH00e:Z00@c9V</S56Ld`9Td`:<D@04[EFNNH@@<b`2HbH00c</
HbaQS002<b`00f<VW=>me`02g_/01IioQ12449cC[ED00Yii00c669iiWWV]
EFIcW==TdhaAI<aS9X@@S542[ED01KgGaQS>NLiiWWT00/ii00BNOiiiWWVL
f@:]E@04=W>44;gGWW<2_ML2aQP04icCS56443</S56]EFCCHc><DFCC[EFN
NJeE_MO>NIii[EFLdh@@00:Ld`:]E@03S56LdjeE00Rme`04[EFmehaAW=<3
[ED5aQP00lcIWWVLd`02W=<00ic<I<bLd`02[ED01[gG[EF]EKgG[EFLd`6]
E@0000N<DFCCQ12448aAI=>Lc002Hb`01VC<Q10c9V</<bH2X09S9P06100c
;666<bIQQVC<0V<V00MS;8aAS56<DIcCIW>]E@02W=<03fIcW==TdfCCS55S
;8@@I<aS<ic<Q12LdhaAQ10c9P04Q10018aAI=>LdfIc0YcC00UVLhaAI<aT
c3C<HbaTc8aAI<`00f</0S<V00=S;8@@Hb`00S<V00US;8aAIW>meiicI=><
DFC<S5400/ii00KNnhaA<bIS9V<PHI<2I=<00jeEW=>Lf@02WWT04/iiWWVN
NJeEWWVLc9cCW<b44:eEW=>mehaAWWWNnliig__>N@:NN@09[EFLdfCCaQRN
NJeEI=><DFCC009S;0:4400<W=>]EJeE[EFLdh@@S56LdicIWWW66;gG0ZeE
0XaA00FLdkgG[EF<DIcC00:]E@Bme`B]E@09_MNLdhaA[EFmejeEaQRLfLii
00?66009_MN]EIicW<bK;9cCW<b]EIcC00B]E@6me`6]E@6me`000h@@011B
ZS<PHbaTc6<VHb`c9V<V<baBZS60HbJ446CCI<bLd`9Tc00=Q11Tc6C<HbaQ
QVC<S56Lc8@@I=><DF</I<`00XaA012LdfCCW==VLicCI=>LdfIcQ11Tc6CC
I<`c;3<V<0Hc809BZP050Z1QQV</Hbb<D@02Q1001VCCS56<DIcCI<b4408c
9P03HbHc9S</009S;003Q02<DC</009BZP03<bIS;8@@00B44005S57>NMkk
g_/fN@03Hb`010@@[EDc;6<V0V</1;gG00FLfIcCWWW>NIio00:NN@04_MMT
dicCS542[ED03lHH_MN]EJeEW==TdhaAI=><DIcI[EETdjeEIWV]E@04WWT0
19cC[EFmeicC0X@@00QS9ZeE_MO<fKgGW=VLdic<0XaA00F]EIcCS56<DJeE
00:Ld`04c=>mekgG[ED3_ML2[ED01XaA[EF]EKgGc=Vme`C660:]E@:Ld`:L
c003S56LdjeE00Bme`76606me`76600000=Tc8@@<bH00U:Z01ES9S<VHbHc
;3<VHbHc85:Z<bJ<DF<VQ11S9V</S56Lc6CCW=><DFIcW=<00fCC0h@@00AS
;6C<S55Tc0>4400@HbaBZS<VHb`c;8@@S55TdjeEW==VLfCCQ11Tc8@@I<`2
Hb`01f<VQ12443<VHbHc9V<V00AS;00<<bb44:eEWW>LdfIiI=>Ldh@@I<IT
c6660c<V0V<V00<c9V60_ML00]kk00k>NFC<<bb440@@_MMTdf6<<b`ddjeE
Q12<DIc<0X@@00bNNLiicWWNniiiaQQVLjeEI=?>NIiiI=<3Q102I=<03Ic<
W=>NLlHHcWWNnliig__669cIcWW66;gG00B]E@05I<aS9V</W=>]E@02_ML0
1:eEW=><DH@@0YcC00FmehaAS56]EIcC00:]E@04c=V]EKgGc=T2_ML2[ED0
1Y//W=>LdjeE_MO660Fme`05[EFLdicCQ12Lc003W=<4_ML1aQP1[ED1[ED0
000DHbITc6<VDZYS9S<VHbb<DFC<W<b<DFC<Q11TaX@@I<aS9V</Q12<D@:4
4004W<b<DH@@Hb`2S54029cCS56LdfIcW=><DFCCW<`2Q1001PA0<bHc9S<P
DZXaP09BZP04Hbb446<VQ102S54056C<S56Lc6CCI<aS9S</HbHc9V<V<baS
9V</I<J<DIc<S54c9XaAQ102W=<2[ED01cIc[EETfIcC=W><DFC<009S;003
101QQYcC00?Nn`0<I=VLdh@@W=?>NFCIHbITdkgGc=VNNKgG0VCC0YcC0ZeE
00RLdhaAQ11S;8@@Hbb<DIcC0ZeE00IVNIiiWWWNniiiWWl2cWT3g_/00nmm
W=V]E@06[ED029cCQ11S9V<VW=>mejeE_ML2[ED01IcCS56LdicC_ML00XaA
0ZeE00BmejeE_MN]E@>me`>]E@03Q12]EJeE00>me`03aQS<fIii00:me`:]
E@03W=>Lc9c<00:Ld`>me`03[EFmekgG00:me`0000Lc;6</HHHc9V</<bIS
8002Q1000icCQ11Tc002S54039c<W==Tc8@@I<bLc8@@I<bLc8@@HbIS;0:<
D@0?Q11Tc8aAHbaS9S</<bJ446C<S56LdfC<W==Tc8@@009Tc004HbITc6</
HbH2Hb`2<bH01F</HbIS;36<Q0000V<V00f449c<W==Tc8aAI<b<DFC<I==T
aYcCW<aTd`03W=<02V</<bJ448@@Hbb448aAI<b446C<0X@@0mkk016<DFC<
S56<DLHHW=V449/cWWW669iiI=><DH@@WW>mefIi00>4400>I=><DFCCW==T
fLiiWWWNnliig__>NLiocWWNn`;>N@05cWoNnmkkkgfNN@06[ED01[gG[EF4
46</Q02K<`:]E@:me`04W=>Lc9/VW=<2[ED01IcCQ12]EIcC[ED02;gG00F]
EHaAW=>]EIcC00:]E@05_MO<fLHHaQRme`02[ED01IcCQ12LaZeEW=<00ZeE
0[gG0/HH0[gG00002XaAW<aTc6C<HbaTc3<VHbaTc;gG18@@0XaA00UTc6<V
Q12448aAI<b<DFC<Vb`00VC<01J<DFC<I<b443<V<b1BZS60DZXc9V<VDZYS
9S</HbJ446<VHbaTaXaAHbHc9P=S9P0;HbaS9V<VHbaS9X@0Q12<DF<VI<b4
4002S5400ic<W=><D@03S5401FCCI<bLdicCQ1000S<V00]S;3<V<bIS9S<V
HHHc9V<VHbaTc<ii00;Nn`0=IWUS;6</S56NNIcIS56LdiiicWVLfE:ZHbH0
0X@@00jK<jeE[EFNNJeEWWW669ii[EG66=kkcWWNnlio1Mkk00O>NMkkg__N
nloog__66003[ED01YcC_MN]EJeEW=><D@9S9P08W=>]EJeEc=V]EIcCW<bK
;0:Ld`03[EFLdic<00:]E@0@_MO<fKgG_MN]ELcI[EFmejeEW=><DIcCS56]
EKgGc=T3_ML03<HH_MNmejeEW=>Lc9//W=>Lc;gG[EG660>me`7<f@6me`00
00=Tc8@@Hb`00V</00=S9S</HbH018@@00=Tc6</I<`00X@@01iQS8@0Q124
43<PQ10c9S60DZXc9V<VQ11Tc9c<S55Tc8@@I<`c;6</I<`c;6<VHH`c9V66
0Z1BZV<V<bH5HbH02X@@I<aTaV<VQ11Tc8aAI<aS;9c<0XaA0YcC0ZeE00B<
DFC<W=>]E@:<D@:4400=Hb`daX@@HbHc;6<V<baS9S<VHbJ448aA_ML00]kk
00K>NF</11244:eEaQP2W=T00liiaQRNN@02S5400icIWWW>N@02cWT01mkk
cWW>OmkkaQRNOlii00;Nn`05cWWNnmkkg__?o`02g_/00liig__Nn`02g_/0
1/oocWV]EJeE_MNLd`B]E@04S56446<VS542[ED00kgG[EF]E@02S5401IcC
[EF<DHaAVb`00YcC0ZeE0[gG00J]EKgG_MN]EKgG[ED2W=<2[ED019iiaQRm
ekgG0lHH00N]EKgGW=>Lc8aAW<b<D@02[ED4_ML1WWT1_ML00005I<b446</
HbITc003DZX036</<bIS;6C<VbaS;6C<Q11Tc8@@I<b4409Tc007Q10c9U:Z
DZXaP5:Z<bH00h@@00@c9V<V<bIQQP9S9P0@HbaS9S<V<bIS9VC<Q12403</
HbHc9X@@I<b<DF<PW<`2Q1000fC<S56<D@02Q1000fC<Q11Tc002Q1003XaA
Q12446<VW=>]EIcC[EFLdh@@<b1S9X@@<bH2HbH01c<VHHHc9V<V<baS9YcC
00?Nn`07I<aTdi/cW=VNNIcIaQP00/ii00?>OkgGWWT01<ii00C>OmkkcWWN
n`;>N@08g__>NMkkcWW>OmkkcoW>O`?Nn`03cWWNnmkk00?Nn`03cWV]EJeE
00:]E@0@_MN]EJeE[EF<DFC<HbJ<DKgG[EFmejeEVc><DIc<W=<2[ED019cC
Q12LdicC0kgG00C<fKgGaQRme`:]E@>Ld`:me`?660;>N@05aQS<fJeE_MNL
d`02W<`2W=<2[ED01KgG[EFmekgGaQP00KgG00002HaAI<b446</I<aS;6C<
HbJ44002HbH026C<Q11S;6<V<bHaP5:Z<b03Hb`08Ic<I<aTc8@@I<aS9VC<
Hb`c9V</<H1BZS<V<b1BZV<V<bIS9V<PHbIS;6<PQ12406C<HbaS9X@@HbJ4
46<VS55Tc002S5403icC[EFLdc</W<bLdic<W=><DFC<Q11Tc3</Q01S;002
Q10056C<HbaS9U:ZHb`c9S60DZXc9V60DZXc9X@@HbJ44<iig__>OkgGHc<2
W=<01JeEc=W66<cIWWT00/ii00BNNLHHc=VNN@;>N@0;cWo>NIiig__>NMkk
cWW>OloicWW>O`05g_/01Liig__Nnmkkcol00]kk00>]EKgG[ED00ZeE00Rm
ejeE[EF<DF<VQ12K;9cC0ZeE00ZmejeEW=>K;9cC[EFmejeEVbbLd`:]E@03
_MN]EKgG00>me`04c=>mejeES542W=<00jeE_MO<f@05aQP01JeEcW>LdhaA
W<`00YcC0ZeE00>melHH[ED00/HH0KgG0002S5400c<VHbb44002Hb`00f<V
111S9P02Q102Hb`056C<<bIS9S</=<IS;6<VI<b<DF</<bIBZS60<bIS;360
HHIS9S<VDZX2HbH01F</I<aS9V<V<bH00X@@01QTc8@@I<b<DI//W<bLdfC<
Q10c9VC<Q02446<VI<b448@0Hbb448aAW=>]EIcC[ED2W=<03F<VW=>LdfC<
S55Tc6</HbHc9V<V<bIS9S<V009S;006112448@@I<b<DLii0]kk00VNNFCC
S56LdkgGW=VNNKgGaQP00/ii00?66<iiWWT01/ii00ONnliicWo>NMkkcWW>
O`06g_/01Liig__Nnmkkkgd00]kk00=TfJeE[ED00ZeE00NmejeE[EF<DH@@
Hb2<D@02[ED03[gG[EF]EIcCQ12LdjeE_MNLdhaA[EFmejeE_ML2[ED01<cI
[EF]EJeE0YcC00b<DIcCW=>]EKgGc=VNNLiic=VNNKgG[ED3W=<00ic<S56]
E@02[ED6_ML00008I<b446</Q01S;3<PDZXaP09BZP07<bIS9VC<HbJ446</
HbH016</00=S9U:ZDZX00S<V01ES9S<PDZYTc3<VHbIBZV<PQ11Tc3<VS55S
;6C<HbaTc8aAHbJ448aAI<`00XaA0icC00>40:eEW=<00YcC0XaA00eTc6<V
I<aTc6<VQ12408@@I<b446<VS56Ld`02S5402V</HHHc9S</Hb`c85:ZHbIT
djeE0[gG00BLfKgG[EFme`;Nn`04cWV<DH@@S542aQP01icI[EG66<iicWo>
NMkk00S>N@03g__>NMkk00?Nn`03cWWNnmkk00?Nn`05aQSNnmkkg__>O`02
g_/00kgGW=>me`04[ED01kgGS56446<VVbb]EIcC00:me`:]E@07VbbLdjeE
_MN]EI//W=<00ZeE00>melHH[ED00[gG1:eE00N<DIcCW=>]EKgGcWVLf@04
aQP2[ED01IcCW<bK;9c<W=<00jeE0[gG0JeE0KgG0LHH000023</HbaS;6C<
HbaS9V</I<`2HbH03c<VHbaS;6</Q11S9S<VDZXc8666<bIS;3<PHbHc9P02
Hb`03C<VHbaTc6</HbIS;6C<Q10446<VW<aTc8aA00>Ld`08I<b448aAI<b<
DH@@I<b<D@:44003S56Ldic<00>Ld`03[EES;:eE00>Ld`0AI<b446</<bIS
9VC<<bIS;3</HbHc;3C<HbaTc3<VDZZ44002[ED01/HHWWW<fIiic=V]E@?N
n`03I=>Ldiii00C>N@?Nn`06cWWNnmkkcWWNnlii0]kk00?>NLiocWT01mkk
00G>Oliig__Nnlii00;Nn`04cWo_OMkkg_/7[ED2W=<00h@@HbJ<D@02[ED0
1LcI[EF]EIcCW<`00ZeE00VmejeES56]EKgG[EFmelcI[ED01[gG00><DIcC
W=<00[gG00K66<iicWW>NLcIaQP3[ED00ic<S56Lc004[ED3_ML1aQP1c=T0
0005<H1BZV<VHbITc003Hb`01C<VDZYS9S<VHbH00S<V00UBZV<VHb`c9VC<
<bJ443<VHbH00S<V00R446</HbaTc8@@112448aA0h@@00aTdfC<S56<DIc<
W=><DFC<W=>]EIcC[ED3W=<02VC<I=><DIcCI<b446C<S55Tc6CC0h@@00=S
;3</<bH00S</00V448aAW<aTc8@@Hbb448aAQ1000V<V00b44;gGW=W<fIii
c=VNNLcI_MO>NLiog_/2cWT00mkkcWW>N@02g_/00liog__Nn`02g_/01/io
g__NnmkkcWW?o`;Nn`05cWWNnliig__>O`03g_/01Loog__NnmkkcW<01=kk
00G?omkk[EF]EKgG00>]E@06_MN]EIcCI<aS;9//0ZeE0[gG00^]EIcCS56L
djeE_MN]EHaAW=>]EKgG00>]E@04W=>]EKgG[ED2_ML2W=<2[ED01<cIaQS6
6<HH1;gG0ZeE00JLc8aAW<b]EIcC[ED3_ML1[ED1cWT1aQP0009S;005I<`c
;6</<bIS;002DZX02C60HbHc9U:Z<bIS;3<VHbHc;002Q10016</I=>446CC
0h@@00]Tc8@@W<b<DIc<S56]EIcC[EETaXaA00:Ld`03I=>LdfCC009Td`:<
D@03I<b<DHaA00:Ld`08Q02]EIcCW=><DH@@HbIS;0:44006<baS9V</Q12<
DIcC1:eE00ZLdhaAHbIS9U:Z<b1S9U:Z<H2<D@;66003cWVNNLii00;>N@08
WWW>NMkkg__?omkkcWW>O`oNn`05cWWNnmkkg__>O`08g_/01Licg__Nnmkk
col00]kk00>mejeE[ED00ZeE00RmejeE[EFLdh@@HbITc9cC0kgG0ZeE00Z<
DIcC_MN]EKgGS56LdjeE_MN]E@:me`08[EG<fJeE_MO<fJeES56Ld`:]E@05
c=VmelHHc=VNN@02aQP01[gG[EFLdic<S56Lc0:]E@04cW>mekgG_ML3aQP0
0006<bIBZV<VHH`c9V660V<V01iTc0@@Q11Tdh@@I<aS;6C<HbaS9VC<S54c
;9c<S55Tc8@@W==TdicCI==Tc6CCW=><DFIcW==Tdh@@WW<3W=<2[ED019cC
I<b]EJeE0XaA00MTc8@@WW><DH@@Q01S9P03Hb`010@@Q12LdicC1ZeE0[gG
00JLdhaAHbaS9S<PHHH2<H0015:ZHbITdlcI0/ii00K66<iicWW>NLcIcWT7
g_/01Liog__Nnmkkkgd01Mkk00O>Omkkg__Nnliog__>N@02g_/01Liig__>
Omkkcol00mkk00G66=kkg__Nnnmm00;Nn`06[EFmejeE_MN]EKgG0ZeE00NL
dh@@<bJK;9cC_MN]E@02_ML00jeEW=>K<`03[ED019//W=>]EI/c0[gG00>N
NKgG_ML00kgG00W669cCS56]EKgGWWW<fIiicWT00lHH00Jmelic_MNLc8aA
W<`2W=<00lcC_MNme`02_ML2aQP00008Hb1S;3C<HbaTc6</I<aQQP=S;0:4
400<I<b448@@Q11Tc9cCI==Tc9c<I==Tc8aA0icC00QS;9c<[EFLdiicW=>]
EFCC19cC00FLc9cCW<bLdfC<00:<D@03I<b44666009S;003HHaTc8aA00><
D@06[EFmekgG_MN]EKgG0jeE01BmejeE[EF]EIc<Hb`c9V<V<H1S9S<VDZXa
P6<V[EG669iic=W>NMkk0/ii00C66;gGg___O@GNn`07kggNnmkkkgg>Omkk
kgd01Mkk00?_OMkkkgd02=kk00G_OMkkg__>NLic00?Nn`03kggNnloo00R]
E@04W=>Lc6<VVb`2[ED01kgGc=V]EIcCS56Lc9cC00:]E@04S56LdicC[ED2
_ML01<cI_MNmelHH0kgG00VLdhaA[EF]ELHHcWW66<iic=T00lHH0ZeE00NL
c8aAS56Lc:eE_MN]E@03_ML1[ED1_ML00008=<b448aAI<aTdh@@IW>Ld`AT
c006Q11Tc8aAI<b448aA0YcC00=TdfC<[ED00YcC00AVLjeEW==VL`>Ld`06
[EFLc:eEW==Tc:eE0YcC00UTc6</HbaTc8@@HbbK9V66I<`00XaA00=VLicC
[ED00ZeE00>mejeE[ED00ZeE00>mejeE[ED00[gG0ZeE00nmejeEW=>44666
<b1QQS<VHHIS85:Z<b1S9ZeEc=T00lii00WNnliocWVNNLHHcWW_OMkkcWl0
1=kk00?_OMkkkgd04=kk00K?omkkg__Nnnmmg_/2cW<01=kkcWoNnnmm0]kk
00?66:eE[ED00ZeE00NmejeE_MNLdhaAHbIS;002[ED3_ML01jeEW=>LdicC
[EFLdhaA00:Ld`03_MO<fLHH00:me`03c=VmekgG00:me`06[EF<DIcC[EFm
eicI0/ii1<HH00B]EIcCS56Lc0>Ld`B]E@6me`6]E@6me`0000R446<VHbaS
;8@@HbJ446C<0XaA0icC00>Lc9cCIW<00YcC00BNK9cCQ12Lc0:Ld`05[EFL
djeEW==Tc003W=<028aAI<bLdicC=<b446</<b`2Hb`00fC6Q12Lc003W=<0
1ZeEW=>mejeEc=Vme`:]E@04c=>]EJeE[ED2_ML01jeEc=>mejeEc=>]EKgG
00:Ld`9S9P04<b1BZS60<bH2<H0026<VQ12]ELHHcWWNnliicWl3cWT01<cI
cWW_OLio1]kk00G_OMkkg__Nnlio00CNn`03kgg>Onmm00?Nn`03cWoNnmkk
00CNn`04coo>NLicoW<4g_/00nmmcon]E@03[ED02[gG[EF]EJeEW=><DFC6
HbJ]ELcC0[gG0ZeE0YcC0jeE0XaA00>Lc;gG[ED01;gG00O66;gG_MNmeicC
S56]E@02_ML3aQP01<iiWWW<fLHH0ZeE00BLdic6W<bLd`:]E@Fme`766000
0XaA00QVK8aAW=>NK9cCI<bLc8@@0YcC00ATdfC<W=>]E@>Ld`0;[EETdicC
W==Tc9cCS56Lc9cCQ11Tc003Q1001C</<bJ446</Q1000XaA00>Lc:eE[ED0
0ZeE00BmejeE[EFme`F]E@08_MN]EJeE_MN]EKgGW=>me`:]E@0G_MN]EKgG
[EFmeicCS54c8666<bIS9S60HH1BZS<VHb1S;<cIcWW66=kkcWW>O`06cWT0
1^mmg__Nnliog___O@;Nn`04kggNnmkkcWT7g_/00loog__Nn`04g_/02/io
kggNnnmmg__>LliicWoNnloo0]kk00C_OLHH[EFme`:]E@05_MN]EJeE[EF<
D@02HbH029cC[EFmelcI_MN]EIc<W=<2[ED01KgGW=><DHaAW=<00[gG00C<
fLHH_MO<f@>me`05[EF<DIcC[EFme`02aQP01LcIcWW66<HH_ML00ZeE00NL
di//W<bLdjeE_MN]E@03_ML1c=<1_ML00007I<bLc8aAW=>NLhaAI=<00icC
00NNLicCW=>NK8aAW==Tc003W=<01FC<W<b]EHaAQ1000V</00N<DFC<HHb4
46<VQ11Tc002W=<00jeE_MN]E@05[ED01;gG[EF]EKgG0ZeE00>mejeE_ML0
0jeE00>mejeEc=<00ZeE00JmeicC_MNmejeE_ML2[ED02IcCQ10c85:Z<b1Q
QS60HbHc9P02HbH01H@@aQS>NLiicWl00]kk00O<fLiicWW>NLcIg___O@04
g_/00nmmg__>O`06g_/00liig__Nn`04g_/01>mmg__Nnloo0]kk00K_OMkk
kgfNNMkkcWT2g_/01Nmmg___ONmmWWT01:eE00>mejeE[ED00YcC00AS9X@@
W=>]E@:me`:]E@0;S56LdjeE[EG<dicCS56LdlcC_MO66003_ML2aQP2_ML2
W=<00jeE_MN]E@02aQP2cWT03/HHcWW<fKgG[EF<DIc<Q12LdjeE_MN]EKgG
[ED3_ML00003I==Tc9cC00:Ld`03W<aTc:eE00:Ld`0F[EFLdicCI<b]EIcC
S56446C<W=><DF<VQ11S;3<VQ11Tc8@@I<bLdjeEW=<4[ED01;gG[EF]ELcC
0ZeE00>mejeE_ML00ZeE00>mejeEc=<00ZeE00G<djeEc=V]EKgG00:]E@03
_MN]EKgG00:]E@03_MN]EKgG00:]E@0>S55S9V<VHHHaP3<VHbHaP666<bJ4
09//WWW<f@;>N@;Nn`?>N@05g__<fMkkg___O@04g_/01>mmg__Nnlii0mkk
00?>Omkkg_/01]kk00W_OMkkg___OMkkcooNnnmmcWT01Mkk00C?omkkkgg>
N@:]E@04_MN]EJeE_ML2[ED00haAHbJK8002W=<3_ML00jeEW=>K;002[ED0
1;gGS56Ldic<0ZeE00BmelHH_MNme`;66005[EFmeicCS56]E@02_ML2aQP2
cWT2aQP2_ML01/icW=>Lc8aAW<b]E@>me`03c=>LdkgG006me`000ZeE1YcC
00YTc8aAS56Ldic<Hbb446</Q10c809S9P9Tc0:<D@:Ld`>]E@0;_MN]EJeE
_MN]ELcC[EFmejeEc=>me`02[ED01kgG[EF]EJeE_MN]EKgG00:]E@04_MN]
EJeE_ML3[ED01kgG[EF]ELcC_MN]EKgG00:]E@0DW=>Lc8@@<b1QQS60<bIS
9S60<bIBZS<PHHJLdlHHc=WNnliig__<f@;>N@03cWo>NLii00?Nn`03cWoN
nnmm00CNn`05cWoNnmkkg__>N@04g_/00liog___O@04g_/01>mmg__Nnnmm
1Mkk00??omkkkgd00^mm00?>NJeE_ML00jeE00RmejeEW=><DFC<Hbb<DJeE
0[gG00?<dicCW=<00YcC00>meicCW=<00XaA0YcC00FmejeE[EFmelcI00:]
E@05_MNLdicC[EG<d`03_ML5aQP00kgGW=>Ld`02W<`00haA_MN]E@02[ED0
0kgGW=>me`01[ED000:<D@0>W=>Lc9cCS55Tc9cCS55S;6<VHbaTc6<VQ11S
9P:440>Ld`>]E@03c=>]EJeE00>]E@05_MNLdkgG[EFme`02[ED01;gG[EF]
EKgG0ZeE00FmejeE_MO<djeE00:me`:]E@05_MN]EKgG[EFme`02[ED01KgG
[EF]EKgG[ED00[gG00>]EHaAHb`00V<V014c9V<V<H1QQS60HbIQQV<VHb2L
fLii_MO>Oliig__<fMkk00;>N@05g__>NLiig___O@02g_/00nmmg__Nn`03
g_/00liocWWNn`02g_/01>mmg__Nnnmm0mkk00O>Onmmg__Nnnmmg__?o`03
g_/01<iog___OLio0]kk00??omkk[ED00ZeE00VmejeE[EFmejeES55S9X@@
Vb`00ZeE00BmejeEVc>Lc0:Ld`0:[EFmeicCW<bLdjeEW=?<fKgGc=<3_ML0
0jeE_MN]E@02W=<4[ED00kgGc=W66002aQP01[gG[EF]EIcCc<bLd`:]E@:L
d`Bme`000XaA00ETc6<VQ11S;6<V009S;005I<b448@@I<bLd`09[ED02[gG
[EF]EKgG[EFmelcC_MN]EKgG0jeE00BmejeE[EFme`:]E@03_MN]ELcC00:]
E@09_MN]EJeE[EFmelcC_MN]EKgG00:]E@:me`08[EFmelcC[EFmejeES55S
;09S9P0:<bHaP666<b1BZS<PHHHc86<VW=<3cWT00mkkcWW>N@03cWT2g_/2
cWT00mkkkggNn`02g_/00liog__Nn`03g_/00liig__Nn`04g_/01>mmg__>
Onmm0]kk00G_OMkkkgg>Onmm00GNn`08kggNnnmmcoo_OLiiWWV]E@:me`:]
E@07_MNLdhaAQ11S88aA[ED00[gG0ZeE00NLdhaA[EF]EKgGW=><D@02[ED5
_ML03jeE_MN]EKgG[EF<DIcCS56LdjeE_MO<fLHHWWVme`02aQP2[ED01haA
W<bLdicC[EG<dkgG00;6606me`76600000US;6<VHbb406C6Q12Lc:eEI=<0
0YcC00F]EIcC[EF]EKgG00B]E@05c=>mejeE[EFme`02[ED02;gG[EF]ELcC
[EFmejeE_ML4[ED03;gGc=>]ELcC[EFmejeE_MN]ELcC[EFme`:]E@06_MNL
dkgGc=>]EKgG0jeE01:mejeE[EF]EFC<HHIS8360DZXc8666HbHaP666<b1S
;6CCc=T2cWT2g_/00liicWo>N@02g_/00liig__>O`02cWT00nmmg___O@05
g_/00liig__Nn`04g_/00liog___O@02g_/02<ookggNnloog___OMkkkgd3
g_/00nmmg__Nn`02kgd01=kkkgg_OLHH0jeE00ZmejeE[EF]EIc<Q11S88aA
W=?<d`>me`04[EF<DJeEW=<2_ML018aAVc>]EJeE0[gG00S66:eE[EG<djeE
_MN]EHaA0YcC00B]ELcIWWW<f@;>N@05c=W66;gGW=>me`04W<`01IcC_MN]
EKgGaQP00[gG00001X@@VbbLdicC[EFLd`:me`04[EG<fJeE_ML2[ED01[gG
[EF]EKgG[EG<f@:]E@05_MN]EKgG[EFme`02[ED02[gG[EF]EKgG[EG<djeE
_MO<dkgG0ZeE00JmejeE_MN]ELcC_ML2[ED02kgG[EF]EKgGc=>]EKgG[EFm
ejeEc=<00[gG0ZeE00^meicCW<aBZS<PDZXaP6<VDZXaP3<V009S9P07[EG6
6<iicWW>OmkkcWT00]kk00C>NMkkcWW>O`;Nn`;>N@03cWoNnmkk00CNn`03
cWWNnlio00?Nn`07cWoNnnmmg___OMkkkgd00]kk00?_OMkkg_/00^mm0mkk
00K_OMkkcWo_OLoog_/2kgd03]kkaQR]EKgG[EFmejeE_MNLdhaAQ11S9XaA
[ED3_ML2W=<06Yc<W=>]EKgG[EF449cC_MN]ELcI_MN]EIcCc=>LdkgGc=VL
dhaA[EFmelcI_MO>NLHHcWT2aQP02Lii_MNmejeEW<b<DIcC_MN]E@05_ML1
[ED00007_MN]EJeE[EFLfJeE_ML00ZeE00BmejeE[EFme`:]E@0@c=V]EJeE
_MN]EKgGW=?<fJeE_MN]ELcC[EFmejeE_ML3[ED01KgGW=>mejeE_ML00ZeE
00BmejeE_MNme`:]E@04_MN]EJeEc=<2[ED00kgG[EF]E@02[ED05;gG[EF]
EJeE_MN]EKgGS55S9V66<b1QQS<VHb0aP6<V<H1S88@@c=T2cWT01=kkcWW>
Olii0]kk00?>NOiog_/01=kk00W>NMkkkggNnliog__>NLiocWT01Mkk00K_
OMkkg__Nnnmmg_/2kgd00mkkcoo_O@02g_/00nmmcWoNn`05g_/01^mmg__N
nlookgg>N@F]E@07_MN]EIcCI<aS;9//W=<00ZeE00>mejeEW=<00XaA00FL
djeE_MNLdi//00:]E@03_MN]EJeE00>]E@>me`:Ld`05[EFmekgGaQS>N@04
aQP01kgG[EFmeic<S56Lc9cC00:]E@03_MO66<HH00;6600000V]EIcI_MN]
EKgG[EFmejeEc=T00ZeE0[gG0ZeE00JmejeE[EFmejeEc=<2[ED04[gG[EF]
ELcI[EFmeicC_MN]ELcC[EFmejeEc=VLdkgG[EFme`>]E@04_MN]EJeE_ML2
[ED01KgG[EFmejeEc=<00[gG00J]EKgG[EFmejeE_ML2[ED038aAHb1S9S<V
HHHc8666<bIBZS60HbJLd`;>N@;Nn`07cWW>Omkkg__>NLiocWT01=kk0/ii
1Mkk00?>NMkkg_/00mkk00W>NMkkcWWNnnmmg__?omkkkgd00]kk00C_OMkk
kgg?o`CNn`0@cWo_OMkkkggNnnmmcoo_OMkkWWV]EKgG[EFmejeE_ML2W=<0
18@@HbJ449cC0[gG00B]EIcCW=>K;0>]E@03_MN<DHaA00:]E@06_MN]EKgG
_MN]ELcC0jeE00><DIcC[ED00[gG00W<fLHH_MO<fLHHWWW66;gG[ED00Yc<
00RLdjeE_MNmejeEaQS<fLHH0KgG00001KgG[EFmeicI_ML00ZeE1;gG0ZeE
00G<fJeE[EG<fJeE00:me`0G[EFmejeEc=>mejeE_MN]EKgG[EFmeicCc=V]
EKgG[EFmejeE_MO<djeE_MO<d`02[ED02KgG[EG<dkgGW=>melcC[EFme`02
[ED06<cC[EFmejeE_MN]ELcC[EFLdhaA<bIQQS<PDZXaP6<VHHHc8306I<bL
fKgGg__>N@;Nn`06cWWNnmkkcWWNnlii0mkk00K>OmkkaQS>Omkkkgd2g_/0
0lHH[EGNn`02g_/00lHH_MNNN@02cWT01nmmg__Nnnmmg___OLio00;_O@03
g___OMkk00CNn`06cooNnnmmcWo_OMkk0^mm00k>NJeE_MN]ELcI[EFmejeE
W=>446<VQ12]ELcC0[gG00BLdjeEW=>Ld`:]E@03_MNLdh@@00>]E@03_MO<
fKgG00Fme`:Ld`:]E@07_MNNNLcIaQS>NLcIcWT00/HH00B]EIcCW<JLd`:]
E@03_MN]EKgG00>me`0000S<fJeE_MN]EKgG[EFmelcI0ZeE00>mejeE_ML0
1JeE00BmejeE[EG<f@:]E@06_MN]ELcC[EFmelcC0ZeE00FmelcC_MN]EKgG
00:]E@0:_MN]EKgG[EFmejeEc=>]EKgG[ED2_ML2[ED02KgG[EFmejeE_MN]
EKgGc=>me`02[ED04YcCW<`aP6<V<bHaP6<V<bHaP3<VHHJLc<cIcWW>Olii
cWo>N@;Nn`09cWWNnmkkcWWNnliicWo>NMkk00;>N@;Nn`0?cWV]EIcCaQSN
nlii_MN]EIcI[EG66=kkcWoNnnmm00;Nn`03kggNnnmm00;Nn`03kggNnmkk
00;Nn`06kggNnnmmg___OMkk0^mm00CNnlHH[EFme`:]E@09_MN]EJeEW=><
DF<VW<bLdjeE00:me`:]E@03W<bLdlcC00:me`:Ld`Rme`07aQRmejeEW=>L
c;gG[ED00/HH0lii00^LfLiiaQRmejeEW=>Lc8aA[EFmejeE00Fme`0000Jm
ejeE_MN]ELcI_ML2[ED02KgG[EFmejeE_MO<dkgG[EFme`02[ED2_ML3[ED0
0kgG[EFme`02[ED01;gG[EFmekgG0ZeE00?<djeE_ML00jeE00NmejeE_MN]
EKgG[EFme`03[ED01kgG[EF]EJeE_MN]EKgG00>]E@0?_MN]EJeEW=>443<V
HHIS9S<VHH1BZV<V<b0aS:eE00?>N@;Nn`06cWWNnoiocWWNnlio2]kk00_6
66<cW=?66<ii[EFLfKgGW=V]EIii00?Nn`07cWo_OMkkkggNnlookgd01=kk
00c?omkkg__Nnnmmg__?onmmg__?onmmaQP2[ED2_ML2[ED01KgGW=><DF<V
VbH00YcC00BmelcI_MN]E@:<D@04[EFmekgGS543W=<01lcI_MN]EJeE_MN]
ELcC00:me`09[EF<DJeE[EFLfLiiaQS>NLHH00;>N@;66005_MNLdic<c<bL
d`02[ED2_ML1aQP1_ML1_ML00009[EG<fJeE_MN]ELcI_MN]ELcI00:]E@0:
c=VmejeE_MN]ELcC[EFmejeE_ML2[ED02[gG[EF]EJeE_MN]EKgG[EG<dkgG
0ZeE00BmejeE[EFme`>]E@:me`:]E@04c=>mejeE_ML2[ED01;gG[EF]EKgG
0ZeE00?<djeE_ML00ZeE00bmehaAHbIS9S<VHH1BZS<VHbIS;9cCc=T3cWT5
g_/01<iig__Nnlii1mkk0/ii00bmeh@@S55TdicCS54c<h@@S56LfIiicWT2
g_/01nmmg___OMkkkggNnnmm00?Nn`03cWW_OMkk00;Nn`05kggNnliokggN
n`02kgd03mkkaQR]ELcC[EFmejeE_MN]EIcCS55S;9//W=>]E@03_ML00jeE
W<b<D@02[ED01KgG[EF<DIcC[ED00[gG00C<fLHHaQS<f@:me`08aQRLdicC
W=>meicIcWW660;>N@07aQS>NKgG_MO>LjeEW<`00YcC1[gG0LHH00002[gG
[EFmejeEc=V]EKgG[EFmejeE0[gG012]EKgG[EFmejeE_MN]ELcC_MN]ELcI
_MN]EKgG[EG<f@:]E@:me`06[EFmejeE[EG<dkgG0ZeE00>melcC_ML00ZeE
00NmejeE_MN]ELcC[EFme`02[ED01LcC_MN]EKgG[ED00[gG00N]EKgG[EF<
DH@0DZYQQP02<bH01V<PHHJ]ELiig__>N@;Nn`08cWoNnmkkoWoNnliig__>
O`?Nn`0:cWoNnmkkg__>OmkkcWV449cCS542Hb`028@@I=>LdicC_MO66<ii
cWl2kgd01mkkcoo_OMkkkggNnlio00;Nn`07kgg?omkkkggNnnmmg_/00nmm
00??omkkg_/00ZeE00bmejeE_MN]EKgGW=>]EHaAHbJ408aA[ED3_ML02IcC
S56LdkgGc=>meicCS57<d`09_ML01/cC[EFLdjeE_MN]E@;660;>N@07WWW<
fLHHaQR]EIcCW<`00YcC1KgG0LHH0KgG00002:eE_MN]EJeE_MN]EKgG[ED2
_ML3[ED01LcI[EFmejeE_ML00ZeE00JmejeE[EG<djeE_ML2[ED01[gG[EG<
dkgGW=?<f@:me`03[EFmejeE00:me`:]E@0Q_MO<dkgG[EFmejeE_MN]EKgG
[EFmejeE_MN]EKgG[EFmejeEc=>meicCQ11S9S<P<bIQP5:ZHb244<cIaQS>
Olii00KNn`03cWoNnmkk00WNn`04cWV]EJeEQ102<bH01X@@I==Tdf<cVcVN
N@;>N@;Nn`;_O@03g___OMkk00SNn`0Akgg>OmkkkggNnnmmg___OLoog_^m
ejeE_MN]EKgG[EFme`02[ED01YcCHbbK9XaAW=?<f@:me`06[EFLdic<W=>]
EKgG0icC0ZeE1KgG00>]EKgGW=<00YcC00J]EKgGc=VNNLcIaQP2cWT2aQP2
_ML01JeEW=?<c9cC[ED00[gG00>]EKgG_ML00KgG0002_ML02:eEc=VmejeE
_MN]EKgG[ED3_ML2[ED01KgG[EF]EJeEc=T00ZeE00NmejeE_MN]EKgG[EG<
d`02_ML2[ED2_ML2[ED01;gG[EG<djeE0[gG00o<djeE_MN]EKgGc=>mejeE
c=>]EKgG[EFmejeE_ML00jeE00bmejeEW=>406</Hb1BZV60<bIS9XaAaQP2
g_/00liicWoNn`08g_/00liog__Nn`03g_/03_iocWVLdhaAQ10c9S6<Hbb<
DFCCHbb]ELiiaQP2g_/01>mmg__>Omkk0nmm00C?omkkkgg>O`?Nn`05cWo_
OMkkkgg?o`02kgd01MkkkggNnmkkWWT01:eE00RmejeE[EF]EHaAI<aS;8aA
0ZeE0[gG00F]EHaAS56LdkgG00:]E@03Q12LdicC00:]E@04_MN]EKgGc=T2
_ML2[ED018aA[EFmekgG1<ii00G<fLii_MO66;gG00:Ld`03W<bLdkgG00:m
e`03[EG66<HH006me`0000^LfJeE_MN]EKgG[EFmejeEc=V]EKgG00:]E@04
_MN]ELcI[ED2_ML01:eE_MN]EKgG0ZeE00C<dkgG[EFme`:]E@:me`06[EFm
ekgGc=>mejeE0[gG01N]EKgG_MN]EKgG[EFmejeE_MN]EKgGc=>]EKgG[EG<
dkgG[EFmelcC_MN]EIcC00=S9P05<bHaP6<VHHJ]E@04cWT2g_/01Liog__N
nmkkcWT01=kk00?>Omkkg_/00mkk00C>NH@@S55S;08c9P05Q11Tdh@@Hc>N
N@03cWT01]kkkggNnloog___O@;Nn`0;kggNnnmmg__?omkkkggNnloog___
O@02g_/01Lookgg_ONmmg_/00[gG00>]EKgG[ED00[gG00J]EIcCS55S;6<V
W<`2W=<01/cC_MN]EIcCVbbLd`:]E@03_MN<DIcC00:]E@06S56mejeE_MO6
6<cI0kgG00>LdjeE_ML01<HH00C>NLHHcWW660:me`04cW>Ldic<W<`2[ED0
1;gG[EF]EJeE0LcI00003:eE_MO<fJeE_MN]ELcI[EFmejeE_MN]E@:me`04
c=>]EKgG_ML2[ED01[gGc=>mejeE_MO;>@:]E@03_MN]EKgG00>]E@09_MN]
EKgG_MN]EKgGc=>]EKgG00:]E@05_MN]EKgG_MN]E@02_ML01ZeE_MNmejeE
_MN]E@:me`04[EFmeicCS542HbH01U:Z<H1S9U:ZHbK660;>N@03cWoNnmkk
00CNn`07cWWNnliog__nNMkkkgd01=kk00_>NIcIS56443</<bJ448aA<baS
;:eE00;>N@03g__>Omkk00;Nn`04kggNnnmmcWl2kgd00mkkkggNn`02kgd2
g_/02nmmg___ONmmcoo_OMkkkgg?omkkaQP00ZeE00>mejeE_ML00jeE00^L
dh@@Q02<DIcC_MN]EKgG[EFLdic<00>]E@07W=><DIcC_MN]EKgGc=T01[gG
00>]EHaAW=<00kgG00C<fKgGaQS>N@;66003W=>]EIcC00:Lc007W=>]EIcC
[EG>LkgGc=<00KgG00001JeE_MN]EKgG[ED00[gG00V]EKgG_MN]EKgG[EFm
eicIc=<00ZeE00VmelcC_MN]EKgG[EFmejeE_ML00ZeE00JmejeEc=W<djeE
_ML2[ED01;gG[EFmekgG0ZeE00JmelcC_MN]ELcC_ML2[ED2_ML01:eEc=>]
EKgG0ZeE00FmejeE_MN]EH@@009S9P06<b1QQV<VHHITc<cI0lii00?Nnlio
g_/00]kk00G>OmkkcWWNnlio00CNn`06cWoNnmkkg_^]EIcC0V</00Hc9S</
_MMS<h@@[ED2cWT2g_/01NmmcWoNnnmmg_/00^mm00GNnnmmg__?onmm00;N
n`06coo_ONmmg___OMkk0^mm00SNnnmmg___OLHH_MN]EKgG0ZeE00bmejeE
[EFLdh@@HbJ<DIcC_MN]EKgG[ED3W=<02kgG[EF]EIcCVc>]EKgGaQS<fKgG
aQP01KgG00N<DIcCW=VmelHHWWW<f@04aQP01kgG[EF]EIcCW<bLdlc<00>L
d`6]E@6me`6me`0000_<fJeE[EG<fJeE_MO<djeE_MN]ELcI00:]E@07_MN]
EKgG[EG<fJeE_ML00jeE0[gG00R]EKgG[EG<fJeEc=>mejeE0[gG00J]EKgG
[EG<dkgG[ED2_ML02LcC[EFmejeE_MN]EKgGc=>me`02[ED3_ML01jeE_MO<
djeE_MN]EFC<00=S9P0:DZXc86<VS5766=kkcWWNnoiocWT2g_/01<iig__>
NOii2]kk00ZNNIcC<b`c;3<VVbc>NFCCS56]E@?Nn`03kggNnmkk00C_O@04
g___ONmmg_/2kgd01mkkkgg>OmkkkggNnloo00;_O@03g___OLoo00;_O@04
WWV]EJeE[ED2_ML3[ED04haAI<aS;9//W=>]ELcC_MN]EIcCW<bLdkgG[EFm
ehaAW=>mejeE00;66003_MO66;gG00>me`06[EF<DIcC_MN]EKgG0/HH00?>
NIiic=T00/HH0ZeE00FLdic<W=>mejeE00Bme`7>N@0000nmejeE_MN]EKgG
[EFmejeE_MN]ELcI[EFmejeEc=<00[gG0ZeE016mejeEc=VmelcC_MN]EKgG
c=>mejeE_MN]EKgG[EFmelcC00:me`04[EFmejeE[ED2_ML02:eE_MN]EKgG
[EFmejeEc=<2_ML2[ED2_ML01ZeE_MN]EKgGW==S;09S9P09<bIQQV<VHbJL
dlcIcWW>Olii00;Nn`06cWWnOmkkg__>Olii1=kk00CnOmkkg__>O`;Nn`0;
cWV<DH@@HH`c;8aA_MN<DIcCW=W>N@03g_/2kgd01MkkkggNnnmmcWl00nmm
00?Nnnmmkgd00^mm00ONnnmmg___OMkkkgg?o`02kgd01mkkkgg>NKgG[EFm
ejeE00:me`:]E@:<D@05HbJK;9cC_MO66002_ML3W=<00jeE_MNme`02W=<0
0jeE_MO66002aQP00kgGc=Vme`02_ML01<HHS56LdjeE0[gG00C<fLiicWW>
N@;660:me`06cW>Ldic<W<bmelcC0[gG0lHH00004:eEc=VmejeEc=V]EKgG
[EG<fJeE_MN]ELcI_MN]EKgG0ZeE00>mejeE_ML00jeE016mejeE_MN]EKgG
[EFmejeE_MN]ELcC_MN]EKgG[EFmelcC00:me`:]E@06_MO<dkgG[EFmejeE
0[gG00b]EKgG_MN]ELcC[EFmelcC[EFLdh@@Hb02HbH01F66<bIS9YcCaQP0
0/ii1Mkk00?>NMkkg_/00]kk00?>Omkkg_/01mkk00^<DC</Q11TdicCI=VL
diii_MONnlio00;Nn`08kggNnnmmkggNnloog___O@;Nn`;_O@06cWoNnnmm
kgg?omkk0nmm00cNnnmmg___OLoog_^mejeE_MN]EKgGc=<2[ED01IcCS564
08@@W=<00kgG00b]EIcCW=>K;9cCc=>]EHaAW=?<dkgGW=T2aQP00kgGaQRm
e`02_ML02JeEW<bLdlcC_MO<fLHHcWW<f@03aQP01/cI_MO<dicCW<bLd`:]
E@:me`?6600000FmejeE[EFmejeE00>me`07[EFmekgG[EG<dkgGW=T00[gG
00C<dkgGW=?<f@:me`04[EFmejeEc=T2[ED00kgG[EG<d`02_ML00jeE_MO<
d`02_ML00jeE_MO<d`04_ML01:eE_MNmekgG0ZeE0[gG00g<dkgG[EFmejeE
_MN]EKgGW==S9S<VHHHc8003HbH019cCcWW>NLii0]kk00G>Omkkg__>Olii
00_Nn`03cWV<DH@@00:Ld`:]E@0=_MN]EIiocWWNnnmmg__>OmkkkggNnnmm
g_/00^mm00ONnlookggNnnmmcooNn`02kgd01MkkkggNnnmmcol01Nmm00?N
nkgG[ED00[gG00^]EKgG[EF]EIcCI<aS;9//W=>melHH00:me`:Ld`08W<bL
djeE[EFLdhaA[EFme`;66007c=VmekgGaQR]EKgG[ED00YcC0ZeE00FmelHH
aQS>NLHH00Bme`05[EFLdhaAc<b]E@06_ML00006_MN]EKgG_MN]EKgG0ZeE
0[gG00V]EKgG_MN]EKgGc=>]ELcI[ED00[gG00C<djeEc=V]E@:me`03[EFm
elcC00:me`>]E@04_MN]EKgGc=<2_ML2[ED01KgGc=>]EKgGc=<00ZeE00C<
dkgG[EFme`:]E@:me`07c=>mejeE_MNK;6<V<bH00V<V00ABZS60HbJme`;>
N@03cWoNnlii00WNn`03cWoNnmkk00CNn`07Vc<448@@Vc><DIcCW=T00[gG
0/ii0mkk0nmm00GNnnmmkgg_OMkk00G_O@08g___ONmmkggNnlookgg>O`;_
O@06g__?onmmg__?okgG0ZeE00BmejeE_MNme`:Ld`04S55S;8@0W=<2_ML0
2/cI_MNLdicCW<b]EIcC[EFK<haA0kgG0/HH00>melHHaQP00kgG0YcC1;gG
1LHH0[gG00Z]EKgGW<bLdlHH_MN]EKgG[EG<d`6me`0000R]EKgG[EG<fKgG
[EG<fJeE0[gG00F]EKgG[EFmejeE00:me`03[EFmejeE00:me`04[EFmelcC
_ML2[ED00kgG[EF]E@03_ML01ZeE_MNmejeE_MN]E@:me`04[EFmekgG[ED4
_ML01:eE_MN]ELcC0[gG00B]EKgG[EFme`:]E@03S55S85:Z009S9P04DZYS
9X@@c=T3cWT01<iog__Nnlii0mkk00?>Omkkg_/01Mkk00S>Omkkg_^]EF6C
[EG>NIii0/ii00?>Oliig_/00]kk00S_OLiog__NnnmmcWo_OMkk0nmm0]kk
0nmm00G?omkkkgg_OMkk00;_O@07g___ONmmg___OMkkkgd00[gG00bLdkgG
[EF]EKgG[EFLdic<HbaS89cC[ED3_ML00lcCW=>K<`02[ED01;gG[EF<DJeE
0[gG00O<fLHH_MNmelcIaQRme`02[ED2W=<01ZeE_MNLfLHHc=W>N@;660:m
e`07WW?<dic<W=>]ELicW=<00ZeE0KgG0LHH00001:eEc=V]EKgG0ZeE00Vm
ejeE_MN]ELcI[EFmelcI[ED00[gG00F]EKgG[EFmejeE00:me`03[EFmelcC
00:me`0B[EFmelcC_MN]ELcC_MO<djeE_MO<dkgG[EG<dkgG[EFmelcC0ZeE
00^mejeE_MN]EKgG[EFmejeE_MN]EKgG00:]E@05W<`c9V<VHbHc9P02HbH0
1IcCaQS>NMkkcWT00mkk00?>NOiocWT00mkk00GnOmkkg__Nnlio00GNn`03
aQSNnmkk00;Nn`04cWWNnmkkkgd2g_/00nmmg___O@02kgd00mkkkgg_O@02
kgd01mkkkgg_ONmmg___OMkk00?_O@03g__?omkk00;_O@05coo_ONmmkggN
n`02_ML01:eE_MO<dkgG0ZeE00FLdhaAHbaTc9cC00:me`05aQRmejeES56L
d`02_ML00jeEW=><D@02[ED02lcC_MO66;gG[EFmejeEW=?<dicCS5400kgG
00K66<iicWW>NLHHcWT2_ML01:eEW=>Lc9c<0jeE0[gG0/HH00000kgG[EFm
e`02_ML00jeE_MN]E@03_ML01:eE_MN]EKgG0ZeE0[gG00o<dkgG[EG<dkgG
[EFmelcC[EFmejeE_MN]ELcC_ML00ZeE0[gG00>]EKgGc=<00[gG01J]EKgG
_MN]EKgG[EFmelcC_MN]EKgG[EFmelcC_MN]ELcC_MN]EH@@HHHc9P=S9P0<
HHJmeliicWW>Omkkc=WNnliocWWNnlio1mkk00?>NMkkg_/01]kk00?_OMkk
g_/00]kk00G_OLiog__Nnnmm00;Nn`;_O@03g___OMkk00C_O@06cooNnnmm
kgg?omkk0nmm00[Nnnmmg___OMkkkgg?omkk[EFme`:]E@0>_MN]EKgG_MNL
dic<HbJK9Y/c[EG<fKgG[EFme`:Ld`0:[EFmekgG_MNK;:eEW=>melHHc=T6
_ML01jeEW=>]EJeEc=W>NIcI00?>N@08aQRmekgGc=>LdhaAW<b]E@Jme`00
00>mejeEc=T00ZeE0[gG00^]ELcI[EF]ELcC_MN]ELcI[EFmelcI00:]E@04
_MN]EKgG[ED2_ML00jeE_MO<d`02_ML01:eE_MNmejeE0[gG00V]EKgG_MN]
EKgG[EFmelcC[ED00[gG00_<dkgG[EFmejeE_MN]ELcC[EFmejeE00:me`03
W=>446<V009S9P05HHHc9V<VcWW66003cWT2g_/00liig__Nn`07g_/00lii
g__nO`05g_/01Nmmg__NnmkkcWl00]kk00C_OMkkg___O@;Nn`;_O@04g___
ONmmg_/2kgd01MkkkggNnnmmg_/00^mm00CNnnmmcooNn`;_O@04coo_ONmm
col2g_/00kgG[EF]E@02_ML02:eE_MN]EHaAW<b446<PW=<4_ML02jeES56L
dkgG[EFmejeEQ12LdkgG[ED00kgG0/HH0kgG00BLdjeEW=?<d`:me`;66005
cWW<fIiic=V]E@03W<`01HaA[EF]EJeEaQP00kgG0002[ED01[gGc=V]EJeE
c=V]E@Bme`04[EFmejeE_ML2[ED06KgG[EG<fJeE_MO<djeE_MN]EKgG[EFm
elcC_MN]EKgGc=>]EKgG[EG<dkgG[EFmejeE00:me`05[EFmejeE_MN]E@02
_ML00lcC_MNme`02_ML02:eE_MN]EKgG[EF443<PDZX3HbH01I//cWW>NLcO
g_/00/ii00?NnliicWl01Mkk00?>OliioWl01Mkk00K>Omkkg__Nnliokgd4
g_/00loog__Nn`02kgd2g_/2kgd01]kkkgg?omkkkggNn`?_O@05cWo_ONmm
kggNn`02kgd01MkkkggNnnmmg_/00^mm00?>NKgG_ML00ZeE0[gG00N]EKgG
W=><DH@@Hbb<D@02_ML01LHH_MN]EJeES5400ZeE00G66;gGW<bK<jeE00:m
e`;66005c=W66<HH_MO66004W=<01[gGaQS<fLiiaQS>N@;66008_MN]EJeE
W<bK;:eE_MO<d`>me`76600000>]ELcC_ML00ZeE00FmejeE_MN]EKgG00:]
E@:me`07[EFmejeE_MN]ELcI[ED01;gG00[<dkgG_MN]EKgG[EFmejeE_MN]
E@:me`0@c=>mekgG[EFmelcC_MN]ELcC_MN]EKgG[EFmejeE_ML2[ED2_ML0
3:eE_MN]EKgG[EF<DH@0HbaS9S<VHbJ<D@G>N@05cWo>NMkkg__>N@02g_/0
0liog__Nn`08g_/02>mmg___OMkkkggNnnmmcWT2kgd01=kkkgg>Omkk0nmm
00CNnnmmkggNn`;_O@04cWo_ONmmg_/2kgd01]kkkgg>Onmmg__?o`;_O@08
coo_ONmmg_^mejeE_MN]E@:me`0=[EFmejeES56LdfC<HbJLdkgG[EG<fKgG
[ED00YcC00K<dkgG_MN]EHaA[ED3_ML01lcIaQS66<HH_MO<djeE00:Ld`04
[EFLdkgG[ED4cWT01LHHcWVmekgGW=<00Yc<00Fmelc<W=>mejeE00:me`00
00bmejeEc=VmejeE_MO<dkgG[EFmelcI_ML2[ED01<cI_MO<dkgG0ZeE0[gG
0ZeE00bmelcC[EFmelcC_MO<djeE_MO<dkgG[ED2_ML01JeE_MO<dkgG[ED0
0[gG00N]EKgGc=>melcC_MN]E@02_ML00lcC[EF]E@02_ML01/cCaQR]EHaA
HbIBZP=S9P08S57>NLiicWW<fLiig__>N@?Nn`03kggNnmkk00KNn`03kggN
noio00?Nn`0@kggNnnmmg___OMkkcWoNnnmmg___OMkkkggNnnmmcWl6kgd0
1Mkkkgg_OMkkcol01^mm00ONnnmmkggNnlookgfme`02[ED01;gG[EFmejeE
0[gG00ZLdhaAQ12409//[EFmelHH_MO<d`BLd`:]E@03Vbb]EJeE00Nme`:L
d`04S56LdicC[ED2_ML01<HHcWW<fLii0/HH00Z]ELic[EFLdic<W=><DJeE
_MN]E@:me`000ZeE00JmejeE_MN]ELcI[ED2_ML00jeE_MN]E@02_ML2[ED0
1;gG[EG<dkgG0ZeE0[gG00V]EKgGc=V]EKgG[EFmelcC[ED00[gG017<djeE
_MNmejeE_MN]EKgG[EFmelcC_MN]EKgG[EFmelcC00:me`0:[EFmejeE_MO<
dkgG[EFLdh@0<bH3HbH00jeEcWW>N@02cWT00mkkcWWNn`02g_/00oiicWoN
n`05g_/00liog__Nn`03g_/01^mmg__Nnnmmg___O@CNn`06kggNnloog___
OMkk0nmm00CNnnmmkggNn`;_O@05cooNnnmmkggNn`03kgd01Liokgg_ONmm
g_/00^mm00[NnicC_MN]EKgG[EFmejeE_MN]E@:Ld`03W<`aS9cC00:me`0:
aQRmejeEW=>Lc9cC_MO<fJeES542[ED01[gG[EFmekgGaQS<f@>me`:Ld`0C
[EFmejeEc=W66<iiaQS>NLHHcWW<fKgG[EFLdic<[EFmelic[ED00kgG0000
2LcI[EFmejeEc=VmejeE_MN]E@02_ML01/cI_MO<djeEc=V]E@>me`06[EFm
elcC[EFmejeE0[gG00>]EKgG[ED00kgG01:]EKgG_MN]ELcC_MN]EKgGc=>m
ejeE_MN]EKgG[EFmejeE_ML2[ED3_ML01lcC_MNmejeE_MNLdh@@00=S9P0;
<bK<fLiicWW<fLiig__>NLiocWW>O`0<g_/02Nmmg__Nnnmmg___OMkkkgg>
O`03g_/02>mmg___OMkkkgg>Onmmg_/2kgd00mkkkgg_O@03kgd02=kkkgg_
ONmmg__?onmmg_/2kgd01lookggNnnmmg_^]EKgG00>]E@03_MN]EKgG00:]
E@04S56Lc6<VQ102[ED00kgG[EFme`03W=<01JeE_MO668aAW=<00ZeE00?<
fLHHaQP00lHH0[gG00>]EIcC[ED00ZeE0/HH00?>NLHHcWT00/HH00FmejeE
_MNLdic<00>]E@:me`;6600000J]EKgGc=V]EKgG[ED2_ML00lcC_MN]E@04
_ML01ZeE_MNmejeE_MN]E@>me`04c=V]EKgG[ED2_ML01/cC_MN]EKgG[EG<
f@:]E@0=_MN]EKgG_MN]EKgGc=>mejeE_MN]EKgGc=<00[gG00W<fJeE_MN]
ELcI[EFmejeE_ML00XaA00B405:ZHbJK;0;>N@05c=W>NLiig__>N@07g_/0
1<iog__Nnoio0]kk00?_OMkkkgd00]kk00C_OMkkcWo_O@;Nn`05kgg>NMkk
kggNn`02kgd01=kkkgg_OMkk0^mm00GNnnmmkgg_OMkk00;_O@03g___ONmm
00;_O@05g___ONmmkggNn`02kgd02looaQRmekgG[EFmelcC_MN]EKgG[ED0
0YcC00J<DF<VW<b]EKgGc=T2_ML00ic<W=>]E@03_ML01HaA[EFmejeE_ML0
1LHH0[gG00F]EH@@S56LdjeE00>me`03c=W66<HH00;660:me`04W<c<c:eE
[ED2_ML3aQP000:me`07[EFmekgG_MN]EKgG[ED00[gG00^]EKgG[EG<fKgG
[EG<fJeE_MN]ELcC00:me`04[EG<dkgG_ML2[ED2_ML00lcC_MN]E@02_ML0
1:eE_MNmejeE0kgG00R]EKgG_MO<dkgG[EFmejeE0[gG00k<dkgG[EFmejeE
_MO<dkgGW=><DH@@HbIS88aA0lii00G66<iic=oNnlii00?Nn`04cWWnOmkk
cWT7g_/01/iokggNnmkkkggNn`;_O@?Nn`04cWoNnnmmg_/2kgd00mkkcooN
n`04kgd00mkkcooNn`02kgd00liokggNn`04kgd00mkkcoo_O@03kgd00lHH
[EFme`03[ED02KgG[EFmekgG[EF<DFC<Q12K;002[ED01KgGc=>Ldi//W<`0
0jeE00FmeicCW<b]ELcI00;66007c=W66;gGaQS<fJeE_ML00YcC0ZeE00O<
fLiiWWW<fLHHcWW66003_ML01icCW<bLdkgGaQR]ELcC00:me`0000k<fJeE
_MNmejeE_MN]ELcI[EFmejeEc=>mejeE0[gG00V]EKgG[EFmelcC_MN]EKgG
[ED00[gG00B]ELcC_MNme`:]E@Bme`07c=>melcC[EFmelcC[ED00[gG00>]
EKgG[ED01;gG00B]EKgG_MN]E@>me`:]E@:Ld`04W<aS9V</S543cWT00lcI
g__>N@02g_/00oiocWW>O`03g_/01/iicWoNnliig__nO`KNn`03kggNnnmm
00;Nn`08kggNnmkkg__?omkkkggNn`;_O@04g___ONmmcWl3kgd00mkkkggN
n`03kgd01Loog___ONmmcol00^mm00GNnloog__66;gG00B]E@04_MN]ELcC
[ED2W=<01Ic<HbJ449cC_ML00ZeE00BLdhaAS56Ld`:me`03[EFLdhaA00Bm
e`G66004_MN]EIcC[ED3_ML2aQP2cWT2aQP01lii_MN]EIcCW<b]ELcC00:]
E@>me`0000b]EKgG[EG<fJeE_MN]EKgG[EG<fKgG[ED2_ML01:eE_MN]EKgG
0ZeE0[gG00R]EKgG_MN]ELcI_MN]ELcC0[gG0ZeE00BmejeE_MN]E@>me`0;
[EFmelcC[EFmelcC_MN]EKgG[EG<d`02_ML01JeE_MO<dkgG[ED00[gG0ZeE
00RLdhaAQ01S9XaAcWW<fMkk0lii1Mkk00G>NMkkg__Nnlii00SNn`08cWoN
nmkkkggNnnmmcWo_O@?Nn`05kggNnnmmkggNn`02kgd01=kkkgg_OMkk0^mm
00?Nnnmmkgd00^mm00KNnnmmkggNnnmmg_/2kgd01mkkkggNnjeE_MN]EKgG
00:]E@Bme`06W=>]EH@@HbbK;9cC0kgG00F]ELcCW=>LdjeE00:me`03[EFK
<icC00:me`05c=W>NLHHaQS<f@02_ML00jeEW=>Ld`02[ED01IcIcWW<fLHH
cWT00lHH0[gG00>]EIc<W=<00kgG0/HH0KgG00001jeE_MN]EKgG[EFmejeE
00:me`04[EFmekgG_ML2[ED3_ML00lcC_MNme`02[ED01<cI[EFmejeE1;gG
00V]ELcI_MNmelcC_MO<dkgG[ED00kgG00>]EKgG_ML00kgG00>]EKgG_ML0
0ZeE00jmejeE_MNmejeE_MO<dkgG[EFLdhaAHbaS88aA1<ii00C<fLiog__>
N@?Nn`04cWW>OliicWT2g_/00liig__>N@06g_/01>mmg__Nnnmm0]kk00C_
OMkkkgg>O`;_O@04g___ONmmg_/3kgd02=kkkggNnlookggNnnmmg_/2kgd0
0lookgg_O@02kgd01=kkcoo_OMkk1:eE0[gG0ZeE00FmejeEW=>LdhaA00:4
0003W=>mekgG00>me`:Ld`05_MO<dlHH[EF<D@04_ML5aQP2_ML2W=<01JeE
bc>meliiaQP00/ii00W<fLiiaQS66;gGW=>Lc:eEcW<00kgG0LcI0KgG0002
_ML029cI_MN]ELcI_MN]ELcI_ML2[ED2_ML05/cC_MN]EJeE_MN]ELcC_MN]
EKgGc=>mejeE_MN]ELHHc=>]EKgG[EFmejeE0kgG00b]ELcI[EFmelcC_MN]
EKgG[EFmejeEc=<3_ML00jeEc=V]E@02_ML03JeE_MNmejeEW=>Lc8@@HbJ<
DLiiaQS<fMkk00;>N@;Nn`05cWoNnnmmcWWNn`03cWT01LcOg__NnmkkcWl0
0]kk00GnOmkkg__Nnnmm00;Nn`03kggNnnmm00CNn`03kggNnnmm00;_O@04
g___ONmmcWl2kgd01mkkkgg_OLoog___OMkk00;_O@03g__>Onmm00;_O@05
g__>NKgG[EFme`02[ED00lcC_MN]E@02_ML01ZeEW=><DH@@VbJLd`:me`03
aQR]EKgG00:Ld`:]E@:me`05S56]EKgGc=W>N@02aQP03LcIaQRmekgGaQRL
djeEW=>]EKgGaQRNNLcI00?>N@07aQRmelicW=>K;9cC[ED01;gG0LHH0000
2KgG[EF]EKgG[EG<fJeEc=>me`02[ED00kgGc=V]E@02_ML01:eE_MO<fJeE
0kgG00F]EKgG[EFmelcC00:me`08W=>mekgGc=>mejeE_MN]E@:me`03[EFm
ejeE00:me`03W=VmelcC00>me`03[EFmejeE00:me`04[EFmelcC[ED2_ML0
1ZeEc=V<DH@@HbJ440;660C>N@03g__>Omkk00;Nn`;>N@03c=W>NLii00[N
n`06kggNnmkkkggNnnmm0mkk00?_OLoog_/00^mm00?>Onmmg_/01>mm00GN
nnmmkgg_OMkk00C_O@08g___OLookggNnnmmg_^me`:]E@08_MO<dkgG[EFm
ejeE_MN]E@:Ld`0<S55Tc6<PW=>melcCaQRmeicCS56LdlcC0[gG00B]EHaA
_MN]E@G66007cWVmelcI_MN<DIcC[ED00[gG00C<fLHHcWW>N@?66005_MN]
EJeEW<JLd`02_ML00jeEaQRme`01aQP00003[EG<fLcC00Bme`03[EFmekgG
00>me`:]E@09c=VmejeE_MN]EKgG[EFmelcC00>me`07[EFmekgG_MN]EKgG
[ED00kgG00b]EKgGc=>]EKgGc=>NNLcC_MN]EKgGc=<2_ML01jeE_MO<dkgG
[EFmejeE00:me`0@[EFmejeE_MNLdfC<Q02K;<iiaQS<fLiicWo>NMkkcWT2
g_/02<iocWW>NLiig__<fMkkcWT8g_/02<iokggNnnmmg___OLiokgd2g_/2
kgd00mkkkggNn`02kgd00mkkkggNn`03kgd00mkkcooNn`02kgd02mkkcoo_
ONmmg___OLoog__>NJeE_ML00jeE00>mejeE_ML00kgG00F]EIcCS56449/V
00:Ld`>me`03c=>LdicC00:]E@03_MNLdi//00:]E@G66006cWW66;gG_MN]
EIcC0ZeE00RmelHHc=VNNLiiaQRmelHH0ZeE00BLdic<W<b]E@>me`;66000
0ZeE0[gG0jeE0[gG00>]ELcI[ED00[gG00?<fJeE_ML00[gG00?<dkgG_ML0
0kgG00b]EKgG[EFmejeE_MO<dkgG[EFmejeEc=<2_ML01ZeE_MNmejeE_MO<
d`>me`>]E@0:_MO<dkgG_MO<dkgG[EFmelcC[ED3_ML01icCS56K;8@@[EG6
6<ii00GNn`03cWo>NLii00G>N@08g__>NLiooWWNnliog___O@;Nn`;_O@;N
n`03kggNnnmm00;Nn`06kggNnnmmg__?omkk0^mm00?Nnnmmg_/00^mm00?>
Onmmkgd00^mm00C>OnmmkggNn`?_O@;Nn`0;aQR]EJeE[EFmejeE_MN]EKgG
[EFme`02[ED01HaAW=>406</W=<00[gG00?66;gG[ED00YcC00J]EKgG[EFL
dh@@[ED2_ML00lcIaQS<f@03aQP2_ML2W=<2[ED00kgGc=W>N@02cWT03<cI
cWW>NIcIaQRLdic<W=>]EKgGaQRme`;6600000O<fKgG[EF]EKgGc=V]E@02
_ML01:eEc=VmejeE0[gG00>]EKgG[ED00[gG00B]ELcI[EF]E@:me`0<c=W<
dkgG_MN]ELcI_MN]ELcI_MN]ELcC0kgG00C<dkgG_MN]E@:me`04[EFmekgG
[ED2_ML01JeE_MN]EKgG[ED00kgG00[<dkgG_MN]EIcCI<b449cCaQS<f@;>
N@CNn`C>N@05c=WNnliig__>N@0:g_/3kgd02=kkkggNnnmmcWoNnnmmg_/2
kgd00mkkkgg_O@02kgd00mkkkgg_O@02kgd00mkkkgg_O@02kgd2g_/03/oo
kggNnlHH_MN]EKgG[EFmejeE_MN]EKgG[ED2_ML2[ED018aAQ12K;9c<0[gG
00O<fKgG[EFLc8aAW=>]E@02_ML2W=<01:eE_MO66<ii0/HH00G<fKgGW=>]
EIcC00>]E@03_MNNNLcI00?>N@03aQS>NKgG00:me`06W<c<c:eE[EG<dkgG
0/HH0002_ML01:eE_MO<fJeE1;gG016]EKgG_MO<fJeE_MO<fJeE_MN]EKgG
c=V]EKgGc=>mejeE00:me`06[EFmekgG[EFmejeE1;gG00F]EKgG[EFmejeE
00:me`08[EFmelcC_MO<fJeE_MN]E@Jme`0A[EFmekgG[EFmeicCQ12<DIc<
_MO66<iig__>OmkkcWWNn`02aQP3cWT00mkkcWWNn`02g_/00liog__Nn`02
g_/01oiog___OMkkkggNnlio00?_O@;Nn`08kggNnnmmkggNnnmmcooNn`;_
O@06g___ONmmg___OMkk0^mm00C?omkkkgg?o`;_O@0=cWVmejeEc=>meicC
_MN]ELcC[EFmejeE_ML00ZeE0YcC00ETc6<VW=>]ELHH00:me`:Ld`03Vc>m
ejeE00:me`05Vbb]ELHH_MO<f@04aQP3_ML00icC[EF]E@02_ML03lHHcWW>
NLHHcWW<fLiiaQRmejeEW<b<DJeE_MN]E@02_ML1aQP00003[EFmejeE00:m
e`04[EFmejeEc=T2_ML00jeE_MNme`02_ML00jeE_MO<f@02[ED3_ML02JeE
_MNmekgGc=>mejeE_MO<d`02_ML01JeE_MN]EKgGc=<00kgG00B]ELcC_MN]
E@>me`09c=>mekgGc=>]EKgG[EFmelcC00:me`0D[EFmekgG_MN]EIc<W==S
9ZeE_MO<fMkkcWW>OmkkcWW<fLiiaQS<g`;>N@06cWo>NOiicWWNnlii1Mkk
00S>Onmmg___OMkkkggNnloo0]kk00?>Omkkkgd00^mm00?NnnmmcWl00^mm
00?Nnnmmkgd01>mm00CNnnmmg___O@;Nn`03kgg66;gG00:]E@04_MN]EJeE
[ED2_ML2[ED2_ML01jeEW=><DH@@Hb2Ldi/c00>me`:]E@07W=>]EKgG[EG6
69cCVc<00[gG00[66<iiaQS66<iiaQRmelHH[EFLd`:]E@03_MO>NLHH00?>
N@03aQS>NLHH00:me`03W=?<c9cC00Bme`76600000Z]EKgG[EFmejeEc=Vm
ejeE_MN]E@:me`03c=V]EKgG00:me`>]E@:me`06[EFmejeEc=VmejeE0[gG
00F]EKgG_MN]ELcC00:me`07[EFmekgG_MN]EKgGc=<00[gG00F]EKgG[EFm
ejeE00:me`05[EFmekgGc=>]E@02_ML02jeE_MNmelcC_MN]EH@@W==Tc8aA
_ML00/ii0]kk00c>NLcIWWW>NLcIcWWNnliig__66=kkcWl2g_/03Oiog__N
nmkkkggNnnmmg___OMkkkggNnnmm00;Nn`?_O@03g___ONmm00?_O@06g__?
onmmg__?omkk0^mm00_NnnmmkggNnlookggNnkgG[EFmelic00:]E@03_MN]
EKgG00:]E@:me`:]E@:Ld`04W<aS9XaA[ED4_ML00ic<W=?<d`03_ML2W=<3
_ML2aQP00lcIaQS66002aQP01[gGW=>LdicCc=Vme`;66004_MO66<HHaQP2
_ML01<cCW<bLdjeE1KgG00000jeEc=V]E@02_ML01JeE_MNmekgG[ED00kgG
00>]EKgG[ED00kgG00?<djeE_ML00kgG00O<dkgG[EFmelcI[EG<d`03_ML0
1<cC_MNmejeE0[gG00_<dkgG_MN]EKgGc=>mejeE_MO66:eE00:me`04[EFm
ekgGc=<5_ML02:eE_MNmehaAW<bLdiV6_ML2cWT01mkkcWW66<cIaQS>NLHH
00;>N@04aQSnOliicWT5g_/00nmmg__>O`02g_/4kgd00mkkkgg_O@03g_/0
2<oog___OMkkkggNnnmmg_/2kgd01mkkkgg_OMkkcoo_OLio00;_O@05g___
OLii_MNLd`02[ED01KgG[EG<dkgG[ED00[gG00?<dkgG_ML00ZeE00NLdfC<
Q12K;:eE_MO66002_ML2W=<01:eEc=VmelHH0icC00>melHHc=T00[gG00G6
6<cI_MNmejeE00>Ld`05[EFmelcI_MO<f@06_ML00icCW<b]E@02[ED1_ML1
c=T1aQP00007c=VmekgG_MN]ELcC_ML00ZeE00?<fKgG[ED00[gG00G<fJeE
c=>mejeE00:me`03c=W<dkgG00>me`03[EFmejeE00>me`03[EFmejeE00:m
e`04c=>mekgG[ED2_ML00jeE_MN]E@02_ML01LcC_MN]EKgGc=<00[gG00J]
EKgG_MO<dkgG[ED2_ML01jeE_MN<DI//S55Tc:eE00;66006g__<fLHHWWVm
elcI0/ii00C66=kkcWo>N@SNn`04kggNnnmmkgd2g_/01>mmcWo_ONmm0]kk
00?_OMkkkgd01Nmm00??onmmg_/00^mm00C>OmkkkggNn`;_O@06g__>Onmm
WWW>LicC0[gG0ZeE00BmejeE[EFme`:]E@03_MN]EJeE00:Ld`0:S55S;8aA
[EFmelHHc=VmeicC[ED4_ML2W=<4_ML01<HH_MO<fLHH0[gG00>LdhaA[ED0
0kgG0/HH0/ii0/HH0[gG00F]EIcCW<bmejeE00>me`76600000NmejeE[EG<
fKgG[EG<f@02_ML01<cC_MNmejeE0kgG00B]EKgG_MN]E@:me`03[EFmelcC
00Bme`03[EG<fJeE00>me`:]E@:me`04[EFmekgG[ED2_ML00lcC_MN]E@02
_ML01<cC_MNmejeE0kgG00F]EKgG_MNmelcC00Bme`0:W==Tc6</W<bLdkgG
c=W>NIiic=T2_ML00lHHc=W>O`02cWT3g_/01/iig__Nnliog___O@;Nn`05
kggNnnmmkggNn`02kgd01]kkkggNnmkkcooNn`?_O@04g___ONmmg_/2kgd2
g_/01lookgg_ONmmg__?onmm00;Nn`05aQR]EKgG[EFme`02[ED01;gG[EFm
ejeE1;gG0ZeE00FLdhaAQ02Lc9cC00:me`03aQRmejeE00:Ld`03c=VmekgG
00:Ld`03[EFmekgG00Nme`03[EFK<jeE00:me`03W=W>NLcI00;>N@Jme`03
W<bLdlic00>me`7660000ZeE00>mejeE_ML01KgG00>]EKgGc=T00[gG00F]
EKgGc=VmejeE00:me`07[EFmekgG_MN]EKgGc=<01;gG00?<dkgGc=<00[gG
00N]ELcC_MO<fJeE_MO<d`04_ML00jeE_MN]E@03_ML01LcC[EG66;gG[ED0
1;gG00O<dkgGW==S;6<VVbb]E@02_ML2cWT01kgG[EG669iicWWNnlii00;N
n`03cWW>Omkk00CNn`07kggNnnmmkggNnnmmg_/00nmm00CNnloog___O@;N
n`04kggNnloog_/4kgd2g_/2kgd03mkkkggNnnmmg___OMkkcWVmejeE_MN]
ELcC[EFme`02[ED01[gGc=>]EKgG[EFme`:]E@05W<b<DF</S56Ld`03_ML0
0jeEW=>Ld`02_ML2[ED01IcCS56]EJeEc=T00/HH00>melHHaQP00[gG0YcC
0jeE00JmelHHaQS>NLcIcWT4_ML2W<`01JeE_MNmekgG[ED00LHH00000kgG
c=V]E@02_ML05ZeEc=V]EJeEc=VmejeE_MN]EKgGc=>mejeEc=VmejeE_MO<
dlHH[EG<fJeE0[gG00G<dkgG[EFmejeE00:me`03c=>mekgG00:me`07[EFm
ekgG_MN]EKgGc=<00kgG00?<dkgG[ED00kgG00G<dkgG[EFmejeE00:me`04
[EFmejeEHb`2HbH02YcC[EFLfLHHc=VmejeEc=W>NLcI0]kk00?>NMkkg_/0
0]kk01?>Omkkg__NnnmmcWoNnnmmg___OLiokggNnnmmg___OMkkcWoNn`02
kgd04]kkkgg_ONmmg___OMkkcoo_OMkkkggNnnmmg__?omkkkgg660>]E@04
c=>]EJeEc=<2_ML01jeE_MNmejeE_MO<dkgG00:]E@07W=>Lc6<VVbbLdkgG
c=T00[gG00>]EIcC[ED00kgG00B]EIcC[EF]E@Bme`03c=W66;gG00:me`04
W=>]EKgG_ML2aQP2cWT01<HHcWW66<HH0[gG00NLdlc<W=>mejeE_MN]E@01
aQP00003_MN]EKgG00:me`03[EFmejeE00:me`05[EFmekgG_MN]E@02_ML0
0jeE_MO<d`04_ML01JeE_MNmekgG[ED00[gG00F]EKgG_MO<fJeE00:me`04
[EFmekgGc=<2_ML01ZeE_MNmejeE_MN]E@>me`05[EFmejeE_MN]E@03_ML0
0lcC_MN]E@02_ML01YcCHbIS9V<VW<bLd`:me`:]E@09W=W66<iicWWNnlii
g__nOlii00CNn`06kggNnnmmg___OMkk0^mm00?Nnnmmkgd00nmm0]kk0^mm
00[>OnmmkggNnnmmg___OLiokggNn`;_O@06cWoNnnmmg___OLii0ZeE00K>
LjeE[EFmejeE_ML3[ED00kgG[EFme`02[ED01KgG[EFLdicCW<`00X@@00>]
EKgG_ML00[gG0YcC0ZeE0[gG00BLdhaA[EF]E@Rme`03[EF<DJeE00:]E@04
c=W66<HHcWT2aQP02JeEc=W66;gGW=>LaZeE_MN]E@03_ML00005_MN]EKgG
[EG<f@03_ML01JeE_MO<fJeEc=<00[gG00B]EKgG_MN]E@:me`06[EFmelcI
[EFmelcC0[gG00>]EKgGc=<00[gG00J]EKgG[EFmelcC[ED2_ML01LcC_MN]
EKgGc=<00[gG00?<dkgG[ED00kgG00O<dkgG_MO<djeE_MN]E@04_ML029cC
HbaS9S60Q12<DJeEW=<2[ED01lHHc=W>NLiig__>Olii00;Nn`03cWWNnmkk
00CNn`0<kggNnnmmg___OMkkkggNnnmmg___OLoo0mkk00?_OMkkkgd01>mm
0]kk00K_OMkkkgg_OMkkcol2g_/00lHH[EF]E@03[ED02;gG[EF]EJeE_MN]
EKgG[ED5_ML01YcC[EF<DFC<VbbK<`Bme`0<[EF<DJeEW=>]EKgG[EF44:eE
W=>melcI0/HH00^melHH_MN]EKgGS56]EKgG[EFmelcI00?>N@03aQRmelHH
00:me`04[EFLc9c<c=<2_ML1aQP1_ML000:]E@:me`05[EFmekgG[EG<f@02
_ML01jeE_MNmejeE_MO<fJeE00>me`03c=?<fJeE00Fme`05c=>mekgG_MN]
E@02_ML01lcC_MNmekgG[EFmelcC00>me`04[EFmekgG[ED3_ML01<cC[EFm
ejeE0kgG00S<fJeE_MNmelcC[EF<DH@00f<V00NK;9cCW=>]EIcIaQS>N@03
g_/00liig__>N@02g_/02_iog__NnmkkkggNnnmmg___OLio0nmm00?Nnnmm
kgd00^mm0]kk00[?onmmkgg_OMkkkggNnnmmg__?o`;Nn`06kggNnmkkcooN
nlii0[gG00>]ELcC[ED00[gG0ZeE00RmelcC[EFmejeE_MN]ELcI0ZeE0YcC
00FLc9//Q02LdjeE00>me`09c=>LdjeE_MO<fKgG[EF<DJeE00:me`04c=W6
6;gGaQP2_ML00lcI_MNLd`02[ED2_ML01LcIcWW>NLiic=T00/ii00O66;gG
c<bLc:eE_MN]E@02_ML1aQP00005c=VmejeEc=V]E@03_ML02:eEc=>mekgG
[EG<fKgG[ED3_ML00jeE_MNme`02_ML00jeEc=>]E@03_ML01LcI[EFmekgG
[ED00kgG00>]EKgG_ML00kgG00B]EKgG_MN]E@:me`05c=>mejeE_MO<d`02
_ML01ZeE_MNmejeE_MO<d`:me`04W=>446<VHb02HbH02XaA[EFLdicCcWW<
fMkkcWWNnlio1mkk00W_OMkkcWo_OMkkkggNnnmmg_/00nmm00?Nnnmmg_/0
0^mm0mkk0^mm00?Nnloog_/01=kk00C?omkkcWo_O@;Nn`05aQR]EJeE[EFm
e`02[ED02/cC[EFmejeE_MN]EKgG[EFmejeE0kgG00FLdjeES56449//00:]
E@04c=VmejeEc=<2W=<2[ED2_ML01XaAW=>]EJeE_MO<f@:me`05W=>]EJeE
_MNLd`02S5401[gG[EF]EKgGc=W>N@C660:]E@06W<bLdkgGW=>melcC0LHH
00000lcI[EF]E@03_ML00jeEc=Vme`02_ML02JeE_MNmekgG[EG<fJeE_MO<
f@02_ML2[ED3_ML01lcI[EFmekgG[EFmelcC00Fme`03c=>mejeE00:me`04
[EG<fKgG[ED2_ML01JeE_MNmekgG[ED00[gG00>]EKgGc=<01;gG00F]EIcC
W<aS9S<V009S9P04S56LdicC[ED2cWT01=kkcWWnOlii0mkk00C>Omkkg___
O@;Nn`03kggNnmkk00?_O@03g__?omkk00?_O@03g___OMkk00;Nn`07kgg?
omkkkggNnnmmcWl02=kk00G>NKgG[EG<dkgG00B]E@06_MN]EJeE_MN]ELcC
0[gG00B]EKgG[EFme`>Ld`04I<aS9YcC[ED2_ML01JeEW=>LdjeE_ML00jeE
00><DJeE_ML00[gG00?66<ii_ML00[gG0ZeE0YcC00F]EKgGW=>melHH00;>
N@?66007c=VmejeEW<b]EKgG[ED00[gG0LHH0004_ML01JeEc=VmekgG[ED0
0[gG0ZeE00?<dkgG[ED00[gG00F]EKgGc=>]ELcI00:me`07[EFmejeE_MO<
dkgG[ED00kgG00G<dkgG[EFmelcC00:me`04[EFmejeE[ED2_ML01<cC_MN]
ELcC0kgG00>]EKgGc=<00kgG00^]EKgG_MNmeicCQ11S9V66<bIS9Yc<00:L
d`05[EG<fLiig__>N@02g_/02Liig__NnmkkkggNnliokggNn`02kgd01mkk
kggNnnmmg___OMkk00G_O@04g___OLiog_/2kgd01Loog___OLiicWl00]kk
00G?omkkg__66<ii00:me`B]E@04cW>]EKgG_ML2[ED2_ML2[ED4_ML2[ED0
1YcCS56448@0W=>]E@Bme`:Ld`08[EFmejeE_MNK;9cC[EFme`;6600;cWW6
6<HHaQRmejeEW=>]EIcC_MO<f@04aQP00jeEc=>Ld`03_ML019cCc<b]EKgG
0lHH0003[ED02<cI[EFmejeE_MN]ELcI[ED2_ML00lcI[EFme`02_ML00jeE
_MNme`04_ML01LcC_MNmekgG[ED00[gG00G<djeE[EG<fJeE00>me`05[EG<
dkgG_MO<d`02_ML00lcC[EFme`03_ML01:eE_MNmelcC0[gG00R]EKgG[EFm
ejeE_MN]EH@@0V<V00Hc9V66HbJ<DIcC[ED2cWT00liocWWNn`02g_/01/io
g__Nnnmmg___O@;Nn`05kggNnnmmkggNn`04kgd01/oog___ONmmg__?o`;N
n`07kggNnnmmg___OMkkcWT00mkk00O>OmkkcWV]EKgGW=?>L`02[ED02;gG
[EF]EJeE_MNLdlcC_ML2[ED3_ML00jeE_MNme`02[ED01IcCW<b448@@S540
1;gG00V]EIcC[EG<djeEc=V]EHaAW<`00ZeE00?<fLiiaQP01<HH00C<fIcC
[EF]E@>me`04c=VmekgG[ED2_ML2aQP01[gGW<bLdkgG[EFme`;6600000O<
fKgG[EFmelcI_MN]E@02_ML00jeEc=Vme`02_ML03:eEaQR]ELHH[EG<fKgG
[EFmejeE_MN]E@:me`0<c=>mekgG[EG<fKgG[EFmejeEc=V]ELcI0[gG00B]
EKgG_MN]E@>me`05[EFmejeE_MO<d`03_ML02ZeE_MNmekgGc=>melcC_MN]
EHaA16<V00IS86<VW=?<fLiig_/3cWT2g_/00nmmg__Nn`04g_/01>mmg___
OMkk0nmm00GNnnmmg___OMkk00C_O@;Nn`09kggNnnmmcWo_OLiicWo>NLoo
00;Nn`0<cWW66:eE[EFmejeE_MN]ELcC[EFmeicC0[gG00Z]EKgG_MN]EKgG
[EFmejeEc=>me`>]E@04W==Tc9/VS542[ED00lcI_MNme`02W=<02;gG[EFm
ejeEW=>K<jeE_ML3aQP02<cIaQRmekgGaQR]EIcCc=T2_ML2aQP00kgGc=V]
E@02aQP3_ML00li/W=?<d`02_ML1cWT1aQP00009_MN]EKgG_MN]EKgG[EG<
fJeE00:me`0:[EFmejeE_MO<fJeE_MN]EKgG[ED2_ML01/cC_MNmekgGc=>]
E@:me`03[EFmekgG00:me`04[EFmekgG[ED2_ML00lcC_MNme`02_ML02JeE
c=>mekgG[EFmejeE_MN]E@02_ML00jeEc=>]E@04_ML04:eES5640666HbHc
9V66S56mejeEaQS>NLHHg__>Ooii0mkk00KnOmkkg___OMkkkgd2g_/2kgd0
0mkkkggNn`07kgd01]kkkggNnmkkkgg?o`;Nn`04cWW>Oloikgd2g_/02<HH
[EF]ELic[EG<djeE_ML4[ED01;gG[EF]EKgG0ZeE00BmejeE_MN]E@:me`:]
E@:Ld`04W<aS;8aA[ED3_ML01JeES56]EIcCc=<00ZeE00BLdjeE_MNme`C6
6006cWW<fLHHaQR]EIcC0jeE00?66<ii_ML00lii00C66;gG_MNme`:Ld`:m
e`?6600000F]EKgG[EFmejeE00>me`0:[EFmekgG[EG<fKgG[EFmelcIc=<2
_ML01:eE_MNmelcC0[gG00F]ELcI[EFmelcC00:me`08[EG<dkgG_MN]ELcC
_MN]E@:me`05[EFmelcC_MN]E@02_ML01<cC_MNmejeE0[gG00>]EKgG_ML0
0kgG0ZeE0[gG00>LdfC<<bH00V<V00IS89cC[EG<fKgGoWl2cWT00mkkcWoN
n`03g_/01^mmg__NnmkkcWo_O@;Nn`06kggNnnmmg___OMkk0^mm00KNnnmm
coo_OMkkcol2g_/2kgd00loog__Nn`02g_/01<ii_MNmelcC1ZeE00?<djeE
_ML00ZeE00VmelcC[EFmejeE_MN]EKgG[ED00kgG00N]EIcCW=><DH@0VbbL
d`02_ML00lcC_MNLd`02W=<2[ED01kgGW=>LdjeE_MO<fLii00?660:me`08
aQR]EJeEW=>]EKgGW=W>N@?66007cWW66:eEc=?669cCc<`00ZeE0LHH0JeE
0KgG00002kgGc=V]ELcI[EFmejeE_MO<fKgG[ED01KgG016]EKgG_MN]EKgG
c=VmejeE_MO<djeE_MN]EKgG[EFmejeE00:me`03[EFmekgG00:me`08[EFm
ekgG[EFmelcC_MN]E@:me`03[EFmelcC00:me`05[EFmelcCc=V]E@02_ML0
0jeE_MNme`02[ED00i/VHbaS9P02HbH00haA_MO>N@02g_/00liig__Nn`08
g_/01nmmg___OMkkkgg>Omkk00?_O@04g___OMkkcol3kgd3g_/2kgd4g_/0
1Liog_^]EJeEcW<00ZeE00FmejeE[EG<dkgG00:]E@03_MO<djeE00:]E@0A
_MN]ELcC_MN]EKgGc=>mejeE_MNLdjeEW=>Lc6<VS56]E@04_ML00i/c[EF]
E@02[ED02;gGW=><DKgGc=?>NKgGc=T3aQP2_ML00icCW<b]E@02_ML3aQP0
1LiiaQS66<cIaQP00[gG00JLc9cCW=>]EKgGc=<1aQP00003_MN]EKgG00:m
e`04c=V]EKgG[ED2_ML01/cC[EFmekgGc=V]E@:me`03c=>mejeE00Rme`08
c=>mejeEc=>mejeE_MN]E@>me`05c=>mekgG_MN]E@02_ML03:eEc=VmejeE
_MN]EKgGc=>mejeE_MN]E@>me`0>c=>mekgGaQR<DF<V<bIS9V66S57<fLii
c=W>N@WNn`05kggNnmkkg___O@02g_/01>mmg___OMkk0nmm00CNnnmmkggN
n`;_O@05g__>Omkkkgg?o`03g_/00liiaQRme`02[ED01KgG[EG<djeE_ML0
0ZeE00ZmejeE[EFmejeE_MNLdkgG[EFme`:]E@>me`03[EFmejeE00:Ld`:4
4004VbbLdkgGc=T2_ML3W=<01<cI_MNmejeE0YcC00B]EKgG_MO660:me`;6
6004[EFLdi/cW=<2[ED01lcIcWW66<cIWWW>NLHH00:me`07aQRLdhaAc<b]
EIcC_ML00LHH00000jeE_MNme`03[ED01KgGc=V]EKgG[ED00[gG00?<fJeE
[ED00[gG00R]EKgG_MN]EKgGc=>mejeE0[gG00>]ELHH[ED01KgG00[<dkgG
_MO<dkgG[EFmelcC_MN]E@:me`03c=>mejeE00:me`06c=>mekgG[EFmelcC
0[gG00>]EKgGc=<00kgG00><DH@0HbH00V<V00VLc<HHcWW>NMkkcWo>NMkk
cWl00]kk00?>Omkkg_/00]kk00GnOmkkg__Nnnmm00;Nn`04kggNnnmmg_/3
kgd01Mkkkgg_OLoocWT00]kk00C_OMkkcWW660:me`06c=>mejeE_MN]EKgG
0ZeE00BmejeEc=>me`B]E@0=_MO<dkgG[EFmejeEc=>mejeE_MN]EKgG[ED0
0YcC00B<DF</W<bLd`Bme`:Ld`09_MN]EKgG_MNLdi/c[EFmejeE00;66004
c=VmekgG[ED3W=<02JeE_MNmelcIWWW>NLcIcWW<f@02aQP01kgG[EFLc9cC
cW>mejeE00:me`0000G<fJeE_MN]ELcI00:me`04[EFmelcI[ED2_ML01ZeE
_MN]EKgGc=V]E@:me`04c=>mejeEc=T2[ED02;gGc=>mejeE_MO<dkgG[ED2
_ML01JeE_MN]EKgG[ED00[gG00O<dkgG[EFmejeE_MO<d`02_ML01:eE_MNm
ejeE0[gG00>]EKgG[ED01KgG00R]EF</HbHc89/VW=?>NLio0/ii1mkk00W>
Omkkg__Nnnmmg___OMkkkgd01=kk00K_OMkkkggNnnmmg_/3kgd00mkkcooN
n`02g_/2_ML01JeE_MN]EJeEc=<00ZeE00C<dkgGW=>me`>]E@03c=>]EKgG
00:]E@04_MN]EJeE[ED2_ML2[ED01;gGc=>]EKgG0YcC00ZLc6</W<bLdjeE
_MO66;gG[EF<D@Bme`08[EFLdicC_MO66<cI_MO660:me`07c=VmejeE[EFL
djeE_ML00/HH00K>NIiicWW>NLHHcWT2_ML01<cCS56]ELic0kgG00001;gG
c=?<fJeE0[gG00N]EKgG_MN]ELcC_MNLf@02_ML01lcC_MN]EKgGc=?<fJeE
00>me`0=[EFmekgGc=>mejeE_MN]EKgG[EG<fJeEc=<00kgG00G<dkgG[EFm
ejeE00:me`08c=>mejeE_MO<dicI_MO<d`>me`06[EFmekgG[EFmejeE0[gG
00J]EH@@HbIS9X@@aQP2cWT3g_/00liioWo>N@04g_/00nmmg___O@02g_/0
1nmmg___OMkkkggNnnmm00GNn`;_O@0;cooNnmkkcWoNnnmm_MN]EKgGW=?>
L`02[ED00kgG[EFme`03[ED01LicW=>mejeE_ML00jeE0[gG00C<djeE_MNm
e`:]E@:me`03[EFmejeE00:Ld`04W<b448@0W=<2_ML01/cI_MNLdicC_MN]
E@:me`05[EF<DJeE_MO<f@07aQP00kgGVc>]E@03_ML02LcIcWW>NLiic=W>
NLHHW=Vme`02W=<00lic[EFme`02_ML00005_MN]EKgG_MN]E@02_ML01ZeE
c=VmejeE_MN]E@:me`03[EG<fKgG00:me`08[EFmelHH[EFmelcI_MN]E@:m
e`05[EG<fLcC_MN]E@02_ML01<cC[EFmejeE0[gG00K<dkgG_MN]EKgG[ED4
_ML01JeE_MO<dkgG[ED00kgG00C<dkgG_MO<d`>me`05W<aS;666Vbc66004
cWT01LiocWWNnmkkoWl01Mkk00S_OMkkg___OMkkkggNnnmm1Mkk1<ii0]kk
00W>NMkkg__>NKgG[EFmejeE_ML00ZeE00C>LjeE[EFme`:]E@07_MN]EJeE
[EFmejeE_ML00jeE00NmejeE[EF]EKgG[EG<d`03_ML029cC[EFLdhaAQ12K
;9cC[ED3_ML019cCS56]ELcI0kgG00BLdjeE[EFme`;66003_MO66<cI00>m
e`>]E@04_MO>NIiic=T2cWT2aQP02Lii_MO>LjeEW=?<dkgG[EFme`01aQP0
0006W=V]EKgGc=V]EKgG0ZeE0[gG00F]EKgGc=>mejeE00>me`06[EFmekgG
_MN]ELcC0[gG00C<djeEc=V]E@:me`05[EFmekgG_MN]E@02_ML04LcI[EFm
ejeE_MN]EKgGc=>mejeE_MO<djeE_MO<dkgG[ED00kgG00G<dkgG[EFmejeE
00>me`0;[EFLdh@@HH1Ta/HHcWW>OliioWo>N@08g_/01Nmmg__NnnmmcWl0
0]kk00?_OMkkcWl00]kk00NmefCCQ12<DIcC[EFLd`02[ED2g_/02<HH[EFm
ejeEc=>mejeEc=<5[ED01LcC[EF]EKgGc=<00ZeE00BmelcC[EFme`:]E@07
_MO<dkgG[EFmejeE_ML00jeE00VLdhaAQ11Tc9cC[EFmelHH_ML00YcC00K<
dkgG_MNmejeEVc<2[ED3_ML4aQP00kgG[EFLd`02[ED00icI_MO66002cWT0
29cIcWW>NLcIaQRmejeEW<`4[ED1_ML000:me`08[EFmejeE_MO<fKgG[EG<
f@:me`0:[EFmejeE_MN]EKgGc=VmelcC[ED2_ML00jeE_MNme`03_ML01/cC
_MNmejeE_MO<d`Bme`05c=>mejeE_MN]E@02_ML00jeE_MNme`06_ML01JeE
_MNmejeEc=<01;gG00R]EKgG[EFLdfC<HbJK;<cI0lii0]kk00?>NMkkg_/0
0mkk00C_OLiog___O@;Nn`;_O@CNn`0<cWVNNJeES54c;3<VHHHc;8@@<HaS
;<ii0]kk00>NNLcC_ML00jeE00BmejeE_MO<d`:]E@04cW>]EJeE_ML2[ED0
0kgG[EFme`02[ED02;gG[EFmejeE_MN]EKgG[ED2_ML3[ED01Ic<HbbK;9cC
c=<01;gG00NK<jeE[EF]EKgG[EFLd`02[ED01[gGcWW66<HH_MO660>me`:L
d`:me`03c=W66<ii00;>N@07aQS>NLiiaQR]EKgGW<`00ZeE0KgG0JeE0JeE
0002_ML01:eE_MN]ELcI0ZeE0kgG00n]EKgGc=V]ELcI[EG66:eE_MN]EKgG
c=VLdkgGc=<00[gG00F]EKgG[EFmejeE00:me`05[EFmejeE_MN]E@03_ML0
1<cC_MNmejeE0[gG00O<dkgG[EFmelcC_MN]E@02_ML01:eE_MNmekgG0ZeE
00c<djeE[EFLdhaAQ01S9V</_MO66<iig_/2cWT2g_/01liog__NnmkkkggN
nnmm00;Nn`05kggNnmkkg___O@02g_/016CIW=>Ldc<c0V</00J<D@@@DZX2
X5:ZS543aQP01LcC[EF]EKgGc=<00ZeE00BmejeE[EFme`:]E@05_MN]EJeE
[EFme`03[ED00kgG[EF]E@02_ML01JeEc=>mejeE_ML00ZeE0YcC00FLc8aA
Q02LdjeE00>me`03[EF<DJeE00:me`03c=VLdicC00:]E@04c=W66<cIaQP2
_ML00jeE_MN]E@02W=<01/cI_MO66<HHcWW660C>N@08aQRmekgGW<b]ELic
_MN]E@6me`0000>]ELcI[ED01;gG00G<fKgG[EG<fJeE00>me`:]E@03c=V]
ELcC00Fme`06[EG<dkgG[EFmelcC0[gG012]EKgG_MNmelcC_MN]EKgG[EFm
elcC[EFmelcC_MN]E@:me`03[EFmejeE00:me`04c=>mekgG_ML3[ED019cC
S56<DIc<0X@@0V<V00=QQZeEaQP00/ii00K>Oliig__nNMkkcWl5g_/01nmm
g___OMkkkggNnnmm00;Nn`04Vc=Tdh@@Hb`2Hc<02jeEQ11BZU:ZHbb446<c
[EFmejeE_ML00ZeE00S>LjeE[EFmejeEc=>]EKgG0jeE00S>LjeE[EF]EKgG
c=>]EKgG0ZeE0[gG00N]EKgG[EFmelcC_MN]E@02W=<01X@@HbbLdjeEc=W6
60:me`03W=>]EJeE00:me`05aQRK<jeE[EFme`02aQP00lcI_MO<f@03_ML0
29cC[EF]EJeEWWW<fLiic=T2cWT02/cIcWW66;gG[EG<c9cC[EFmelcC0KgG
00002:eEc=VmekgG[EFmejeE_ML2[ED01;gG[EFmejeE1;gG00R]EKgG_MN]
EKgGc=>mejeE0kgG00n]EKgG[EFmelcC_MN]EKgG[EFmelcC_MN]EKgG[ED0
1;gG00>]EKgG[ED00[gG00>]EKgGc=<00[gG0jeE00NLdic<Q12408@@Q024
4002HbH013<VHbJ44;gG0/ii00?Nnliig_/01Mkk00[nOmkkkggnOmkkkggN
nnmmcWo_O@;Nn`05===Tdi/cQ11Td`02W=<03h@@DZX2X8@@HbbLdjeEW=V]
EKgGc=>]EKgG[EFme`02[ED01KgG[EFmejeEc=<00ZeE00BmejeE[EFme`:]
E@0;_MO<djeE_MN]EKgG[EFmejeE_MN]E@03W=<016C<Q02LdjeE0lHH00Rm
eicCW=>]EKgG[EFmeicC0ZeE0[gG0lHH0/ii00RmejeEW=>]EIcC[EG<fLHH
1<ii00ZLfLiiaQS66;gGW=>]EKgGc=>me`76600000N]EKgG[EFmejeEc=V]
E@02_ML02jeE_MO<fKgG[EFmejeEc=>]EKgG[ED00kgG00J]EKgG_MNmejeE
c=T2_ML01JeE_MN]ELcIc=<01;gG00F]ELcC_MO<dkgG00:]E@05_MN]EKgG
c=W<d`02_ML00jeE_MN]E@02_ML019cCS56446</1F<V00Pc9V60<bIS9Y/V
W=?>NLcI0]kk00?>NLiog_/01]kk00G_OMkkkgg_OMkk00;_O@;Nn`0>[EF<
DIcCHc>LdhaAHc=S;5:ZD02448aAI=>Ld`>]E@03_MN]EJeE00>]E@07c=>]
EJeEc=>]EKgGc=<00ZeE00BmejeEc=>me`:]E@06_MN]EJeE[EFmejeE0[gG
00>]EKgGW=<00YcC00>449/VW=<00ZeE00C<fLHH[EFLd`:]E@03c=VmekgG
00:Ld`04[EFmelHHaQP5_ML2[ED01YcC[EFmelHHWWW<f@C>N@?66003c=>L
c9cC00Bme`0000W<fKgG[EG<fJeE_MN]EKgGc=<00[gG00b]EKgG[EG<fJeE
_MN]ELcI[EFmelcC[ED2_ML01:eE_MN]EKgG0ZeE0[gG00N]EKgG_MNmejeE
_MO<d`02_ML02JeE_MN]EKgGc=>mejeE_MN]E@02_ML03JeE_MN]ELcC_MNL
dhaAVb`c9V<V<bIS9V6600AS9P06DZYS83<VS56melHH0lii1]kk0^mm0]kk
00c_OMkkg___OMkkkggNnicIS55Tdf<cW=<3Q10023</DZZ446<cQ11S<icC
_ML3[ED01kgGc=>mejeE_MN]EKgG00:]E@06_MN]EKgG[EG<dkgG0jeE0[gG
00B]EKgG_MN]E@:me`0:[EFmejeEW=>]EIcCW<b408aA[ED3_ML01jeEbc>m
ekgGaQRmejeE00:Ld`:]E@08_MO<fLHHcWW66;gGc=Vme`:Ld`04[EFmekgG
aQP3cWT02<cIcWVNNLiiaQRmeic<[ED2_ML1c=<1_ML0000>[EFmekgGc=W<
dkgG[EFmelcI[EFmejeE_MN]E@>me`03c=>mekgG00:me`03c=>]EKgG00:m
e`0;[EG<fLic_MN]EKgG[EFmelcC_MN]E@04_ML02:eE_MN]EKgGc=>melcC
_ML2[ED02;gG[EG<fKgG[EFmeicCI<`2HbH019//HbITc9/V0V</00MS9V<P
HbIS9S<VVbbme`02cWT01<iocWWnNLii0]kk00KnOmkkg__Nnnmmg_/2kgd0
4MkkkggNnnmmg_^LfJeEW=><DFCCDZYS;6<cS55S<icCI=<00V</00BLdkgG
[EG>L`>]E@05_MN]EKgGW=>me`05[ED01KgG[EF]EJeE_ML01:eE00S<djeE
_MO<dkgG[EG>LkgG0icC00B<DF</Q12]E@Bme`06W=>]EJeEc=V]EKgG0YcC
00?<fKgGaQP00/HH00[<fLiiaQRmelHHW=VLdjeE_MO<f@;660C>N@06c=W6
6<HH_MNLdic<1;gG0002_ML2[ED4_ML01:eE_MNmejeE0kgG0ZeE0[gG01>]
EKgG[EF]EKgGc=V]EKgGc=>mejeEc=V]EKgGc=>mejeE_MO<d`02_ML00jeE
c=>me`02_ML01JeE_MNmekgG[ED00kgG00?<djeE_ML00[gG01N<DI//HbbL
c8@@W<bLdi//S56Lc6</Q00c;3<VHbJK;:eEaQS>NMkkcWWNnlcO00CNn`06
kggNnnmmg___OMkk0^mm00GNnnmmg__>NIcI009Td`9S;009<baS;8@@Hc=T
dicCHc=Tdf<c00B]E@09_MN]EJeE_MN]ELcC_MN]EKgG00:]E@08c=>]EJeE
[EFmejeEc=>]E@:me`04[EFmejeE[ED3_ML01jeEW=>Ldic<W==S;8@000:L
d`03c=>]EJeE00:Ld`04_MN]EKgG[ED2W=<01:eE_MNmekgG1<HH0[gG0jeE
00NmelcIaQS66<iiaQS>N@02aQP01Lii_MN]EIc<c<`01;gG0002[ED03kgG
[EFmekgG[EG<fJeE_MO<djeEc=V]EKgGc=V]E@02_ML00lcC[EG<f@02_ML2
[ED3_ML01JeEc=VmekgG[ED00[gG00>]EKgGc=<00kgG00J]ELcC_MN]EKgG
[ED2_ML03LcC[EFmekgG[EFmejeE_MNLdi//W<b]EIcC00B]E@:Ld`03W<bK
;6<V009S9P05W=?66<cIg__<f@02g_/00liig__Nn`03g_/00nmmg___O@02
g_/03?iokggNnnmmg__>NKgGS54c;8@@Hb`c;0:4400:I=>Ldi/cI==S<kgG
[EFmejeEc=<2[ED01;gG[EFNLlcC0ZeE00VmejeE_MN]EKgGc=>mejeE_ML0
0ZeE00NmejeE[EFmejeE_MN]E@02_ML2[ED01haAW<b449//W=>]ELcI00:m
e`04[EFLdjeE[ED3_ML01I/c[EFmelHH_ML01<HH0[gG00N]EIcC[EF]EIii
aQS<f@04cWT2aQP2_ML00haAW<b]E@03_ML00008_MO<fJeE_MO<fJeE_MN]
E@:me`07W=VmekgG[EFmejeE_ML00ZeE1;gG00>]EKgGc=T00ZeE00G<dkgG
_MNmejeE00>me`0:[EFmekgG[EFmejeE_MO<fKgG[ED2_ML00lcC_MN]E@02
_ML02ZeE_MNmelcC_MN]EIcC[EFLdlcC0[gG00B]EKgG_MN]E@:Ld`:Lc003
HbbLdkgG00G>N@CNn`06oWoNnmkkkggnOmkk0^mm00SNnnmmg__>OliiW=VK
<icC0X@@00lc;6<cQ12449cCHc=TdhaAaQR]EKgG[EFmejeEcW<00ZeE00Fm
elcC[EFmelcC00N]E@05_MN]EKgG[EG<d`02_ML01JeE_MN]EKgGc=<019cC
00=TaV<V[ED01;gG0YcC00K<djeE[EF]EIcCVb`2[ED04kgGc=W>NKgGW=W6
6<cI_MN]EIcC[EG<fKgGc=W66<iiW=W>NLcI00>me`04W=>K;9c<[ED3_ML0
000E[EG<fJeE[EFmejeEc=VmejeEc=>mejeE_MO<dkgG[EFmelcIc=>mejeE
00:me`04c=>mejeEc=T3_ML01jeE_MN]EKgGc=>melcC00:me`03[EG<fKgG
00:]E@0@_MN]EKgG_MN]EKgG[EFmelcC_MN]EKgG[EFmelcC[ED3_ML01:eE
_MNmelHH0[gG00S<djeEW=>]EIc<S56melHH1/ii1]kk00S_OMkkg___OMkk
kggNnnmm0/ii00o669cIS56<DFCCVc=Tdf<cQ12<DI/cHc?66:eEc=<01jeE
00^mejeE[EF]EKgG[EFmejeE_MN]EKgG00:]E@06_MN]EKgG[EG<djeE0[gG
00>]EKgGW=<00YcC00><DH@@Vb`00ZeE0kgG00R]EIcC[EFLdjeE_MN]EHaA
0ZeE00BmelHHc=W>N@;66004_MO<fLHHW=<2[ED01iiicWW66<iiaQS>NLHH
00>me`06cW>]EHaAc<b]EKgG0LHH00001[gG[EFmelcI_MN]E@:me`08[EG<
fJeE_MO<fJeE_MO<f@:]E@:me`03[EG<fJeE00:me`03[EFmekgG00:me`05
[EFmelcC_MN]E@03_ML01<cC_MNmelcC0[gG00?<dkgGc=T00ZeE00?<fJeE
_ML00[gG00B]EKgG_MN]E@>me`03[EFmelcC00Rme`07[EG<c9cC_MO66<ii
g_/01<ii00GNnliig__Nnoio00?Nn`;_O@03g___ONmm00?Nn`04aQR]EH@@
Hc<2Q1003fCCVc<449/cI=>LdlHH[EFmejeEc=>mejeEc=>me`03[ED02kgG
[EFmejeE_MNLdkgG[EFmejeE_ML00ZeE00RmejeE_MN]EKgGc=>]EKgG0icC
00RLc8@@I<JLdjeEaQRmelcC0YcC00J]ELcC_MN]EKgGW=<2[ED01;gGaQS6
6<ii0/HH0[gG00>]EIcC[ED00[gG00C<fLHHcWW>N@;66007c=W66<HH_MNL
dic6W=<00[gG0JeE0003_ML00jeE_MN]E@05_ML02ZeE_MNmekgG[EG<fKgG
[EFmejeE0[gG00B]EKgG_MNme`:]E@03_MO<dkgG00>me`05c=>mejeE_MN]
E@02_ML01JeE_MNmekgG[ED01;gG0ZeE0[gG00O<dkgG_MN]ELcC_MN]E@02
_ML01:eE_MNmelHH0[gG00R]ELic_MO>Lli/[EG66<cI1<ii00?nNLiicWT0
1=kk00O_OMkkg__Nnnmmg___O@03g_/03LiiW=UTdfCCQ12LdfCCVc=Tdh@@
I=>LdlHH00:]E@04_MN]EJeE_ML2[ED00kgG[EG<d`04[ED03KgGc=>]EKgG
c=>]EKgGc=>]EKgG[EFmejeE00:me`08[EFmeicC[EFLdhaAHbbK;0:Ld`04
c=VmekgG[ED2W=<01JeE_MNLdjeES5400ZeE00G<fLHHaQS66<cI00Bme`B]
E@05_MO>NLHHc=W>N@02aQP01liiaQRmejeEW<bLdkgG00;660000ZeE00K6
6:eE_MN]ELcI[ED2_ML01:eE_MO<fJeE0[gG00f]EKgG_MNmelcC_MN]EKgG
c=V]ELcC_MO<f@03_ML2[ED01;gG[EFmejeE0kgG00W<djeE_MNmelcC_MN]
EKgG[ED00[gG00O<dlcI[EFmejeE_MN]E@02_ML00jeE_MNme`03_ML00lic
c=?>L`02cV`01/c<cVK<a/c6[EG660K>N@;Nn`03cWWNnmkk00;Nn`0;kggN
nmkkkggNnliokggNnlio_MNLd`02[ED03IcI[EETdfCCS56LfLii_MN]ELcC
_MN]EKgG00:]E@03c=>]EJeE00:me`03[EG>LjeE00:]E@06_MN]EJeE[EFm
ejeE0[gG00V]EKgGc=>mejeE_MN]EIcC[ED00YcC00FLc6<VW=?<dlHH00:m
e`0<Vc>]EJeE_MNLdjeE_MN<DLcC[EG<fKgG1<HH0[gG00F]EIcC[EF]ELcI
00:me`0<c=W>NLiiaQS>NLHH_MN]EIcCS57<dkgG0/HH00001LcI[EFmejeE
c=T00[gG00F]EKgGc=VmejeE00:me`03[EG<fKgG00:]E@>me`03[EG<dkgG
00:me`04[EFmekgG[ED2_ML01lcC_MNmekgGc=>mejeE00>me`05[EFmelcC
_MN]E@02_ML01:eE_MNmejeE1KgG00B]EKgGaQR]E@:me`09[EG<dli/c<K>
H<c6cV3<a/c000;>IP06c=?66<iic=W>NMkk0lii00?nNLiig_/00]kk00?>
Onmmg_/02=kk00_66<cIaQRLfKgG[EFLfJeEW=W>NKgG00B]E@03cW>]EJeE
00:me`F]E@08c=>meicC_MO<dkgG[EFme`:]E@05_MN]EKgG_MN]E@03_ML0
2:eEW=>LdhaAQ11S9YcC[ED2_ML01JeEW=>Ldi/c_ML00ZeE00JmeicC[EF]
EKgGcWT3aQP4_ML01YcC[EF]EKgGWWW>N@;6600;cWW66<HHc=Vmelic[EFL
aYcCc=?66001c=<000:me`08[EFmekgG[EFmejeEc=V]E@>me`04c=>]EKgG
[ED2_ML00lcI[EF]E@03_ML02:eE_MN]EKgG[EG<fKgGc=<2_ML01jeEaQRm
ekgGc=>mejeE00:me`:]E@:me`05c=>]EKgG_MO<d`02_ML01:eEc=>]ELcI
0kgG00f]EKgG[EG<c<iVcVc<a/i/c<cnI/c6cV3>IP02c<`00kgGaQS>N@04
cWT01oiicWWNnliig__>NMkk00C>N@CNn`06kggNnmkkcWVNNIcI0[gG00VL
fKgGcWW>NIii[EFmejeEcW<00ZeE0[gG0ZeE00FmejeE_MN]EKgG00:]E@0;
_MN]EKgG[EFmejeEc=>mejeE_MN]E@02_ML00jeEc=>Ld`03W=<01FC<Q02L
djeEaQP00[gG00>]EHaA[ED00ZeE00?<fKgGS5400ZeE00>melcIaQP00/HH
00W<fLHH_MNmeicC[EG<dlHHc=T00kgG0/HH00W<fLHHaQRmeicCW<bLdkgG
[ED00KgG00001ZeE_MO<fJeE_MO<d`Jme`07[EG<fJeE_MN]EKgG[ED00[gG
00V]EKgG_MO<djeE_MO<dkgG[ED00kgG00B]ELcI[EG<d`Bme`0>[EG<dkgG
_MN]EKgG[EG<fJeE_MN]EKgGc=>]E@:me`08[EFmejeE_MO<dkgG[EG>L`;<
c0?>K005c<c>K?c6cVKlaP02cV`01/cCaQS>NLiic=WNn`?>N@03g__>NMkk
00;Nn`05cWVmeh@@HbJ]E@05g_/01/iog__669cCI=W<f@:NN@;Nn`03cWV]
EKgG00>]E@04c=>]EJeE_ML3[ED01LcC[EFmejeE_ML00ZeE00FmejeE[EFm
ejeE00:me`03[EFmejeE00>me`0:[EFLdicCW=>449/VS56]EKgGaQP2_ML0
1Y/c[EF]EKgG[EG660:Ld`:]E@03aQS<fLHH00>me`03[EFmeicC00:]E@08
_MO66;gG_MO<fLiiaQS>N@;660:me`04W<c;;;gGaQP1_ML00003_MO<fJeE
00:me`06[EFmejeE[EG<fKgG0ZeE0kgG00R]ELcI[EFmejeEc=?<fJeE0[gG
00K<fJeE_MO<dkgG[ED3_ML01ZeE_MNmejeE_MN]E@:me`03[EFmelcC00>m
e`05c=>mekgG_MN]E@02_ML2[ED06[gGc=>mejeE_MO<dli/c<c>Lli/c=?>
Lli/cW?>I/i/c<c>I/c<cW>meliiaQS>NMkkc=T2g_/2cWT02MkkcWW>NIcI
110`1S60DZ[66004g_/02>mmg__>NLiic=W>NMkkcWT2g_/01<ii_MN]EKgG
0ZeE00>mejeE_ML00ZeE00C>LjeE[EFme`:]E@03_MN]ELcC00:]E@03_MN]
EKgG00>]E@05_MN]EKgG[EFme`04W=<01Ic<<bJ<DKgGc=<00[gG00B]EIcC
[EF]E@>me`:Ld`03_MN]EKgG00;660:me`04c=V]EKgGW=<2[ED2_ML01LcI
cWW>NLHHcWT00lHH00BmeicCW<b]E@:me`76600000J]EKgG_MN]ELcI[ED2
_ML02<cC_MNmelcI_MN]EKgG[ED3_ML01LcI_MNmekgG[ED00[gG00>]EKgG
[ED00[gG00>]EKgGc=<00[gG00F]EKgG[EG<fLcC00:me`04[EFmekgG[ED3
_ML01/cC[EFmekgGc=>]E@:me`03[EFmekgG00:me`06[EG>Lli/_MO66<cC
0kgG00C<dli/c<c>IP;>K005W=?<fLiic=WNn`02cWT4g_/2cWT01[gG0Z02
X5:Z<Hbme`;Nn`06kggNnmkkkggNnnmm1Mkk00C_OMkk_MO<d`:me`04[EFm
ejeEc=<2[ED02<cC_MN]EKgG[EG<djeE_ML3[ED02KgG[EF]ELcI_MO<djeE
_MN]E@02_ML02JeEW=>LdicCS56K9Y//W=>]E@02_ML00lcCW=>Ld`02[ED2
_ML00jeEVc>]E@03_ML01/cI_MO66<HHc=Vme`>]E@:me`04aQS<fLHHaQP2
_ML01<HH_MNmelcC0Yc<0KgG0LHH0LHH00001:eE_MO<fJeE0[gG00?<fJeE
_ML00kgG00F]ELcC_MN]ELcI00:]E@04c=>mejeE[ED2_ML01ZeE_MO<fJeE
_MN]E@>me`05[EFmejeE_MO<d`03_ML01lcC_MN]EKgGc=>mejeE00Bme`:]
E@:me`05c=>]EKgGc=>]E@04_ML01LcCaQRmekgGc=<00[gG00F]EKgGcW?<
a/i/00:me`04aQS>NLiicWT5g_/2cWT01Yii<H`aS5:ZQ13>N@;Nn`0>oWoN
nmkkkggNnnmmg___OMkkkggNnnmmg__660>]E@07_MN]EKgG[EFmejeE_ML0
1:eE00RmejeE_MN]EKgG[EG<djeE0[gG0ZeE0[gG00B]ELcI[EF]E@>Ld`04
S56408@@W=<2_ML00lcI_MNLd`02[ED01KgGc=V]EJeEW=<01;gG00O66;gG
aQS66<cIaQRme`02[ED2_ML2aQP01Lii_MO66;gGc=T00/HH00>]EIc<W=<0
0/HH0KgG00001<cI[EFmekgG0ZeE00>mejeE_ML00kgG00FLfKgG[EFmejeE
00:me`07[EFmekgG_MO<dkgG[ED01KgG00G<dkgG_MNmelcC00:me`09[EFm
ejeE_MO<dkgG[EFmejeE00:me`:]E@05c=>mekgG_MN]E@06_ML00jeE_MO<
d`03_ML01<cI_MNmejeE0[gG00C<dkgG_MO<d`:me`03aQS>NLii00;Nn`0;
cWWNnliioWo>NMkkcWVmejeE_MO>N@04g_/02>mmg___OMkkcooNnnmmg_/3
kgd01=kk_MNmekgG0jeE013<djeE_MN]EKgG[EFmelcC[EFmejeE_MN]EKgG
[EFme`:]E@:me`:]E@05_MN]EKgG_MN]E@03W=<01XaAHbbLc9cC_MO660:m
e`0;[EFLdjeE[EFmelHH[EF<DIcC[EG<f@05aQP02[gGaQRmejeEVc>]EKgG
c=VNNLii1LHH0[gG00>Ldic<[ED00[gG0002[ED00kgG[EFme`02_ML01JeE
c=VmejeEc=<00kgG00B]ELcC_MNLf@:me`0=[EFmejeE_MN]EKgG[EG66<cC
_MN]EKgG[ED00kgG00B]EKgG_MN]E@Fme`03[EFmelcC00Bme`03[EG<dkgG
00:]E@06_MN]EKgG_MN]ELcI0kgG00?66;gG_ML00kgG00C<dkgG_MN]E@:m
e`03[EG<dlHH00?>N@08g__nOliioWo>NMkkc=W>N@GNn`08kggNnnmmg___
OMkkkggNn`;_O@05cooNnnmmg_^me`02[ED01lcC_MNmejeE_MN]ELcC00:]
E@03_MN]EKgG00:]E@09c=>]EKgG[EFmejeE_MO<djeE00>me`06c=>mejeE
[EFLdjeE0YcC00F408@@W=>melcI00:me`:Ld`06c=>mekgG_MN]EHaA1;gG
0/HH00S<fLHHaQRmejeES56]EKgG0ZeE00G66<iic=W>NIcI00;660:me`:L
c07<d`6me`6me`0000C<fKgGc=Vme`:]E@:me`03[EG<fKgG00:]E@04c=>m
ekgG[ED2_ML05:eE_MO<dkgG[EFmelcC_MO<diiic=>mejeE_MO<dkgG[EFm
ejeEc=<2_ML01LcC[EFmekgGc=<00[gG00N]EKgG[EF]ELcI_MN]E@02_ML0
1LcC_MNmejeE_ML00ZeE1[gG00V]EKgG_MNmejeE_MO<djeE_ML00ZeE00>m
elcIcWT00/ii00?Nnliig_/00mkk0/ii00[>OmkkkggNnnmmcWWnOmkkkggN
n`?_O@0Ag___OMkkkggNnjeE_MN]ELicW=>mejeE_MN]EKgG[EFme`03[ED0
1KgG[EFmejeE_ML00ZeE00BmejeE_MO<d`:]E@05_MN]EKgG[EG<d`03W=<0
0haAHbbK;002W=<01;gGc=VmeicC0ZeE00W<fJeE_MNmehaA[EFmelHHc=T0
1[gG00V]EHaAW=>]EKgGc=W66<iic=T00/ii00S66<ii_MNmeicCS56]EKgG
0LHH0002_ML02:eE_MN]ELcI_MN]EKgG[ED3_ML01lcI[EFmejeE_MO<djeE
00>me`03[EG<fJeE00:me`04[EG<djeEc=T3_ML00jeE_MO<d`02_ML01JeE
_MNmekgGc=<00[gG00B]EKgG_MO<d`Bme`05[EG<dkgG_MN]E@02_ML00lcC
_MNme`02_ML00lcI_MNme`04_ML01<cC_MNmejeE0[gG00G>LjeE_MNmelHH
00?>N@GNn`03oWoNnmkk00CNn`05kggNnnmmg___O@03g_/02^mmg___OLHH
_MO>LjeE_MN]EKgG0ZeE01;<djeE[EFmejeE_MN]ELcC[EFmejeEc=>mejeE
_MN]EKgG[ED2_ML01JeE_MNmekgG[ED00icC00BLc8@@VbJ]E@:me`06aQRm
eicC[EFLdjeE0[gG00>]EHaA[ED00[gG00W<fIii_MN]EKgG[EG66:eEW=<0
0ZeE00G66;gGaQS>NLHH00;>N@06c=W66<HHc=>Ldic<0kgG00000jeE_MN]
E@02_ML03:eE_MN]ELcI_MN]EKgG[EFmejeEc=V]E@:me`05c=>]EJeE_MN]
E@02_ML00jeEc=Vme`02_ML01LcC[EF]EKgG[ED00[gG012]EKgG[EFmejeE
_MO<djeE_MO<dkgG[EG<fJeEc=>]E@>me`03[EFmelcC00:me`03[EFmelcC
00Jme`05c=>mekgG_MN]E@02_ML00lcC[EFme`02[ED3_ML01<cIcWW>NLii
1Mkk00?>NOiog_/01=kk00W_OMkkg___OLiokggNnnmmg_/00[gG0ZeE00Fm
ejeE[EFmejeE00:me`03[EG<djeE00:me`0:[EFmejeE_MN]EKgG[EG<djeE
_ML2[ED2_ML2[ED00kgG[EFLd`02W=<028aAI<bK;9cC[EFmelHH_ML2W=<2
[ED00kgG[EFme`02W=<01ZeEaQS66<HHc=V]E@>me`05[EFLdhaA[EG<f@03
aQP00liiaQRme`04_ML00icCVbc<d`02_ML0000:[EFmejeEc=V]EKgGc=V]
EKgG[ED2_ML01jeE_MNmekgG[EFmejeE00:me`09c=V]ELcC_MN]EKgG[EFm
ejeE00>me`0=c=V]EJeE_MN]EKgGc=>melcI_MN]EKgG[ED00[gG00B]EKgG
_MN]E@>me`08[EFmejeE[EFmejeE_MN]E@>me`03[EG66<HH00Bme`03[EFm
ekgG00:me`05[EFmejeEc=>me`02[ED4_ML00lHHcWW>N@08g_/01Oiog__N
nmkkoWl00]kk00?_OMkkg_/00[gG0ZeE00O>LicC_MN]ELcC[EFme`02[ED0
0kgG[EFme`02[ED01[gG[EFmejeEc=>]E@>me`04[EFmelcC[ED3_ML00icC
[EFLd`02W=<01h@@Hb2LdkgGc=W66;gG00>Ld`08_MN]ELcI_MNLdjeE_MO<
f@;660Bme`04[EFmei/cW=<3[ED01/HHc=W>NLHH_MN]E@;66004_MNLc9c<
[ED2_ML00005[EG<fJeE_MN]E@02_ML00jeE_MN]E@02_ML02LcI[EF]EKgG
[EG<fJeE_MN]E@02_ML00jeEc=V]E@02_ML01<cC_MNmejeE0kgG00O<fKgG
c=>mejeE_MO<d`04_ML01:eE_MN]ELcC0kgG00>]ELcC_ML00[gG00?<dkgG
[ED00[gG00?<dkgGaQP00[gG00?66;gGc=<00[gG00J]EKgG_MN]ELcC[ED2
_ML00jeE_MO<d`02[ED01KgG[EFmekgGc=T00lii0]kk00C>NMkkg__>N@WN
n`0:cWVLdkgGc=>]EKgGc=>mejeE_ML2[ED03;gG[EF]ELcC[EFmejeEc=>]
EKgG[EFme`>]E@06_MN]EJeE_MN]ELcC0[gG00Z]EIcC[EFLdic<Q12K;9cC
[EG660:me`:]E@07W=>]EKgG[EFmei/cW=<00ZeE00FmelHH_MNmelcI00>m
e`08Vc>]EJeE[EFLdkgGaQS<f@:me`07[EG66;gG_MNLdic6[ED00[gG0000
1/cI_MN]EKgGc=?<f@:]E@:me`03c=V]EJeE00>me`08[EFmejeE_MN]EKgG
c=>]E@>me`03[EFmekgG00:]E@03aQRmelcC00:me`0;[EFmejeE_MN]EKgG
[EFmelcC_MO<f@03_ML00jeE_MN]E@02_ML03jeEc=>mekgG[EFmelcC[EFm
ejeEc=?66;gGc=?66002_ML01<cC_MNmejeE0[gG00^]ELcC[EFmelcC_MN]
ELicW=>mejeE00:me`03aQS>NLii00;>N@07g__>NMkkg__>NMkkcWT00mkk
00G>NKgG[EF]EKgG00:]E@07_MN]EJeE[EFmejeE_ML00ZeE00ZmejeE[EFm
ejeE_MN]EKgG[EFme`:]E@05_MN]ELcC_MN]E@03_ML3[ED05IcCW<bLdh@@
I<JLdjeE_MO<fKgG[EFLc8aA[EG<dkgG[EF<DKgG[EFme`02aQP6_ML02icC
[EF]EJeEaQS<fLHHcWW669iic=T00/HH00>meic<W<`00ZeE0Ic<00002:eE
_MN]EKgG[EFmelcI_ML3[ED02<cI[EF]EJeEc=W<dkgG[ED2_ML01ZeE_MN]
EKgGc=>me`:]E@:me`06c=>]EKgG[EFmelcC1;gG01C<dkgG_MNmejeE_MN]
EKgG[EFmejeE_MO<djeE_MN]EKgG[EFmelcC0[gG00F]EKgG_MNmelcI00Jm
e`0<[EG<dkgG[EFmejeE_MN]EKgG[EFmejeE0[gG00O<dkgGc=>]EKgGaQS<
d`02aQP5cWT00mkkcWW>N@02aQP01ZeEcW>]ELcC[EFme`>]E@06cW>]EKgG
[EG<dkgG0ZeE00BmejeE[EFme`:]E@06_MN]EJeE_MO<djeE0[gG0ZeE00nm
ejeE_MNmejeEW=>]EIcCS56449/VS56]EKgGaQP00[gG00JK<icCW=>]ELcI
aQP2W=<04:eE_MO<fLHH_MO<fKgG[EG<djeEW=>]ELcI[EFmelii0/HH0/ii
0/HH0[gG00BLdi//W<bme`7<d`000[gG00R]EKgG[EG<fJeE_MN]ELcI0[gG
00>]EKgGc=T00ZeE00FmejeEc=V]ELcC00>me`06[EFmejeEc=?<fJeE0[gG
00?<fJeEc=<00[gG00>]ELcI[ED00[gG00W<dkgG[EFmejeEc=V]EKgGc=<0
1;gG00?<dkgG_ML00kgG00B]EKgG_MO<f@Bme`05c=?66:eE_MO<d`02_ML0
1:eE_MNmelcC0[gG0ZeE00K<djeE[EF]EKgG[ED2_ML00jeE_MNme`04_ML3
aQP2_ML02jeE_MN]EKgGW=>mejeE_MO<djeE_ML00ZeE00>mejeE_ML00ZeE
00BmelcC[EFme`>]E@05_MN]ELcC_MN]E@02_ML01ZeE_MN]EKgG[EFme`:]
E@BLd`09W<aS9YcC[EFmelHHc=V]EIcC00:]E@>me`:Ld`05[EFmekgGaQRm
e`05[ED01IcC[EF]EJeE_ML00/HH0/ii00?<fLHHcWT00[gG00B]EI/V[EFm
e`76600000F]ELcI[EG<fKgG00:]E@:me`06c=>]EKgG_MN]ELcC0kgG00V]
EKgG_MN]EKgG[EFmejeEc=T00[gG00>]EKgG[ED01;gG00>]EKgG[ED00[gG
00N]EKgG[EFmelcC_MO<d`02_ML03jeE_MN]EKgG[EG<fJeE_MO<djeE_MO<
dkgGaQR]E@05_ML00jeEc=Vme`02_ML01ZeE_MNmejeE_MO<d`:]E@07_MN]
EKgGc=>mejeE_ML00ZeE01?>LjeE_MN]EKgGc=>mejeE_MN]ELcC[EFmelcC
[EG<dkgG[EFme`02[ED01[gG[EFmejeEc=>me`:]E@04_MN]EJeE_ML2[ED0
1;gG[EG<dkgG0ZeE00^mejeE[EFmejeE_MN]EKgG[EG<fKgG00:]E@>Ld`05
S55S;8aA[EG<d`03_ML2W=<03:eEW=VmelHHW=>K<jeE_MO66<cI_MN]E@:m
e`03[EFmeicC00:]E@06c=VmeiiicWW<fLii0lHH00JmejeE[EFLc9cCc=<1
_ML00003[EFmejeE00:me`03[EFmelcI00:]E@04_MO<fJeE[ED2_ML2[ED0
1[gGc=>]EKgGc=V]E@:me`03[EFmejeE00:me`05[EFmejeE_MN]E@02_ML0
2<cC_MN]ELcI_MN]EKgG[ED2_ML2[ED2_ML03jeEc=V]EKgG[EFmejeE_MO<
fJeE_MN]ELcC_MO<d`0:_ML00lcC[EFme`02[ED2_ML01lcC_MN]EKgG[EFm
elcC00:me`09[EFmelcC_MN]EKgGc=>mejeE00:me`0>c=>]EJeE_MNLdkgG
c=>]EKgG[EG<dkgGW=>me`:]E@:me`05c=>mejeE[EFme`02[ED01;gG[EF]
EKgG0ZeE00RmejeE[EFmejeE_MN]EKgG0ZeE19cC00>Lc6</S5400ZeE00C6
6:eE_MN<D@:]E@>me`:Ld`:]E@:me`;66005_MN]EKgGc=VLd`02[ED2_ML0
2<cIaQS>NLHHcWW<fIiiaQP2_ML2W<`2_ML00009[EFmekgG[EFmejeE_MN]
ELcI00Bme`07[EFmejeEc=VmejeEc=T00[gG00F]EKgG[EG<fJeE00:me`07
[EG<fLcC_MN]EKgGc=<00[gG00J]EKgG_MN]EKgGc=<2_ML01JeE_MO<fJeE
c=<00[gG00B]EKgG[EG<d`:me`04[EFmejeEc=T4_ML00lcI_MNme`02_ML0
0jeE_MO66002[ED01kgGc=>mekgGc=>]EKgG00>]E@05cW>]EKgG[EG<d`03
_ML01jeEcW>]EKgGc=>melcC00>]E@08_MN]ELicW=>]ELic[EFme`:]E@0<
_MN]EJeE_MO<dicC_MN]EKgG[EG<dkgG0ZeE00FmejeE[EFmelcC00:]E@06
_MN]EKgG[EFmelcC0[gG00?<djeEW=<00YcC00><DH@0W<`00YcC00?<fKgG
_ML00YcC00K;<kgG[EG<fKgGS542[ED2aQP00lcI[EFme`02_ML01lHHW=>]
EJeE_MNNNLcI00;66003cWW66<HH00;66004_MN]EIc<Vb`2_ML0000:_MO<
fKgG[EFmejeEc=VmejeE_ML2[ED01[gG[EFmejeE_MN]E@>me`04[EFmekgG
c=<3_ML00lcC[EFme`03_ML01<cI[EFmejeE0[gG00C<djeE_MN]E@:me`04
[EFmekgG[ED2_ML00jeE_MNme`02_ML01JeE_MN]EKgG[ED00[gG00>]EKgG
_ML01;gG00G<dkgG_MN]ELcC00:me`0A[EFmejeE_MN]EKgG[EFmelcC_MN]
EKgG[EG>LjeE_MN]E@02_ML02JeEcW>]EKgGW=>melic[EG>L`03[ED02KgG
[EF]ELcC[EFmejeEc=>me`03[ED01KgG[EFmejeE_ML00ZeE00BmejeE[EFm
e`:]E@09_MN]ELcC_MN]ELcC_MN]EKgG00:]E@BLd`04S56K9X@@W=<3_ML0
3JeEW=>LdjeE_MN]EKgG[EF<DKgG[EFmelcI00Bme`04[EFmehaA[ED4_ML0
0lHH_MNme`03_ML01/cI_MN]EIc<S56me`6]E@0000BmejeEc=V]E@:me`0@
[EFmekgG[EFmejeEc=VmejeEc=>mejeE_MN]EKgGc=<3_ML02<cC_MN]ELcI
_MN]EKgG[ED2_ML01JeE_MO<dkgG[ED01;gG013<djeE_MO<dkgG[EFmejeE
_MO<dkgG[EFmejeE_MO<d`:me`06[EG<dkgG_MO<fLHH0kgG01>]EKgG_MN]
EKgG[EFmejeE_MO<dkgG[EG<djeE_MN]EKgGc=>]E@02_ML02JeE_MN]ELcC
_MN]EKgG[EFme`02[ED03;gG[EF]EKgGc=>]ELcC_MN]EKgG[EFme`:]E@04
_MO<djeE_ML5[ED02KgG[EFmejeEc=>]EKgG[EFme`02[ED01;gG[EFmejeE
0kgG0ZeE00bLdjeEW=><DF<VW<bK<icC_MO<djeEVc<2W=<2[ED01<HH[EF<
DJeE0kgG00W66;gG[EFmejeE_MN]EIcCc=T01;gG00C<fIiiaQS660>me`03
[EFLc9//00:me`000ZeE01FmejeE_MO<fJeE_MN]EKgGc=VmejeE_MN]EKgG
[EFmelcC[EFmelcI[ED00[gG00>]EKgG_ML00[gG00C<dkgG_MNme`:]E@09
_MO<dkgG[EFmelcC[EFmejeE00:me`0?[EFmejeEc=V]EKgG[EFmejeEc=>]
EKgG[EFmejeE00>me`05[EFmekgGc=?66003_ML02<cC_MNmelcC_MN]EKgG
[ED3_ML00jeE_MN]E@04_ML01<cC_MN]ELcC0[gG00V]EKgG[EFmelcC_MN]
ELcC_ML00jeE00JmejeE[EFmejeE_ML2[ED02KgG[EF]EKgG[EG<dkgG[EFm
e`02[ED04LcC[EFmejeE_MNLdkgG[EFmejeEc=>mejeE_MN]EKgG[ED019cC
00B<DH@@Q12Ld`>me`03[EFLdicC00>]E@06c=V]EHaA[EFmelcI0/HH0[gG
00W<fIcC[EF]EIcC[EFLdkgGc=T00/HH00C>NLcIaQS660:me`03[EFLc9c<
00:me`0000O<fJeEc=VmejeE_MO<d`03_ML01:eE_MN]EJeE0[gG00F]EKgG
_MNmelcC00:me`05[EG<fKgG_MN]E@03_ML00jeEc=>me`02_ML01:eEc=>m
ejeE0[gG00^]EKgG_MN]EKgG[EFmelcC[EFmelcC00Bme`0=c=>mejeE_MO<
dkgG[EFmelcC_MO66;gGc=<00[gG00?66:eE_ML00[gG00?<djeE_ML00ZeE
00G<djeE[EG<dkgG00:]E@03c=>mejeE00>me`0:WW>melcC_MO<dkgG[EG>
LjeE_ML2[ED00kgG[EG<d`02[ED01<cC[EF]EKgG0ZeE00>mejeE_ML00ZeE
00JmejeE[EFmejeE_ML2[ED01/cC_MN]ELcC[EFme`:]E@04_MN]EKgG[ED2
_ML01IcC[EFLdicCI<`00Y//00>LdjeE_ML00[gG00>]EHaAW=<00ZeE0[gG
00ZK<icC[EFmelHHc=VmejeEc=Vme`:]E@06W=>]EJeE_MO66<cI1LHH0[gG
00B]EIcCVbJ]E@6me`000[gG00B]EKgG_MN]E@:me`:]E@:me`03c=>melcI
00:]E@03c=V]EKgG00:me`0:[EFmekgG[EFmejeE_MN]EKgGc=T3_ML00lcC
_MNme`02_ML02/cC[EFmelcC_MN]EKgGc=>mejeE0[gG00C<dkgG[EFme`:]
E@04_MN]EKgG[ED3_ML00jeE_MNme`05_ML01:eEc=VmejeE0kgG00?<dkgG
_ML00[gG00F]EKgG[EFmelic00:]E@06_MN]EKgGc=>]EKgG0ZeE00RmeicC
_MO<dkgG[EG<dkgG0ZeE00fmejeE_MN]EKgG[EG<djeE_MN]EKgG[EFme`02
[ED01<cC[EF]EKgG0ZeE00RmejeE[EFmejeE_MN]EKgG0ZeE00NmejeE_MN]
EIcC[EFLc002W=<01H@@HbJLdkgGc=T00[gG00>LdhaA[ED00ZeE00>mejeE
S5400ZeE0[gG00?66;gG[ED00ZeE00jLdjeEW=>]EKgGc=VmelHHcWVmelHH
_MO<fLHH0[gG00>Lc9//W=<00KgG00004JeEc=V]EJeE_MO<dicIcW?<fJeE
_MN]ELcI[EG<dkgG[ED00kgG00F]ELcI_MN]ELcC00:me`04c=>mekgG[ED2
_ML01ZeE_MNmejeE_MN]E@:me`07[EFmelcC_MN]EKgGc=<00[gG00R]EKgG
[EFmelcC[EFmejeE0[gG00W<dkgG[EFmelcC_MO66;gGc=T00[gG00?<dkgG
[ED00[gG00?<djeE_ML00[gG0jeE00>mejeE_ML00ZeE0[gG00?<dkgG[ED0
0[gG00O<dkgGcW>]EKgG[EFme`02[ED01[gGc=>Ldlic[EG<d`>]E@04_MN]
EKgGc=<3[ED02LcC[EFmejeE_MO<dkgG[EFme`02[ED02;gG[EF]EJeE_MN]
EKgGc=<2_ML01LcC_MNmeicC[ED00YcC00><DH@@VbH00YcC00JmelHH_MN]
EI//W=<2[ED2_ML01IcC[EF]EKgGc=T00[gG00?<djeE[ED00ZeE00BK<jeE
[EFme`;66003cWW<fLii00?66005_MN]EHaAVbb]E@01_ML00009[EFmejeE
_MO<fJeE_MO<dicI00:me`03[EFmejeE00:me`04[EFmelcC[ED3_ML01:eE
_MNmelcC0kgG00?<dkgG[ED00[gG00K<dkgG_MN]ELcC[ED2_ML03:eE_MO<
dkgG[EFmejeE_MO<djeE_MN]E@:me`03c=>mejeE00>me`06[EFmekgG_MO<
dlHH1;gG00S<dkgG[EFmejeE_MO<djeE0[gG00g<dkgG[EFmelcC_MN]EKgG
[EFmelcC_MN]E@02_ML01IcC_MNmelcC_ML00ZeE00VmejeE_MNmeicC_MN]
ELcC_ML00ZeE00JmejeE[EFmejeE_ML:[ED01kgG[EFmejeE_MN]EKgG00:]
E@03_MN]EKgG00:]E@BLd`04W<aS;:eEW=<2_ML3W=<02;gG[EG<fKgG[EF<
DIcCc=<3_ML01jeEW=>]EJeE_MN]EIcC00:]E@:me`05c=W66<HHcWW<f@03
aQP00jeES56LaP02[ED00003[EFmejeE00:me`0B[EFmekgG[EG<djeE_MO<
dkgG[EG<fKgG[EG<fKgG[EFmelcC0[gG00B]EKgG_MN]E@:me`06c=>mekgG
_MN]ELcC0kgG00B]EKgGc=>me`:]E@0D_MN]EKgG_MN]EKgG[EG<fJeEc=>m
ejeE_MN]EKgGc=>NNLcC_MN]E@Fme`05[EFmekgG_MO<d`02_ML02JeE_MN]
ELcC_MN]ELcC_MN]E@02_ML01LcC_MN]EKgG[ED00[gG00Z]EKgG_MN]EKgG
[EFmelcC[EFme`:]E@03_MNLdlic00:]E@04cW>]EJeE_ML2[ED03KgG[EF]
EKgG[EFmejeE_MN]ELcC[EFmelcC00:]E@06_MN]ELcC_MN]EKgG0ZeE00Bm
ejeE[EF]E@>Ld`03S55Tc6<V00:Ld`04_MO<fKgGc=<2W=<2[ED2_ML3W=<4
_ML01:eE_MNmekgG0icC00RK<jeE[EG66<cIcWW66<ii0/HH00FmelHHW=>K
;9cC006me`0000BmelcI[EFme`:]E@03_MNLfKgG00:me`04c=V]EKgGW=<2
_ML01ZeE_MNmekgGc=V]E@:me`06c=>mejeEc=VmelcC0[gG00?<dkgG[ED0
0[gG00O<djeE_MNmejeE_MN]E@02_ML01:eE_MO<djeE0[gG00^]EKgG_MNm
ejeE_MN]EKgG[EFmelcC00:me`05c=>mekgG_MO<d`03_ML01JeE_MN]EKgG
[ED00[gG01>]EKgG[EF]EKgG[EFmelcC[EFmejeEcW>]EKgG[EG<dkgG[EG<
d`02[ED02;gGc=>]ELic[EFmejeE_ML2[ED01[gGW=>melcC[EG<d`>]E@:m
e`04[EG<djeE_ML3[ED01kgG[EF]EKgG[EG<dkgG00>]E@03_MO<dkgG00:m
e`FLd`0@S56K9XaA[EFmelcI_MN]EHaAW=>]EKgG[EG<fIcCS542[ED01KgG
aQRmekgGc=T00ZeE00BLdjeE_MN]E@:me`07cWW66<iiaQS>NLHHcWT00[gG
00>Ldic<W<`00JeE00002:eEc=V]EKgGc=V]ELcC_ML2[ED01kgG[EF]ELcI
_MN]EKgG00:]E@Bme`03[EFmejeE00:me`06[EFmekgG[EFmelcC0kgG00B]
EKgG_MO<d`:me`05[EFmelcC_MN]E@03_ML01JeE_MO<dkgG[ED00[gG00C<
djeEc=V]E@:me`03[EFmelcI00Fme`0:[EFmekgGc=V]EKgGc=>]EKgGc=<3
_ML02lcC_MN]EKgG[EFmejeE_MO<dkgG[ED00[gG00B]ELic_MN]E@:me`>]
E@08c=>]EKgG[EG<dkgGW=>me`>]E@04_MN]EJeEc=<3[ED00kgG[EF]E@03
[ED00kgG[EF]E@04[ED01;gG[EF]EKgG0ZeE00>mejeEW=<00YcC00B<DFC<
Vbb<D@:]E@:me`07[EFLdjeEW=?<fJeE_ML00YcC00B]EKgGc=W660Bme`03
[EFmeicC00>]E@05_MO66<HHaQS<f@04_ML01:eEVbaTaX@@0Lc<00001:eE
_MN]EKgG0ZeE0[gG00J]ELcI_MN]ELcI[ED2_ML01/cC[EG<fKgG[EFme`:]
E@03c=VmelcC00:me`09c=V]EKgG_MO<fJeE_MN]ELcC00:me`06[EFmejeE
_MO<dkgG0ZeE00>mejeEc=<00[gG00J]EKgG[EFmejeEc=<2_ML00jeE_MO<
d`02_ML00jeE_MNme`03_ML01/cC_MNmejeE_MN]E@:me`B]E@07c=>mejeE
[EFmejeEc=<00[gG00N]EKgG[EFmejeEc=>me`02[ED01/ic[EF]EKgG[EG>
L`:]E@0;c=>mejeE[EFmejeE_MN]ELcC[EFme`02[ED05kgG[EG<djeE_MN]
EKgG[EFmejeE_MO<djeE_MN]EKgGc=>]EKgG[EFmelcC[ED019cC00FLc6<V
S56mejeE00:me`>Ld`06c=>mekgG[EF<DIcC0ZeE00?<fLHH_ML00jeE00FL
djeEVc>LdlcI00>me`03c=VmekgG00Bme`04[EFLc8@@Vb`1[ED0000:_MN]
ELcC[EG<fKgG[EG<fJeE_ML2[ED03;gG[EF]EKgG[EFmelcC[EFmelcC_MN]
E@>me`05[EFmekgG[EG<d`02_ML02jeEc=V]EKgG[EG<fJeE_MN]EKgG[ED0
0[gG00[<dkgG_MN]ELcC_MN]EKgG[EG<d`:me`06[EFmejeE_MN]ELcI1;gG
00o<dkgG_MN]EKgG[EFmelcC_MN]EKgG[EFmelcC_ML00ZeE00^melcC[EFm
elcC[EFmejeEcW>mejeE00:me`07[EFmekgG[EFmelcC_ML00ZeE00RmejeE
[EF]EKgG[EG<djeE0[gG0jeE00VmejeE_MNLdkgG[EG<djeE_ML01:eE00?<
fJeE_ML00ZeE00FmejeE_MN]EKgG00:]E@07W=>]EIcCW=>446C<Vb`00ZeE
0[gG00J]EIcCW=>]EIcC_ML2[ED00icC[EF]E@04_ML01:eEc=>LdkgG0YcC
00F]EKgG_MNmejeE00Bme`04c=VmekgG[ED2W<`1[ED0000>[EG<fJeE_MN]
EKgG[EFmejeE_MN]ELcI_MN]E@:me`03[EFmejeE00:me`07[EFmelcC_MN]
EKgGc=<00[gG016]EKgG_MNmejeE_MN]EKgG[EFmejeE_MO<dkgG[EFmejeE
00:me`03[EFmelcC00:me`07c=>mejeE_MN]EKgG[ED01;gG00B]EKgG_MO<
f@:me`0A[EFmekgGc=>mejeE_MN]ELcC[EFmejeE_MN]ELcC_MN]E@02_ML0
5:eE_MNmelcC_MN]EKgGc=>mejeE_MO<djeE_MN]EKgGW=>mejeEc=<2_ML3
[ED01[gG[EF]EJeE_MO<d`:]E@03c=>]EKgG00:]E@05_MN]EJeEc=>me`03
[ED02;gG[EF]EKgG[EFmejeE_ML2[ED4W=<049c<Q12K;9cC_MO<djeEW=><
DIcC[EFmelcI_MN]EHaA0ZeE0[gG00?<fJeE[ED00jeE00BLdjeE[EG<f@>m
e`03aQRNNLcI00:me`05[EFmeicCVbJ<D@01_ML0000=[EFmejeE_MN]EKgG
[EFmelcI[EFmejeE_ML00ZeE00O<fJeE[EFmejeEc=Vme`02[ED3_ML02ZeE
_MNmejeE_MN]ELcIc=>melcC0kgG00R]EKgG[EFmelcC_MO<djeE0[gG00n]
EKgG[EFmejeEc=V]EKgG[EG<fKgG[EFmelcC[ED02[gG00>]EKgG_ML00[gG
00O<dkgG[EFmejeE_MO<d`02[ED2_ML02:eE_MN]EKgG[EFmejeE_ML2[ED0
1[gGc=>]EJeE_MO<d`:me`>]E@06c=>mejeE[EG<dkgG0jeE00JmeicC_MNL
fJeE_ML2[ED00kgG[EF]E@02[ED01;gG[EF]EKgG0jeE00FmejeE[EFmejeE
00BLd`04Q11S9X@@W=<2[ED02[gG[EF<DIcC[EFLdjeE_MN]EHaA0ZeE1;gG
0jeE19cC00N]EKgG[EFmelcIaQS<f@02_ML01JeE_MNLdfC<Vb`00JeE0000
2;gGc=V]EJeE_MN]EKgGc=T2[ED01KgG[EFmejeEc=T00ZeE00RmelcI[EFm
elcC[EFmelcI0ZeE00>melcI[ED00[gG00F]EKgG_MNmejeE00:me`03c=>]
EKgG00:]E@0C_MN]ELcI[EFmelcC[EFmejeEc=V]EKgG[EFmelcC_MN]EKgG
c=<00kgG00C<dkgG_MO<d`:me`03[EG<fJeE00:me`08c=>]EJeE_MN]EKgG
[EFme`:]E@05_MO<dkgG[EG<d`03_ML01LcC_MN]EJeEc=<00[gG00F]EKgG
_MN]ELcC00>]E@05_MO<djeE[EFme`04[ED01kgG[EG<djeE_MN]ELcC00:]
E@0>_MO<djeE_MN]EKgG[EG<djeE_MN]ELcC_MN]E@:me`03[EFLdicC00>L
d`03S56446C600:Ld`05c=VmejeEVc>Ld`02[ED02KgGc=VLdhaA[EFLdlcI
_MNNN@02[ED01KgGW=>]EI/cW=<00kgG00>LfLHHaQP00/ii0/HH0[gG00>]
EIc<Vb`00JeE0002[ED00kgG[EG<f@02[ED2_ML01ZeEc=V]EJeE_MO<d`>m
e`:]E@:me`09W=>mekgGc=>mejeE_MN]ELcC00>me`04[EFmekgG[ED2_ML0
1jeE_MO<fJeE_MN]EKgG00:]E@07_MO<dkgG[EFmejeEc=<00[gG00N]EKgG
[EFmejeE_MN]E@05_ML01<cC_MNmejeE0[gG01Z]EKgG_MN]EKgG[EFmelcC
[EG>LjeE_MN]EKgG[EFmelcC[EFmejeE_MO>LjeE_MO<dkgG0ZeE0[gG0ZeE
00>mejeE[ED01:eE00JmejeE_MO<dicC_ML3[ED00kgG[EFme`04[ED01KgG
[EF]EJeE_ML00ZeE00>mejeE_ML00ZeE00>melcC_ML019cC00>Lc6</Vb`0
0YcC0kgG00B]EIc<W=>]E@:me`03[EFK<jeE00>me`06c=VmeicI_MN]EKgG
0icC00B]EKgG_MO660;>N@;66006c=VmekgG[EF<DIc<0KgG00001jeE_MO<
fJeE_MN]EKgG00:]E@04_MN]EJeEc=T2[ED01KgG[EF]EJeEc=T00ZeE0[gG
00K<djeE_MN]EKgGc=<2_ML02jeE_MN]EKgGc=>]EKgG[EG<dkgGc=<00[gG
00Z]EKgG_MO<dkgG[EFmejeE_MN]E@:me`:]E@03_MO<dkgG00:me`03[EG<
fJeE00Rme`0@c=>]EKgG[EFmejeEc=>]EKgG[EFmeicC_MN]ELic[ED2_ML0
1JeE_MN]EKgG[ED00[gG00BLdlic[EG>L`:]E@:me`08c=>]EJeE_MN]EKgG
[EG<d`B]E@03_MN]EKgG00N]E@05_MN]EJeE[EFme`02[ED02;gG[EF]EKgG
[EFmejeE_ML5W=<019c<Q11S;9cC0[gG00C<fKgGW=><D@:Ld`04[EG66:eE
S542[ED01[gGc=VmekgG[EFme`:]E@:Ld`:]E@03c=VmelcI00G660:me`03
[EFLc9//006Ld`000ZeE00>mejeE_ML00ZeE00C<fJeEc=Vme`:]E@08_MN]
EKgGc=>mejeEc=>me`:]E@:me`0=W=VmelcC[EG<fJeE_MN]ELcC_MN]EKgG
c=<00[gG00B]EKgG[EG<d`:me`09[EFmelcC_MN]EKgGc=>]EKgG00:]E@0:
_MO<djeE_MN]ELcC_MN]EKgGc=<2_ML01LHH[EFmekgG[ED00[gG00K<dkgG
[EFmejeE_ML3[ED01;gGc=>mejeE0[gG00F]EKgGc=>mejeE00:me`07c=>m
ejeE[EFmelcC_ML01:eE00FmejeEc=>LdkgG00:]E@03c=>]EKgG00>]E@06
_MN]EJeE_MN]EKgG1:eE012mejeE[EFmejeEc=>]EKgG[EG<dkgG[EFmejeE
W=>]E@:Ld`03S56449//00:Ld`03_MN]EKgG00>Ld`06c=>]EKgG_MN<DIcC
0ZeE0[gG00C<fJeE_MO<d`:]E@03S56]EIcC00:me`C66007c=>melHHaQR]
EFC<Q1000Lc<00000kgGc=V]E@02[ED02LcI[EFmejeE_MN]EKgG[EG<f@03
[ED01[gG[EFmekgG[EG<f@:]E@03c=>mejeE00:me`03[EFmelcC00:me`05
[EG<fJeE_MN]E@02_ML02jeE_MN]EKgG[EFmejeE_MO<dkgG[ED00[gG00C<
dkgG_MN]E@:me`04c=>mekgG[ED5_ML00lcC_MN]E@02_ML02:eE_MNmejeE
_MO<djeEc=<2_ML04jeE_MN]EKgG[EG<djeEcW>]EKgG[EFmelcC[EFmejeE
_MN]EKgG00:]E@03cW>]EJeE00:]E@03c=>mekgG00:]E@06_MN]EKgG[EFm
elcC0ZeE00S<djeE[EG<djeE_MN]EKgG0ZeE00C<djeE_MN]E@:me`04[EFm
ejeE_ML2[ED2W=<02XaAW=>LdfC<Q02LdjeE_MN]ELcI0icC00J]EIcC_MO<
dhaAW=<5_ML01ZeE_MN]EJeES56K;0:]E@09_MN]EKgGc=W66:eES5766;gG
00:]E@:4406Ld`0000N]EKgG[EFmejeE_MO<d`02[ED00kgG[EFme`02[ED2
_ML03JeEc=V]EJeE_MO<dkgG[EFmejeEc=>mejeE00:me`0M[EFmejeE_MN]
EKgGc=>mejeEc=>mejeE_MO<dkgG[EFmejeE_MN]EKgGc=>]EKgG[EG<djeE
_MN]E@02_ML2[ED3_ML00lcC_MNme`02_ML01JeE_MNmekgG[ED01KgG0ZeE
00FmejeE_MO<djeE00:me`05[EFmejeE_MO<d`02_ML03JeE_MN]ELcC[EFm
elcC[EFmejeEc=>]EKgG00>]E@03_MNLdkgG00F]E@03_MN]EKgG00:]E@04
_MN]EJeEc=<3[ED00kgG[EFme`04[ED01KgG[EFmejeE_ML00YcC00Z]EIcC
S56449//S56K<jeEaQRme`:Ld`03Vc>meicC00:me`04S56K<jeE[ED3_ML0
2JeE_MNLdjeEW=><DIcC[EG<f@02[ED01KgGc=VmejeEc=T00kgG0Ic<0I/V
0JeE0003[ED01/cI[EF]EKgG[EG<f@:]E@06_MN]EKgGc=>]EKgG0ZeE00Nm
elcC[EFmejeE_MN]E@02_ML03:eE_MO<djeE_MNLfKgGc=>mejeE_MN]E@:m
e`0?[EG<fJeE_MN]EKgGc=>mejeE_MN]EKgGc=>mejeE00:me`03c=>]EJeE
00>me`04[EFmekgGc=T2_ML01lcC_MNmelcC_MN]EKgG00:]E@06c=>]EKgG
[EG<dkgG0ZeE0[gG013<djeE_MN]ELic[EFmejeEc=>mejeE_MN]EKgG[EFm
e`:]E@03cW>]EJeE00:]E@04c=>]EJeEcW<3[ED00kgG[EF]E@03[ED01;gG
[EF]ELcC0ZeE00>mejeE[ED00jeE00JmejeE[EFmejeE_ML2[ED5W=<018@@
HbJ<DJeE0[gG00B]EIcCW=>Ld`:]E@04_MNLdhaAW=<2[ED01lcI_MNmekgG
c=V]EKgG00:Ld`03[EFmejeE00:]E@Bme`06[EFmekgGc=>Lc8@@0HaA0000
3:eEc=VmejeE_MN]EKgG[EFmelcI[EFme`:]E@07c=V]EKgG[EFmejeE_ML0
0ZeE00NmelcC_MN]EKgGc=>]E@02_ML01<cC_MNmejeE0kgG0ZeE00jmelcC
_MN]EKgG[EFmeicCc=V]EKgG[EFmejeE0[gG00>]EKgG[ED00[gG00C<djeE
_MO<d`Jme`03[EFmejeE00:me`04c=>mejeE_ML2[ED00kgGc=>]E@02_ML2
[ED00kgGc=>]E@02_ML03:eE_MNmejeEcW?<dkgGW=>meicC_MO<d`:]E@03
cW>]EKgG00:]E@06_MN]EJeE_MN]ELcC1:eE00>mejeE[ED00jeE00JmejeE
[EFmejeEc=<3[ED01lcI[EF]EJeE_MN]EKgG00BLd`04W<b449/VS542[ED0
1LcIaQRLdhaAW=<00jeE00RLdhaAW=>]EIcC_MO<fKgG0ZeE00G<djeEW=>K
<icC00>]E@04_MO66<HHc=T3_ML01:eE_MNLc9/V0Ic<00003lcI_MN]EJeE
c=V]EKgG[EFmejeE_MO<djeE_MN]E@02_ML00icCc=V]E@02_ML03jeEc=V]
EJeE_MO<dkgG[EFmejeEc=>mejeEc=>me`02[ED01<cC_MNmejeE0[gG00B]
ELcC_MN]E@>me`04c=>mejeE_ML2[ED00kgG[EG<f@02[ED00kgGc=V]E@03
_ML07LcC_MNmelcC_MN]EKgGc=>]EKgG[EFmejeE_MO<djeE_MN]ELcC[EG>
LjeE_MN]EKgGc=>]EKgGc=<00jeE00FmejeEcW>]EKgG00:]E@05_MN]EJeE
[EG<d`04[ED02lcC[EFmejeE_MN]ELcC[EFmejeE_ML00ZeE012mejeE[EFm
ejeE_MN]EKgG[EG<dkgG[EG<fJeE_MN]E@FLd`07S55S9YcC[EG<djeE_ML0
0icC00B]EIcCc=V]E@:<D@04[EG<dkgG_ML3W=<01:eEW=>]EIcC0ZeE00?<
fKgG_ML00lHH0[gG0ZeE00>Lc9//S5400IcC0002[ED01KgG[EFmejeEc=T0
0ZeE00>mejeEc=T00ZeE00NmejeE_MNmejeE_MN]E@02_ML01JeE_MN]EKgG
[ED00[gG00W<dkgG[EFmejeE_MN]ELcI_ML00ZeE00?<djeE[ED00[gG00>]
ELcI_ML00ZeE00VmejeE_MO<djeE_MO<dkgG[ED00[gG0ZeE00>mejeE_ML0
1kgG00N]EKgG_MN]EKgGc=>me`02[ED05kgG[EFmejeE_MN]EKgG[EFmelcC
_MN]EKgG[EFmejeE_MO<dkgG[EG>LjeE_ML00ZeE00?<dkgG[ED00ZeE00>m
ejeE_ML01JeE00>mejeE[ED00jeE00?<dkgG[ED00ZeE00?<djeE[ED00jeE
00BmejeE[EFme`:]E@03_MO<dicC00>Ld`05S55Tc6</S56Ld`02_ML01<HH
[EFLdi/c0jeE00FmehaAW=>LdjeE00:me`07[EG<djeE[EFLdjeEW=<00jeE
00>LfLHH_ML00[gG00?<fKgG_ML00ZeE0FC<0I//0HaA00001lcI[EFmejeE
c=V]EKgG00:]E@05_MNLfLcC[EFme`02[ED2_ML2[ED01<cI[EFmekgG0ZeE
00^melcC[EFmejeE_MN]EKgG[EFmelcC00:me`04[EFmekgG[ED2_ML03ZeE
c=>]EKgG[EG<dkgG[EFmejeEc=>]EKgG[ED3_ML01:eEc=>mejeE0[gG00C<
fKgG_MN]E@:me`0<c=>mejeE_MN]EKgG[EG<djeE_MNLdkgG0ZeE01K<djeE
_MNmejeEcW>]ELcC[EFmejeE_MN]EKgGc=>mejeE_MN]ELic[EG<d`:]E@04
c=>]EJeE_ML3[ED01KgG[EFmejeE_ML00ZeE00BmejeE[EFme`>]E@03_MN]
EJeE00>]E@03_MN]ELcC00:me`>]E@09W=><DIcCW=>Lc3</Vbb]EIcC00:m
e`03[EFLdi/c00:]E@04_MN]EHaAVb`2W=<019/cW=>meicC1:eE0YcC0ZeE
00FmelHH_MO<fIcC00>]E@04W=>meicCI<H1VbH00009_MN]EJeE[EFmejeE
c=V]ELcI00:]E@:me`06[EG<djeE_MN]EKgG0ZeE0[gG00f]ELcC_MO<djeE
_MO<fJeE_MN]EKgGc=>me`02[ED01[gGc=>mejeE_MO<d`:]E@:me`:]E@05
_MN]ELcC_MN]E@02_ML01ZeE_MN]EJeE_MN]E@:me`03[EG<fKgG00:me`04
c=>mekgGc=<2_ML00jeE_MO<d`02[ED02;gG[EFmelcC_MN]EKgG[ED2_ML0
0jeE_MN]E@02_ML02jeE_MN]EKgG[EG<djeE_MN]EKgGc=<01:eE00BmejeE
[EFme`:]E@04c=>mejeEc=<5[ED01kgG[EF]EJeEc=>]EKgG00>]E@06c=>]
EJeE_MN]EKgG0jeE00>meicCW=<00icC00J<DFC<VbbLdjeE_ML2[ED029/c
W=>]EJeE_MN]EIcCS542[ED3_ML3[ED2W=<01Yc<[EF]EKgGc=V]E@C66006
_MN]EKgG_MNLdic<0H@@00001:eEc=V]EKgG0ZeE00VmejeE[EFmelcCW=>m
ejeEc=T00jeE00G<fJeE_MN]EKgG00:]E@:me`>]E@05_MO<dkgG_MN]E@02
_ML00jeE_MNme`02[ED01;gG[EFmekgG0ZeE00JmelcC[EFmejeEc=T2[ED0
1KgG[EG<dkgG[ED00[gG00>]EKgG[ED01KgG00f]EKgG_MN]EKgG[EFmejeE
_MN]EKgG[EFme`02[ED03/cC_MN]EJeE_MN]ELcC_MN]EKgGc=>mejeEcW<3
[ED01;gG[EF]EKgG0ZeE00BmejeE[EFme`:]E@06_MN]EJeE_MNLdkgG0ZeE
00BmejeE[EG<d`>]E@05_MNLdlcC[EFme`02[ED01;gGW=>melcC0ZeE00>m
ejeE_ML01IcC00B<DF<VVbbLd`Bme`04W=>]EIcC[ED2_ML01IcCS56K<jeE
aQP00kgG00[<djeE[EF]EIcCS56LdjeEc=Vme`?660:me`:]E@03_MNLdi//
006Lc00000^]EKgG[EFmejeE_MN]ELcC_MO<fJeE00:me`:]E@:me`06c=V]
EJeE_MO<djeE0[gG0ZeE0kgG00?<djeE_ML00ZeE00BmelcC[EFme`:]E@:m
e`07c=>mejeE_MN]ELcI[ED00[gG00j]EKgG[EFmejeEc=>mejeE_MN]ELcC
[EFmelcC0kgG00S<dkgG_MNmejeE_MN]EKgG0ZeE00JmelcC_MN]ELcC[ED2
_ML2[ED00lic[EG<d`02_ML01:eEcW>]EKgG0ZeE00FmelcC_MN]ELcC00B]
E@04c=>]EJeE_ML2[ED01/cC[EFmejeEW=>me`:]E@03c=>]EKgG00:]E@05
_MN]EJeE[EFme`03[ED01;gG[EF]EKgG0jeE00>mejeE[ED01IcC00J<DH@0
Q12LdjeEc=T2_ML02HaAW=>LdjeE_MNLfIc<S56Ld`03_ML01LcI_MNmeicC
[ED00YcC00V<DKgG[EF]EKgGc=VNNLHHc=T00kgG0ZeE0Ic<0H@@00001jeE
_MN]ELcIW=?<fKgG00:]E@06_MN]EJeE_MN]EKgG0jeE00C;<kgG[EG<f@:]
E@03c=>mejeE00:]E@0D_MN]EKgG[EG<fKgG[EFmelcC[EFmelcC[EFmejeE
_MN]EKgGc=>me`:]E@06c=V]EKgGc=>]EKgG0ZeE0[gG00F]EKgG[EFmejeE
00Bme`03[EFmejeE00>me`04c=>mejeE_ML2[ED2_ML3[ED06kgG[EFmejeE
_MNLdkgG[EFmejeEcW>melcC_MN]ELic[EFmelcC[EFmejeE_MN]ELcC[EFm
e`04[ED01Lic[EF]EJeE_ML00jeE00BmejeE[EG<d`N]E@03c=>]EJeE00:m
e`03[EG<dkgG00:]E@BLd`03S55S;9/V00:Ld`03_MO<fKgG00:Ld`>]E@06
aQRLdhaAW=>]ELcI0[gG00N]EKgG[EF]EIcC[EFK<`02[ED2_ML02/cIaQS6
6<HHc=VmelHH_MN]EFC<0H@@00000lcI[EFme`02[ED01kgG[EFmejeEc=>L
fKgG00:]E@03c=V]EKgG00>me`09[EFmejeE_MO<dicI_MN]ELcI00:]E@06
_MO<dkgG_MN]EKgG0ZeE00NmelcI[EFmejeE_MO<d`02[ED01kgG[EFmejeE
_MO<djeE00:me`07[EG<fJeEc=>]EKgGc=<00[gG00?<djeEc=T00kgG00C<
dkgG[EG<d`:]E@04c=>mejeEc=<3[ED02[gG[EG<djeE_MN]EKgG[EFmelcC
0[gG0jeE00FmeicC_MN]EKgG00:]E@05_MN]EJeE[EFme`03[ED00kgG[EG<
d`03[ED00lcC[EF]E@02[ED01/cC[EF]EKgG[EFme`:]E@03c=>]EJeE00:]
E@05_MN]EJeE[EFme`03[ED3W=<01XaAW==Tc6<VS56Ld`>me`:Ld`08[EG<
fJeE_MNLdhaAW=>]E@Bme`B]E@03W=>]EJeE00:]E@:me`06cWVmekgG_MN]
EKgG0ZeE0Y//0003[ED01kgG[EFmeicCc=V]EKgG00:]E@04_MN]EJeE_ML3
[ED01;gG[EG<djeE0[gG00N]EKgGc=>]EKgG[EFme`02[ED02kgG[EF]ELcI
_MN]EKgG[EG<dkgG[ED00[gG00J]EKgGc=>]EKgG[ED2_ML2[ED01/cC_MN]
EKgG[EFme`:]E@Bme`05c=>mekgG[EG<f@04_ML2[ED03[gG[EFmejeEc=>m
ejeE_MO<dkgGc=>mejeE_ML2[ED03[gG[EG>LjeE_MN]EKgGc=>]EKgG[EFm
ejeE_ML3[ED00kgG[EF]E@03[ED01KgG[EF]EJeE_ML00jeE00>mejeE[ED0
1JeE00^mejeE_MNLdkgG[EG<dkgG[EFmejeE00FLd`04S56448@0Vc<2[ED2
_ML03:eEW=>LdjeE_MO669cCVbbLdjeE_MO<f@:me`04[EFmehaA[ED3W=<0
1kgGW=V]EKgGc=VNNLcI00:me`04[EG<djeEI<`1VbH000:me`>]E@0=_MNL
dkgG[EFmejeEc=?<fJeE_MO<fJeE_ML00jeE0[gG00G<fIcC[EFmejeE00:m
e`0<c=>mejeE_MN]EKgGc=>mejeE_MO<djeE0[gG00N]EKgG[EG<dkgG[EFm
e`02[ED02KgG[EF]EKgG[EFmejeEc=V]E@02_ML00lcC_MN]E@04_ML00jeE
_MNme`02[ED2_ML01:eE_MN]EKgG0ZeE00BmejeE[EFme`:]E@0?_MN]ELcC
_MN]EKgGc=>]EKgG[EFmejeE_MN]EKgG00:]E@06c=>]EJeEc=>]EKgG0jeE
00G>LjeE[EF]ELcC00B]E@03c=>]EJeE00B]E@03c=>mejeE00B]E@03_MN]
EJeE00F]E@03W<bLdic<00:Ld`09HbaS9YcC[EFmelHHc=VLdhaA00:]E@06
_MO<fJeEQ12<DJeE1;gG0YcC00NK<jeEW=>LdjeE_MN]E@03_ML2aQP01[gG
[EFmekgG[EFLc06440000ZeE00K<fJeE[EG<fJeE_ML2[ED00kgG[EFme`04
[ED02[gGc=V]EKgGW=>mejeE_MO<dkgG0ZeE00ZmejeEW=W<dkgG[EFmejeE
_MN]E@>me`0A[EFmelcC[EFmejeE_MN]ELcC[EG<djeE_MO<dkgG[EFme`02
[ED01KgG[EF]EKgG[ED01[gG00>]ELcC_ML00ZeE00>melcC_ML00ZeE00Fm
elcC[EFmejeE00:me`0A[EFmekgGc=>mejeE_MN]EKgGc=>]ELcC[EFmejeE
c=>me`02[ED00kgG[EFme`02[ED00lcC[EF]E@02[ED00kgGW=>me`05[ED0
1KgG[EF]EJeE_ML00jeE00BmejeE[EG<d`:]E@05_MN]ELcC[EFme`02[ED3
W=<01haAW<b449/VS56LdicI00:me`07[EF<DJeEW=>meicI_ML00XaA00>]
EKgGc=T00kgG00NLdjeE[EFLdi/cW=>me`02[ED00lcI_MNme`04_ML2[ED1
W<`1Q10000:]E@03_MN]ELcI00B]E@08_MN]EJeE_MN]ELcI[EFme`>]E@03
_MN]ELcI00:]E@0?_MN]EJeE_MO<djeE_MO<djeE_MO<djeE_MO<dkgG00:]
E@0:_MN]EKgG[EG<fJeE_MN]EKgG[ED2_ML02JeE_MN]EJeE_MO<dkgG[EG<
d`02_ML01:eE_MNmelcC0kgG00^]EKgG_MN]EKgGc=>]EKgG[EFmelcC00:]
E@06cW>]EJeE[EG<dkgG0ZeE00bmejeE_MN]EKgG[EFmejeE_MO<djeE_ML3
[ED01LicW=>mejeEc=<00jeE00NmejeEc=>]EKgGW=>me`03[ED01KgGW=>m
ejeEc=<01ZeE00>mejeE[ED00ZeE00BmejeE_MN]E@JLd`04Q11S9XaA[ED2
_ML00jeEW=><D@02[ED2_ML00jeEQ12<D@02[ED3_ML00jeEW=>]E@04W=<2
[ED01LcI[EG669iic=T00[gG0jeE0HaA0FC600002<cI[EF]EKgGbc>mejeE
_ML2[ED04/cI[EF]EJeE_MN]EKgG[EFmelcC[EFmejeE_MO<djeE_MN]E@:m
e`03[EFmekgG00:]E@0:_MN]EKgG_MN]EKgG[EFmejeE_ML3[ED02kgGc=>]
EKgGW=>mejeEc=>mejeE_ML00ZeE00FmejeE[EFmejeE00Bme`04c=>mekgG
[ED3_ML2[ED01KgGW=>mejeE_ML00ZeE00jmelcC_MN]ELcC_MN]EKgG[EG>
LjeE_MN]ELic0ZeE00FmejeE_MN]ELcC00F]E@03_MN]EKgG00F]E@04_MN]
EJeEc=<3[ED01LcC[EF]EJeE_ML00ZeE00?<djeE[ED00ZeE00BmejeE[EFm
e`B]E@BLd`06S56Lc6<VS56Ldl/c0[gG00N]EHaAW=?;<jeE_MN]E@02Q100
1JeEW=>]EIcCc=<00ZeE00>K;:eEW=<00icC0ZeE00BmelcIaQS660Bme`6]
E@6Ld`6K;0000ZeE00RmejeE[EFmejeEc=V]EKgG0ZeE016mejeEc=>]ELcI
[EFmelcC_MN]EKgG[EFmejeE_MO<dkgG00:]E@07_MN]EJeE_MN]ELcC_ML0
0ZeE00G<dkgG[EFmelcC00:me`07[EFmejeE[EFmelcC_ML00ZeE00VmejeE
_MN]EKgGc=>mejeEc=<00[gG00>]EKgG_ML00[gG00j]ELcC_MN]EKgG[EFm
ejeEc=>mejeEc=>]EKgG0ZeE00FmejeE_MN]ELic00:]E@03_MN]ELcC00>]
E@0;cW>]EJeE[EFmejeE_MN]EKgG[EG<d`03[ED00lcC[EFme`02[ED00lcC
[EFme`02[ED00kgG[EFme`06[ED00kgG[EFme`02[ED00lcC[EFme`02[ED0
0kgG[EFLd`04W=<018aAW<`c;8aA0ZeE00JmejeE[EF<DIcC[ED2_ML03jeE
S56<DJeEW=>]ELcI_MNLdjeEW=>]EIcCS56Ld`02[ED01kgGc=VmekgGaQRm
elcI00:me`6Ld`6Lc06<D@0000c<fJeE[EFmejeE_MN]EKgG[EG<dkgG[ED2
_ML3[ED02kgG[EF]EKgG[EFmelcC_MN]EKgG[ED00[gG00C<djeE_MO<d`:m
e`06[EG<dkgG_MN]ELcC0[gG00V]ELcC_MN]EKgGc=>mejeEc=<00[gG00N]
EKgGc=>mejeE_MN]E@02_ML00jeE_MO<d`02_ML00lcC_MNme`03_ML00jeE
_MO<d`02_ML03:eE_MN]EKgG[EG<dkgG[EFmelcC_MNLd`:me`05c=>mejeE
_MO<d`02_ML01LcC[EFmelcC_ML00ZeE00G<djeE[EF]ELcC00F]E@03_MN]
EJeE00N]E@04_MN]EJeEc=<:[ED01KgG[EFmekgG[ED00YcC00RLc9cCS56L
c6<VVbbLdjeE0[gG00>]EHaAW=<00ZeE00BmejeEW=>K;0>]E@:me`03[EFL
djeE00:Ld`05S56LdjeEW=>]E@02_ML01<HHc=VmekgG0jeE0HaA0H@0000?
[ED01KgG[EFmejeE_ML01ZeE00>mejeE[ED00ZeE00>mejeE[ED00jeE00Fm
ejeE[EF]EKgG00B]E@03_MN]EJeE00:]E@03_MN]EJeE00J]E@03_MN]EJeE
00B]E@:me`04[EFmejeE_ML3[ED00kgG[EF]E@0=[ED00kgG[EF]E@02[ED0
0kgG[EF]E@0C[ED00icC[EF]E@07[ED00icC[EF]E@0>[ED3W=<01haAW=><
DHaAHbJ448aA00>]E@07S56K;8@@S56]EKgG[ED00XaA0YcC00BmejeEW=><
D@:Ld`06S56LdhaAW=><DIcC1;gG00>]EKgG_ML00ZeE0IcC0Ic<0H@@0032
ool00001\
\>"], "ItemizedTextNote",
  CellLabel->"",
  ShowCellBracket->True,
  Evaluatable->True,
  ImageSize->{194, 265},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "This reference is Copyright \[Copyright] 1998-1999 Wolfram Research, Inc.  \
All rights reserved.  It may be distributed without charge provided that its \
content remains unaltered.  No guarantees of support are made or implied.  \
Suggestions for improvement are welcome at e-mail address ",
  ButtonBox["paulh@wolfram.com",
    ButtonData:>{
      URL[ "mailto:paulh@wolfram.com"], None},
    ButtonStyle->"Hyperlink",
    ButtonNote->"Send mail to P.J. Hinton"],
  ".  This notebook was composed and tested with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4 for Linux (ELF binary).\nSpecial thanks goes to Murray Eisenberg at the \
University of Massachusetts/Amherst for his input on improving this notebook.\
\nThe parrot in the bitmap image is our ",
  ButtonBox["medium sulphur crested cockatoo",
    ButtonData:>{
      URL[ "http://www.ub.tu-clausthal.de/PAhtml/cacatuidae/c_galerita.html"],
       None},
    Active->True,
    ButtonStyle->"Hyperlink",
    ButtonNote->
      "Jump to Online Book of Parrots entry for Cacatua Galerita family"],
  ", Lenny.  In his spare times he likes to unravel drinking straws, destroy \
wooden blocks of various shapes and colors, unscrew the nuts on quick links, \
and make all kinds of interesting squawks."
}], "Note"]
},
FrontEndVersion->"4.0 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
AutoGeneratedPackage->None,
InitializationCellEvaluation->False,
InitializationCellWarning->False,
CellGrouping->Manual,
WindowSize->{530, 500},
WindowMargins->{{251, Automatic}, {Automatic, 41}},
WindowElements->{
  "StatusArea", "HorizontalScrollBar", "VerticalScrollBar", "MenuBar"},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "usr1", \
"paulh"}, "CellLegendv3.nb.ps", CharacterEncoding -> "ISO8859-1"],
"Magnification"->1},
ShowCellBracket->False,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{5, Inherited}, {2, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 10}, {2, 0}},
    FontSize->28,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{7, 10}, {2, 4}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{7, 10}, {2, 8}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0.5}, {0.5, 0.5}},
    CellMargins->{{8, 4}, {2, 50}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0, 0, 1],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Section", "Printout"],
    CellFrame->{{6, 0.5}, {0.5, 0.5}},
    CellMargins->{{6, 4}, {2, 70}},
    CellFrameColor->GrayLevel[0],
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{19, 4}, {2, 18}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{7, 4}, {2, 18}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{7, 0}, {0, 8}},
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{3, 0}, {0, 0.5}},
    CellMargins->{{47, 14}, {0, 14}},
    CellFrameColor->RGBColor[0, 0, 1],
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 54}, {0, 14}},
    CellFrameColor->GrayLevel[0],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{54, 14}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{43, 4}, {3, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 4}, {8, 3}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->StandardForm,
    CounterIncrements->"Output",
    FontSize->14],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{43, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{44, 4}, {3, 8}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{44, 4}, {3, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{42, 4}, {3, 8}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellDingbat->"\[GrayCircle]",
    CellMargins->{{26, 4}, {10, 8}},
    ShowSpecialCharacters->Automatic,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    ParagraphIndent->0,
    CounterIncrements->"Text",
    FontSize->14],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{20, 4}, {0, 8}},
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{45, 4}, {10, 5}},
    ShowSpecialCharacters->Automatic,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 5},
    FontSize->14],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    ShowCellBracket->True,
    CellMargins->{{34, 4}, {0, 4}},
    ParagraphSpacing->{0, 4},
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{26, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontSize->14],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{20, 4}, {0, 8}},
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0, 0, 1],
    ShowSpecialCharacters->Automatic,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{7, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{7, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{7, 50}, {2, 4}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{7, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{7, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True,
    FontSize->14],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{43, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    FontSize->14,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{43, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{7, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 55, 0, 108, "Title"],
Cell[1797, 53, 308, 10, 68, "Subsubtitle"],
Cell[2108, 65, 51, 0, 32, "Subsubtitle"],
Cell[2162, 67, 105, 3, 27, "Text"],
Cell[2270, 72, 276, 5, 75, "ItemizedText"],
Cell[2549, 79, 231, 6, 53, "ItemizedTextNote",
  Evaluatable->False],
Cell[2783, 87, 398, 9, 94, "ItemizedText"],
Cell[3184, 98, 438, 13, 34, "ItemizedTextNote",
  Evaluatable->True],
Cell[3625, 113, 374, 5, 94, "ItemizedText"],
Cell[4002, 120, 412, 12, 60, "ItemizedTextNote",
  Evaluatable->True],
Cell[4417, 134, 473, 7, 113, "ItemizedText"],
Cell[4893, 143, 852, 23, 36, "ItemizedTextNote",
  Evaluatable->True],
Cell[5748, 168, 177, 4, 56, "ItemizedText"],
Cell[5928, 174, 222, 7, 53, "ItemizedTextNote",
  Evaluatable->True],
Cell[6153, 183, 400, 7, 113, "ItemizedText"],
Cell[6556, 192, 177, 4, 70, "ItemizedTextNote",
  Evaluatable->True,
  InitializationCell->True],
Cell[6736, 198, 307, 5, 75, "ItemizedText"],

Cell[CellGroupData[{
Cell[7068, 207, 193, 5, 53, "ItemizedTextNote",
  Evaluatable->True],
Cell[7264, 214, 110, 2, 34, "ItemizedTextNote",
  Evaluatable->True]
}, Closed]],
Cell[7389, 219, 326, 5, 71, "ItemizedText"],
Cell[7718, 226, 105670, 1357, 193, 17343, 259, "GraphicsData", "PostScript", \
"ItemizedTextNote",
  Evaluatable->True]
}, Open  ]],
Cell[113403, 1586, 233, 6, 56, "ItemizedText"],
Cell[113639, 1594, 141012, 2316, 280, 140856, 2310, "GraphicsData", "Bitmap", \
"ItemizedTextNote",
  Evaluatable->True],
Cell[254654, 3912, 1303, 27, 184, "Note"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

